(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     69331,       1946]
NotebookOptionsPosition[     59170,       1606]
NotebookOutlinePosition[     61449,       1657]
CellTagsIndexPosition[     61406,       1654]
WindowTitle->Control the Precision and Accuracy of Numerical Results - \
Wolfram Mathematica
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[GridBox[{
   {Cell["MATHEMATICA HOW TO", "PacletNameCell"], Cell[TextData[{
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "Tutorials",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"Tutorials", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->False], {"\<\"Numerical Precision\"\>":>
       Documentation`HelpLookup[
       "paclet:tutorial/NumericalPrecision"], "\<\"Exact and Approximate \
Results\"\>":>Documentation`HelpLookup[
       "paclet:tutorial/ExactAndApproximateResults"]},
       Appearance->None,
       MenuAppearance->Automatic,
       MenuStyle->"Tutorials"]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "See Also",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"See Also", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->False], {"\<\"N\"\>":>Documentation`HelpLookup[
       "paclet:ref/N"], "\<\"Precision\"\>":>Documentation`HelpLookup[
       "paclet:ref/Precision"], "\<\"Accuracy\"\>":>Documentation`HelpLookup[
       "paclet:ref/Accuracy"], "\<\"RealExponent\"\>":>
       Documentation`HelpLookup["paclet:ref/RealExponent"]},
       Appearance->None,
       MenuAppearance->Automatic,
       MenuStyle->"SeeAlso"]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "Related Guides",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"Related Guides", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->False], {"\<\"Precision & Accuracy Control\"\>":>
       Documentation`HelpLookup[
       "paclet:guide/PrecisionAndAccuracyControl"], "\<\"Numerical Evaluation \
& Precision\"\>":>Documentation`HelpLookup[
       "paclet:guide/NumericalEvaluationAndPrecision"], "\<\"\\\"How to\\\" \
Topics\"\>":>Documentation`HelpLookup["paclet:guide/HowToTopics"]},
       Appearance->None,
       MenuAppearance->Automatic,
       MenuStyle->"MoreAbout"]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "URL",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"URL", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->
         False], {"\<\"howto/ControlThePrecisionAndAccuracyOfNumericalResults\
\"\>":>None, "\<\"Copy Mathematica URL\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell["howto/ControlThePrecisionAndAccuracyOfNumericalResults"]}, 
            Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; Null], 
       Delimiter, "\<\"Copy web URL\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell[
              BoxData[
               MakeBoxes[
                Hyperlink[
                "http://reference.wolfram.com/mathematica/howto/\
ControlThePrecisionAndAccuracyOfNumericalResults.html"], StandardForm]], 
              "Input", TextClipboardType -> "PlainText"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; 
        Null], "\<\"Go to web URL\"\>":>FrontEndExecute[{
         NotebookLocate[{
           URL[
            StringJoin[
            "http://reference.wolfram.com/mathematica/", 
             "howto/ControlThePrecisionAndAccuracyOfNumericalResults", 
             ".html"]], None}]}]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}]
    }], "AnchorBar"]}
  }]], "AnchorBarGrid",
 CellID->1],

Cell[CellGroupData[{

Cell[TextData[{
 Cell["\:041a\:0440\:0430\:0442\:043a\:0438\:0439 \:043a\:0443\:0440\:0441 ", 
  "HowToTitlePrefix"],
 " ",
 "\:041a\:043e\:043d\:0442\:0440\:043e\:043b\:044c \:0442\:043e\:0447\:043d\
\:043e\:0441\:0442\:0438 \:0438 \:0430\:043a\:043a\:0443\:0440\:0430\:0442\
\:043d\:043e\:0441\:0442\:0438 \:0447\:0438\:0441\:043b\:0435\:043d\:043d\
\:044b\:0445 \:0440\:0435\:0437\:0443\:043b\:044c\:0442\:0430\:0442\:043e\
\:0432"
}], "HowToTitle",
 CellID->509267359],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " \:0440\:0430\:0431\:043e\:0442\:0430\:0435\:0442 \:043a\:0430\:043a \:0441 \
\:0442\:043e\:0447\:043d\:044b\:043c\:0438 \:0432\:0435\:043b\:0438\:0447\
\:0438\:043d\:0430\:043c\:0438, \:0442\:0430\:043a \:0438 \:0441 \:043f\:0440\
\:0438\:0431\:043b\:0438\:0437\:0438\:0442\:0435\:043b\:044c\:043d\:044b\:043c\
\:0438 \:0447\:0438\:0441\:043b\:0430\:043c\:0438. \:0418\:0441\:043f\:043e\
\:043b\:044c\:0437\:0443\:044f \:0444\:0443\:043d\:043a\:0446\:0438\:044e ",
 Cell[BoxData[
  ButtonBox["N",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/N"]], "InlineFormula"],
 ", \:043c\:043e\:0436\:043d\:043e \:043f\:043e\:043b\:0443\:0447\:0438\:0442\
\:044c \:0447\:0438\:0441\:043b\:0435\:043d\:043d\:0443\:044e \:0430\:043f\
\:043f\:0440\:043e\:043a\:0441\:0438\:043c\:0430\:0446\:0438\:044e \:043a \
\:0442\:043e\:0447\:043d\:043e\:0439 \:0432\:0435\:043b\:0438\:0447\:0438\
\:043d\:0435 \:0441 \:043b\:044e\:0431\:043e\:0439 \:0436\:0435\:043b\:0430\
\:0435\:043c\:043e\:0439 \:0442\:043e\:0447\:043d\:043e\:0441\:0442\:044c\
\:044e \:0438\:043b\:0438 \:0430\:043a\:043a\:0443\:0440\:0430\:0442\:043d\
\:043e\:0441\:0442\:044c\:044e. \:0412 \:0432\:044b\:0447\:0438\:0441\:043b\
\:0435\:043d\:0438\:044f\:0445 \:0441 \:043f\:0440\:0438\:0431\:043b\:0438\
\:0437\:0438\:0442\:0435\:043b\:044c\:043d\:044b\:043c\:0438 \:0447\:0438\
\:0441\:043b\:0430\:043c\:0438 \:043f\:0440\:043e\:0438\:0437\:0432\:043e\
\:043b\:044c\:043d\:043e\:0439 \:0442\:043e\:0447\:043d\:043e\:0441\:0442\
\:0438, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " \:043e\:0442\:0441\:043b\:0435\:0436\:0438\:0432\:0430\:0435\:0442 \:0440\
\:0430\:0441\:043f\:0440\:043e\:0441\:0442\:0440\:0430\:043d\:0435\:043d\:0438\
\:0435 \:0447\:0438\:0441\:043b\:0435\:043d\:043d\:043e\:0439 \:043f\:043e\
\:0433\:0440\:0435\:0448\:043d\:043e\:0441\:0442\:0438. \:0418\:0441\:043f\
\:043e\:043b\:044c\:0437\:043e\:0432\:0430\:043d\:0438\:0435 \:0432\:044b\
\:0441\:043e\:043a\:043e\:0442\:043e\:0447\:043d\:044b\:0445 \:0447\:0438\
\:0441\:0435\:043b \:0434\:0430\:0435\:0442 \:0434\:043e\:0441\:0442\:043e\
\:0432\:0435\:0440\:043d\:044b\:0435 \:0440\:0435\:0437\:0443\:043b\:044c\
\:0442\:0430\:0442\:044b \:0442\:0430\:043c, \:0433\:0434\:0435 \:0434\:0440\
\:0443\:0433\:0438\:0435 \:0447\:0438\:0441\:043b\:0435\:043d\:043d\:044b\
\:0435 \:0441\:0438\:0441\:0442\:0435\:043c\:044b \:0442\:0435\:0440\:043f\
\:044f\:0442 \:043d\:0435\:0443\:0434\:0430\:0447\:0443."
}], "HowToAbstract",
 CellID->1045883471],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " \:0434\:0430\:0435\:0442 \:0442\:043e\:0447\:043d\:044b\:0439 \:043e\:0442\
\:0432\:0435\:0442 \:0432\:0435\:0437\:0434\:0435, \:0433\:0434\:0435 \:044d\
\:0442\:043e \:0432\:043e\:0437\:043c\:043e\:0436\:043d\:043e:"
}], "HowToText",
 CellID->1009846402],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Sin", "[", 
  FractionBox["\[Pi]", "4"], "]"}]], "Input",
 CellLabel->"In[206]:=",
 CellID->827466675],

Cell[BoxData[
 FractionBox["1", 
  SqrtBox["2"]]], "Output",
 ImageSize->{33, 35},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[206]=",
 CellID->612872562]
}, Open  ]],

Cell[TextData[{
 "\:0424\:0443\:043d\:043a\:0446\:0438\:044f ",
 Cell[BoxData[
  ButtonBox["N",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/N"]], "InlineFormula"],
 " \:0438\:0441\:043f\:043e\:043b\:044c\:0437\:0443\:0435\:0442\:0441\:044f \
\:0434\:043b\:044f \:043f\:043e\:043b\:0443\:0447\:0435\:043d\:0438\:044f \
\:0447\:0438\:0441\:043b\:0435\:043d\:043d\:043e\:0433\:043e \:043f\:0440\
\:0438\:0431\:043b\:0438\:0436\:0435\:043d\:0438\:044f \:043a \:0442\:043e\
\:0447\:043d\:043e\:043c\:0443 \:0440\:0435\:0437\:0443\:043b\:044c\:0442\
\:0430\:0442\:0443:"
}], "HowToText",
 CellID->220800003],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"Sin", "[", 
   FractionBox["\[Pi]", "4"], "]"}], "]"}]], "Input",
 CellLabel->"In[207]:=",
 CellID->411630083],

Cell[BoxData["0.7071067811865475`"], "Output",
 ImageSize->{60, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[207]=",
 CellID->232096490]
}, Open  ]],

Cell[TextData[{
 "\:0412 ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", \"\:0442\:043e\:0447\:043d\:043e\:0441\:0442\:044c\" \:0444\:0430\:043a\
\:0442\:0438\:0447\:0435\:0441\:043a\:0438 \:043e\:0437\:043d\:0430\:0447\
\:0430\:0435\:0442 \:043a\:043e\:043b\:0438\:0447\:0435\:0441\:0442\:0432\
\:043e \:0437\:043d\:0430\:0447\:0430\:0449\:0438\:0445 \:0446\:0438\:0444\
\:0440. \:0423\:043a\:0430\:0437\:0430\:0442\:044c \:0442\:0440\:0435\:0431\
\:0443\:0435\:043c\:0443\:044e \:0442\:043e\:0447\:043d\:043e\:0441\:0442\
\:044c \:0440\:0435\:0437\:0443\:043b\:044c\:0442\:0430\:0442\:0430 \:043c\
\:043e\:0436\:043d\:043e \:043f\:0440\:0438 \:043f\:043e\:043c\:043e\:0449\
\:0438 \:0432\:0442\:043e\:0440\:043e\:0433\:043e \:0430\:0440\:0433\:0443\
\:043c\:0435\:043d\:0442\:0430 \:0444\:0443\:043d\:043a\:0446\:0438\:0438 ",
 Cell[BoxData[
  ButtonBox["N",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/N"]], "InlineFormula"],
 ". \:0412\:044b\:0447\:0438\:0441\:043b\:0438\:043c \:0440\:0435\:0437\:0443\
\:043b\:044c\:0442\:0430\:0442 \:0441 \:0442\:043e\:0447\:043d\:043e\:0441\
\:0442\:044c\:044e \:0432 50 \:0437\:043d\:0430\:0447\:0430\:0449\:0438\:0445 \
\:0446\:0438\:0444\:0440:"
}], "HowToText",
 CellID->292885398],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{
   RowBox[{"Sin", "[", 
    FractionBox["\[Pi]", "4"], "]"}], ",", "50"}], "]"}]], "Input",
 CellLabel->"In[208]:=",
 CellID->28235575],

Cell[BoxData["0.\
70710678118654752440084436210484903928483593768847403658833986899536623923105`\
50."], "Output",
 ImageSize->{368, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[208]=",
 CellID->172362]
}, Open  ]],

Cell[TextData[{
 "\"\:0410\:043a\:043a\:0443\:0440\:0430\:0442\:043d\:043e\:0441\:0442\:044c\"\
 \:0444\:0430\:043a\:0442\:0438\:0447\:0435\:0441\:043a\:0438 \:043e\:0437\
\:043d\:0430\:0447\:0430\:0435\:0442 \:043a\:043e\:043b\:0438\:0447\:0435\
\:0441\:0442\:0432\:043e \:0432\:0435\:0440\:043d\:044b\:0445 \:0434\:0435\
\:0441\:044f\:0442\:0438\:0447\:043d\:044b\:0445 \:0440\:0430\:0437\:0440\
\:044f\:0434\:043e\:0432 \:043f\:043e\:0441\:043b\:0435 \:0437\:0430\:043f\
\:044f\:0442\:043e\:0439. \:0417\:0430\:0434\:0430\:0434\:0438\:043c ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{"\[Infinity]", ",", 
    StyleBox["a", "TI"]}], "}"}]], "InlineFormula"],
 " \:0432 \:043a\:0430\:0447\:0435\:0441\:0442\:0432\:0435 \:0432\:0442\:043e\
\:0440\:043e\:0433\:043e \:0430\:0440\:0433\:0443\:043c\:0435\:043d\:0442\
\:0430 \:0444\:0443\:043d\:043a\:0446\:0438\:0438 ",
 Cell[BoxData[
  ButtonBox["N",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/N"]], "InlineFormula"],
 " \:0434\:043b\:044f \:043f\:043e\:043b\:0443\:0447\:0435\:043d\:0438\:044f \
\:0440\:0435\:0437\:0443\:043b\:044c\:0442\:0430\:0442\:0430 \:0441 \:0430\
\:043a\:043a\:0443\:0440\:0430\:0442\:043d\:043e\:0441\:0442\:044c\:044e ",
 Cell[BoxData[
  StyleBox["a", "TI"]], "InlineFormula"],
 ". \:0421\:0438\:043c\:0432\:043e\:043b ",
 Cell[BoxData["\[Infinity]"], "InlineFormula"],
 " \:043e\:0431\:043e\:0437\:043d\:0430\:0447\:0430\:0435\:0442 \:043b\:044e\
\:0431\:0443\:044e \:0442\:043e\:0447\:043d\:043e\:0441\:0442\:044c. \:041d\
\:0430\:043f\:0440\:0438\:043c\:0435\:0440, \:0437\:0430\:0434\:0430\:0434\
\:0438\:043c \:0430\:043a\:043a\:0443\:0440\:0430\:0442\:043d\:043e\:0441\
\:0442\:044c 10:"
}], "HowToText",
 CellID->4432995],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{
   RowBox[{"Exp", "[", "12", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Infinity]", ",", "10"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[91]:=",
 CellID->56810723],

Cell[BoxData["162754.79141900392080800520489848678317020929`15.\
211533782839027"], "Output",
 ImageSize->{125, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[91]=",
 CellID->240389006]
}, Open  ]],

Cell[TextData[{
 "\:0424\:0443\:043d\:043a\:0446\:0438\:0438 ",
 Cell[BoxData[
  ButtonBox["Precision",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Precision"]], "InlineFormula"],
 " \:0438 ",
 Cell[BoxData[
  ButtonBox["Accuracy",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Accuracy"]], "InlineFormula"],
 " \:0438\:0441\:043f\:043e\:043b\:044c\:0437\:0443\:044e\:0442\:0441\:044f \
\:0434\:043b\:044f \:043d\:0430\:0445\:043e\:0436\:0434\:0435\:043d\:0438\
\:044f \:0442\:043e\:0447\:043d\:043e\:0441\:0442\:0438 \:0438 \:0430\:043a\
\:043a\:0443\:0440\:0430\:0442\:043d\:043e\:0441\:0442\:0438 \:043b\:044e\
\:0431\:043e\:0433\:043e \:0447\:0438\:0441\:043b\:0430. \:0423\:0434\:043e\
\:0441\:0442\:043e\:0432\:0435\:0440\:0438\:043c\:0441\:044f \:0432 \:0442\
\:043e\:0447\:043d\:043e\:0441\:0442\:0438 \:0438 \:0430\:043a\:043a\:0443\
\:0440\:0430\:0442\:043d\:043e\:0441\:0442\:0438 \:0440\:0435\:0437\:0443\
\:043b\:044c\:0442\:0430\:0442\:043e\:0432, \:043f\:043e\:043b\:0443\:0447\
\:0435\:043d\:043d\:044b\:0445 \:0441 \:043f\:043e\:043c\:043e\:0449\:044c\
\:044e \:0444\:0443\:043d\:043a\:0446\:0438\:0438 ",
 Cell[BoxData[
  ButtonBox["N",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/N"]], "InlineFormula"],
 ":"
}], "HowToText",
 CellID->295574741],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Precision", "[", 
    RowBox[{"N", "[", 
     RowBox[{
      RowBox[{"Sin", "[", 
       FractionBox["\[Pi]", "4"], "]"}], ",", "50"}], "]"}], "]"}], ",", 
   RowBox[{"Accuracy", "[", 
    RowBox[{"N", "[", 
     RowBox[{
      RowBox[{"Exp", "[", "12", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"\[Infinity]", ",", "10"}], "}"}]}], "]"}], "]"}]}], 
  "}"}]], "Input",
 CellLabel->"In[29]:=",
 CellID->126038806],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"50.`", ",", "10.000000000000004`"}], "}"}]], "Output",
 ImageSize->{71, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[29]=",
 CellID->289991519]
}, Open  ]],

Cell[TextData[{
 "\:041c\:043e\:0436\:043d\:043e \:0438\:0441\:043f\:043e\:043b\:044c\:0437\
\:043e\:0432\:0430\:0442\:044c \:043d\:043e\:0442\:0430\:0446\:0438\:044e ",
 Cell[BoxData[
  StyleBox[
   RowBox[{
    StyleBox["\:0447\:0438\:0441\:043b\:043e", "TI"], "`", 
    StyleBox["n", "TI"]}]]], "InlineFormula"],
 " \:0434\:043b\:044f \:043f\:0440\:044f\:043c\:043e\:0433\:043e \:0432\:0432\
\:043e\:0434\:0430 \:0447\:0438\:0441\:043b\:0430 \:0441 \:043a\:043e\:043b\
\:0438\:0447\:0435\:0441\:0442\:0432\:043e\:043c \:0437\:043d\:0430\:0447\
\:0430\:0449\:0438\:0445 \:0446\:0438\:0444\:0440 \:0440\:0430\:0432\:043d\
\:044b\:043c ",
 Cell[BoxData[
  StyleBox["n", "TI"]], "InlineFormula"],
 ", \:0430 \:0442\:0430\:043a\:0436\:0435 ",
 Cell[BoxData[
  StyleBox[
   RowBox[{
    StyleBox["\:0447\:0438\:0441\:043b\:043e", "TI"], "``", 
    StyleBox["a", "TI"]}]]], "InlineFormula"],
 " \:0434\:043b\:044f \:043f\:0440\:044f\:043c\:043e\:0433\:043e \:0432\:0432\
\:043e\:0434\:0430 \:0447\:0438\:0441\:043b\:0430 \:0441 \:0430\:043a\:043a\
\:0443\:0440\:0430\:0442\:043d\:043e\:0441\:0442\:044c\:044e \:0432 ",
 Cell[BoxData[
  StyleBox["a", "TI"]], "InlineFormula"],
 " \:0437\:043d\:0430\:043a\:043e\:0432 \:043f\:043e\:0441\:043b\:0435 \:0437\
\:0430\:043f\:044f\:0442\:043e\:0439: "
}], "HowToText",
 CellID->307833781],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"12.5`15", ",", "0.0000925``10"}], "}"}]], "Input",
 CellLabel->"In[42]:=",
 CellID->532172238],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"12.5`15.", ",", "0.0000925`5.966141732739037"}], "}"}]], "Output",
 GeneratedCell->False,
 ImageSize->{225, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[42]=",
 CellID->718689386]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\t", "HowToDelimiter",
 Editable->False,
 CellID->817571008],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " \:0440\:0430\:0431\:043e\:0442\:0430\:0435\:0442 \:0441 \:0442\:043e\:0447\
\:043d\:044b\:043c\:0438 \:0447\:0438\:0441\:043b\:0430\:043c\:0438 \:0438 \
\:0434\:0432\:0443\:043c\:044f \:0440\:0430\:0437\:043b\:0438\:0447\:043d\
\:044b\:043c\:0438 \:0442\:0438\:043f\:0430\:043c\:0438 \:043f\:0440\:0438\
\:0431\:043b\:0438\:0436\:0435\:043d\:043d\:044b\:0445 \:0447\:0438\:0441\
\:0435\:043b: \:0447\:0438\:0441\:043b\:0430\:043c\:0438 \:0441 \:043c\:0430\
\:0448\:0438\:043d\:043d\:043e\:0439 \:0441\:0442\:0435\:043f\:0435\:043d\
\:044c\:044e \:0442\:043e\:0447\:043d\:043e\:0441\:0442\:0438, \:043a\:043e\
\:0442\:043e\:0440\:044b\:0435 \:0438\:0441\:043f\:043e\:043b\:044c\:0437\
\:0443\:044e\:0442 \:043f\:0440\:0435\:0438\:043c\:0443\:0449\:0435\:0441\
\:0442\:0432\:043e \:0441\:043f\:0435\:0446\:0438\:0430\:043b\:0438\:0437\
\:0438\:0440\:043e\:0432\:0430\:043d\:043d\:044b\:0445 \:0430\:043f\:043f\
\:0430\:0440\:0430\:0442\:043d\:044b\:0445 \:0441\:0440\:0435\:0434\:0441\
\:0442\:0432 \:0434\:043b\:044f \:0432\:044b\:043f\:043e\:043b\:043d\:0435\
\:043d\:0438\:044f \:0431\:044b\:0441\:0442\:0440\:044b\:0445 \:0430\:0440\
\:0438\:0444\:043c\:0435\:0442\:0438\:0447\:0435\:0441\:043a\:0438\:0445 \
\:043e\:043f\:0435\:0440\:0430\:0446\:0438\:0439, \:0438 \:0447\:0438\:0441\
\:043b\:0430\:043c\:0438 \:0441 \:043f\:0440\:043e\:0438\:0437\:0432\:043e\
\:043b\:044c\:043d\:043e\:0439 \:0442\:043e\:0447\:043d\:043e\:0441\:0442\
\:044c\:044e, \:0441\:043e\:043e\:0442\:0432\:0435\:0442\:0441\:0442\:0432\
\:0443\:044e\:0449\:0435\:0439 \:0437\:0430\:0434\:0430\:043d\:043d\:043e\
\:043c\:0443 \:043a\:043e\:043b\:0438\:0447\:0435\:0441\:0442\:0432\:0443 \
\:0440\:0430\:0437\:0440\:044f\:0434\:043e\:0432."
}], "HowToText",
 CellID->147268061],

Cell["\:0422\:043e\:0447\:043d\:044b\:0435 \:0447\:0438\:0441\:043b\:0430 \
\:0438\:043c\:0435\:044e\:0442 \:0431\:0435\:0441\:043a\:043e\:043d\:0435\
\:0447\:043d\:0443\:044e \:0442\:043e\:0447\:043d\:043e\:0441\:0442\:044c \
\:0438 \:0430\:043a\:043a\:0443\:0440\:0430\:0442\:043d\:043e\:0441\:0442\
\:044c:", "HowToText",
 CellID->2089015097],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Precision", "[", 
    FractionBox["5", "2"], "]"}], ",", 
   RowBox[{"Accuracy", "[", "\[Pi]", "]"}]}], "}"}]], "Input",
 CellLabel->"In[225]:=",
 CellID->94881430],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\[Infinity]", ",", "\[Infinity]"}], "}"}]], "Output",
 ImageSize->{45, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[225]=",
 CellID->249923319]
}, Open  ]],

Cell[TextData[{
 "\:0427\:0438\:0441\:043b\:0430, \:0432\:0432\:0435\:0434\:0435\:043d\:043d\
\:044b\:0435 \:0441 \:0434\:0435\:0441\:044f\:0442\:0438\:0447\:043d\:043e\
\:0439 \:0442\:043e\:0447\:043a\:043e\:0439, \:043e\:0431\:044b\:0447\:043d\
\:043e \:0438\:043d\:0442\:0435\:0440\:043f\:0440\:0435\:0442\:0438\:0440\
\:0443\:044e\:0442\:0441\:044f \:043a\:0430\:043a \:0447\:0438\:0441\:043b\
\:0430 \:0441 \:043c\:0430\:0448\:0438\:043d\:043d\:043e\:0439 \:0441\:0442\
\:0435\:043f\:0435\:043d\:044c\:044e \:0442\:043e\:0447\:043d\:043e\:0441\
\:0442\:0438, \:043a\:043e\:0442\:043e\:0440\:044b\:0435 \:0438\:043c\:0435\
\:044e\:0442 \:0442\:043e\:0447\:043d\:043e\:0441\:0442\:044c ",
 Cell[BoxData[
  ButtonBox["MachinePrecision",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/MachinePrecision"]], "InlineFormula"],
 ":"
}], "HowToText",
 CellID->279436623],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Precision", "[", "2.5", "]"}]], "Input",
 CellLabel->"In[106]:=",
 CellID->217641976],

Cell[BoxData["MachinePrecision"], "Output",
 ImageSize->{116, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[106]=",
 CellID->85992639]
}, Open  ]],

Cell[TextData[{
 "\:041f\:043e \:0443\:043c\:043e\:043b\:0447\:0430\:043d\:0438\:044e, \:0432\
\:043e\:0437\:0432\:0440\:0430\:0449\:0430\:0435\:043c\:044b\:0435 \:0444\
\:0443\:043d\:043a\:0446\:0438\:0435\:0439 ",
 Cell[BoxData[
  ButtonBox["N",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/N"]], "InlineFormula"],
 " \:0440\:0435\:0437\:0443\:043b\:044c\:0442\:0430\:0442\:044b \:044f\:0432\
\:043b\:044f\:044e\:0442\:0441\:044f \:0447\:0438\:0441\:043b\:0430\:043c\
\:0438 \:0441 \:043c\:0430\:0448\:0438\:043d\:043d\:043e\:0439 \:0442\:043e\
\:0447\:043d\:043e\:0441\:0442\:044c\:044e:"
}], "HowToText",
 CellID->4951644],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Precision", "[", 
  RowBox[{"N", "[", 
   RowBox[{"Exp", "[", "3", "]"}], "]"}], "]"}]], "Input",
 CellLabel->"In[148]:=",
 CellID->163041784],

Cell[BoxData["MachinePrecision"], "Output",
 ImageSize->{116, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[148]=",
 CellID->116151760]
}, Open  ]],

Cell["\<\
\:0427\:0438\:0441\:043b\:0430 \:0441 \:043c\:0430\:0448\:0438\:043d\:043d\
\:043e\:0439 \:0442\:043e\:0447\:043d\:043e\:0441\:0442\:044c\:044e \:043e\
\:0431\:044b\:0447\:043d\:043e \:0441\:043e\:0434\:0435\:0440\:0436\:0430\
\:0442 \:0447\:0443\:0442\:044c \:043c\:0435\:043d\:0435\:0435 16 \
\:0446\:0438\:0444\:0440, \:0447\:0442\:043e \:0441\:043e\:043e\:0442\:0432\
\:0435\:0442\:0441\:0442\:0432\:0443\:0435\:0442 53 \:0431\:0438\:0442\:0430\
\:043c:\
\>", "HowToText",
 CellID->460967059],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"$MachinePrecision", ",", 
   FractionBox["$MachinePrecision", 
    RowBox[{"Log", "[", 
     RowBox[{"10", ",", "2"}], "]"}]]}], "}"}]], "Input",
 CellLabel->"In[172]:=",
 CellID->289995683],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"15.954589770191003`", ",", "53.`"}], "}"}]], "Output",
 ImageSize->{99, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[172]=",
 CellID->450189499]
}, Open  ]],

Cell[TextData[{
 "\:0427\:0438\:0441\:043b\:0430 \:0441 \:043f\:0440\:043e\:0438\:0437\:0432\
\:043e\:043b\:044c\:043d\:043e\:0439 \:0442\:043e\:0447\:043d\:043e\:0441\
\:0442\:044c\:044e \:0432\:0432\:043e\:0434\:044f\:0442\:0441\:044f \:043f\
\:0440\:0438 \:043f\:043e\:043c\:043e\:0449\:0438 \:043d\:043e\:0442\:0430\
\:0446\:0438\:0438 ",
 Cell[BoxData[
  StyleBox[
   RowBox[{
    StyleBox["\:0447\:0438\:0441\:043b\:043e", "TI"], "`", 
    StyleBox["n", "TI"]}]]], "InlineFormula"],
 " \:0438 ",
 Cell[BoxData[
  StyleBox[
   RowBox[{
    StyleBox["\:0447\:0438\:0441\:043b\:043e", "TI"], "``", 
    StyleBox["a", "TI"]}]]], "InlineFormula"],
 ". \:0412\:0432\:0435\:0434\:0435\:043c \:0447\:0438\:0441\:043b\:043e \
\:0441 \:043f\:0440\:043e\:0438\:0437\:0432\:043e\:043b\:044c\:043d\:043e\
\:0439 \:0442\:043e\:0447\:043d\:043e\:0441\:0442\:044c\:044e \:0432 10 \
\:0437\:043d\:0430\:043a\:043e\:0432 \:0438 \:0442\:0430\:043a\:043e\:0435 \
\:0436\:0435 \:0447\:0438\:0441\:043b\:043e \:0441 \:0430\:043a\:043a\:0443\
\:0440\:0430\:0442\:043d\:043e\:0441\:0442\:044c\:044e \:0432 10 \:0437\:043d\
\:0430\:043a\:043e\:0432:"
}], "HowToText",
 CellID->18816112],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"x", "=", "123.456`10"}]], "Input",
 CellLabel->"In[4]:=",
 CellID->499609852],

Cell[BoxData["123.456`10."], "Output",
 ImageSize->{81, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[4]=",
 CellID->836593827]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"y", "=", "123.456``10"}]], "Input",
 CellLabel->"In[5]:=",
 CellID->23374448],

Cell[BoxData["123.456`12.091512201627769"], "Output",
 ImageSize->{95, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[5]=",
 CellID->2117101369]
}, Open  ]],

Cell[TextData[{
 "\:0417\:0430\:0434\:0430\:043d\:043d\:0430\:044f \:0434\:043b\:044f \:0447\
\:0438\:0441\:043b\:0430 ",
 Cell[BoxData["x"], "InlineFormula"],
 " \:0442\:043e\:0447\:043d\:043e\:0441\:0442\:044c \:0432 10 \:0437\:043d\
\:0430\:043a\:043e\:0432 \:0432\:043b\:0435\:0447\:0435\:0442 \:0437\:0430 \
\:0441\:043e\:0431\:043e\:0439 \:043e\:043f\:0440\:0435\:0434\:0435\:043b\
\:0435\:043d\:043d\:043e\:0435 \:0437\:043d\:0430\:0447\:0435\:043d\:0438\
\:0435 \:0434\:043b\:044f \:0435\:0433\:043e \:0430\:043a\:043a\:0443\:0440\
\:0430\:0442\:043d\:043e\:0441\:0442\:0438, \:043a\:043e\:0442\:043e\:0440\
\:0430\:044f, \:0432 \:0434\:0430\:043d\:043d\:043e\:043c \:0441\:043b\:0443\
\:0447\:0430\:0435, \:0441\:043e\:0441\:0442\:0430\:0432\:043b\:044f\:0435\
\:0442 \:043c\:0435\:043d\:0435\:0435 10. \
\:0420\:0430\:0437\:043d\:0438\:0446\:0430 \:043c\:0435\:0436\:0434\:0443 \
\:043d\:0438\:043c\:0438 (",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    ButtonBox["Precision",
     BaseStyle->"Link",
     ButtonData->"paclet:ref/Precision"], "[", "x", "]"}], "-", 
   RowBox[{
    ButtonBox["Accuracy",
     BaseStyle->"Link",
     ButtonData->"paclet:ref/Accuracy"], "[", "x", "]"}]}]], "InlineFormula"],
 ") \:044f\:0432\:043b\:044f\:0435\:0442\:0441\:044f, \:043f\:043e \:0441\
\:0443\:0449\:0435\:0441\:0442\:0432\:0443, \:0432\:0435\:0449\:0435\:0441\
\:0442\:0432\:0435\:043d\:043d\:044b\:043c \:043f\:043e\:043a\:0430\:0437\
\:0430\:0442\:0435\:043b\:0435\:043c \:0447\:0438\:0441\:043b\:0430, \:0437\
\:043d\:0430\:0447\:0435\:043d\:0438\:0435 \:043a\:043e\:0442\:043e\:0440\
\:043e\:0433\:043e \:0432\:043e\:0437\:0432\:0440\:0430\:0449\:0430\:0435\
\:0442\:0441\:044f \:0444\:0443\:043d\:043a\:0446\:0438\:0435\:0439 ",
 Cell[BoxData[
  RowBox[{
   ButtonBox["RealExponent",
    BaseStyle->"Link",
    ButtonData->"paclet:ref/RealExponent"], "[", "x", "]"}]], "InlineFormula"],
 ":"
}], "HowToText",
 CellID->674362101],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Precision", "[", "x", "]"}], ",", 
   RowBox[{"Accuracy", "[", "x", "]"}], ",", 
   RowBox[{"RealExponent", "[", "x", "]"}]}], "}"}]], "Input",
 CellLabel->"In[6]:=",
 CellID->840451682],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "10.000000000000004`", ",", "7.90848779837223`", ",", 
   "2.091512201627771`"}], "}"}]], "Output",
 ImageSize->{159, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[6]=",
 CellID->760616613]
}, Open  ]],

Cell[TextData[{
 "\:0417\:0430\:0434\:0430\:043d\:043d\:0430\:044f \:0434\:043b\:044f ",
 Cell[BoxData["y"], "InlineFormula"],
 " \:0430\:043a\:043a\:0443\:0440\:0430\:0442\:043d\:043e\:0441\:0442\:044c \
\:0432 10 \:0437\:043d\:0430\:043a\:043e\:0432 \:043f\:043e\:0441\:043b\:0435 \
\:0437\:0430\:043f\:044f\:0442\:043e\:0439 \:0432\:043b\:0435\:0447\:0435\
\:0442 \:0437\:0430 \:0441\:043e\:0431\:043e\:0439 \:043e\:043f\:0440\:0435\
\:0434\:0435\:043b\:0435\:043d\:043d\:043e\:0435 \:0437\:043d\:0430\:0447\
\:0435\:043d\:0438\:0435 \:0434\:043b\:044f \:0435\:0433\:043e \:0442\:043e\
\:0447\:043d\:043e\:0441\:0442\:0438, \:043a\:043e\:0442\:043e\:0440\:0430\
\:044f, \:0432 \:0434\:0430\:043d\:043d\:043e\:043c \:0441\:043b\:0443\:0447\
\:0430\:0435, \:0441\:043e\:0441\:0442\:0430\:0432\:043b\:044f\:0435\:0442 \
\:0431\:043e\:043b\:0435\:0435 10:"
}], "HowToText",
 CellID->295243252],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Precision", "[", "y", "]"}], ",", 
   RowBox[{"Accuracy", "[", "y", "]"}], ",", 
   RowBox[{"RealExponent", "[", "y", "]"}]}], "}"}]], "Input",
 CellLabel->"In[7]:=",
 CellID->688956937],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "12.091512201627769`", ",", "9.999999999999995`", ",", 
   "2.091512201627771`"}], "}"}]], "Output",
 ImageSize->{159, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[7]=",
 CellID->841595091]
}, Open  ]],

Cell["\<\
\:0410\:043a\:043a\:0443\:0440\:0430\:0442\:043d\:043e\:0441\:0442\:044c \
\:0447\:0438\:0441\:043b\:0430 \:043c\:043e\:0436\:0435\:0442 \:043f\:0440\
\:0438\:043e\:0431\:0440\:0435\:0442\:0430\:0442\:044c \:043e\:0442\:0440\
\:0438\:0446\:0430\:0442\:0435\:043b\:044c\:043d\:043e\:0435 \:0437\:043d\
\:0430\:0447\:0435\:043d\:0438\:0435, \:0443\:043a\:0430\:0437\:044b\:0432\
\:0430\:044f \:043d\:0430 \:0442\:043e, \:0447\:0442\:043e \:0432\:0441\:0435 \
\:0432\:0435\:0440\:043d\:044b\:0435 \:043e\:0442\:043b\:0438\:0447\:043d\
\:044b\:0435 \:043e\:0442 \:043d\:0443\:043b\:044f \:0446\:0438\:0444\:0440\
\:044b \:043d\:0430\:0445\:043e\:0434\:044f\:0442\:0441\:044f \:0441\:043b\
\:0435\:0432\:0430 \:043e\:0442 \:0434\:0435\:0441\:044f\:0442\:0438\:0447\
\:043d\:043e\:0439 \:0442\:043e\:0447\:043a\:0438:\
\>", "HowToText",
 CellID->73881109],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Accuracy", "[", 
  RowBox[{"1.23`10", "*", 
   SuperscriptBox["10", "20"]}], "]"}]], "Input",
 CellLabel->"In[184]:=",
 CellID->731903681],

Cell[BoxData[
 RowBox[{"-", "10.089905111439395`"}]], "Output",
 ImageSize->{61, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[184]=",
 CellID->53552176]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\t", "HowToDelimiter",
 Editable->False,
 CellID->273356048],

Cell[TextData[{
 "\:041c\:0430\:0448\:0438\:043d\:043d\:0430\:044f \:0442\:043e\:0447\:043d\
\:043e\:0441\:0442\:044c ",
 Cell[BoxData[
  ButtonBox["MachinePrecision",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/MachinePrecision"]], "InlineFormula"],
 " \:0441\:0447\:0438\:0442\:0430\:0435\:0442\:0441\:044f \:043d\:0430\:0438\
\:043c\:0435\:043d\:044c\:0448\:0435\:0439 \:0442\:043e\:0447\:043d\:043e\
\:0441\:0442\:044c\:044e \:0441\:0440\:0435\:0434\:0438 \:043e\:0441\:0442\
\:0430\:043b\:044c\:043d\:044b\:0445. \:042d\:0442\:043e \:043f\:0440\:043e\
\:0438\:0441\:0445\:043e\:0434\:0438\:0442 \:043f\:043e\:0442\:043e\:043c\
\:0443, \:0447\:0442\:043e \:043d\:0435\:0441\:043c\:043e\:0442\:0440\:044f \
\:043d\:0430 \:0442\:043e, \:0447\:0442\:043e \:0447\:0438\:0441\:043b\:0430 \
\:0441 \:043c\:0430\:0448\:0438\:043d\:043d\:043e\:0439 \:0442\:043e\:0447\
\:043d\:043e\:0441\:0442\:044c\:044e \:0432\:0441\:0435\:0433\:0434\:0430 \
\:0441\:043e\:0441\:0442\:043e\:044f\:0442 \:0438\:0437 \:0447\:0443\:0442\
\:044c \:043c\:0435\:043d\:0435\:0435 16 \:0446\:0438\:0444\:0440, \:043d\
\:0435\:043b\:044c\:0437\:044f \:0443\:0442\:0432\:0435\:0440\:0436\:0434\
\:0430\:0442\:044c, \:0447\:0442\:043e \:0432\:0441\:0435 \:043e\:043d\:0438 \
\:044f\:0432\:043b\:044f\:044e\:0442\:0441\:044f \:043a\:043e\:0440\:0440\
\:0435\:043a\:0442\:043d\:044b\:043c\:0438."
}], "HowToText",
 CellID->360798399],

Cell[TextData[{
 "\:0417\:0434\:0435\:0441\:044c \:0432\:0441\:0435 \:0446\:0438\:0444\:0440\
\:044b \:0440\:0435\:0437\:0443\:043b\:044c\:0442\:0430\:0442\:0430, \:0434\
\:0430\:043d\:043d\:043e\:0433\:043e \:0441 \:043c\:0430\:0448\:0438\:043d\
\:043d\:043e\:0439 \:0442\:043e\:0447\:043d\:043e\:0441\:0442\:044c\:044e, \
\:044f\:0432\:043b\:044f\:044e\:0442\:0441\:044f \:043a\:043e\:0440\:0440\
\:0435\:043a\:0442\:043d\:044b\:043c\:0438 (",
 Cell[BoxData[
  ButtonBox["InputForm",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/InputForm"]], "InlineFormula"],
 " \:0438\:0441\:043f\:043e\:043b\:044c\:0437\:0443\:0435\:0442\:0441\:044f \
\:0434\:043b\:044f \:043e\:0442\:043e\:0431\:0440\:0430\:0436\:0435\:043d\
\:0438\:044f \:0432\:0441\:0435\:0445 \:043e\:0442\:043b\:0438\:0447\:043d\
\:044b\:0445 \:043e\:0442 \:043d\:0443\:043b\:044f \:0446\:0438\:0444\:0440 \
\:0447\:0438\:0441\:043b\:0430): "
}], "HowToText",
 CellID->59069615],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"InputForm", "[", 
  RowBox[{"N", "[", 
   FractionBox["1", "3"], "]"}], "]"}]], "Input",
 CellLabel->"In[211]:=",
 CellID->32781402],

Cell["0.3333333333333333", "Output",
 ImageSize->{126, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[211]//InputForm=",
 CellID->103178974]
}, Open  ]],

Cell["\<\
\:0417\:0434\:0435\:0441\:044c \:043d\:0438 \:043e\:0434\:043d\:0430 \:0438\
\:0437 \:0446\:0438\:0444\:0440 \:0440\:0435\:0437\:0443\:043b\:044c\:0442\
\:0430\:0442\:0430, \:0434\:0430\:043d\:043d\:043e\:0433\:043e \:0441 \:043c\
\:0430\:0448\:0438\:043d\:043d\:043e\:0439 \:0442\:043e\:0447\:043d\:043e\
\:0441\:0442\:044c\:044e, \:043d\:0435 \:044f\:0432\:043b\:044f\:0435\:0442\
\:0441\:044f \:043a\:043e\:0440\:0440\:0435\:043a\:0442\:043d\:043e\:0439 \
\:043f\:043e \:043f\:0440\:0438\:0447\:0438\:043d\:0435 \:043f\:043e\:0433\
\:0440\:0435\:0448\:043d\:043e\:0441\:0442\:0438 \:0432 \:0432\:044b\:0447\
\:0438\:0442\:0430\:043d\:0438\:0438 \:0434\:0432\:0443\:0445 \:0447\:0438\
\:0441\:0435\:043b, \:043a\:043e\:0442\:043e\:0440\:044b\:0435 \:043f\:0440\
\:0430\:043a\:0442\:0438\:0447\:0435\:0441\:043a\:0438 \:0438\:0434\:0435\
\:043d\:0442\:0438\:0447\:043d\:044b \:0435\:0441\:043b\:0438 \:043f\:0440\
\:0435\:0434\:0441\:0442\:0430\:0432\:043b\:0435\:043d\:044b \:0441 \:043c\
\:0430\:0448\:0438\:043d\:043d\:043e\:0439 \:0442\:043e\:0447\:043d\:043e\
\:0441\:0442\:044c\:044e:\
\>", "HowToText",
 CellID->507341218],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"\[Pi]", "-", 
   FractionBox["80143857", "25510582"]}], "]"}]], "Input",
 CellLabel->"In[205]:=",
 CellID->22701373],

Cell[BoxData["4.440892098500626`*^-16"], "Output",
 ImageSize->{94, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[205]=",
 CellID->300458961]
}, Open  ]],

Cell[TextData[{
 "\:0427\:0442\:043e\:0431\:044b \:0431\:044b\:0442\:044c \:0443\:0432\:0435\
\:0440\:0435\:043d\:043d\:044b\:043c \:0432 ",
 Cell[BoxData[
  StyleBox["n", "TI"]], "InlineFormula"],
 "-\:043d\:043e\:043c \:043a\:043e\:043b\:0438\:0447\:0435\:0441\:0442\:0432\
\:0435 \:0446\:0438\:0444\:0440, \:0432\:043e\:0441\:043f\:043e\:043b\:044c\
\:0437\:0443\:0435\:043c\:0441\:044f \:0444\:0443\:043d\:043a\:0446\:0438\
\:0435\:0439 ",
 Cell[BoxData[
  RowBox[{
   ButtonBox["N",
    BaseStyle->"Link",
    ButtonData->"paclet:ref/N"], "[", 
   RowBox[{
    StyleBox["\:0432\:044b\:0440\:0430\:0436\:0435\:043d\:0438\:0435", "TI"], 
    ",", 
    StyleBox["n", "TI"]}], "]"}]], "InlineFormula"],
 ". \:0414\:0430\:0432\:0430\:0439\:0442\:0435 \:043f\:043e\:043b\:0443\:0447\
\:0438\:043c \:0440\:0435\:0437\:0443\:043b\:044c\:0442\:0430\:0442 \:0441 10 \
\:0432\:0435\:0440\:043d\:044b\:043c\:0438 \:0446\:0438\:0444\:0440\:0430\
\:043c\:0438:"
}], "HowToText",
 CellID->34597867],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{
   RowBox[{"\[Pi]", "-", 
    FractionBox["80143857", "25510582"]}], ",", "10"}], "]"}]], "Input",
 CellLabel->"In[207]:=",
 CellID->550764148],

Cell[BoxData["5.790870164375673274426490306701214964756452`10.*^-16"], \
"Output",
 ImageSize->{122, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[207]=",
 CellID->723010979]
}, Open  ]],

Cell[TextData[{
 "\:0424\:0443\:043d\:043a\:0446\:0438\:044f ",
 Cell[BoxData[
  ButtonBox["N",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/N"]], "InlineFormula"],
 " \:043d\:0435 \:043c\:043e\:0436\:0435\:0442 \:0434\:0430\:0442\:044c \
\:0440\:0435\:0437\:0443\:043b\:044c\:0442\:0430\:0442 \:0441 \:0442\:043e\
\:0447\:043d\:043e\:0441\:0442\:044c\:044e \:0432\:044b\:0448\:0435, \:0447\
\:0435\:043c \:0431\:044b\:043b\:0430 \:0437\:0430\:0434\:0430\:043d\:0430 \
\:043d\:0430 \:0432\:0445\:043e\:0434\:0435. \:0417\:0434\:0435\:0441\:044c \
\:043f\:043e\:043a\:0430\:0437\:0430\:043d\:043e, \:0447\:0442\:043e ",
 Cell[BoxData[
  ButtonBox["N",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/N"]], "InlineFormula"],
 " \:043d\:0435 \:0432 \:0441\:043e\:0441\:0442\:043e\:044f\:043d\:0438\:0438 \
\:043f\:043e\:043b\:0443\:0447\:0438\:0442\:044c \:0440\:0435\:0437\:0443\
\:043b\:044c\:0442\:0430\:0442 \:0441\:043e 100 \
\:0446\:0438\:0444\:0440\:0430\:043c\:0438, \:0442\:0430\:043a \:043a\:0430\
\:043a \:043d\:0430 \:0432\:0445\:043e\:0434\:0435 \:0442\:043e\:0447\:043d\
\:043e\:0441\:0442\:044c \:0441\:043e\:0441\:0442\:0430\:0432\:043b\:044f\
\:0435\:0442 \:0442\:043e\:043b\:044c\:043a\:043e 10 \:0437\:043d\:0430\:0447\
\:0430\:0449\:0438\:0445 \:0446\:0438\:0444\:0440:"
}], "HowToText",
 CellID->398920349],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"x", "=", 
   RowBox[{"N", "[", 
    RowBox[{"0.5`10", ",", "100"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{"x", ",", 
   RowBox[{"Precision", "[", "x", "]"}]}], "}"}]}], "Input",
 CellLabel->"In[240]:=",
 CellID->7653986],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.5`10.", ",", "10.000000000000004`"}], "}"}]], "Output",
 ImageSize->{134, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[241]=",
 CellID->480830627]
}, Open  ]],

Cell[TextData[{
 "\:0417\:0434\:0435\:0441\:044c ",
 Cell[BoxData[
  ButtonBox["N",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/N"]], "InlineFormula"],
 " \:043d\:0435 \:0432 \:0441\:043e\:0441\:0442\:043e\:044f\:043d\:0438\:0438 \
\:043f\:043e\:043b\:0443\:0447\:0438\:0442\:044c \:0440\:0435\:0437\:0443\
\:043b\:044c\:0442\:0430\:0442 \:0441 \:0442\:043e\:0447\:043d\:043e\:0441\
\:0442\:044c\:044e \:0432 6 \:0437\:043d\:0430\:0447\:0430\:0449\:0438\:0445 \
\:0446\:0438\:0444\:0440, \:0442\:0430\:043a \:043a\:0430\:043a \:043d\:0430 \
\:0432\:0445\:043e\:0434\:0435 \:0437\:0430\:0434\:0430\:043d\:043e \:0447\
\:0438\:0441\:043b\:043e \:0441 \:043c\:0430\:0448\:0438\:043d\:043d\:043e\
\:0439 \:0442\:043e\:0447\:043d\:043e\:0441\:0442\:044c\:044e, \:043a\:043e\
\:0442\:043e\:0440\:0430\:044f \:0440\:0430\:0441\:0441\:043c\:0430\:0442\
\:0440\:0438\:0432\:0430\:0435\:0442\:0441\:044f \:043a\:0430\:043a \:043d\
\:0430\:0438\:043c\:0435\:043d\:044c\:0448\:0430\:044f \:0438\:0437 \:0432\
\:0441\:0435\:0445 \:0432\:043e\:0437\:043c\:043e\:0436\:043d\:044b\:0445:"
}], "HowToText",
 CellID->488573772],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"x", "=", 
   RowBox[{"N", "[", 
    RowBox[{"0.5", ",", "6"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{"x", ",", 
   RowBox[{"Precision", "[", "x", "]"}]}], "}"}]}], "Input",
 CellLabel->"In[247]:=",
 CellID->259857588],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.5`", ",", "MachinePrecision"}], "}"}]], "Output",
 ImageSize->{162, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[248]=",
 CellID->264441550]
}, Open  ]],

Cell[TextData[{
 "\:0415\:0441\:043b\:0438 \:0438\:0437\:0432\:0435\:0441\:0442\:043d\:043e, \
\:0447\:0442\:043e \:043f\:0440\:0438\:0431\:043b\:0438\:0437\:0438\:0442\
\:0435\:043b\:044c\:043d\:043e\:0435 \:0447\:0438\:0441\:043b\:043e ",
 Cell[BoxData[
  StyleBox["\:0447\:0438\:0441\:043b\:043e", "TI"]], "InlineFormula"],
 " \:044f\:0432\:043b\:044f\:0435\:0442\:0441\:044f \:0431\:043e\:043b\:0435\
\:0435 \:0442\:043e\:0447\:043d\:044b\:043c, \:0447\:0435\:043c \:0443\:043a\
\:0430\:0437\:044b\:0432\:0430\:0435\:0442 \:0444\:0443\:043d\:043a\:0446\
\:0438\:044f ",
 Cell[BoxData[
  RowBox[{
   ButtonBox["Precision",
    BaseStyle->"Link",
    ButtonData->"paclet:ref/Precision"], "[", 
   StyleBox["\:0447\:0438\:0441\:043b\:043e", "TI"], "]"}]], "InlineFormula"],
 ", \:043c\:043e\:0436\:043d\:043e \:044f\:0432\:043d\:043e \
\:0437\:0430\:0434\:0430\:0442\:044c \:0435\:0433\:043e \:0442\:043e\:0447\
\:043d\:043e\:0441\:0442\:044c \:0441 \:043f\:043e\:043c\:043e\:0449\:044c\
\:044e \:0444\:0443\:043d\:043a\:0446\:0438\:0438 ",
 Cell[BoxData[
  ButtonBox["SetPrecision",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/SetPrecision"]], "InlineFormula"],
 ". \:0417\:0430\:0434\:0430\:0434\:0438\:043c \:0447\:0438\:0441\:043b\:043e \
\:0441 \:0436\:0435\:043b\:0430\:0435\:043c\:043e\:0439 \:0441\:0442\:0435\
\:043f\:0435\:043d\:044c\:044e \:0442\:043e\:0447\:043d\:043e\:0441\:0442\
\:0438 \:0432 20 \:0437\:043d\:0430\:0447\:0430\:0449\:0438\:0445 \
\:0446\:0438\:0444\:0440, \:0441\:043e\:043e\:0442\:0432\:0435\:0442\:0441\
\:0442\:0432\:0443\:044e\:0449\:0435\:0435 \:0447\:0438\:0441\:043b\:0443 0.5 \
\:0441 \:043c\:0430\:0448\:0438\:043d\:043d\:043e\:0439 \:0441\:0442\:0435\
\:043f\:0435\:043d\:044c\:044e \:0442\:043e\:0447\:043d\:043e\:0441\:0442\
\:0438:"
}], "HowToText",
 CellID->794400130],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetPrecision", "[", 
  RowBox[{"0.5", ",", "20"}], "]"}]], "Input",
 CellLabel->"In[246]:=",
 CellID->253756534],

Cell[BoxData["0.5`20."], "Output",
 ImageSize->{158, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[246]=",
 CellID->155025007]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\t", "HowToDelimiter",
 Editable->False,
 CellID->30574310],

Cell[TextData[{
 "\:041a\:043e\:0433\:0434\:0430 \:0432\:044b\:0440\:0430\:0436\:0435\:043d\
\:0438\:0435 \:0441\:043e\:0434\:0435\:0440\:0436\:0438\:0442 \:043f\:0440\
\:0438\:0431\:043b\:0438\:0437\:0438\:0442\:0435\:043b\:044c\:043d\:044b\:0435\
 \:0447\:0438\:0441\:043b\:0430, \:043f\:043e\:043b\:044c\:0437\:043e\:0432\
\:0430\:0442\:0435\:043b\:044e \:043e\:0431\:044b\:0447\:043d\:043e \:043d\
\:0435 \:043d\:0443\:0436\:043d\:043e \:0438\:0441\:043f\:043e\:043b\:044c\
\:0437\:043e\:0432\:0430\:0442\:044c \:0444\:0443\:043d\:043a\:0446\:0438\
\:044e ",
 Cell[BoxData[
  ButtonBox["N",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/N"]], "InlineFormula"],
 ". ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " \:0430\:0432\:0442\:043e\:043c\:0430\:0442\:0438\:0447\:0435\:0441\:043a\
\:0438 \:0432\:044b\:0447\:0438\:0441\:043b\:044f\:0435\:0442 \:043f\:0440\
\:0438\:0431\:043b\:0438\:0437\:0438\:0442\:0435\:043b\:044c\:043d\:044b\:0439\
 \:0440\:0435\:0437\:0443\:043b\:044c\:0442\:0430\:0442 \:0438 \:043e\:043f\
\:0440\:0435\:0434\:0435\:043b\:044f\:0435\:0442 \:0442\:043e\:0447\:043d\
\:043e\:0441\:0442\:044c \:0440\:0435\:0437\:0443\:043b\:044c\:0442\:0430\
\:0442\:0430 \:0441 \:0443\:0447\:0435\:0442\:043e\:043c \:0442\:043e\:0447\
\:043d\:043e\:0441\:0442\:0438, \:0437\:0430\:0434\:0430\:043d\:043d\:043e\
\:0439 \:043f\:0440\:0438 \:0432\:0432\:043e\:0434\:0435. \:041a\:0430\:043a \
\:043f\:0440\:0430\:0432\:0438\:043b\:043e, \:0442\:043e\:0447\:043d\:043e\
\:0441\:0442\:044c \:0440\:0435\:0437\:0443\:043b\:044c\:0442\:0430\:0442\
\:0430 \:0431\:0443\:0434\:0435\:0442 \:043e\:0442\:043b\:0438\:0447\:0430\
\:0442\:044c\:0441\:044f \:043e\:0442 \:0442\:043e\:0447\:043d\:043e\:0441\
\:0442\:0438 \:043a\:0430\:0436\:0434\:043e\:0439 \:0447\:0430\:0441\:0442\
\:0438 \:0432\:0432\:043e\:0434\:0430."
}], "HowToText",
 CellID->20482469],

Cell["\<\
\:041f\:0440\:0438\:0431\:0430\:0432\:0438\:043c \:0447\:0438\:0441\:043b\
\:043e \:0441 10 \:0437\:043d\:0430\:0447\:0430\:0449\:0438\:043c\:0438 \
\:0446\:0438\:0444\:0440\:0430\:043c\:0438 \:043a \:0447\:0438\:0441\:043b\
\:0443 \:0441 1000 \:0437\:043d\:0430\:0447\:0430\:0449\:0438\:0445 \:0446\
\:0438\:0444\:0440:\
\>", "HowToText",
 CellID->152778577],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"1`10", "+", "9`1000"}]], "Input",
 CellLabel->"In[286]:=",
 CellID->456380146],

Cell[BoxData["10.`11."], "Output",
 ImageSize->{88, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[286]=",
 CellID->8175660]
}, Open  ]],

Cell[TextData[{
 "\:041f\:0440\:0438\:043c\:0435\:043d\:0438\:043c ",
 Cell[BoxData[
  ButtonBox["Precision",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Precision"]], "InlineFormula"],
 " \:043a \:043f\:043e\:0441\:043b\:0435\:0434\:043d\:0435\:043c\:0443 \:043f\
\:043e\:043b\:0443\:0447\:0435\:043d\:043d\:043e\:043c\:0443 \:0440\:0435\
\:0437\:0443\:043b\:044c\:0442\:0430\:0442\:0443 (",
 Cell[BoxData["%"], "InlineFormula"],
 "), \:0447\:0442\:043e\:0431\:044b \
\:0443\:0432\:0438\:0434\:0435\:0442\:044c, \:0447\:0442\:043e ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " \:0443\:0441\:0442\:0430\:043d\:043e\:0432\:0438\:043b\:0430 \:0434\:043b\
\:044f \:0440\:0435\:0437\:0443\:043b\:044c\:0442\:0430\:0442\:0430 \:0442\
\:043e\:0447\:043d\:043e\:0441\:0442\:044c \:0432 11 \:0437\:043d\:0430\:0447\
\:0430\:0449\:0438\:0445 \:0446\:0438\:0444\:0440:"
}], "HowToText",
 CellID->407950852],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Precision", "[", "%", "]"}]], "Input",
 CellLabel->"In[287]:=",
 CellID->278947095],

Cell[BoxData["11.000000000000005`"], "Output",
 ImageSize->{25, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[287]=",
 CellID->96745192]
}, Open  ]],

Cell["\<\
\:0422\:0430\:043a \:043a\:0430\:043a \:0447\:0438\:0441\:043b\:0430 \:0441 \
\:043c\:0430\:0448\:0438\:043d\:043d\:043e\:0439 \:0442\:043e\:0447\:043d\
\:043e\:0441\:0442\:044c\:044e \:0441\:0447\:0438\:0442\:0430\:044e\:0442\
\:0441\:044f \:043d\:0430\:0438\:043c\:0435\:043d\:0435\:0435 \:0442\:043e\
\:0447\:043d\:044b\:043c\:0438 \:0447\:0435\:043c \:043b\:044e\:0431\:044b\
\:0435 \:0434\:0440\:0443\:0433\:0438\:0435, \:0435\:0441\:043b\:0438 \:0432\
\:0432\:043e\:0434 \:0441\:043e\:0434\:0435\:0440\:0436\:0438\:0442 \:0447\
\:0438\:0441\:043b\:043e \:0441 \:043c\:0430\:0448\:0438\:043d\:043d\:043e\
\:0439 \:0442\:043e\:0447\:043d\:043e\:0441\:0442\:044c\:044e, \:0440\:0435\
\:0437\:0443\:043b\:044c\:0442\:0430\:0442, \:043a\:0430\:043a \:043f\:0440\
\:0430\:0432\:0438\:043b\:043e, \:0432\:043e\:0437\:0432\:0440\:0430\:0449\
\:0430\:0435\:0442\:0441\:044f \:0447\:0438\:0441\:043b\:043e\:043c \:0441 \
\:043c\:0430\:0448\:0438\:043d\:043d\:043e\:0439 \:0442\:043e\:0447\:043d\
\:043e\:0441\:0442\:044c\:044e.\
\>", "HowToText",
 CellID->812217608],

Cell[TextData[{
 "\:0418\:0441\:043f\:043e\:043b\:044c\:0437\:0443\:0435\:043c ",
 Cell[BoxData["/@"], "InlineFormula"],
 " (\:043a\:0440\:0430\:0442\:043a\:0443\:044e \:0444\:043e\:0440\:043c\:0443 \
\:0437\:0430\:043f\:0438\:0441\:0438 \:0434\:043b\:044f ",
 Cell[BoxData[
  ButtonBox["Map",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Map"]], "InlineFormula"],
 ") \:0447\:0442\:043e\:0431\:044b \:043f\:0440\:0438\:043c\:0435\:043d\:0438\
\:0442\:044c \:0444\:0443\:043d\:043a\:0446\:0438\:044e ",
 Cell[BoxData[
  ButtonBox["Precision",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Precision"]], "InlineFormula"],
 " \:043a \:043a\:0430\:0436\:0434\:043e\:0439 \:0447\:0430\:0441\:0442\:0438 \
\:0441\:043f\:0438\:0441\:043a\:0430 \:0432\:044b\:0447\:0438\:0441\:043b\
\:0435\:043d\:0438\:0439, \:0433\:0434\:0435 \:0438\:0441\:043f\:043e\:043b\
\:044c\:0437\:043e\:0432\:0430\:043d\:044b \:0447\:0438\:0441\:043b\:0430 \
\:0441 \:043c\:0430\:0448\:0438\:043d\:043d\:043e\:0439 \:0442\:043e\:0447\
\:043d\:043e\:0441\:0442\:044c\:044e:"
}], "HowToText",
 CellID->160808516],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Precision", "/@", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"1.0", "+", "9`1000"}], ",", 
    RowBox[{"0.0", "+", "500"}], ",", 
    SqrtBox["2.25"]}], "}"}]}]], "Input",
 CellLabel->"In[28]:=",
 CellID->832173913],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "MachinePrecision", ",", "MachinePrecision", ",", "MachinePrecision"}], 
  "}"}]], "Output",
 ImageSize->{376, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[28]=",
 CellID->701346208]
}, Open  ]],

Cell["\<\
\:0417\:0430\:0447\:0430\:0441\:0442\:0443\:044e, \:0442\:043e\:0447\:043d\
\:043e\:0441\:0442\:044c \:0440\:0435\:0437\:0443\:043b\:044c\:0442\:0430\
\:0442\:0430 \:043d\:0435 \:043e\:0447\:0435\:043d\:044c \:0441\:0438\:043b\
\:044c\:043d\:043e \:043e\:0442\:043b\:0438\:0447\:0430\:0435\:0442\:0441\
\:044f \:043e\:0442 \:0442\:043e\:0439, \:043a\:043e\:0442\:043e\:0440\:0443\
\:044e \:0438\:043c\:0435\:0435\:0442 \:044d\:043b\:0435\:043c\:0435\:043d\
\:0442 \:0432\:0432\:043e\:0434\:0430, \:043e\:0431\:043b\:0430\:0434\:0430\
\:044e\:0449\:0435\:0439 \:043d\:0430\:0438\:043c\:0435\:043d\:044c\:0448\
\:0435\:0439 \:0442\:043e\:0447\:043d\:043e\:0441\:0442\:044c\:044e:\
\>", "HowToText",
 CellID->110544337],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  FractionBox["2", "3"], "+", "\[Pi]", "+", "5.5`30"}]], "Input",
 CellLabel->"In[296]:=",
 CellID->205003966],

Cell[BoxData["9.3082593202564599051293100499461695508638360660417724876417`30.\
22850578436708"], "Output",
 ImageSize->{221, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[296]=",
 CellID->69386310]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Precision", "[", "%", "]"}]], "Input",
 CellLabel->"In[297]:=",
 CellID->243014452],

Cell[BoxData["30.22850578436708`"], "Output",
 ImageSize->{53, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[297]=",
 CellID->61605454]
}, Open  ]],

Cell["\<\
\:0412 \:043d\:0435\:043a\:043e\:0442\:043e\:0440\:044b\:0445 \:0441\:043b\
\:0443\:0447\:0430\:044f\:0445, \:0442\:043e\:0447\:043d\:043e\:0441\:0442\
\:044c \:0440\:0435\:0437\:0443\:043b\:044c\:0442\:0430\:0442\:0430 \:043c\
\:043e\:0436\:0435\:0442 \:0431\:044b\:0442\:044c \:043d\:0430\:043c\:043d\
\:043e\:0433\:043e \:043c\:0435\:043d\:044c\:0448\:0435 \:0442\:043e\:0447\
\:043d\:043e\:0441\:0442\:0438, \:0437\:0430\:0434\:0430\:043d\:043d\:043e\
\:0439 \:0434\:043b\:044f \:0432\:0432\:043e\:0434\:0430. \:0427\:0430\:0449\
\:0435 \:0432\:0441\:0435\:0433\:043e \:044d\:0442\:043e \:043f\:0440\:043e\
\:0438\:0441\:0445\:043e\:0434\:0438\:0442 \:043f\:0440\:0438 \:0432\:044b\
\:0447\:0438\:0442\:0430\:043d\:0438\:0438 \:0434\:0432\:0443\:0445 \:043f\
\:043e\:0447\:0442\:0438 \:0438\:0434\:0435\:043d\:0442\:0438\:0447\:043d\
\:044b\:0445 \:043f\:0440\:0438\:0431\:043b\:0438\:0437\:0438\:0442\:0435\
\:043b\:044c\:043d\:044b\:0445 \:0447\:0438\:0441\:0435\:043b:\
\>", "HowToText",
 CellID->31644728],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"1`20", "-", 
  RowBox[{"Sqrt", "[", 
   RowBox[{"1", "-", 
    RowBox[{"Exp", "[", 
     RowBox[{"-", "40"}], "]"}]}], "]"}]}]], "Input",
 CellLabel->"In[5]:=",
 CellID->181972925],

Cell[BoxData["2.1241771276457944999206816262360979791222`2.3271907282059456*^-\
18"], "Output",
 ImageSize->{66, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[5]=",
 CellID->277646496]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Precision", "[", "%", "]"}]], "Input",
 CellLabel->"In[6]:=",
 CellID->45031707],

Cell[BoxData["2.3271907282059456`"], "Output",
 ImageSize->{53, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[6]=",
 CellID->291636354]
}, Open  ]],

Cell[TextData[{
 "\:041a\:043e\:0433\:0434\:0430 \:0432\:0430\:043c \:043d\:0443\:0436\:0435\
\:043d \:0440\:0435\:0437\:0443\:043b\:044c\:0442\:0430\:0442 \:0441 \:043e\
\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\:043d\:043e\:0439 \:0442\
\:043e\:0447\:043d\:043e\:0441\:0442\:044c\:044e \:0438\:043b\:0438 \:0430\
\:043a\:043a\:0443\:0440\:0430\:0442\:043d\:043e\:0441\:0442\:044c\:044e, \
\:043a\:0430\:043a \:043f\:0440\:0430\:0432\:0438\:043b\:043e \:043d\:0430\
\:0438\:043b\:0443\:0447\:0448\:0438\:043c \:0441\:043f\:043e\:0441\:043e\
\:0431\:043e\:043c \:044f\:0432\:043b\:044f\:0435\:0442\:0441\:044f \:0438\
\:0441\:043f\:043e\:043b\:044c\:0437\:043e\:0432\:0430\:043d\:0438\:0435 \
\:0442\:043e\:0447\:043d\:044b\:0445 \:0437\:043d\:0430\:0447\:0435\:043d\
\:0438\:0439 \:0434\:043b\:044f \:0432\:0432\:043e\:0434\:0430 \:0438 \:0438\
\:0441\:043f\:043e\:043b\:044c\:0437\:043e\:0432\:0430\:043d\:0438\:0435 \
\:0444\:0443\:043d\:043a\:0446\:0438\:0438 ",
 Cell[BoxData[
  ButtonBox["N",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/N"]], "InlineFormula"],
 ". \:042d\:0442\:043e \:043f\:043e\:0442\:043e\:043c\:0443, \:0447\:0442\
\:043e ",
 Cell[BoxData[
  ButtonBox["N",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/N"]], "InlineFormula"],
 " \:0438\:043d\:043e\:0433\:0434\:0430 \:0431\:0443\:0434\:0435\:0442 \:043f\
\:0440\:043e\:0432\:043e\:0434\:0438\:0442\:044c \:043f\:0440\:043e\:043c\
\:0435\:0436\:0443\:0442\:043e\:0447\:043d\:044b\:0435 \:0432\:044b\:0447\
\:0438\:0441\:043b\:0435\:043d\:0438\:044f \:0441 \:0431\:043e\:043b\:044c\
\:0448\:0435\:0439 \:0442\:043e\:0447\:043d\:043e\:0441\:0442\:044c\:044e, \
\:0447\:0435\:043c \:0431\:044b\:043b\:0430 \:0437\:0430\:0434\:0430\:043d\
\:0430 \:0434\:043b\:044f ",
 Cell[BoxData[
  ButtonBox["N",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/N"]], "InlineFormula"],
 ", \:0447\:0442\:043e\:0431\:044b \:043f\:043e\:043b\:0443\:0447\:0438\:0442\
\:044c \:0440\:0435\:0437\:0443\:043b\:044c\:0442\:0430\:0442, \:043a\:043e\
\:0442\:043e\:0440\:044b\:0439 \:0443\:0434\:043e\:0432\:043b\:0435\:0442\
\:0432\:043e\:0440\:0438\:0442 \:0432\:0430\:0448\:0438 \:0442\:0440\:0435\
\:0431\:043e\:0432\:0430\:043d\:0438\:044f. "
}], "HowToText",
 CellID->230352071],

Cell[TextData[{
 "\:041d\:0430\:0439\:0434\:0435\:043c \:043f\:0440\:0438\:0431\:043b\:0438\
\:0437\:0438\:0442\:0435\:043b\:044c\:043d\:043e\:0435 \:0440\:0435\:0448\
\:0435\:043d\:0438\:0435 \:0432\:044b\:0440\:0430\:0436\:0435\:043d\:0438\
\:044f ",
 Cell[BoxData[
  RowBox[{"1", "-", 
   SqrtBox[
    RowBox[{"1", "-", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"-", "40"}]]}]]}]], "InlineFormula"],
 " \:0441 \:0442\:043e\:0447\:043d\:043e\:0441\:0442\:044c\:044e 20 \:0437\
\:043d\:0430\:0447\:0430\:0449\:0438\:0445 \:0446\:0438\:0444\:0440:"
}], "HowToText",
 CellID->124946305],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{
   RowBox[{"1", "-", 
    RowBox[{"Sqrt", "[", 
     RowBox[{"1", "-", 
      RowBox[{"Exp", "[", 
       RowBox[{"-", "40"}], "]"}]}], "]"}]}], ",", "20"}], "]"}]], "Input",
 CellLabel->"In[166]:=",
 CellID->748069994],

Cell[BoxData["2.1241771276457944999206816262360979791222`20.*^-18"], "Output",
 ImageSize->{192, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[166]=",
 CellID->198944497]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Precision", "[", "%", "]"}]], "Input",
 CellLabel->"In[167]:=",
 CellID->687917947],

Cell[BoxData["20.`"], "Output",
 ImageSize->{25, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[167]=",
 CellID->336588590]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  InterpretationBox[
   StyleBox[
    GraphicsBox[{},
     BaselinePosition->Baseline,
     ImageSize->{6, 0}],
    CacheGraphics->False],
   Spacer[6]]]],
 "\:0423\:0447\:0435\:0431\:043d\:044b\:0435 \:043c\:0430\:0442\:0435\:0440\
\:0438\:0430\:043b\:044b"
}], "TutorialsSection",
 WholeCellGroupOpener->True,
 CellID->250839057],

Cell["", "SectionHeaderSpacer"],

Cell[BoxData[
 TemplateBox[{
  Cell["Numerical Precision"],"paclet:tutorial/NumericalPrecision"},
  "RefLink",
  BaseStyle->"Tutorials"]], "Tutorials",
 CellID->341631938],

Cell[BoxData[
 TemplateBox[{
  Cell["Exact and Approximate Results"],
   "paclet:tutorial/ExactAndApproximateResults"},
  "RefLink",
  BaseStyle->"Tutorials"]], "Tutorials",
 CellID->1526861278],

Cell["", "SectionFooterSpacer"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  InterpretationBox[
   StyleBox[
    GraphicsBox[{},
     BaselinePosition->Baseline,
     ImageSize->{6, 0}],
    CacheGraphics->False],
   Spacer[6]]]],
 "\:0421\:043c\:043e\:0442\:0440\:0438 \:0442\:0430\:043a\:0436\:0435"
}], "SeeAlsoSection",
 WholeCellGroupOpener->True,
 CellID->1255426704],

Cell[TextData[{
 Cell[BoxData[
  TemplateBox[{Cell["N"],"paclet:ref/N"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  TemplateBox[{Cell["Precision"],"paclet:ref/Precision"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  TemplateBox[{Cell["Accuracy"],"paclet:ref/Accuracy"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  TemplateBox[{Cell["RealExponent"],"paclet:ref/RealExponent"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"]
}], "SeeAlso",
 CellID->929782353]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  InterpretationBox[
   StyleBox[
    GraphicsBox[{},
     BaselinePosition->Baseline,
     ImageSize->{6, 0}],
    CacheGraphics->False],
   Spacer[6]]]],
 "\:0423\:0437\:043d\:0430\:0442\:044c \:0431\:043e\:043b\:044c\:0448\:0435"
}], "MoreAboutSection",
 WholeCellGroupOpener->True,
 CellID->38303248],

Cell["", "SectionHeaderSpacer"],

Cell[BoxData[
 TemplateBox[{
  Cell["Precision & Accuracy Control"],
   "paclet:guide/PrecisionAndAccuracyControl"},
  "RefLink",
  BaseStyle->"MoreAbout"]], "MoreAbout",
 CellID->1665078683],

Cell[BoxData[
 TemplateBox[{
  Cell["Numerical Evaluation & Precision"],
   "paclet:guide/NumericalEvaluationAndPrecision"},
  "RefLink",
  BaseStyle->"MoreAbout"]], "MoreAbout",
 CellID->1002088036],

Cell[BoxData[
 TemplateBox[{Cell["\"How to\" Topics"],"paclet:guide/HowToTopics"},
  "RefLink",
  BaseStyle->"MoreAbout"]], "MoreAbout",
 CellID->118337878]
}, Open  ]]
}, Open  ]],

Cell[" ", "FooterCell"]
},
FileChangeProtection->None,
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{Automatic, 510},
WindowMargins->{{312, Automatic}, {Automatic, 0}},
WindowFrame->"Normal",
WindowTitle->"Control the Precision and Accuracy of Numerical Results - \
Wolfram Mathematica",
DockedCells->FEPrivate`FrontEndResource["FEExpressions", "HelpViewerToolbar"],
TaggingRules->{
 "ModificationHighlight" -> False, "ColorType" -> "TutorialColor", 
  "LinkTrails" -> "", "ExampleCounter" -> 1, "ExamplePageLinks" -> {}, 
  "RootCaptions" -> "", 
  "Metadata" -> {
   "built" -> "{2013, 1, 24, 22, 46, 41.7858335}", 
    "history" -> {"7", "", "", ""}, "context" -> "System`", 
    "keywords" -> {
     "control precision", "control accuracy", "numerical precision", 
      "approximate numbers", "approximate arithmetic", 
      "numerical approximation", "significant figures", "more digits", 
      "number of digits", "arbitrary precision", "machine precision"}, 
    "specialkeywords" -> {}, "tutorialcollectionlinks" -> {}, "index" -> True,
     "label" -> "Mathematica How To", "language" -> "en", "paclet" -> 
    "Mathematica", "status" -> "None", "summary" -> 
    "Mathematica works with both exact quantities and approximate numbers. \
Using N , you can obtain a numerical approximation to an exact quantity with \
any desired precision or accuracy. In calculations involving \
arbitrary-precision approximate numbers, Mathematica tracks the propagation \
of the numerical error. The use of high-precision numbers can yield accurate \
results where other numerical systems fail.", "synonyms" -> {}, "title" -> 
    "Control the Precision and Accuracy of Numerical Results", 
    "titlemodifier" -> "", "windowtitle" -> 
    "Control the Precision and Accuracy of Numerical Results", "type" -> 
    "HowTo", "uri" -> 
    "howto/ControlThePrecisionAndAccuracyOfNumericalResults"}, 
  "SearchTextTranslated" -> ""},
Magnification->1.,
FrontEndVersion->"10.1 for Microsoft Windows (64-bit) (March 23, 2015)",
StyleDefinitions->FrontEnd`FileName[{"Wolfram"}, "Reference.nb", 
  CharacterEncoding -> "WindowsANSI"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[650, 22, 4794, 117, 48, "AnchorBarGrid",
 CellID->1],
Cell[CellGroupData[{
Cell[5469, 143, 472, 10, 91, "HowToTitle",
 CellID->509267359],
Cell[CellGroupData[{
Cell[5966, 157, 2549, 41, 109, "HowToAbstract",
 CellID->1045883471],
Cell[8518, 200, 323, 7, 38, "HowToText",
 CellID->1009846402],
Cell[CellGroupData[{
Cell[8866, 211, 126, 4, 42, "Input",
 CellID->827466675],
Cell[8995, 217, 192, 7, 57, "Output",
 CellID->612872562]
}, Open  ]],
Cell[9202, 227, 606, 13, 40, "HowToText",
 CellID->220800003],
Cell[CellGroupData[{
Cell[9833, 244, 155, 5, 42, "Input",
 CellID->411630083],
Cell[9991, 251, 178, 5, 36, "Output",
 CellID->232096490]
}, Open  ]],
Cell[10184, 259, 1240, 23, 76, "HowToText",
 CellID->292885398],
Cell[CellGroupData[{
Cell[11449, 286, 180, 6, 42, "Input",
 CellID->28235575],
Cell[11632, 294, 244, 7, 36, "Output",
 CellID->172362]
}, Open  ]],
Cell[11891, 304, 1712, 32, 78, "HowToText",
 CellID->4432995],
Cell[CellGroupData[{
Cell[13628, 340, 212, 7, 28, "Input",
 CellID->56810723],
Cell[13843, 349, 225, 6, 36, "Output",
 CellID->240389006]
}, Open  ]],
Cell[14083, 358, 1277, 28, 60, "HowToText",
 CellID->295574741],
Cell[CellGroupData[{
Cell[15385, 390, 470, 16, 42, "Input",
 CellID->126038806],
Cell[15858, 408, 225, 7, 36, "Output",
 CellID->289991519]
}, Open  ]],
Cell[16098, 418, 1327, 29, 60, "HowToText",
 CellID->307833781],
Cell[CellGroupData[{
Cell[17450, 451, 134, 4, 28, "Input",
 CellID->532172238],
Cell[17587, 457, 261, 8, 36, "Output",
 CellID->718689386]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[17897, 471, 66, 2, 15, "HowToDelimiter",
 CellID->817571008],
Cell[17966, 475, 1821, 27, 92, "HowToText",
 CellID->147268061],
Cell[19790, 504, 345, 5, 38, "HowToText",
 CellID->2089015097],
Cell[CellGroupData[{
Cell[20160, 513, 216, 7, 44, "Input",
 CellID->94881430],
Cell[20379, 522, 225, 7, 36, "Output",
 CellID->249923319]
}, Open  ]],
Cell[20619, 532, 868, 16, 58, "HowToText",
 CellID->279436623],
Cell[CellGroupData[{
Cell[21512, 552, 109, 3, 28, "Input",
 CellID->217641976],
Cell[21624, 557, 175, 5, 36, "Output",
 CellID->85992639]
}, Open  ]],
Cell[21814, 565, 630, 13, 40, "HowToText",
 CellID->4951644],
Cell[CellGroupData[{
Cell[22469, 582, 166, 5, 28, "Input",
 CellID->163041784],
Cell[22638, 589, 176, 5, 36, "Output",
 CellID->116151760]
}, Open  ]],
Cell[22829, 597, 506, 9, 38, "HowToText",
 CellID->460967059],
Cell[CellGroupData[{
Cell[23360, 610, 230, 7, 47, "Input",
 CellID->289995683],
Cell[23593, 619, 226, 7, 36, "Output",
 CellID->450189499]
}, Open  ]],
Cell[23834, 629, 1167, 25, 58, "HowToText",
 CellID->18816112],
Cell[CellGroupData[{
Cell[25026, 658, 101, 3, 28, "Input",
 CellID->499609852],
Cell[25130, 663, 168, 5, 36, "Output",
 CellID->836593827]
}, Open  ]],
Cell[CellGroupData[{
Cell[25335, 673, 101, 3, 28, "Input",
 CellID->23374448],
Cell[25439, 678, 184, 5, 36, "Output",
 CellID->2117101369]
}, Open  ]],
Cell[25638, 686, 1937, 39, 98, "HowToText",
 CellID->674362101],
Cell[CellGroupData[{
Cell[27600, 729, 238, 7, 28, "Input",
 CellID->840451682],
Cell[27841, 738, 272, 9, 36, "Output",
 CellID->760616613]
}, Open  ]],
Cell[28128, 750, 892, 14, 58, "HowToText",
 CellID->295243252],
Cell[CellGroupData[{
Cell[29045, 768, 238, 7, 28, "Input",
 CellID->688956937],
Cell[29286, 777, 273, 9, 36, "Output",
 CellID->841595091]
}, Open  ]],
Cell[29574, 789, 859, 13, 56, "HowToText",
 CellID->73881109],
Cell[CellGroupData[{
Cell[30458, 806, 162, 5, 30, "Input",
 CellID->731903681],
Cell[30623, 813, 194, 6, 36, "Output",
 CellID->53552176]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[30866, 825, 66, 2, 15, "HowToDelimiter",
 CellID->273356048],
Cell[30935, 829, 1407, 23, 76, "HowToText",
 CellID->360798399],
Cell[32345, 854, 944, 17, 58, "HowToText",
 CellID->59069615],
Cell[CellGroupData[{
Cell[33314, 875, 156, 5, 44, "Input",
 CellID->32781402],
Cell[33473, 882, 180, 5, 50, "Output",
 CellID->103178974]
}, Open  ]],
Cell[33668, 890, 1140, 17, 74, "HowToText",
 CellID->507341218],
Cell[CellGroupData[{
Cell[34833, 911, 161, 5, 44, "Input",
 CellID->22701373],
Cell[34997, 918, 182, 5, 36, "Output",
 CellID->300458961]
}, Open  ]],
Cell[35194, 926, 988, 23, 58, "HowToText",
 CellID->34597867],
Cell[CellGroupData[{
Cell[36207, 953, 188, 6, 44, "Input",
 CellID->550764148],
Cell[36398, 961, 215, 6, 36, "Output",
 CellID->723010979]
}, Open  ]],
Cell[36628, 970, 1329, 25, 78, "HowToText",
 CellID->398920349],
Cell[CellGroupData[{
Cell[37982, 999, 283, 9, 47, "Input",
 CellID->7653986],
Cell[38268, 1010, 230, 7, 36, "Output",
 CellID->480830627]
}, Open  ]],
Cell[38513, 1020, 1114, 19, 58, "HowToText",
 CellID->488573772],
Cell[CellGroupData[{
Cell[39652, 1043, 280, 9, 47, "Input",
 CellID->259857588],
Cell[39935, 1054, 224, 7, 36, "Output",
 CellID->264441550]
}, Open  ]],
Cell[40174, 1064, 1820, 34, 95, "HowToText",
 CellID->794400130],
Cell[CellGroupData[{
Cell[42019, 1102, 136, 4, 28, "Input",
 CellID->253756534],
Cell[42158, 1108, 167, 5, 36, "Output",
 CellID->155025007]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[42374, 1119, 65, 2, 15, "HowToDelimiter",
 CellID->30574310],
Cell[42442, 1123, 1870, 32, 94, "HowToText",
 CellID->20482469],
Cell[44315, 1157, 369, 7, 38, "HowToText",
 CellID->152778577],
Cell[CellGroupData[{
Cell[44709, 1168, 102, 3, 28, "Input",
 CellID->456380146],
Cell[44814, 1173, 164, 5, 36, "Output",
 CellID->8175660]
}, Open  ]],
Cell[44993, 1181, 910, 19, 58, "HowToText",
 CellID->407950852],
Cell[CellGroupData[{
Cell[45928, 1204, 107, 3, 28, "Input",
 CellID->278947095],
Cell[46038, 1209, 177, 5, 36, "Output",
 CellID->96745192]
}, Open  ]],
Cell[46230, 1217, 1072, 16, 74, "HowToText",
 CellID->812217608],
Cell[47305, 1235, 1087, 22, 58, "HowToText",
 CellID->160808516],
Cell[CellGroupData[{
Cell[48417, 1261, 237, 8, 36, "Input",
 CellID->832173913],
Cell[48657, 1271, 266, 9, 36, "Output",
 CellID->701346208]
}, Open  ]],
Cell[48938, 1283, 726, 11, 56, "HowToText",
 CellID->110544337],
Cell[CellGroupData[{
Cell[49689, 1298, 134, 4, 44, "Input",
 CellID->205003966],
Cell[49826, 1304, 239, 6, 36, "Output",
 CellID->69386310]
}, Open  ]],
Cell[CellGroupData[{
Cell[50102, 1315, 107, 3, 28, "Input",
 CellID->243014452],
Cell[50212, 1320, 176, 5, 36, "Output",
 CellID->61605454]
}, Open  ]],
Cell[50403, 1328, 1023, 15, 56, "HowToText",
 CellID->31644728],
Cell[CellGroupData[{
Cell[51451, 1347, 204, 7, 28, "Input",
 CellID->181972925],
Cell[51658, 1356, 225, 6, 36, "Output",
 CellID->277646496]
}, Open  ]],
Cell[CellGroupData[{
Cell[51920, 1367, 104, 3, 28, "Input",
 CellID->45031707],
Cell[52027, 1372, 176, 5, 36, "Output",
 CellID->291636354]
}, Open  ]],
Cell[52218, 1380, 2250, 41, 98, "HowToText",
 CellID->230352071],
Cell[54471, 1423, 598, 14, 48, "HowToText",
 CellID->124946305],
Cell[CellGroupData[{
Cell[55094, 1441, 264, 9, 28, "Input",
 CellID->748069994],
Cell[55361, 1452, 211, 5, 36, "Output",
 CellID->198944497]
}, Open  ]],
Cell[CellGroupData[{
Cell[55609, 1462, 107, 3, 28, "Input",
 CellID->687917947],
Cell[55719, 1467, 163, 5, 36, "Output",
 CellID->336588590]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[55931, 1478, 362, 13, 31, "TutorialsSection",
 CellID->250839057],
Cell[56296, 1493, 31, 0, 14, "SectionHeaderSpacer"],
Cell[56330, 1495, 171, 5, 19, "Tutorials",
 CellID->341631938],
Cell[56504, 1502, 194, 6, 19, "Tutorials",
 CellID->1526861278],
Cell[56701, 1510, 31, 0, 29, "SectionFooterSpacer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[56769, 1515, 329, 12, 31, "SeeAlsoSection",
 CellID->1255426704],
Cell[57101, 1529, 1054, 30, 58, "SeeAlso",
 CellID->929782353]
}, Open  ]],
Cell[CellGroupData[{
Cell[58192, 1564, 335, 12, 31, "MoreAboutSection",
 CellID->38303248],
Cell[58530, 1578, 31, 0, 14, "SectionHeaderSpacer"],
Cell[58564, 1580, 191, 6, 19, "MoreAbout",
 CellID->1665078683],
Cell[58758, 1588, 199, 6, 19, "MoreAbout",
 CellID->1002088036],
Cell[58960, 1596, 156, 4, 19, "MoreAbout",
 CellID->118337878]
}, Open  ]]
}, Open  ]],
Cell[59143, 1604, 23, 0, 41, "FooterCell"]
}
]
*)

(* End of internal cache information *)
