(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     54642,       1373]
NotebookOptionsPosition[     48322,       1185]
NotebookOutlinePosition[     50612,       1234]
CellTagsIndexPosition[     50569,       1231]
WindowTitle->Fit Models with Measurement Errors - Wolfram Mathematica
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[GridBox[{
   {Cell["MATHEMATICA HOW TO", "PacletNameCell"], Cell[TextData[{
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "Tutorials",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"Tutorials", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->False], {"\<\"Statistical Model Analysis\"\>":>
       Documentation`HelpLookup["paclet:tutorial/StatisticalModelAnalysis"]},
       Appearance->None,
       MenuAppearance->Automatic,
       MenuStyle->"Tutorials"]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "See Also",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"See Also", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->False], {"\<\"NonlinearModelFit\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/NonlinearModelFit"], "\<\"LinearModelFit\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/LinearModelFit"], "\<\"FittedModel\"\>":>
       Documentation`HelpLookup["paclet:ref/FittedModel"], "\<\"Weights\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/Weights"], "\<\"VarianceEstimatorFunction\"\>":>
       Documentation`HelpLookup["paclet:ref/VarianceEstimatorFunction"]},
       Appearance->None,
       MenuAppearance->Automatic,
       MenuStyle->"SeeAlso"]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "Related Guides",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"Related Guides", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->False], {"\<\"Statistics\"\>":>Documentation`HelpLookup[
       "paclet:guide/Statistics"], "\<\"Statistical Model Analysis\"\>":>
       Documentation`HelpLookup[
       "paclet:guide/StatisticalModelAnalysis"], "\<\"\\\"How to\\\" Topics\"\
\>":>Documentation`HelpLookup["paclet:guide/HowToTopics"]},
       Appearance->None,
       MenuAppearance->Automatic,
       MenuStyle->"MoreAbout"]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "URL",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"URL", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->False], {"\<\"howto/FitModelsWithMeasurementErrors\"\>":>
       None, "\<\"Copy Mathematica URL\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell["howto/FitModelsWithMeasurementErrors"]}, Visible -> 
            False]]; SelectionMove[
         DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; Null], 
       Delimiter, "\<\"Copy web URL\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell[
              BoxData[
               MakeBoxes[
                Hyperlink[
                "http://reference.wolfram.com/mathematica/howto/\
FitModelsWithMeasurementErrors.html"], StandardForm]], "Input", 
              TextClipboardType -> "PlainText"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; 
        Null], "\<\"Go to web URL\"\>":>FrontEndExecute[{
         NotebookLocate[{
           URL[
            StringJoin[
            "http://reference.wolfram.com/mathematica/", 
             "howto/FitModelsWithMeasurementErrors", ".html"]], None}]}]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}]
    }], "AnchorBar"]}
  }]], "AnchorBarGrid",
 CellID->1],

Cell[CellGroupData[{

Cell[TextData[{
 Cell["\:041a\:0440\:0430\:0442\:043a\:0438\:0439 \:043a\:0443\:0440\:0441 ", 
  "HowToTitlePrefix"],
 " ",
 "\:041f\:043e\:0434\:0431\:043e\:0440 \:043c\:043e\:0434\:0435\:043b\:0438 \
\:0441 \:0443\:0447\:0435\:0442\:043e\:043c \:043f\:043e\:0433\:0440\:0435\
\:0448\:043d\:043e\:0441\:0442\:0438 \:0438\:0437\:043c\:0435\:0440\:0435\
\:043d\:0438\:0439"
}], "HowToTitle",
 CellID->509267359],

Cell[CellGroupData[{

Cell[TextData[{
 "\:041f\:0440\:0438 \:0440\:0435\:0448\:0435\:043d\:0438\:0438 \:0437\:0430\
\:0434\:0430\:0447 \:0432 \:043e\:0431\:043b\:0430\:0441\:0442\:0438 \:0444\
\:0438\:0437\:0438\:043a\:0438, \:0445\:0430\:0440\:0430\:043a\:0442\:0435\
\:0440\:043d\:044b\:043c \:044f\:0432\:043b\:044f\:0435\:0442\:0441\:044f \
\:0438\:0441\:043f\:043e\:043b\:044c\:0437\:043e\:0432\:0430\:043d\:0438\:0435\
 \:043f\:043e\:0433\:0440\:0435\:0448\:043d\:043e\:0441\:0442\:0438 \:0438\
\:0437\:043c\:0435\:0440\:0435\:043d\:0438\:0439 \:0432 \:043a\:0430\:0447\
\:0435\:0441\:0442\:0432\:0435 \:0432\:0435\:0441\:043e\:0432, \:0434\:043b\
\:044f \:0432\:043a\:043b\:044e\:0447\:0435\:043d\:0438\:044f \:0438\:0437\
\:043c\:0435\:0440\:0435\:043d\:043d\:043e\:0433\:043e \:043e\:0442\:043a\
\:043b\:043e\:043d\:0435\:043d\:0438\:044f \:0432 \:043f\:043e\:0434\:0431\
\:043e\:0440 \:0444\:0443\:043d\:043a\:0446\:0438\:0438 \:043f\:043e \:0442\
\:043e\:0447\:043a\:0430\:043c.  \:0412\:0435\:0441\:0430 \:0434\:043e\:0432\
\:043e\:043b\:044c\:043d\:043e \:043e\:0442\:043d\:043e\:0441\:0438\:0442\
\:0435\:043b\:044c\:043d\:043e \:0432\:043b\:0438\:044f\:044e\:0442 \:043d\
\:0430 \:043e\:0446\:0435\:043d\:043a\:0438 \:0441\:043e\:043e\:0442\:0432\
\:0435\:0442\:0441\:0442\:0432\:0443\:044e\:0449\:0438\:0445 \:0438\:043c \
\:043f\:0430\:0440\:0430\:043c\:0435\:0442\:0440\:043e\:0432, \:043e\:0434\
\:043d\:0430\:043a\:043e, \:0432\:043e \:0432\:0437\:0432\:0435\:0448\:0435\
\:043d\:043d\:043e\:0439 \:0440\:0435\:0433\:0440\:0435\:0441\:0441\:0438\
\:0438 \:0432\:0441\:0435 \:0436\:0435 \:0442\:0440\:0435\:0431\:0443\:0435\
\:0442\:0441\:044f \:043e\:043f\:0440\:0435\:0434\:0435\:043b\:044f\:0442\
\:044c \:0434\:0438\:0441\:043f\:0435\:0440\:0441\:0438\:044e \:043f\:043e\
\:0433\:0440\:0435\:0448\:043d\:043e\:0441\:0442\:0435\:0439, \:043a\:043e\
\:0442\:043e\:0440\:0430\:044f \:0432\:043b\:0438\:044f\:0435\:0442 \:043d\
\:0430 \:043e\:0431\:0449\:0443\:044e \:043e\:0446\:0435\:043d\:043a\:0443 \
\:043f\:043e\:0433\:0440\:0435\:0448\:043d\:043e\:0441\:0442\:0435\:0439 \
\:0440\:0435\:0437\:0443\:043b\:044c\:0442\:0430\:0442\:043e\:0432 \:0438\
\:0437\:043c\:0435\:0440\:0435\:043d\:0438\:0439. \:0414\:043b\:044f \:043f\
\:043e\:043b\:0443\:0447\:0435\:043d\:0438\:044f \:0436\:0435\:043b\:0430\
\:0435\:043c\:043e\:0433\:043e \:0440\:0435\:0437\:0443\:043b\:044c\:0442\
\:0430\:0442\:0430, \:043c\:043e\:0436\:043d\:043e \:0432\:043e\:0441\:043f\
\:043e\:043b\:044c\:0437\:043e\:0432\:0430\:0442\:044c\:0441\:044f \:0442\
\:0430\:043a\:0438\:043c\:0438 \:043e\:043f\:0446\:0438\:044f\:043c\:0438 \
\:0434\:043b\:044f \:0444\:0443\:043d\:043a\:0446\:0438\:0439 ",
 Cell[BoxData[
  ButtonBox["LinearModelFit",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/LinearModelFit"]], "InlineFormula"],
 " \:0438 ",
 Cell[BoxData[
  ButtonBox["NonlinearModelFit",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/NonlinearModelFit"]], "InlineFormula"],
 ", \:043a\:0430\:043a ",
 Cell[BoxData[
  ButtonBox["VarianceEstimatorFunction",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/VarianceEstimatorFunction"]], "InlineFormula"],
 " \:0438 ",
 Cell[BoxData[
  ButtonBox["Weights",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Weights"]], "InlineFormula"],
 ", \:0432 \:0441\:043b\:0443\:0447\:0430\:0435, \:043a\:043e\:0433\:0434\
\:0430 \:0432\:0435\:0441\:0430 \:0441\:043e\:043e\:0442\:043d\:043e\:0441\
\:044f\:0442\:0441\:044f \:0441 \:043f\:043e\:0433\:0440\:0435\:0448\:043d\
\:043e\:0441\:0442\:044f\:043c\:0438 \:0438\:0437\:043c\:0435\:0440\:0435\
\:043d\:0438\:0439."
}], "HowToAbstract",
 CellID->1045883471],

Cell["\<\
\:0417\:0430\:0434\:0430\:0434\:0438\:043c \:043d\:0430\:0431\:043e\:0440 \
\:0434\:0430\:043d\:043d\:044b\:0445, \:0433\:0434\:0435 \:043f\:0435\:0440\
\:0432\:044b\:0435 \:0434\:0432\:0430 \:044d\:043b\:0435\:043c\:0435\:043d\
\:0442\:0430 \:043a\:0430\:0436\:0434\:043e\:0439 \:0442\:043e\:0447\:043a\
\:0438 \:044f\:0432\:043b\:044f\:044e\:0442\:0441\:044f \:043f\:0440\:0435\
\:0434\:0438\:043a\:0442\:043e\:0440\:0430\:043c\:0438, \:0430 \:0442\:0440\
\:0435\:0442\:0438\:0439 \:044d\:043b\:0435\:043c\:0435\:043d\:0442 \:043f\
\:0440\:0435\:0434\:0441\:0442\:0430\:0432\:043b\:044f\:0435\:0442 \:0441\
\:043e\:0431\:043e\:0439 \:0438\:0437\:043c\:0435\:0440\:0435\:043d\:043d\
\:043e\:0435 \:0437\:043d\:0430\:0447\:0435\:043d\:0438\:0435:\
\>", "HowToText",
 CellID->1009846402],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.9", ",", "6.1", ",", "9.5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3.9", ",", "6.", ",", "9.7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3", ",", "2.8", ",", "6.6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.", ",", "2.2", ",", "5.9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.8", ",", "2.4", ",", "7.2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"9.", ",", "1.7", ",", "7."}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"7.9", ",", "8.", ",", "10.4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4.9", ",", "3.9", ",", "9."}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2.3", ",", "2.6", ",", "7.4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4.7", ",", "8.4", ",", "10."}], "}"}]}], "}"}]}], 
  ";"}]], "Input",
 CellLabel->"In[4]:=",
 CellID->827466675],

Cell[TextData[{
 "\:0417\:0430\:0434\:0430\:0434\:0438\:043c \:043f\:043e\:0433\:0440\:0435\
\:0448\:043d\:043e\:0441\:0442\:0438 \:0438\:0437\:043c\:0435\:0440\:0435\
\:043d\:0438\:0439 \:0434\:043b\:044f \:0438\:0437\:043c\:0435\:0440\:0435\
\:043d\:043d\:044b\:0445 \:0437\:043d\:0430\:0447\:0435\:043d\:0438\:0439 \
\:0432 \:043d\:0430\:0431\:043e\:0440\:0435 \:0434\:0430\:043d\:043d\:044b\
\:0445 ",
 Cell[BoxData["data"], "InlineFormula"],
 ":"
}], "HowToText",
 CellID->1389965763],

Cell[BoxData[
 RowBox[{
  RowBox[{"errors", "=", 
   RowBox[{"{", 
    RowBox[{
    ".4", ",", ".4", ",", ".2", ",", ".4", ",", ".1", ",", ".3", ",", ".1", 
     ",", ".2", ",", ".2", ",", ".2"}], "}"}]}], ";"}]], "Input",
 CellLabel->"In[5]:=",
 CellID->411630083],

Cell[TextData[{
 "\:041c\:043e\:0436\:043d\:043e \:0432\:043e\:0441\:043f\:043e\:043b\:044c\
\:0437\:043e\:0432\:0430\:0442\:044c\:0441\:044f \:0444\:0443\:043d\:043a\
\:0446\:0438\:0435\:0439 ",
 Cell[BoxData[
  ButtonBox["NonlinearModelFit",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/NonlinearModelFit"]], "InlineFormula"],
 " \:0434\:043b\:044f \:043f\:043e\:0434\:0431\:043e\:0440\:0430 \:043b\:043e\
\:0433\:0430\:0440\:0438\:0444\:043c\:0438\:0447\:0435\:0441\:043a\:043e\:0439\
 \:0444\:0443\:043d\:043a\:0446\:0438\:0438 \:043f\:0440\:0435\:0434\:0438\
\:043a\:0442\:043e\:0440\:043e\:0432 \:043f\:043e \:044d\:0442\:0438\:043c \
\:0434\:0430\:043d\:043d\:044b\:043c. \:0418\:0441\:043f\:043e\:043b\:044c\
\:0437\:043e\:0432\:0430\:043d\:0438\:0435 \:043e\:043f\:0446\:0438\:0438 ",
 Cell[BoxData[
  ButtonBox["Weights",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Weights"]], "InlineFormula"],
 " \:0432\:043a\:043b\:044e\:0447\:0430\:0435\:0442 \:0432 \:043f\:043e\:0434\
\:0431\:043e\:0440 \:043d\:043e\:0440\:043c\:0430\:043b\:044c\:043d\:043e \
\:0440\:0430\:0441\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\:043d\:0443\
\:044e \:0438\:0437\:043c\:0435\:043d\:0447\:0438\:0432\:043e\:0441\:0442\
\:044c, \:043e\:0441\:043d\:043e\:0432\:0430\:043d\:043d\:0443\:044e \:043d\
\:0430 \:043f\:043e\:0433\:0440\:0435\:0448\:043d\:043e\:0441\:0442\:044f\
\:0445 \:0438\:0437\:043c\:0435\:0440\:0435\:043d\:0438\:0439. \:041a\:0430\
\:0436\:0434\:0430\:044f \:0442\:043e\:0447\:043a\:0430 \:0434\:0430\:043d\
\:043d\:044b\:0445 \:0432\:0437\:0432\:0435\:0448\:0438\:0432\:0430\:0435\
\:0442\:0441\:044f \:043f\:043e \:0444\:043e\:0440\:043c\:0443\:043b\:0435 ",
 Cell[BoxData[
  FormBox[
   FractionBox["1", 
    RowBox[{"\[CapitalDelta]", "\[InvisibleSpace]", 
     SuperscriptBox["z", "2"]}]], TraditionalForm]], "InlineMath"],
 ", \:0433\:0434\:0435 ",
 Cell[BoxData[
  FormBox["\[CapitalDelta]z", TraditionalForm]], "InlineMath"],
 " \:044f\:0432\:043b\:044f\:0435\:0442\:0441\:044f \:043f\:043e\:0433\:0440\
\:0435\:0448\:043d\:043e\:0441\:0442\:044c\:044e \:0438\:0437\:043c\:0435\
\:0440\:0435\:043d\:0438\:044f \:0434\:043b\:044f \:0442\:0430\:043a\:043e\
\:0439 \:0442\:043e\:0447\:043a\:0438."
}], "HowToText",
 CellID->182412616],

Cell[TextData[{
 "\:041f\:0440\:0438 \:0438\:0441\:043f\:043e\:043b\:044c\:0437\:043e\:0432\
\:0430\:043d\:0438\:0438 \:043e\:043f\:0446\:0438\:0438 ",
 Cell[BoxData[
  ButtonBox["Weights",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Weights"]], "InlineFormula"],
 " \:043e\:0442\:0434\:0435\:043b\:044c\:043d\:043e, \:0433\:0440\:0430\:0434\
\:0430\:0446\:0438\:044f \:0434\:0438\:0441\:043f\:0435\:0440\:0441\:0438\
\:0438 \:043e\:0446\:0435\:043d\:0438\:0432\:0430\:0435\:0442\:0441\:044f \
\:0441 \:0438\:0441\:043f\:043e\:043b\:044c\:0437\:043e\:0432\:0430\:043d\
\:0438\:0435\:043c \:043c\:0435\:0442\:043e\:0434\:043e\:0432 \:043f\:043e \
\:0443\:043c\:043e\:043b\:0447\:0430\:043d\:0438\:044e. \:041f\:043e\:0433\
\:0440\:0435\:0448\:043d\:043e\:0441\:0442\:044c \:043e\:0446\:0435\:043d\
\:043a\:0438 \:0431\:0443\:0434\:0435\:0442 \:0437\:0430\:0432\:0438\:0441\
\:0435\:0442\:044c \:043a\:0430\:043a \:043e\:0442 \:0432\:0435\:0441\:043e\
\:0432, \:0442\:0430\:043a \:0438 \:043e\:0442 \:0433\:0440\:0430\:0434\:0430\
\:0446\:0438\:0438 \:043e\:0446\:0435\:043d\:043a\:0438 \:0434\:0438\:0441\
\:043f\:0435\:0440\:0441\:0438\:0438. \:041e\:0434\:043d\:0430\:043a\:043e, \
\:0435\:0441\:043b\:0438 \:0432\:0435\:0441\:0430 \:0431\:0435\:0440\:0443\
\:0442\:0441\:044f \:0438\:0437 \:043f\:043e\:0433\:0440\:0435\:0448\:043d\
\:043e\:0441\:0442\:0435\:0439 \:0438\:0437\:043c\:0435\:0440\:0435\:043d\
\:0438\:0439, \:0442\:043e \:0447\:0430\:0441\:0442\:043e \:043f\:0440\:0435\
\:0434\:043f\:043e\:0447\:0438\:0442\:0430\:044e\:0442, \:0447\:0442\:043e\
\:0431\:044b \:043e\:0446\:0435\:043d\:043a\:0430 \:043f\:043e\:0433\:0440\
\:0435\:0448\:043d\:043e\:0441\:0442\:0435\:0439 \:0437\:0430\:0432\:0438\
\:0441\:0435\:043b\:0430 \:0442\:043e\:043b\:044c\:043a\:043e \:043e\:0442 \
\:0432\:0435\:0441\:043e\:0432."
}], "HowToText",
 CellID->794171750],

Cell["\<\
\:041f\:043e\:0434\:0431\:0435\:0440\:0435\:043c \:043d\:0435\:043b\:0438\
\:043d\:0435\:0439\:043d\:0443\:044e \:043c\:043e\:0434\:0435\:043b\:044c \
\:0438 \:0432\:043a\:043b\:044e\:0447\:0438\:043c \:0432 \:043d\:0435\:0435 \
\:043f\:043e\:0433\:0440\:0435\:0448\:043d\:043e\:0441\:0442\:0438 \:043f\
\:0443\:0442\:0435\:043c \:0438\:0441\:043f\:043e\:043b\:044c\:0437\:043e\
\:0432\:0430\:043d\:0438\:044f \:0432\:0435\:0441\:043e\:0432, \:0441 \:043e\
\:0446\:0435\:043d\:043a\:043e\:0439 \:0433\:0440\:0430\:0434\:0430\:0446\
\:0438\:0438 \:0434\:0438\:0441\:043f\:0435\:0440\:0441\:0438\:0438 \:043c\
\:0435\:0442\:043e\:0434\:043e\:043c \:043f\:043e \:0443\:043c\:043e\:043b\
\:0447\:0430\:043d\:0438\:044e:\
\>", "HowToText",
 CellID->812217608],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"nlm", "=", 
  RowBox[{"NonlinearModelFit", "[", 
   RowBox[{"data", ",", 
    RowBox[{"a", " ", 
     RowBox[{"Log", "[", 
      RowBox[{
       RowBox[{"b", " ", "x"}], " ", "+", 
       RowBox[{"c", " ", "y"}]}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "y"}], "}"}], ",", 
    RowBox[{"Weights", "\[Rule]", 
     RowBox[{"1", "/", 
      RowBox[{"errors", "^", "2"}]}]}]}], "]"}]}]], "Input",
 CellLabel->"In[6]:=",
 CellID->1398028897],

Cell[BoxData[
 RowBox[{"FittedModel", "[", 
  PanelBox[
   TagBox[
    RowBox[{"2.688073796057137`", " ", 
     RowBox[{"Log", "[", 
      RowBox[{
       RowBox[{"0.9413442818034686`", " ", "x"}], "+", 
       RowBox[{"5.015412786003381`", " ", "y"}]}], "]"}]}],
    Short],
   FrameMargins->5], "]"}]], "Output",
 ImageSize->{293, 35},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[6]=",
 CellID->243951942]
}, Open  ]],

Cell[TextData[{
 "\:041c\:043e\:0436\:043d\:043e \:0432\:044b\:043f\:043e\:043b\:043d\:0438\
\:0442\:044c \:0438\:043d\:0444\:043e\:0440\:043c\:0430\:0446\:0438\:043e\
\:043d\:043d\:044b\:0439 \:0437\:0430\:043f\:0440\:043e\:0441 \:043f\:043e \
\:043e\:0431\:044a\:0435\:043a\:0442\:0443 \:0432\:044b\:0432\:043e\:0434\
\:0430 ",
 Cell[BoxData[
  ButtonBox["FittedModel",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/FittedModel"]], "InlineFormula"],
 " \:0434\:043b\:044f ",
 Cell[BoxData["nlm"], "InlineFormula"],
 ", \:0447\:0442\:043e\:0431\:044b \:0432\:044b\:0432\:0435\:0441\:0442\:0438 \
\:0441\:0432\:043e\:0439\:0441\:0442\:0432\:0430 \:0438 \:0434\:0438\:0430\
\:0433\:043d\:043e\:0441\:0442\:0438\:043a\:0443 \:0440\:0435\:0437\:0443\
\:043b\:044c\:0442\:0430\:0442\:043e\:0432 \:0432\:044b\:043f\:043e\:043b\
\:043d\:0435\:043d\:043d\:043e\:0433\:043e \:043f\:043e\:0434\:0431\:043e\
\:0440\:0430."
}], "HowToText",
 CellID->122558677],

Cell[TextData[{
 "\:0412\:043e\:0441\:043f\:043e\:043b\:044c\:0437\:0443\:0435\:043c\:0441\
\:044f \:0441\:0432\:043e\:0439\:0441\:0442\:0432\:0430\:043c\:0438 ",
 Cell[BoxData["\<\"BestFit\"\>"], "InlineFormula"],
 " \:0438 ",
 Cell[BoxData["\<\"ParameterTable\"\>"], "InlineFormula"],
 " \:0434\:043b\:044f \:0432\:044b\:0432\:043e\:0434\:0430 \:043f\:043e\:0434\
\:043e\:0431\:0440\:0430\:043d\:043d\:043e\:0439 \:0444\:0443\:043d\:043a\
\:0446\:0438\:0438 \:0438 \:0442\:0430\:0431\:043b\:0438\:0446\:044b \:0437\
\:043d\:0430\:0447\:0435\:043d\:0438\:0439 \:043f\:0430\:0440\:0430\:043c\
\:0435\:0442\:0440\:043e\:0432 \:043f\:043e\:0434\:0431\:043e\:0440\:0430 \
\:043c\:043e\:0434\:0435\:043b\:0438 ",
 Cell[BoxData["nlm"], "InlineFormula"],
 ":"
}], "HowToText",
 CellID->13002146],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"nlm", "[", 
  RowBox[{"{", 
   RowBox[{"\"\<BestFit\>\"", ",", "\"\<ParameterTable\>\""}], "}"}], 
  "]"}]], "Input",
 CellLabel->"In[7]:=",
 CellID->279856212],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"2.688073796057137`", " ", 
    RowBox[{"Log", "[", 
     RowBox[{
      RowBox[{"0.9413442818034686`", " ", "x"}], "+", 
      RowBox[{"5.015412786003381`", " ", "y"}]}], "]"}]}], ",", 
   StyleBox[
    TagBox[GridBox[{
       {"\<\"\"\>", "\<\"Estimate\"\>", "\<\"Standard Error\"\>", "\<\"t\
\[Hyphen]Statistic\"\>", "\<\"P\[Hyphen]Value\"\>"},
       {"a", "2.688073796057137`", "0.18962160853512947`", 
        "14.17598878536642`", "2.063585714681298`*^-6"},
       {"b", "0.9413442818034686`", "0.480592376651436`", 
        "1.958716632923636`", "0.09099158659087407`"},
       {"c", "5.015412786003381`", "1.1627983201650653`", 
        "4.3132267212868145`", "0.0035091930092611204`"}
      },
      AutoDelete->False,
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
      GridBoxDividers->{
       "ColumnsIndexed" -> {2 -> GrayLevel[0.7]}, 
        "RowsIndexed" -> {2 -> GrayLevel[0.7]}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
      GridBoxSpacings->{
       "ColumnsIndexed" -> {2 -> 1}, "RowsIndexed" -> {2 -> 0.75}}],
     "Grid"], "DialogStyle",
    StripOnInput->False]}], "}"}]], "Output",
 ImageSize->{545, 70},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[7]=",
 CellID->389881090]
}, Open  ]],

Cell["\<\
\:0414\:043b\:044f \:0442\:0430\:043a\:043e\:0433\:043e \:0432\:0437\:0432\
\:0435\:0448\:0435\:043d\:043d\:043e\:0433\:043e \:043f\:043e\:0434\:0431\
\:043e\:0440\:0430, \:0442\:0440\:0435\:0431\:0443\:0435\:0442\:0441\:044f \
\:043e\:0446\:0435\:043d\:0438\:0442\:044c \:043c\:0430\:0441\:0448\:0442\
\:0430\:0431 \:0434\:0438\:0441\:043f\:0435\:0440\:0441\:0438\:0438 \:0434\
\:043b\:044f \:043f\:043e\:043b\:0443\:0447\:0435\:043d\:0438\:044f \:0441\
\:0442\:0430\:043d\:0434\:0430\:0440\:0442\:043d\:044b\:0445 \:043e\:0448\
\:0438\:0431\:043e\:043a \:043e\:0446\:0435\:043d\:043e\:043a \:043f\:0430\
\:0440\:0430\:043c\:0435\:0442\:0440\:043e\:0432. \:0422\:0438\:043f\:0438\
\:0447\:043d\:0430\:044f \:043e\:0446\:0435\:043d\:043a\:0430, \:043f\:0440\
\:0438\:043c\:0435\:043d\:044f\:0435\:043c\:0430\:044f \:043b\:0438\:043d\
\:0435\:0439\:043d\:043e\:0439 \:0438 \:043d\:0435\:043b\:0438\:043d\:0435\
\:0439\:043d\:043e\:0439 \:043c\:043e\:0434\:0435\:043b\:044f\:043c\:0438 \
\:043f\:043e \:0443\:043c\:043e\:043b\:0447\:0430\:043d\:0438\:044e, \:0438\
\:0441\:043f\:043e\:043b\:044c\:0437\:0443\:0435\:0442 \:0432\:0437\:0432\
\:0435\:0448\:0435\:043d\:043d\:0443\:044e \:0441\:0443\:043c\:043c\:0443 \
\:043a\:0432\:0430\:0434\:0440\:0430\:0442\:043e\:0432. \
\>", "HowToText",
 CellID->28517667],

Cell["\<\
\:0412\:0430\:0436\:043d\:043e \:043e\:0442\:043c\:0435\:0442\:0438\:0442\
\:044c, \:0447\:0442\:043e \:0432\:0435\:0441\:0430 \:043d\:0435 \:043c\:0435\
\:043d\:044f\:044e\:0442 \:043e\:0446\:0435\:043d\:043a\:0443 \:043f\:043e\
\:0434\:0431\:043e\:0440\:0430 \:0438\:043b\:0438 \:043f\:043e\:0433\:0440\
\:0435\:0448\:043d\:043e\:0441\:0442\:0435\:0439. \:041d\:0430\:043f\:0440\
\:0438\:043c\:0435\:0440, \:0443\:043c\:043d\:043e\:0436\:0435\:043d\:0438\
\:0435 \:0432\:0441\:0435\:0445 \:0432\:0435\:0441\:043e\:0432 \:043d\:0430 \
\:043a\:043e\:043d\:0441\:0442\:0430\:043d\:0442\:0443 \:0443\:0432\:0435\
\:043b\:0438\:0447\:0438\:0432\:0430\:0435\:0442 \:043e\:0446\:0435\:043d\
\:0438\:0432\:0430\:0435\:043c\:0443\:044e \:0434\:0438\:0441\:043f\:0435\
\:0440\:0441\:0438\:044e, \:043e\:0434\:043d\:0430\:043a\:043e, \:043d\:0435 \
\:043c\:0435\:043d\:044f\:0435\:0442 \:043e\:0446\:0435\:043d\:043a\:0438 \
\:043f\:0430\:0440\:0430\:043c\:0435\:0442\:0440\:043e\:0432 \:0438\:043b\
\:0438 \:0441\:0442\:0430\:043d\:0434\:0430\:0440\:0442\:043d\:044b\:0435 \
\:043f\:043e\:0433\:0440\:0435\:0448\:043d\:043e\:0441\:0442\:0438.\
\>", "HowToText",
 CellID->1558340912],

Cell["\<\
\:0412\:044b\:043f\:043e\:043b\:043d\:0438\:043c \:043f\:043e\:0434\:0431\
\:043e\:0440 \:0442\:043e\:0439 \:0436\:0435 \:0441\:0430\:043c\:043e\:0439 \
\:043c\:043e\:0434\:0435\:043b\:0438 \:0441\:043e \:0432\:0441\:0435\:043c\
\:0438 \:0432\:0435\:0441\:0430\:043c\:0438, \:0443\:0432\:0435\:043b\:0438\
\:0447\:0435\:043d\:043d\:044b\:043c\:0438 \:0432 100 \:0440\:0430\:0437:\
\>", "HowToText",
 CellID->1663260],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"nlm100", "=", 
  RowBox[{"NonlinearModelFit", "[", 
   RowBox[{"data", ",", 
    RowBox[{"a", " ", 
     RowBox[{"Log", "[", 
      RowBox[{
       RowBox[{"b", " ", "x"}], " ", "+", 
       RowBox[{"c", " ", "y"}]}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "y"}], "}"}], ",", 
    RowBox[{"Weights", "\[Rule]", 
     RowBox[{"100", "/", 
      RowBox[{"errors", "^", "2"}]}]}]}], "]"}]}]], "Input",
 CellLabel->"In[8]:=",
 CellID->117412505],

Cell[BoxData[
 RowBox[{"FittedModel", "[", 
  PanelBox[
   TagBox[
    RowBox[{"2.6880737960571364`", " ", 
     RowBox[{"Log", "[", 
      RowBox[{
       RowBox[{"0.9413442818034689`", " ", "x"}], "+", 
       RowBox[{"5.015412786003383`", " ", "y"}]}], "]"}]}],
    Short],
   FrameMargins->5], "]"}]], "Output",
 ImageSize->{293, 35},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[8]=",
 CellID->467645152]
}, Open  ]],

Cell["\<\
\:041e\:0431\:0440\:0430\:0442\:0438\:0442\:0435 \:0432\:043d\:0438\:043c\
\:0430\:043d\:0438\:0435, \:0447\:0442\:043e \:043f\:043e\:0434\:043e\:0431\
\:0440\:0430\:043d\:043d\:0430\:044f \:0444\:0443\:043d\:043a\:0446\:0438\
\:044f, \:0430 \:0442\:0430\:043a\:0436\:0435 \:043e\:0446\:0435\:043d\:043a\
\:0438 \:043f\:043e\:0433\:0440\:0435\:0448\:043d\:043e\:0441\:0442\:0435\
\:0439 \:043e\:0441\:0442\:0430\:043b\:0438\:0441\:044c \:0442\:0430\:043a\
\:0438\:043c\:0438 \:0436\:0435, \:043a\:0430\:043a \:0438 \:043f\:0440\:0435\
\:0436\:0434\:0435:\
\>", "HowToText",
 CellID->158626265],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"nlm100", "[", 
  RowBox[{"{", 
   RowBox[{"\"\<BestFit\>\"", ",", "\"\<ParameterTable\>\""}], "}"}], 
  "]"}]], "Input",
 CellLabel->"In[9]:=",
 CellID->75142099],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"2.6880737960571364`", " ", 
    RowBox[{"Log", "[", 
     RowBox[{
      RowBox[{"0.9413442818034689`", " ", "x"}], "+", 
      RowBox[{"5.015412786003383`", " ", "y"}]}], "]"}]}], ",", 
   StyleBox[
    TagBox[GridBox[{
       {"\<\"\"\>", "\<\"Estimate\"\>", "\<\"Standard Error\"\>", "\<\"t\
\[Hyphen]Statistic\"\>", "\<\"P\[Hyphen]Value\"\>"},
       {"a", "2.6880737960571364`", "0.18962160853512983`", 
        "14.17598878536639`", "2.063585714681325`*^-6"},
       {"b", "0.9413442818034689`", "0.4805923766514368`", 
        "1.9587166329236334`", "0.09099158659087435`"},
       {"c", "5.015412786003383`", "1.162798320165068`", 
        "4.3132267212868065`", "0.0035091930092611546`"}
      },
      AutoDelete->False,
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
      GridBoxDividers->{
       "ColumnsIndexed" -> {2 -> GrayLevel[0.7]}, 
        "RowsIndexed" -> {2 -> GrayLevel[0.7]}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
      GridBoxSpacings->{
       "ColumnsIndexed" -> {2 -> 1}, "RowsIndexed" -> {2 -> 0.75}}],
     "Grid"], "DialogStyle",
    StripOnInput->False]}], "}"}]], "Output",
 ImageSize->{545, 70},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[9]=",
 CellID->170016190]
}, Open  ]],

Cell[TextData[{
 "\:0412\:043e\:0441\:043f\:043e\:043b\:044c\:0437\:0443\:0435\:043c\:0441\
\:044f \:0441\:0432\:043e\:0439\:0441\:0442\:0432\:043e\:043c ",
 Cell[BoxData["\<\"EstimatedVariance\"\>"], "InlineFormula"],
 " \:0434\:043b\:044f \:0442\:043e\:0433\:043e, \
\:0447\:0442\:043e\:0431\:044b \:0441\:0440\:0430\:0432\:043d\:0438\:0442\
\:044c \:043e\:0446\:0435\:043d\:043a\:0438 \:0434\:0438\:0441\:043f\:0435\
\:0440\:0441\:0438\:0438. \:042d\:0442\:043e \:0441\:0440\:0430\:0432\:043d\
\:0435\:043d\:0438\:0435 \:043f\:043e\:043a\:0430\:0437\:044b\:0432\:0430\
\:0435\:0442, \:0447\:0442\:043e \:043e\:0446\:0435\:043d\:043a\:0430 \:0443\
\:0432\:0435\:043b\:0438\:0447\:0438\:043b\:0430\:0441\:044c \:043d\:0430 \
\:0442\:043e\:0442 \:0436\:0435 \:043c\:043d\:043e\:0436\:0438\:0442\:0435\
\:043b\:044c (100), \:0447\:0442\:043e \:0438 \:0432\:0435\:0441\:0430:"
}], "HowToText",
 CellID->307405684],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"nlm", "[", "\"\<EstimatedVariance\>\"", "]"}], ",", 
   RowBox[{"nlm100", "[", "\"\<EstimatedVariance\>\"", "]"}]}], 
  "}"}]], "Input",
 CellLabel->"In[10]:=",
 CellID->257363350],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"3.7852822750896236`", ",", "378.52822750896263`"}], 
  "}"}]], "Output",
 ImageSize->{127, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[10]=",
 CellID->76314185]
}, Open  ]],

Cell["\<\
\:0412\:0435\:0441\:0430, \:0432 \:043f\:0440\:0438\:0432\:0435\:0434\:0435\
\:043d\:043d\:044b\:0445 \:0432\:044b\:0448\:0435 \:043f\:0440\:0438\:043c\
\:0435\:0440\:0430\:0445, \:044f\:0432\:043b\:044f\:044e\:0442\:0441\:044f \
\:043f\:0440\:043e\:0441\:0442\:043e \:0432\:0435\:0441\:0430\:043c\:0438. \
\:041e\:043d\:0438 \:0438\:043c\:0435\:044e\:0442 \:0434\:043e\:0441\:0442\
\:0430\:0442\:043e\:0447\:043d\:043e \:043e\:0442\:043d\:043e\:0441\:0438\
\:0442\:0435\:043b\:044c\:043d\:043e\:0435 \:0432\:043b\:0438\:044f\:043d\
\:0438\:0435 \:043d\:0430 \:043f\:043e\:0434\:0431\:043e\:0440, \:0432\:0435\
\:0434\:044c \:043e\:0446\:0435\:043d\:043a\:0438 \:0438 \:043e\:0448\:0438\
\:0431\:043a\:0438 \:043e\:0441\:0442\:0430\:044e\:0442\:0441\:044f \:0442\
\:0435\:043c\:0438 \:0436\:0435 \:0441\:0430\:043c\:044b\:043c\:0438. \
\>", "HowToText",
 CellID->375525489],

Cell[TextData[{
 "\:0414\:043b\:044f \:0442\:043e\:0433\:043e, \:0447\:0442\:043e\:0431\:044b \
\:043f\:0440\:0438\:043c\:0435\:043d\:044f\:0442\:044c \:0432\:0435\:0441\
\:0430, \:043f\:043e\:043b\:0443\:0447\:0435\:043d\:043d\:044b\:0435 \:0438\
\:0437 \:043f\:043e\:0433\:0440\:0435\:0448\:043d\:043e\:0441\:0442\:0435\
\:0439 \:0438\:0437\:043c\:0435\:0440\:0435\:043d\:0438\:0439, \:043c\:043e\
\:0436\:043d\:043e \:0432\:043e\:0441\:043f\:043e\:043b\:044c\:0437\:043e\
\:0432\:0430\:0442\:044c\:0441\:044f \:043e\:043f\:0446\:0438\:0435\:0439 ",
 Cell[BoxData[
  ButtonBox["VarianceEstimatorFunction",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/VarianceEstimatorFunction"]], "InlineFormula"],
 " \:0432 \:0434\:043e\:043f\:043e\:043b\:043d\:0435\:043d\:0438\:0435 \:043a \
\:043e\:043f\:0446\:0438\:0438 ",
 Cell[BoxData[
  ButtonBox["Weights",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Weights"]], "InlineFormula"],
 ". \:041e\:043f\:0446\:0438\:044f ",
 Cell[BoxData[
  ButtonBox["VarianceEstimatorFunction",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/VarianceEstimatorFunction"]], "InlineFormula"],
 " \:0447\:0435\:0442\:043a\:043e \:043e\:043f\:0440\:0435\:0434\:0435\:043b\
\:044f\:0435\:0442 \:0438\:0441\:043f\:043e\:043b\:044c\:0437\:0443\:0435\
\:043c\:0443\:044e \:043e\:0446\:0435\:043d\:043a\:0443 \:0433\:0440\:0430\
\:0434\:0430\:0446\:0438\:0438 \:0434\:0438\:0441\:043f\:0435\:0440\:0441\
\:0438\:0438. \:0414\:043b\:044f \:043f\:043e\:0433\:0440\:0435\:0448\:043d\
\:043e\:0441\:0442\:0435\:0439 \:0438\:0437\:043c\:0435\:0440\:0435\:043d\
\:0438\:044f \:043d\:0443\:0436\:043d\:043e, \:0447\:0442\:043e\:0431\:044b \
\:0441\:0442\:0430\:043d\:0434\:0430\:0440\:0442\:043d\:044b\:0435 \:043f\
\:043e\:0433\:0440\:0435\:0448\:043d\:043e\:0441\:0442\:0438 \:0431\:044b\
\:043b\:0438 \:0440\:0430\:0441\:0441\:0447\:0438\:0442\:0430\:043d\:044b \
\:0438\:0437 \:0432\:0435\:0441\:043e\:0432, \:0438 \:043f\:043e\:044d\:0442\
\:043e\:043c\:0443 \:043e\:0446\:0435\:043d\:043a\:0430 \:0434\:0438\:0441\
\:043f\:0435\:0440\:0441\:0438\:0438 \:0434\:043e\:043b\:0436\:043d\:0430 \
\:0431\:044b\:0442\:044c \:043a\:043e\:043d\:0441\:0442\:0430\:043d\:0442\
\:043e\:0439 1:"
}], "HowToText",
 CellID->361897506],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"nlmvar1", "=", 
  RowBox[{"NonlinearModelFit", "[", 
   RowBox[{"data", ",", 
    RowBox[{"a", " ", 
     RowBox[{"Log", "[", 
      RowBox[{
       RowBox[{"b", " ", "x"}], " ", "+", 
       RowBox[{"c", " ", "y"}]}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "y"}], "}"}], ",", 
    RowBox[{"Weights", "\[Rule]", 
     RowBox[{"1", "/", 
      RowBox[{"errors", "^", "2"}]}]}], ",", 
    RowBox[{"VarianceEstimatorFunction", "\[Rule]", 
     RowBox[{"(", 
      RowBox[{"1", "&"}], ")"}]}]}], "]"}]}]], "Input",
 CellLabel->"In[11]:=",
 CellID->408453449],

Cell[BoxData[
 RowBox[{"FittedModel", "[", 
  PanelBox[
   TagBox[
    RowBox[{"2.688073796057137`", " ", 
     RowBox[{"Log", "[", 
      RowBox[{
       RowBox[{"0.9413442818034686`", " ", "x"}], "+", 
       RowBox[{"5.015412786003381`", " ", "y"}]}], "]"}]}],
    Short],
   FrameMargins->5], "]"}]], "Output",
 ImageSize->{293, 35},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[11]=",
 CellID->166473203]
}, Open  ]],

Cell["\<\
\:0412\:044b\:0432\:0435\:0434\:0435\:043c \:043d\:0430\:0438\:043b\:0443\
\:0447\:0448\:0435 \:043f\:043e\:0434\:043e\:0431\:0440\:0430\:043d\:043d\
\:0443\:044e \:0444\:0443\:043d\:043a\:0446\:0438\:044e \:0438 \:0442\:0430\
\:0431\:043b\:0438\:0446\:0443 \:043f\:0430\:0440\:0430\:043c\:0435\:0442\
\:0440\:043e\:0432 \:0434\:043b\:044f \:044d\:0442\:043e\:0439 \:043c\:043e\
\:0434\:0435\:043b\:0438:\
\>", "HowToText",
 CellID->93150997],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"nlmvar1", "[", 
  RowBox[{"{", 
   RowBox[{"\"\<BestFit\>\"", ",", "\"\<ParameterTable\>\""}], "}"}], 
  "]"}]], "Input",
 CellLabel->"In[12]:=",
 CellID->230119046],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"2.688073796057137`", " ", 
    RowBox[{"Log", "[", 
     RowBox[{
      RowBox[{"0.9413442818034686`", " ", "x"}], "+", 
      RowBox[{"5.015412786003381`", " ", "y"}]}], "]"}]}], ",", 
   StyleBox[
    TagBox[GridBox[{
       {"\<\"\"\>", "\<\"Estimate\"\>", "\<\"Standard Error\"\>", "\<\"t\
\[Hyphen]Statistic\"\>", "\<\"P\[Hyphen]Value\"\>"},
       {"a", "2.688073796057137`", "0.09746275662424872`", 
        "27.580522952172934`", "2.114364962896086`*^-8"},
       {"b", "0.9413442818034686`", "0.24701751136327157`", 
        "3.810840278522192`", "0.0066206638847333766`"},
       {"c", "5.015412786003381`", "0.5976614720064326`", 
        "8.391728463215044`", "0.00006708864103226711`"}
      },
      AutoDelete->False,
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
      GridBoxDividers->{
       "ColumnsIndexed" -> {2 -> GrayLevel[0.7]}, 
        "RowsIndexed" -> {2 -> GrayLevel[0.7]}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
      GridBoxSpacings->{
       "ColumnsIndexed" -> {2 -> 1}, "RowsIndexed" -> {2 -> 0.75}}],
     "Grid"], "DialogStyle",
    StripOnInput->False]}], "}"}]], "Output",
 ImageSize->{545, 70},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[12]=",
 CellID->237658634]
}, Open  ]],

Cell[TextData[{
 "\:0421\:0440\:0430\:0432\:043d\:0435\:043d\:0438\:0435 \:0442\:0430\:0431\
\:043b\:0438\:0446 \:043f\:0430\:0440\:0430\:043c\:0435\:0442\:0440\:043e\
\:0432 \:0434\:043b\:044f ",
 Cell[BoxData["nlmvar1"], "InlineFormula"],
 " \:0438 ",
 Cell[BoxData["nlm"], "InlineFormula"],
 " \:043f\:043e\:043a\:0430\:0437\:044b\:0432\:0430\:0435\:0442, \:0447\:0442\
\:043e \:043e\:0446\:0435\:043d\:043a\:0438 \:043f\:0430\:0440\:0430\:043c\
\:0435\:0442\:0440\:043e\:0432 \:044d\:043a\:0432\:0438\:0432\:0430\:043b\
\:0435\:043d\:0442\:043d\:044b, \:043d\:043e \:0441\:0442\:0430\:043d\:0434\
\:0430\:0440\:0442\:043d\:044b\:0435 \:043f\:043e\:0433\:0440\:0435\:0448\
\:043d\:043e\:0441\:0442\:0438 \:0438 \:0441\:0432\:044f\:0437\:0430\:043d\
\:043d\:044b\:0435 \:0441 \:043d\:0438\:043c\:0438 \:0440\:0435\:0437\:0443\
\:043b\:044c\:0442\:0430\:0442\:044b \:043f\:0440\:0435\:0442\:0435\:0440\
\:043f\:0435\:043b\:0438 \:0438\:0437\:043c\:0435\:043d\:0435\:043d\:0438\
\:044f:"
}], "HowToText",
 CellID->377971093],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"nlm", "[", "\"\<ParameterTable\>\"", "]"}], ",", 
   RowBox[{"nlmvar1", "[", "\"\<ParameterTable\>\"", "]"}]}], "}"}]], "Input",
 CellLabel->"In[13]:=",
 CellID->488702275],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   StyleBox[
    TagBox[GridBox[{
       {"\<\"\"\>", "\<\"Estimate\"\>", "\<\"Standard Error\"\>", "\<\"t\
\[Hyphen]Statistic\"\>", "\<\"P\[Hyphen]Value\"\>"},
       {"a", "2.688073796057137`", "0.18962160853512947`", 
        "14.17598878536642`", "2.063585714681298`*^-6"},
       {"b", "0.9413442818034686`", "0.480592376651436`", 
        "1.958716632923636`", "0.09099158659087407`"},
       {"c", "5.015412786003381`", "1.1627983201650653`", 
        "4.3132267212868145`", "0.0035091930092611204`"}
      },
      AutoDelete->False,
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
      GridBoxDividers->{
       "ColumnsIndexed" -> {2 -> GrayLevel[0.7]}, 
        "RowsIndexed" -> {2 -> GrayLevel[0.7]}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
      GridBoxSpacings->{
       "ColumnsIndexed" -> {2 -> 1}, "RowsIndexed" -> {2 -> 0.75}}],
     "Grid"], "DialogStyle",
    StripOnInput->False], ",", 
   StyleBox[
    TagBox[GridBox[{
       {"\<\"\"\>", "\<\"Estimate\"\>", "\<\"Standard Error\"\>", "\<\"t\
\[Hyphen]Statistic\"\>", "\<\"P\[Hyphen]Value\"\>"},
       {"a", "2.688073796057137`", "0.09746275662424872`", 
        "27.580522952172934`", "2.114364962896086`*^-8"},
       {"b", "0.9413442818034686`", "0.24701751136327157`", 
        "3.810840278522192`", "0.0066206638847333766`"},
       {"c", "5.015412786003381`", "0.5976614720064326`", 
        "8.391728463215044`", "0.00006708864103226711`"}
      },
      AutoDelete->False,
      GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
      GridBoxDividers->{
       "ColumnsIndexed" -> {2 -> GrayLevel[0.7]}, 
        "RowsIndexed" -> {2 -> GrayLevel[0.7]}},
      GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
      GridBoxSpacings->{
       "ColumnsIndexed" -> {2 -> 1}, "RowsIndexed" -> {2 -> 0.75}}],
     "Grid"], "DialogStyle",
    StripOnInput->False]}], "}"}]], "Output",
 ImageSize->{312, 144},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[13]=",
 CellID->758581267]
}, Open  ]],

Cell[TextData[{
 "\:0420\:0435\:0437\:0443\:043b\:044c\:0442\:0430\:0442\:044b, \:043f\:043e\
\:043b\:0443\:0447\:0435\:043d\:043d\:044b\:0435 \:0434\:043b\:044f ",
 Cell[BoxData["nlmvar1"], "InlineFormula"],
 " \:0432\:043a\:043b\:044e\:0447\:0430\:044e\:0442 \:0432 \:0441\:0435\:0431\
\:044f \:0432\:0435\:0441\:0430 \:0438 \:043e\:0446\:0435\:043d\:043a\:0443 \
\:0434\:0438\:0441\:043f\:0435\:0440\:0441\:0438\:0438 \:0441\:043e\:043e\
\:0442\:0432\:0435\:0442\:0441\:0442\:0432\:0443\:044e\:0449\:0443\:044e \
\:0432\:0435\:0441\:0430\:043c, \:043f\:043e\:043b\:0443\:0447\:0435\:043d\
\:043d\:044b\:043c \:0438\:0437 \:043f\:043e\:0433\:0440\:0435\:0448\:043d\
\:043e\:0441\:0442\:0435\:0439 \:0438\:0437\:043c\:0435\:0440\:0435\:043d\
\:0438\:044f. \:041d\:0435\:0441\:043c\:043e\:0442\:0440\:044f \:043d\:0430 \
\:0442\:043e, \:0447\:0442\:043e \:0432\:0435\:0441\:0430 \:043e\:043a\:0430\
\:0437\:044b\:0432\:0430\:044e\:0442 \:0432\:043b\:0438\:044f\:043d\:0438\
\:0435 \:043d\:0430 \:043e\:0446\:0435\:043d\:043a\:0438 \:043f\:0430\:0440\
\:0430\:043c\:0435\:0442\:0440\:043e\:0432, \:0434\:0438\:0441\:043f\:0435\
\:0440\:0441\:0438\:044f \:043e\:0446\:0435\:043d\:043a\:0438 \:0441\:0430\
\:043c\:0430 \:043f\:043e \:0441\:0435\:0431\:0435 \:043d\:0430 \:043d\:0438\
\:0445 \:043d\:0435 \:0432\:043b\:0438\:044f\:0435\:0442. \:041c\:043e\:0436\
\:043d\:043e \:043d\:0435 \:043f\:0440\:0438\:043d\:0438\:043c\:0430\:0442\
\:044c \:0432\:043e \:0432\:043d\:0438\:043c\:0430\:043d\:0438\:0435 \:043e\
\:0446\:0435\:043d\:043a\:0443 \:043f\:0430\:0440\:0430\:043c\:0435\:0442\
\:0440\:043e\:0432 \:0432\:043e \:0432\:0440\:0435\:043c\:044f \:0432\:044b\
\:043f\:043e\:043b\:043d\:0435\:043d\:0438\:044f \:043f\:043e\:0434\:0431\
\:043e\:0440\:0430 \:043f\:043e \:0442\:043e\:0447\:043a\:0430\:043c, \:0447\
\:0442\:043e\:0431\:044b \:043f\:043e\:043b\:0443\:0447\:0438\:0442\:044c \
\:0440\:0435\:0437\:0443\:043b\:044c\:0442\:0430\:0442\:044b \:043f\:043e\
\:0433\:0440\:0435\:0448\:043d\:043e\:0441\:0442\:0435\:0439 \:0438\:0437\
\:043c\:0435\:0440\:0435\:043d\:0438\:044f \:0438\:0437 ",
 Cell[BoxData["nlm"], "InlineFormula"],
 "."
}], "HowToText",
 CellID->303594522],

Cell["\<\
\:041f\:043e\:043b\:0443\:0447\:0438\:043c \:0442\:0430\:043a\:0443\:044e \
\:0436\:0435 \:0441\:0430\:043c\:0443\:044e \:0442\:0430\:0431\:043b\:0438\
\:0446\:0443 \:043f\:0430\:0440\:0430\:043c\:0435\:0442\:0440\:043e\:0432  \
\:0434\:043b\:044f \:043f\:043e\:0434\:0431\:043e\:0440\:0430 \:043f\:043e \
\:0442\:043e\:0447\:043a\:0430\:043c \:0441 \:043f\:043e\:0433\:0440\:0435\
\:0448\:043d\:043e\:0441\:0442\:044f\:043c\:0438 \:0438\:0437\:043c\:0435\
\:0440\:0435\:043d\:0438\:0439 \:0438\:0437 \:043f\:0435\:0440\:0432\:043e\
\:0433\:043e \:043f\:0440\:0438\:043c\:0435\:0440\:0430:\
\>", "HowToText",
 CellID->385655951],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"nlm", "[", 
  RowBox[{"\"\<ParameterTable\>\"", ",", 
   RowBox[{"VarianceEstimatorFunction", "\[Rule]", 
    RowBox[{"(", 
     RowBox[{"1", "&"}], ")"}]}]}], "]"}]], "Input",
 CellLabel->"In[14]:=",
 CellID->83382210],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\"\>", "\<\"Estimate\"\>", "\<\"Standard Error\"\>", "\<\"t\
\[Hyphen]Statistic\"\>", "\<\"P\[Hyphen]Value\"\>"},
     {"a", "2.688073796057137`", "0.09746275662424872`", 
      "27.580522952172934`", "2.114364962896086`*^-8"},
     {"b", "0.9413442818034686`", "0.24701751136327157`", 
      "3.810840278522192`", "0.0066206638847333766`"},
     {"c", "5.015412786003381`", "0.5976614720064326`", "8.391728463215044`", 
      "0.00006708864103226711`"}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxDividers->{
     "ColumnsIndexed" -> {2 -> GrayLevel[0.7]}, 
      "RowsIndexed" -> {2 -> GrayLevel[0.7]}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{
     "ColumnsIndexed" -> {2 -> 1}, "RowsIndexed" -> {2 -> 0.75}}],
   "Grid"], "DialogStyle",
  StripOnInput->False]], "Output",
 ImageSize->{292, 70},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[14]=",
 CellID->659313933]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  InterpretationBox[
   StyleBox[
    GraphicsBox[{},
     BaselinePosition->Baseline,
     ImageSize->{6, 0}],
    CacheGraphics->False],
   Spacer[6]]]],
 "\:0423\:0447\:0435\:0431\:043d\:044b\:0435 \:043c\:0430\:0442\:0435\:0440\
\:0438\:0430\:043b\:044b"
}], "TutorialsSection",
 WholeCellGroupOpener->True,
 CellID->250839057],

Cell["", "SectionHeaderSpacer"],

Cell[BoxData[
 TemplateBox[{
  Cell["Statistical Model Analysis"],
   "paclet:tutorial/StatisticalModelAnalysis"},
  "RefLink",
  BaseStyle->"Tutorials"]], "Tutorials",
 CellID->341631938],

Cell["", "SectionFooterSpacer"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  InterpretationBox[
   StyleBox[
    GraphicsBox[{},
     BaselinePosition->Baseline,
     ImageSize->{6, 0}],
    CacheGraphics->False],
   Spacer[6]]]],
 "\:0421\:043e\:043f\:0443\:0442\:0441\:0442\:0432\:0443\:044e\:0449\:0438\
\:0435 \:0440\:0430\:0437\:0434\:0435\:043b\:044b \:043a\:0440\:0430\:0442\
\:043a\:043e\:0433\:043e \:043a\:0443\:0440\:0441\:0430"
}], "RelatedLinksSection",
 WholeCellGroupOpener->True,
 CellID->1584193535],

Cell["", "SectionHeaderSpacer"],

Cell[TextData[ButtonBox["\:041a\:0440\:0430\:0442\:043a\:0438\:0439 \:043a\
\:0443\:0440\:0441: \:0414\:0438\:0430\:0433\:043d\:043e\:0441\:0442\:0438\
\:043a\:0430 \:0440\:0435\:0437\:0443\:043b\:044c\:0442\:0430\:0442\:043e\
\:0432 \:0434\:043b\:044f \:043c\:043e\:0434\:0435\:043b\:0438, \:043d\:0430\
\:0439\:0434\:0435\:043d\:043d\:043e\:0439 \:043f\:0443\:0442\:0435\:043c \
\:043f\:043e\:0434\:0431\:043e\:0440\:0430",
 BaseStyle->"Hyperlink",
 ButtonData->{"GetResultsForFittedModelsRU.nb", None}]], "RelatedLinks",
 FontFamily->"Verdana",
 FontSize->11,
 CellID->405226890],

Cell[TextData[ButtonBox["\:041a\:0440\:0430\:0442\:043a\:0438\:0439 \:043a\
\:0443\:0440\:0441: \:0413\:0440\:0430\:0444\:0438\:0447\:0435\:0441\:043a\
\:0438\:0435 \:0438\:043d\:0441\:0442\:0440\:0443\:043c\:0435\:043d\:0442\
\:044b \:043f\:0440\:043e\:0432\:0435\:0440\:043a\:0438 \:043a\:043e\:0440\
\:0440\:0435\:043a\:0442\:043d\:043e\:0441\:0442\:0438 \:043f\:043e\:0434\
\:0431\:043e\:0440\:0430 \:043c\:043e\:0434\:0435\:043b\:0438 \:043f\:043e \
\:0442\:043e\:0447\:043a\:0430\:043c",
 BaseStyle->"Hyperlink",
 ButtonData->{"PlotDiagnosticsForFittedModelsRU.nb", None}]], "RelatedLinks",
 FontFamily->"Verdana",
 FontSize->11,
 CellID->48249342],

Cell[TextData[ButtonBox["\:041a\:0440\:0430\:0442\:043a\:0438\:0439 \:043a\
\:0443\:0440\:0441: \:0421\:0442\:0430\:0442\:0438\:0441\:0442\:0438\:0447\
\:0435\:0441\:043a\:0438\:0439 \:0430\:043d\:0430\:043b\:0438\:0437",
 BaseStyle->"Hyperlink",
 ButtonData->{"DoStatisticalAnalysisRU.nb", None}]], "RelatedLinks",
 FontFamily->"Verdana",
 FontSize->11,
 CellID->627519472],

Cell["", "SectionFooterSpacer"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  InterpretationBox[
   StyleBox[
    GraphicsBox[{},
     BaselinePosition->Baseline,
     ImageSize->{6, 0}],
    CacheGraphics->False],
   Spacer[6]]]],
 "\:0421\:043c\:043e\:0442\:0440\:0438 \:0442\:0430\:043a\:0436\:0435"
}], "SeeAlsoSection",
 WholeCellGroupOpener->True,
 CellID->1255426704],

Cell[TextData[{
 Cell[BoxData[
  TemplateBox[{Cell["NonlinearModelFit"],"paclet:ref/NonlinearModelFit"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  TemplateBox[{Cell["LinearModelFit"],"paclet:ref/LinearModelFit"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  TemplateBox[{Cell["FittedModel"],"paclet:ref/FittedModel"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  TemplateBox[{Cell["Weights"],"paclet:ref/Weights"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  TemplateBox[{
   Cell["VarianceEstimatorFunction"],"paclet:ref/VarianceEstimatorFunction"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"]
}], "SeeAlso",
 CellID->929782353]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  InterpretationBox[
   StyleBox[
    GraphicsBox[{},
     BaselinePosition->Baseline,
     ImageSize->{6, 0}],
    CacheGraphics->False],
   Spacer[6]]]],
 "\:0423\:0437\:043d\:0430\:0442\:044c \:0431\:043e\:043b\:044c\:0448\:0435"
}], "MoreAboutSection",
 WholeCellGroupOpener->True,
 CellID->38303248],

Cell["", "SectionHeaderSpacer"],

Cell[BoxData[
 TemplateBox[{Cell["Statistics"],"paclet:guide/Statistics"},
  "RefLink",
  BaseStyle->"MoreAbout"]], "MoreAbout",
 CellID->164248854],

Cell[BoxData[
 TemplateBox[{
  Cell["Statistical Model Analysis"],"paclet:guide/StatisticalModelAnalysis"},
  "RefLink",
  BaseStyle->"MoreAbout"]], "MoreAbout",
 CellID->54545674],

Cell[BoxData[
 TemplateBox[{Cell["\"How to\" Topics"],"paclet:guide/HowToTopics"},
  "RefLink",
  BaseStyle->"MoreAbout"]], "MoreAbout",
 CellID->1040501511]
}, Open  ]]
}, Open  ]],

Cell[" ", "FooterCell"]
},
FileChangeProtection->None,
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{Automatic, 510},
WindowMargins->{{312, Automatic}, {Automatic, 0}},
WindowFrame->"Normal",
WindowTitle->"Fit Models with Measurement Errors - Wolfram Mathematica",
DockedCells->FEPrivate`FrontEndResource["FEExpressions", "HelpViewerToolbar"],
TaggingRules->{
 "ModificationHighlight" -> False, "ColorType" -> "TutorialColor", 
  "LinkTrails" -> "", "ExampleCounter" -> 1, "ExamplePageLinks" -> {}, 
  "RootCaptions" -> "", 
  "Metadata" -> {
   "built" -> "{2013, 1, 24, 22, 47, 37.8678335}", 
    "history" -> {"8", "", "", ""}, "context" -> "System`", 
    "keywords" -> {
     "measurement errors", "experimental errors", "experiment errors", 
      "error estimates", "fitting with errors", "weighted fitting", 
      "weighted regression", "nonlinear fitting", "nonlinear regression", 
      "linear fitting", "linear regression", "statistical fitting"}, 
    "specialkeywords" -> {}, "tutorialcollectionlinks" -> {}, "index" -> True,
     "label" -> "Mathematica How To", "language" -> "en", "paclet" -> 
    "Mathematica", "status" -> "None", "summary" -> 
    "Particularly in the physical sciences, it is common to use measurement \
errors as weights to incorporate measured variation into the fitting. Weights \
have a relative effect on the parameter estimates, but an error variance \
still needs to be estimated in weighted regression, and this impacts error \
estimates for results. The VarianceEstimatorFunction and Weights options to \
LinearModelFit and NonlinearModelFit can be used to get the desired results \
when weights are from measurement errors.", "synonyms" -> {}, "title" -> 
    "Fit Models with Measurement Errors", "titlemodifier" -> "", 
    "windowtitle" -> "Fit Models with Measurement Errors", "type" -> "HowTo", 
    "uri" -> "howto/FitModelsWithMeasurementErrors"}, "SearchTextTranslated" -> 
  ""},
Magnification->1.,
FrontEndVersion->"10.1 for Microsoft Windows (64-bit) (March 23, 2015)",
StyleDefinitions->FrontEnd`FileName[{"Wolfram"}, "Reference.nb", 
  CharacterEncoding -> "WindowsANSI"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[627, 21, 4710, 115, 48, "AnchorBarGrid",
 CellID->1],
Cell[CellGroupData[{
Cell[5362, 140, 410, 9, 91, "HowToTitle",
 CellID->509267359],
Cell[CellGroupData[{
Cell[5797, 153, 3626, 61, 164, "HowToAbstract",
 CellID->1045883471],
Cell[9426, 216, 796, 12, 56, "HowToText",
 CellID->1009846402],
Cell[10225, 230, 930, 27, 65, "Input",
 CellID->827466675],
Cell[11158, 259, 489, 10, 40, "HowToText",
 CellID->1389965763],
Cell[11650, 271, 265, 8, 28, "Input",
 CellID->411630083],
Cell[11918, 281, 2261, 41, 126, "HowToText",
 CellID->182412616],
Cell[14182, 324, 1866, 29, 94, "HowToText",
 CellID->794171750],
Cell[16051, 355, 764, 12, 56, "HowToText",
 CellID->812217608],
Cell[CellGroupData[{
Cell[16840, 371, 549, 17, 47, "Input",
 CellID->1398028897],
Cell[17392, 390, 445, 15, 56, "Output",
 CellID->243951942]
}, Open  ]],
Cell[17852, 408, 952, 19, 58, "HowToText",
 CellID->122558677],
Cell[18807, 429, 789, 15, 60, "HowToText",
 CellID->13002146],
Cell[CellGroupData[{
Cell[19621, 448, 184, 6, 28, "Input",
 CellID->279856212],
Cell[19808, 456, 1356, 33, 91, "Output",
 CellID->389881090]
}, Open  ]],
Cell[21179, 492, 1318, 19, 74, "HowToText",
 CellID->28517667],
Cell[22500, 513, 1184, 17, 74, "HowToText",
 CellID->1558340912],
Cell[23687, 532, 426, 7, 38, "HowToText",
 CellID->1663260],
Cell[CellGroupData[{
Cell[24138, 543, 553, 17, 47, "Input",
 CellID->117412505],
Cell[24694, 562, 446, 15, 56, "Output",
 CellID->467645152]
}, Open  ]],
Cell[25155, 580, 603, 10, 56, "HowToText",
 CellID->158626265],
Cell[CellGroupData[{
Cell[25783, 594, 186, 6, 28, "Input",
 CellID->75142099],
Cell[25972, 602, 1359, 33, 91, "Output",
 CellID->170016190]
}, Open  ]],
Cell[27346, 638, 911, 14, 76, "HowToText",
 CellID->307405684],
Cell[CellGroupData[{
Cell[28282, 656, 232, 7, 28, "Input",
 CellID->257363350],
Cell[28517, 665, 243, 8, 36, "Output",
 CellID->76314185]
}, Open  ]],
Cell[28775, 676, 883, 13, 56, "HowToText",
 CellID->375525489],
Cell[29661, 691, 2245, 39, 114, "HowToText",
 CellID->361897506],
Cell[CellGroupData[{
Cell[31931, 734, 666, 20, 47, "Input",
 CellID->408453449],
Cell[32600, 756, 446, 15, 56, "Output",
 CellID->166473203]
}, Open  ]],
Cell[33061, 774, 452, 8, 38, "HowToText",
 CellID->93150997],
Cell[CellGroupData[{
Cell[33538, 786, 189, 6, 28, "Input",
 CellID->230119046],
Cell[33730, 794, 1362, 33, 91, "Output",
 CellID->237658634]
}, Open  ]],
Cell[35107, 830, 1024, 18, 76, "HowToText",
 CellID->377971093],
Cell[CellGroupData[{
Cell[36156, 852, 224, 6, 28, "Input",
 CellID->488702275],
Cell[36383, 860, 2139, 49, 165, "Output",
 CellID->758581267]
}, Open  ]],
Cell[38537, 912, 2183, 32, 114, "HowToText",
 CellID->303594522],
Cell[40723, 946, 638, 10, 56, "HowToText",
 CellID->385655951],
Cell[CellGroupData[{
Cell[41386, 960, 243, 7, 28, "Input",
 CellID->83382210],
Cell[41632, 969, 1089, 26, 91, "Output",
 CellID->659313933]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[42770, 1001, 362, 13, 30, "TutorialsSection",
 CellID->250839057],
Cell[43135, 1016, 31, 0, 14, "SectionHeaderSpacer"],
Cell[43169, 1018, 188, 6, 19, "Tutorials",
 CellID->341631938],
Cell[43360, 1026, 31, 0, 29, "SectionFooterSpacer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[43428, 1031, 472, 14, 30, "RelatedLinksSection",
 CellID->1584193535],
Cell[43903, 1047, 31, 0, 14, "SectionHeaderSpacer"],
Cell[43937, 1049, 582, 10, 18, "RelatedLinks",
 CellID->405226890],
Cell[44522, 1061, 654, 11, 18, "RelatedLinks",
 CellID->48249342],
Cell[45179, 1074, 374, 7, 18, "RelatedLinks",
 CellID->627519472],
Cell[45556, 1083, 31, 0, 29, "SectionFooterSpacer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[45624, 1088, 329, 12, 30, "SeeAlsoSection",
 CellID->1255426704],
Cell[45956, 1102, 1412, 39, 58, "SeeAlso",
 CellID->929782353]
}, Open  ]],
Cell[CellGroupData[{
Cell[47405, 1146, 335, 12, 30, "MoreAboutSection",
 CellID->38303248],
Cell[47743, 1160, 31, 0, 14, "SectionHeaderSpacer"],
Cell[47777, 1162, 148, 4, 19, "MoreAbout",
 CellID->164248854],
Cell[47928, 1168, 180, 5, 19, "MoreAbout",
 CellID->54545674],
Cell[48111, 1175, 157, 4, 19, "MoreAbout",
 CellID->1040501511]
}, Open  ]]
}, Open  ]],
Cell[48295, 1183, 23, 0, 41, "FooterCell"]
}
]
*)

(* End of internal cache information *)
