(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     84594,       2178]
NotebookOptionsPosition[     74254,       1866]
NotebookOutlinePosition[     77524,       1934]
CellTagsIndexPosition[     77444,       1929]
WindowTitle->Get Results for Fitted Models - Wolfram Mathematica
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[GridBox[{
   {Cell["MATHEMATICA HOW TO", "PacletNameCell"], Cell[TextData[{
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "Tutorials",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"Tutorials", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->False], {"\<\"Statistical Model Analysis\"\>":>
       Documentation`HelpLookup[
       "paclet:tutorial/StatisticalModelAnalysis"], "\<\"Plotting Lists of \
Data\"\>":>Documentation`HelpLookup[
       "paclet:tutorial/PlottingListsOfData"], "\<\"Options for Graphics\"\>":>
       Documentation`HelpLookup[
       "paclet:tutorial/Options"], "\<\"Basic Plotting\"\>":>
       Documentation`HelpLookup["paclet:tutorial/BasicPlotting"]},
       Appearance->None,
       MenuAppearance->Automatic,
       MenuStyle->"Tutorials"]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "See Also",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"See Also", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->False], {"\<\"LinearModelFit\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/LinearModelFit"], "\<\"FittedModel\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/FittedModel"], "\<\"NonlinearModelFit\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/NonlinearModelFit"], "\<\"GeneralizedLinearModelFit\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/GeneralizedLinearModelFit"], "\<\"Plot\"\>":>
       Documentation`HelpLookup["paclet:ref/Plot"], "\<\"ListPlot\"\>":>
       Documentation`HelpLookup["paclet:ref/ListPlot"], "\<\"Show\"\>":>
       Documentation`HelpLookup["paclet:ref/Show"]},
       Appearance->None,
       MenuAppearance->Automatic,
       MenuStyle->"SeeAlso"]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "Related Guides",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"Related Guides", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->False], {"\<\"Statistics\"\>":>Documentation`HelpLookup[
       "paclet:guide/Statistics"], "\<\"Statistical Model Analysis\"\>":>
       Documentation`HelpLookup[
       "paclet:guide/StatisticalModelAnalysis"], "\<\"Data Visualization\"\>":>
       Documentation`HelpLookup[
       "paclet:guide/DataVisualization"], "\<\"\\\"How to\\\" Topics\"\>":>
       Documentation`HelpLookup["paclet:guide/HowToTopics"]},
       Appearance->None,
       MenuAppearance->Automatic,
       MenuStyle->"MoreAbout"]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "URL",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"URL", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->False], {"\<\"howto/GetResultsForFittedModels\"\>":>
       None, "\<\"Copy Mathematica URL\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell["howto/GetResultsForFittedModels"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; Null], 
       Delimiter, "\<\"Copy web URL\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell[
              BoxData[
               MakeBoxes[
                Hyperlink[
                "http://reference.wolfram.com/mathematica/howto/\
GetResultsForFittedModels.html"], StandardForm]], "Input", TextClipboardType -> 
              "PlainText"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; 
        Null], "\<\"Go to web URL\"\>":>FrontEndExecute[{
         NotebookLocate[{
           URL[
            StringJoin[
            "http://reference.wolfram.com/mathematica/", 
             "howto/GetResultsForFittedModels", ".html"]], None}]}]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}]
    }], "AnchorBar"]}
  }]], "AnchorBarGrid",
 CellID->1],

Cell[CellGroupData[{

Cell[TextData[{
 Cell["\:041a\:0440\:0430\:0442\:043a\:0438\:0439 \:043a\:0443\:0440\:0441 ", 
  "HowToTitlePrefix"],
 " \:0414\:0438\:0430\:0433\:043d\:043e\:0441\:0442\:0438\:043a\:0430 \:0440\
\:0435\:0437\:0443\:043b\:044c\:0442\:0430\:0442\:043e\:0432 \:0434\:043b\
\:044f \:043c\:043e\:0434\:0435\:043b\:0438,  \:043d\:0430\:0439\:0434\:0435\
\:043d\:043d\:043e\:0439 \:043f\:0443\:0442\:0435\:043c \:043f\:043e\:0434\
\:0431\:043e\:0440\:0430"
}], "HowToTitle",
 CellID->509267359],

Cell[CellGroupData[{

Cell[TextData[{
 "\:041f\:0440\:0438 \:043f\:043e\:0434\:0431\:043e\:0440\:0435 \:043c\:043e\
\:0434\:0435\:043b\:0438 \:043f\:043e \:0442\:043e\:0447\:043a\:0430\:043c, \
\:0447\:0430\:0441\:0442\:043e \:0431\:044b\:0432\:0430\:0435\:0442 \:0432\
\:0430\:0436\:043d\:043e \:043f\:043e\:043b\:0443\:0447\:0438\:0442\:044c \
\:0434\:043e\:043f\:043e\:043b\:043d\:0438\:0442\:0435\:043b\:044c\:043d\:044b\
\:0435 \:0440\:0435\:0437\:0443\:043b\:044c\:0442\:0430\:0442\:044b, \:0434\
\:043b\:044f \:0441\:0440\:0430\:0432\:043d\:0435\:043d\:0438\:044f \:0434\
\:0430\:043d\:043d\:044b\:0445 \:0441 \:043f\:043e\:0434\:043e\:0431\:0440\
\:0430\:043d\:043e\:0439 \:0444\:0443\:043d\:043a\:0446\:0438\:0435\:0439. \
\:0412\:043e\:0437\:043d\:0438\:043a\:0430\:0435\:0442 \:043d\:0435\:043e\
\:0431\:0445\:043e\:0434\:0438\:043c\:043e\:0441\:0442\:044c \:0432 \:043f\
\:0440\:043e\:0432\:0435\:0440\:043a\:0435 \:0437\:043d\:0430\:0447\:0438\
\:043c\:043e\:0441\:0442\:0438 (\:0434\:043e\:0441\:0442\:043e\:0432\:0435\
\:0440\:043d\:043e\:0441\:0442\:0438) \:043f\:0430\:0440\:0430\:043c\:0435\
\:0442\:0440\:043e\:0432 \:0438 \:043e\:0446\:0435\:043d\:043a\:0435 \:043e\
\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\:0438\:044f \:043c\:043e\
\:0434\:0435\:043b\:0438, \:0432\:043b\:0438\:044f\:043d\:0438\:044f \:0442\
\:043e\:0447\:0435\:043a \:0434\:0430\:043d\:043d\:044b\:0445 \:0438 \:043a\
\:0430\:0447\:0435\:0441\:0442\:0432\:0430 \:043f\:043e\:0434\:0433\:043e\
\:043d\:043a\:0438 \:043c\:043e\:0434\:0435\:043b\:0438. \:0412 ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " \:043c\:043e\:0436\:043d\:043e \:043f\:043e\:043b\:0443\:0447\:0438\:0442\
\:044c \:044d\:0442\:0438 \:0440\:0435\:0437\:0443\:043b\:044c\:0442\:0430\
\:0442\:044b \:043f\:0440\:044f\:043c\:043e \:0438\:0437 \:043e\:0431\:044a\
\:0435\:043a\:0442\:043e\:0432 ",
 Cell[BoxData[
  ButtonBox["FittedModel",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/FittedModel"]], "InlineFormula"],
 ", \:043a\:043e\:0442\:043e\:0440\:044b\:0435 \:0432\:043e\:0437\:0432\:0440\
\:0430\:0449\:0430\:044e\:0442\:0441\:044f \:0444\:0443\:043d\:043a\:0446\
\:0438\:044f\:043c\:0438 \:043f\:043e\:0434\:0431\:043e\:0440\:0430 \:043c\
\:043e\:0434\:0435\:043b\:0438, \:0442\:0430\:043a\:0438\:043c\:0438 \:043a\
\:0430\:043a ",
 Cell[BoxData[
  ButtonBox["LinearModelFit",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/LinearModelFit"]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  ButtonBox["NonlinearModelFit",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/NonlinearModelFit"]], "InlineFormula"],
 " \:0438 ",
 Cell[BoxData[
  ButtonBox["GeneralizedLinearModelFit",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/GeneralizedLinearModelFit"]], "InlineFormula"],
 "."
}], "HowToAbstract",
 CellID->1045883471],

Cell["\:0414\:043b\:044f \:043d\:0430\:0447\:0430\:043b\:0430, \:0437\:0430\
\:0434\:0430\:0434\:0438\:043c \:043d\:0430\:0431\:043e\:0440 \:0434\:0430\
\:043d\:043d\:044b\:0445 \:0434\:043b\:044f \:043f\:043e\:0441\:043b\:0435\
\:0434\:0443\:044e\:0449\:0435\:0439 \:043e\:0431\:0440\:0430\:0431\:043e\
\:0442\:043a\:0438:", "HowToText",
 CellID->1009846402],

Cell[BoxData[
 RowBox[{
  RowBox[{"data1", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1.2", ",", "3.4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.7", ",", "4.2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2.8", ",", "6.5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4.3", ",", "11.2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4.8", ",", "13.8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5.9", ",", "19.9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"7.4", ",", "30."}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"7.7", ",", "31.5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"8.9", ",", "41.9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"10.2", ",", "54.3"}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellLabel->"In[11]:=",
 CellID->827466675],

Cell[TextData[{
 "\:0412\:044b\:043f\:043e\:043b\:043d\:0438\:043c \:043f\:043e\:0434\:0431\
\:043e\:0440 \:043f\:0440\:043e\:0441\:0442\:043e\:0439 \:043c\:043e\:0434\
\:0435\:043b\:0438 \:043b\:0438\:043d\:0435\:0439\:043d\:043e\:0439 \:0440\
\:0435\:0433\:0440\:0435\:0441\:0441\:0438\:0438, \:0432\:043e\:0441\:043f\
\:043e\:043b\:044c\:0437\:043e\:0432\:0430\:0432\:0448\:0438\:0441\:044c \
\:0444\:0443\:043d\:043a\:0446\:0438\:0435\:0439 ",
 Cell[BoxData[
  ButtonBox["LinearModelFit",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/LinearModelFit"]], "InlineFormula"],
 ":"
}], "HowToText",
 CellID->1389965763],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"lm", "=", 
  RowBox[{"LinearModelFit", "[", 
   RowBox[{"data1", ",", "x", ",", "x"}], "]"}]}]], "Input",
 CellLabel->"In[12]:=",
 CellID->411630083],

Cell[BoxData[
 RowBox[{"FittedModel", "[", 
  PanelBox[
   TagBox[
    RowBox[{
     RowBox[{"-", "8.435081567131478`"}], "+", 
     RowBox[{"5.483621414778047`", " ", "x"}]}],
    Short],
   FrameMargins->5], "]"}]], "Output",
 ImageSize->{219, 35},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[12]=",
 CellID->147115952]
}, Open  ]],

Cell[TextData[{
 "\:0412\:044b\:0432\:043e\:0434\:0438\:043c\:044b\:0439 \:0440\:0435\:0437\
\:0443\:043b\:044c\:0442\:0430\:0442 \:044f\:0432\:043b\:044f\:0435\:0442\
\:0441\:044f \:043e\:0431\:044a\:0435\:043a\:0442\:043e\:043c ",
 Cell[BoxData[
  ButtonBox["FittedModel",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/FittedModel"]], "InlineFormula"],
 ", \:043a\:043e\:0442\:043e\:0440\:044b\:0439 \:0441\:043e\:0434\:0435\:0440\
\:0436\:0438\:0442 \:0438\:043d\:0444\:043e\:0440\:043c\:0430\:0446\:0438\
\:044e \:043e \:043f\:043e\:0434\:0431\:043e\:0440\:0435 \:0444\:0443\:043d\
\:043a\:0446\:0438\:0438 \:0438 \:043f\:0435\:0440\:0432\:043e\:043d\:0430\
\:0447\:0430\:043b\:044c\:043d\:044b\:0445 \:0434\:0430\:043d\:043d\:044b\
\:0445. \:0420\:0435\:0437\:0443\:043b\:044c\:0442\:0430\:0442\:044b \:0438 \
\:0434\:0430\:043d\:043d\:044b\:0435 \:0434\:0438\:0430\:0433\:043d\:043e\
\:0441\:0442\:0438\:043a\:0438 \:043c\:043e\:0436\:043d\:043e \:043f\:043e\
\:043b\:0443\:0447\:0438\:0442\:044c \:043d\:0435\:043f\:043e\:0441\:0440\
\:0435\:0434\:0441\:0442\:0432\:0435\:043d\:043d\:043e \:0438\:0437 \:043e\
\:0431\:044a\:0435\:043a\:0442\:0430."
}], "HowToText",
 CellID->160271121],

Cell[TextData[{
 "\:0418\:0441\:043f\:043e\:043b\:044c\:0437\:0443\:0435\:043c \:043a\:043e\
\:043c\:0430\:043d\:0434\:0443 ",
 Cell[BoxData[
  ButtonBox["Normal",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Normal"]], "InlineFormula"],
 " \:0434\:043b\:044f \:0432\:044b\:0434\:0435\:043b\:0435\:043d\:0438\:044f \
\:0444\:0443\:043d\:043a\:0446\:0438\:043e\:043d\:0430\:043b\:044c\:043d\:043e\
\:0439 \:0444\:043e\:0440\:043c\:0443\:043b\:044b \:043f\:043e\:0434\:043e\
\:0431\:0440\:0430\:043d\:043d\:043e\:0439 \:043c\:043e\:0434\:0435\:043b\
\:0438:"
}], "HowToText",
 CellID->812217608],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Normal", "[", "lm", "]"}]], "Input",
 CellLabel->"In[13]:=",
 CellID->1398028897],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "8.435081567131478`"}], "+", 
  RowBox[{"5.483621414778047`", " ", "x"}]}]], "Output",
 ImageSize->{133, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[13]=",
 CellID->113312487]
}, Open  ]],

Cell["\<\
\:041f\:043e\:043c\:0438\:043c\:043e \:044d\:0442\:043e\:0433\:043e, \:043c\
\:043e\:0436\:043d\:043e \:0442\:0430\:043a\:0436\:0435 \:043d\:0430\:0439\
\:0442\:0438 \:0437\:043d\:0430\:0447\:0435\:043d\:0438\:044f \:043c\:043e\
\:0434\:0435\:043b\:0438 \:0432 \:043e\:043f\:0440\:0435\:0434\:0435\:043b\
\:0435\:043d\:043d\:044b\:0445 \:0442\:043e\:0447\:043a\:0430\:0445.\
\>", "HowToText",
 CellID->503057640],

Cell[TextData[{
 "\:0412\:044b\:0440\:0430\:0437\:0438\:043c \:043c\:043e\:0434\:0435\:043b\
\:044c \:0432 \:0432\:0438\:0434\:0435 \:0444\:0443\:043d\:043a\:0446\:0438\
\:0438 \:043f\:0435\:0440\:0435\:043c\:0435\:043d\:043d\:043e\:0439 ",
 Cell[BoxData["z"], "InlineFormula"],
 ", \:0432\:043c\:0435\:0441\:0442\:043e \:043f\:0435\:0440\:0432\:043e\:043d\
\:0430\:0447\:0430\:043b\:044c\:043d\:043e\:0439 \:043f\:0435\:0440\:0435\
\:043c\:0435\:043d\:043d\:043e\:0439 ",
 Cell[BoxData["x"], "InlineFormula"],
 ":"
}], "HowToText",
 CellID->1445501569],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"lm", "[", "z", "]"}]], "Input",
 CellLabel->"In[14]:=",
 CellID->89859940],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "8.435081567131478`"}], "+", 
  RowBox[{"5.483621414778047`", " ", "z"}]}]], "Output",
 ImageSize->{133, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[14]=",
 CellID->88375730]
}, Open  ]],

Cell[TextData[{
 "\:041d\:0430\:0445\:043e\:0436\:0434\:0435\:043d\:0438\:0435 \:0447\:0438\
\:0441\:043b\:0435\:043d\:043d\:043e\:0433\:043e \:0437\:043d\:0430\:0447\
\:0435\:043d\:0438\:044f \:0434\:0430\:0435\:0442 \:0440\:0435\:0437\:0443\
\:043b\:044c\:0442\:0430\:0442, \:043f\:0440\:0435\:0434\:0441\:043a\:0430\
\:0437\:0430\:043d\:043d\:044b\:0439 \:0444\:0443\:043d\:043a\:0446\:0438\
\:0435\:0439 \:043f\:0440\:0438 \:0437\:0430\:0434\:0430\:043d\:043d\:043e\
\:043c \:0447\:0438\:0441\:043b\:0435\:043d\:043d\:043e\:043c \:0437\:043d\
\:0430\:0447\:0435\:043d\:0438\:0438 \:043f\:0435\:0440\:0435\:043c\:0435\
\:043d\:043d\:043e\:0439 ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]], "InlineMath"],
 ":"
}], "HowToText",
 CellID->1611208941],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"lm", "[", "2.5", "]"}]], "Input",
 CellLabel->"In[24]:=",
 CellID->1967366364],

Cell[BoxData["5.273971969813646`"], "Output",
 ImageSize->{53, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[24]=",
 CellID->8883197]
}, Open  ]],

Cell[TextData[{
 "\:0412\:0432\:0438\:0434\:0443 \:0442\:043e\:0433\:043e, \:0447\:0442\:043e \
\:043e\:0431\:044a\:0435\:043a\:0442 ",
 Cell[BoxData[
  ButtonBox["FittedModel",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/FittedModel"]], "InlineFormula"],
 " \:0440\:0430\:0441\:0446\:0435\:043d\:0438\:0432\:0430\:0435\:0442\:0441\
\:044f \:043a\:0430\:043a \:0444\:0443\:043d\:043a\:0446\:0438\:044f, \:0435\
\:0433\:043e \:0433\:0440\:0430\:0444\:0438\:043a \:043c\:043e\:0436\:0435\
\:0442 \:0431\:044b\:0442\:044c \:043f\:043e\:0441\:0442\:0440\:043e\:0435\
\:043d \:043f\:0440\:0438 \:043f\:043e\:043c\:043e\:0449\:0438 \:0444\:0443\
\:043d\:043a\:0446\:0438\:0438 ",
 Cell[BoxData[
  ButtonBox["Plot",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Plot"]], "InlineFormula"],
 " \:043d\:0430\:043f\:0440\:044f\:043c\:0443\:044e:"
}], "HowToText",
 CellID->84424557],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p1", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"lm", "[", "x", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "1", ",", "10"}], "}"}]}], "]"}]}]], "Input",
 CellLabel->"In[25]:=",
 CellID->146308799],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVxXk01AkAB/Bxs0YNzQoJMz9paJRzMsjvOxMzPM/xkChbOqzaanVQvbbT
0UqOcpOonNVQpFCOX5YSJcum2qTj2Qk1NeQqZXb3j8/7sDZHBUQo02g0n//8
/7MxH1saTU66xrQUZBdoUPfmXUvx1ZaTzxQFvdlHNKgbyxijBfpy8mDSIc2c
DRpUakTvJb61nLxV5BidY6ZBrX4ezNy3Tk7adV71zi1Rp6qojdP/1MpJjmnu
1zyJGpWQtqepa/sYyXiwO+R8owplZ53lldM3Tj7ku3M8GxQtrE0R1dpDk+RM
/zFL4VNZy500Vb14aoak+fQ9aSisIEt01O0LU2dJPP4zvdVCTrLjzxRn5c2R
A/5FEs4OGsq+Rp/0rKdh+EnndKSDJhJWSN86CJXxNlOH7R7AAD050XS8TQXJ
o5upi/uZGIlID6m2VoNJd03AnUADMBrD+a9q1WFgmBXhEW+MlLRs/flsTczO
ON1q55mhJul73/xELXjPNsWksdhgKVvyj9G14WebHKPLM4d06k6+fD8dHlVr
o8YsLDAZuaCkR6GDTxt2Xj4l4EBCK0g5cWI+DpTmFHkGWCFM+x4/P5qBz3ZU
WgTJRWLQBdrVlbpYMmFLOQcvx8awqvZGmS4sjvpP3jK3wfpLhYNqN/SgVyC5
wrW3xbLD5ZF10QvwUZXZfNPVDqXMoY/bLZkQ6h7q3uVgD4/3yp2BMib21qkq
lAQOOHN8TbFbyY8wUkrltrs4ouoy9eHsWn3UZLHrz9nyMM6Yl2RstBDmbS+2
+LquxBte2pKKxwuhl51Bt3F0wmT+OHNHpgGeKe1+IhPy8TL91+jsNYZIrV/7
rdnbGVFeJr2tWkZo1HMzaxG6YKnb9TiLR0ZoU/faes7XFUljMfan4xbBszCg
tMxzFSinoMAQnjFuH490b1/lBuNm5v2wGWOof7+gQolJEMpa/M2Vi/Fz6odX
E6aAX/yrucI9JuC9N+o+UAZYtI+0DnBM8Udeh7OeuQA9efTp2AFT3Jf9Fswr
EsC/P5G87meG+lRBbIe5EPPI0tiiK2bYduIkd+9FIQbv1URZ6bCgcvel9BRn
NXJzH2aO7GJBv8zZf1nlalR40fiWHSy8G9B3GuK4o9Nwye+qVmyUhKvZaF9z
h/DBlqDwBDZMePvKvLgeKGmtCpUPssGolnbplnvA4MWopjEIfDq4U8mTK8Lb
XqzsyCdwOn3PzawKEQo53vo/FRBQetfQQl0RIfTomsmx8wT2uyh3vpeI0GP5
y41FFwlsGkofFFSL0Hw8Y0VUOQEnXq3GxwYRzi2XLtWvJSB9PhUq6hIhKOm0
wdZHBMA6PDclE4HxOmt6pptAXUybJlsuQpfjhf6UHgLcTvoCn3ERhG9qM+v6
CCzcd35p8ZQINk6DDO2/Ccjamv39FCLQpTZaNVIC+duUissZYnS4uAyLhgkw
mrwqe/XEiDvrcf/FCIEE3fS670wxvrquS1CTEdh9m/0w0FCM4Yw4pdDPBER0
90kFS4ySkZTXsgkCTeHJCitzMTaSuS2xUwRsb/6lFWwhRv+o5IjkC4HFGyJM
JFZipKMuTDBLIKOmkvOUK4Zv9l2X/m8EtDSm7JRXiPHDhy6jHXMEjq13W2Vt
K0a7oP+LQkFg4tpJcYi9GP8CIycasA==
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{2., 0},
  PlotRange->{{1, 10}, {-2.9514591451576546`, 46.40113157345323}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 ImageSize->{184, 117},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[25]=",
 CellID->858141887]
}, Open  ]],

Cell[TextData[{
 "\:041e\:0442\:043e\:0431\:0440\:0430\:0437\:0438\:043c, \:0434\:043b\:044f \
\:0431\:043e\:043b\:044c\:0448\:0435\:0439 \:043d\:0430\:0433\:043b\:044f\
\:0434\:043d\:043e\:0441\:0442\:0438, \:043e\:043f\:043e\:0440\:043d\:044b\
\:0435 \:0442\:043e\:0447\:043a\:0438 \:0432\:043c\:0435\:0441\:0442\:0435 \
\:0441 \:043f\:043e\:0434\:043e\:0431\:0440\:0430\:043d\:043d\:043e\:0439 \
\:0444\:0443\:043d\:043a\:0446\:0438\:0435\:0439, \:0438\:0441\:043f\:043e\
\:043b\:044c\:0437\:043e\:0432\:0430\:0432 \:043a\:043e\:043c\:0430\:043d\
\:0434\:0443 ",
 Cell[BoxData[
  TemplateBox[{Cell["Show"],"paclet:ref/Show"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " \:0434\:043b\:044f \:0441\:043e\:0432\:043c\:0435\:0449\:0435\:043d\:0438\
\:044f \:0433\:0440\:0430\:0444\:0438\:043a\:0430 ",
 Cell[BoxData[
  ButtonBox["ListPlot",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/ListPlot"]], "InlineFormula"],
 " \:0438\:0441\:0445\:043e\:0434\:043d\:043e\:0433\:043e \:043d\:0430\:0431\
\:043e\:0440\:0430 \:0434\:0430\:043d\:043d\:044b\:0445 (\:043e\:043f\:043e\
\:0440\:043d\:044b\:0445 \:0442\:043e\:0447\:0435\:043a) \:0438 \:043f\:0440\
\:0435\:0434\:044b\:0434\:0443\:0449\:0435\:0433\:043e \:0433\:0440\:0430\
\:0444\:0438\:043a\:0430:"
}], "HowToText",
 CellID->58727254],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"ListPlot", "[", "data1", "]"}], ",", "p1"}], "]"}]], "Input",
 CellLabel->"In[26]:=",
 CellID->71688609],

Cell[BoxData[
 GraphicsBox[{
   {Hue[0.67, 0.6, 0.6], 
    PointBox[{{1.2, 3.4}, {1.7, 4.2}, {2.8, 6.5}, {4.3, 11.2}, {4.8, 13.8}, {
     5.9, 19.9}, {7.4, 30.}, {7.7, 31.5}, {8.9, 41.9}, {10.2, 
     54.3}}]}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVxXk01AkAB/Bxs0YNzQoJMz9paJRzMsjvOxMzPM/xkChbOqzaanVQvbbT
0UqOcpOonNVQpFCOX5YSJcum2qTj2Qk1NeQqZXb3j8/7sDZHBUQo02g0n//8
/7MxH1saTU66xrQUZBdoUPfmXUvx1ZaTzxQFvdlHNKgbyxijBfpy8mDSIc2c
DRpUakTvJb61nLxV5BidY6ZBrX4ezNy3Tk7adV71zi1Rp6qojdP/1MpJjmnu
1zyJGpWQtqepa/sYyXiwO+R8owplZ53lldM3Tj7ku3M8GxQtrE0R1dpDk+RM
/zFL4VNZy500Vb14aoak+fQ9aSisIEt01O0LU2dJPP4zvdVCTrLjzxRn5c2R
A/5FEs4OGsq+Rp/0rKdh+EnndKSDJhJWSN86CJXxNlOH7R7AAD050XS8TQXJ
o5upi/uZGIlID6m2VoNJd03AnUADMBrD+a9q1WFgmBXhEW+MlLRs/flsTczO
ON1q55mhJul73/xELXjPNsWksdhgKVvyj9G14WebHKPLM4d06k6+fD8dHlVr
o8YsLDAZuaCkR6GDTxt2Xj4l4EBCK0g5cWI+DpTmFHkGWCFM+x4/P5qBz3ZU
WgTJRWLQBdrVlbpYMmFLOQcvx8awqvZGmS4sjvpP3jK3wfpLhYNqN/SgVyC5
wrW3xbLD5ZF10QvwUZXZfNPVDqXMoY/bLZkQ6h7q3uVgD4/3yp2BMib21qkq
lAQOOHN8TbFbyY8wUkrltrs4ouoy9eHsWn3UZLHrz9nyMM6Yl2RstBDmbS+2
+LquxBte2pKKxwuhl51Bt3F0wmT+OHNHpgGeKe1+IhPy8TL91+jsNYZIrV/7
rdnbGVFeJr2tWkZo1HMzaxG6YKnb9TiLR0ZoU/faes7XFUljMfan4xbBszCg
tMxzFSinoMAQnjFuH490b1/lBuNm5v2wGWOof7+gQolJEMpa/M2Vi/Fz6odX
E6aAX/yrucI9JuC9N+o+UAZYtI+0DnBM8Udeh7OeuQA9efTp2AFT3Jf9Fswr
EsC/P5G87meG+lRBbIe5EPPI0tiiK2bYduIkd+9FIQbv1URZ6bCgcvel9BRn
NXJzH2aO7GJBv8zZf1nlalR40fiWHSy8G9B3GuK4o9Nwye+qVmyUhKvZaF9z
h/DBlqDwBDZMePvKvLgeKGmtCpUPssGolnbplnvA4MWopjEIfDq4U8mTK8Lb
XqzsyCdwOn3PzawKEQo53vo/FRBQetfQQl0RIfTomsmx8wT2uyh3vpeI0GP5
y41FFwlsGkofFFSL0Hw8Y0VUOQEnXq3GxwYRzi2XLtWvJSB9PhUq6hIhKOm0
wdZHBMA6PDclE4HxOmt6pptAXUybJlsuQpfjhf6UHgLcTvoCn3ERhG9qM+v6
CCzcd35p8ZQINk6DDO2/Ccjamv39FCLQpTZaNVIC+duUissZYnS4uAyLhgkw
mrwqe/XEiDvrcf/FCIEE3fS670wxvrquS1CTEdh9m/0w0FCM4Yw4pdDPBER0
90kFS4ySkZTXsgkCTeHJCitzMTaSuS2xUwRsb/6lFWwhRv+o5IjkC4HFGyJM
JFZipKMuTDBLIKOmkvOUK4Zv9l2X/m8EtDSm7JRXiPHDhy6jHXMEjq13W2Vt
K0a7oP+LQkFg4tpJcYi9GP8CIycasA==
      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  PlotRange->Automatic,
  PlotRangeClipping->True]], "Output",
 ImageSize->{184, 112},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[26]=",
 CellID->90140410]
}, Open  ]],

Cell[TextData[{
 "\:041e\:0431\:044a\:0435\:043a\:0442\:044b ",
 Cell[BoxData[
  ButtonBox["FittedModel",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/FittedModel"]], "InlineFormula"],
 " \:0441\:043e\:0434\:0435\:0440\:0436\:0430\:0442, \:0442\:0430\:043a\:0436\
\:0435 \:043c\:043d\:043e\:0436\:0435\:0441\:0442\:0432\:043e \:0441\:0432\
\:0435\:0434\:0435\:043d\:0438\:0439 \:0438 \:043e\:0446\:0435\:043d\:043e\
\:043a, \:043e\:0442\:043d\:043e\:0441\:044f\:0449\:0438\:0445\:0441\:044f \
\:043a \:0442\:0438\:043f\:0443 \:043c\:043e\:0434\:0435\:043b\:0438, \:043a\
\:043e\:0442\:043e\:0440\:0443\:044e \:043e\:043d\:0438 \:043f\:0440\:0435\
\:0434\:0441\:0442\:0430\:0432\:043b\:044f\:044e\:0442 (\:0432 \:0434\:0430\
\:043d\:043d\:043e\:043c \:0441\:043b\:0443\:0447\:0430\:0435 - \:043b\:0438\
\:043d\:0435\:0439\:043d\:0430\:044f \:043c\:043e\:0434\:0435\:043b\:044c). \
\:041c\:043e\:0436\:043d\:043e \:0432\:044b\:043f\:043e\:043b\:043d\:0438\
\:0442\:044c \:0432\:044b\:0447\:0438\:0441\:043b\:0435\:043d\:0438\:0435 \
\:043f\:043e\:0434\:043e\:0431\:0440\:0430\:043d\:043d\:043e\:0439 \:043c\
\:043e\:0434\:0435\:043b\:0438 ",
 Cell[BoxData[
  ButtonBox["FittedModel",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/FittedModel"]], "InlineFormula"],
 ", \:0443\:043a\:0430\:0437\:0430\:0432 \:0432 \
\:043a\:0430\:0447\:0435\:0441\:0442\:0432\:0435 \:0430\:0440\:0433\:0443\
\:043c\:0435\:043d\:0442\:0430 \:0437\:043d\:0430\:0447\:0435\:043d\:0438\
\:0435 ",
 Cell[BoxData["\<\"Properties\"\>"], "InlineFormula"],
 ", \:0447\:0442\:043e\:0431\:044b \:043f\:043e\:043b\:0443\:0447\:0438\:0442\
\:044c \:043f\:043e\:043b\:043d\:044b\:0439 \:0441\:043f\:0438\:0441\:043e\
\:043a \:0441\:0432\:043e\:0439\:0441\:0442\:0432, \:0434\:043e\:0441\:0442\
\:0443\:043f\:043d\:044b\:0445 \:0434\:043b\:044f \:0434\:0430\:043d\:043d\
\:043e\:0439 \:043c\:043e\:0434\:0435\:043b\:0438."
}], "HowToText",
 CellID->438571833],

Cell[TextData[{
 "\:0417\:0434\:0435\:0441\:044c, \:0444\:0443\:043d\:043a\:0446\:0438\:044f ",
 Cell[BoxData[
  ButtonBox["Length",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Length"]], "InlineFormula"],
 " \:0438\:0441\:043f\:043e\:043b\:044c\:0437\:043e\:0432\:0430\:043d\:0430 \
\:0434\:043b\:044f \:043e\:0442\:043e\:0431\:0440\:0430\:0436\:0435\:043d\
\:0438\:044f \:043a\:043e\:043b\:0438\:0447\:0435\:0441\:0442\:0432\:0430 \
\:0441\:0432\:043e\:0439\:0441\:0442\:0432, \:0438\:0437\:0432\:0435\:0441\
\:0442\:043d\:044b\:0445 \:0434\:043b\:044f \:044d\:0442\:043e\:0439 \:043c\
\:043e\:0434\:0435\:043b\:0438:"
}], "HowToText",
 CellID->223094117],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"lm", "[", "\"\<Properties\>\"", "]"}], "//", "Length"}]], "Input",
 CellLabel->"In[27]:=",
 CellID->187861414],

Cell[BoxData["63"], "Output",
 ImageSize->{18, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[27]=",
 CellID->374649664]
}, Open  ]],

Cell[TextData[{
 "\:0417\:0430\:0447\:0430\:0441\:0442\:0443\:044e, \:0431\:044b\:0432\:0430\
\:0435\:0442 \:0432\:0430\:0436\:043d\:043e \:0437\:0430\:0434\:0430\:0442\
\:044c\:0441\:044f \:0432\:043e\:043f\:0440\:043e\:0441\:043e\:043c: \:0438\
\:043c\:0435\:044e\:0442 \:0438\:043b\:0438 \:043d\:0435\:0442 \:043e\:0446\
\:0435\:043d\:043a\:0438 \:043f\:0430\:0440\:0430\:043c\:0435\:0442\:0440\
\:043e\:0432 \:0441\:0442\:0430\:0442\:0438\:0441\:0442\:0438\:0447\:0435\
\:0441\:043a\:0443\:044e \:0437\:043d\:0430\:0447\:0438\:043c\:043e\:0441\
\:0442\:044c, \:0442\:043e \:0435\:0441\:0442\:044c \:043d\:0430\:0441\:043a\
\:043e\:043b\:044c\:043a\:043e \:043e\:0446\:0435\:043d\:043a\:0438 \:043f\
\:0430\:0440\:0430\:043c\:0435\:0442\:0440\:043e\:0432 \:043e\:0442\:043b\
\:0438\:0447\:0430\:044e\:0442\:0441\:044f \:043e\:0442 0. \:041a \
\:043f\:0440\:0438\:043c\:0435\:0440\:0443, \:0432 \:043b\:0438\:043d\:0435\
\:0439\:043d\:043e\:0439 \:043c\:043e\:0434\:0435\:043b\:0438 \:043c\:043e\
\:0436\:043d\:043e \:043f\:043e\:0441\:043c\:043e\:0442\:0440\:0435\:0442\
\:044c \:043d\:0430 ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]], "InlineMath"],
 "\[Hyphen]\:0437\:043d\:0430\:0447\:0435\:043d\:0438\:0435 \
\:0434\:043b\:044f ",
 Cell[BoxData[
  FormBox["t", TraditionalForm]], "InlineMath"],
 "-\:0441\:0442\:0430\:0442\:0438\:0441\:0442\:0438\:043a\:0438, \:0441\:0432\
\:044f\:0437\:0430\:043d\:043d\:043e\:0435 \:0441 \:044d\:0442\:0438\:043c \
\:043f\:0430\:0440\:0430\:043c\:0435\:0442\:0440\:043e\:043c.  \:042d\:0442\
\:043e ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]], "InlineMath"],
 "\[Hyphen]\:0437\:043d\:0430\:0447\:0435\:043d\:0438\:0435 \
\:044f\:0432\:043b\:044f\:0435\:0442\:0441\:044f \:0432\:0435\:0440\:043e\
\:044f\:0442\:043d\:043e\:0441\:0442\:044c\:044e \:0442\:043e\:0433\:043e, \
\:0447\:0442\:043e \:0441\:043b\:0443\:0447\:0430\:0439\:043d\:0430\:044f \
\:0432\:0435\:043b\:0438\:0447\:0438\:043d\:0430, \:0441 \:0440\:0430\:0441\
\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\:0438\:0435\:043c ",
 Cell[BoxData[
  FormBox["t", TraditionalForm]], "InlineMath"],
 "-\:0441\:0442\:0430\:0442\:0438\:0441\:0442\:0438\:043a\:0438 \:043f\:0440\
\:0438 \:043d\:0443\:043b\:0435\:0432\:043e\:0439 \:0433\:0438\:043f\:043e\
\:0442\:0435\:0437\:0435, \:043f\:0440\:0438\:043c\:0435\:0442 \:0437\:043d\
\:0430\:0447\:0435\:043d\:0438\:0435 \:043d\:0435 \:043c\:0435\:043d\:044c\
\:0448\:0435\:0435, \:0447\:0435\:043c \:0444\:0430\:043a\:0442\:0438\:0447\
\:0435\:0441\:043a\:043e\:0435 \:0437\:043d\:0430\:0447\:0435\:043d\:0438\
\:0435 ",
 Cell[BoxData[
  FormBox["t", TraditionalForm]], "InlineMath"],
 "-\:0441\:0442\:0430\:0442\:0438\:0441\:0442\:0438\:043a\:0438. "
}], "HowToText",
 CellID->626748087],

Cell[TextData[{
 "\:0412\:043e\:0441\:043f\:043e\:043b\:044c\:0437\:0443\:0435\:043c\:0441\
\:044f \:0441\:0432\:043e\:0439\:0441\:0442\:0432\:043e\:043c ",
 Cell[BoxData["\<\"ParameterTable\"\>"], "InlineFormula"],
 " \:0434\:043b\:044f ",
 Cell[BoxData[
  ButtonBox["FittedModel",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/FittedModel"]], "InlineFormula"],
 ", \:0447\:0442\:043e\:0431\:044b \:0432\:044b\:0432\:0435\:0441\:0442\:0438 \
\:0442\:0430\:0431\:043b\:0438\:0446\:0443, \:043e\:0431\:043e\:0431\:0449\
\:0430\:044e\:0449\:0443\:044e \:043e\:0446\:0435\:043d\:043a\:0438 \:043f\
\:0430\:0440\:0430\:043c\:0435\:0442\:0440\:043e\:0432, ",
 Cell[BoxData[
  FormBox["t", TraditionalForm]], "InlineMath"],
 "-\:0441\:0442\:0430\:0442\:0438\:0441\:0442\:0438\:043a\:0443 \:0438 ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]], "InlineMath"],
 "\[Hyphen]\:0437\:043d\:0430\:0447\:0435\:043d\:0438\:044f:"
}], "HowToText",
 CellID->301606275],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"lm", "[", "\"\<ParameterTable\>\"", "]"}]], "Input",
 CellLabel->"In[28]:=",
 CellID->281808015],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"\"\>", "\<\"Estimate\"\>", "\<\"Standard Error\"\>", "\<\"t\
\[Hyphen]Statistic\"\>", "\<\"P\[Hyphen]Value\"\>"},
     {"1", 
      RowBox[{"-", "8.435081567131471`"}], "2.8843525893322335`", 
      RowBox[{"-", "2.9244280322484104`"}], "0.01916090273121236`"},
     {"x", "5.483621414778047`", "0.46436727697685126`", 
      "11.808802399854299`", "2.4227830037255936`*^-6"}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxDividers->{
     "ColumnsIndexed" -> {2 -> GrayLevel[0.7]}, 
      "RowsIndexed" -> {2 -> GrayLevel[0.7]}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{
     "ColumnsIndexed" -> {2 -> 1}, "RowsIndexed" -> {2 -> 0.75}}],
   "Grid"], "DialogStyle",
  StripOnInput->False]], "Output",
 ImageSize->{294, 53},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[28]=",
 CellID->350168195]
}, Open  ]],

Cell[TextData[{
 "\:041c\:043e\:0436\:043d\:043e \:0432\:043e\:0441\:043f\:043e\:043b\:044c\
\:0437\:043e\:0432\:0430\:0442\:044c\:0441\:044f \:0434\:0440\:0443\:0433\
\:0438\:043c\:0438 \:0441\:0432\:043e\:0439\:0441\:0442\:0432\:0430\:043c\
\:0438, \:0447\:0442\:043e\:0431\:044b \:043f\:043e\:043b\:0443\:0447\:0438\
\:0442\:044c ",
 Cell[BoxData[
  FormBox["t", TraditionalForm]], "InlineMath"],
 "-\:0441\:0442\:0430\:0442\:0438\:0441\:0442\:0438\:043a\:0443 \:0438 ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]], "InlineMath"],
 "\[Hyphen]\:0437\:043d\:0430\:0447\:0435\:043d\:0438\:044f \
\:043f\:043e\:0440\:043e\:0437\:043d\:044c. \:042d\:0442\:043e \:043e\:0441\
\:043e\:0431\:0435\:043d\:043d\:043e \:0443\:0434\:043e\:0431\:043d\:043e, \
\:0435\:0441\:043b\:0438 \:0442\:0440\:0435\:0431\:0443\:0435\:0442\:0441\
\:044f \:0432\:044b\:0447\:0438\:0441\:043b\:044f\:0442\:044c \:0434\:0440\
\:0443\:0433\:0438\:0435 \:0440\:0435\:0437\:0443\:043b\:044c\:0442\:0430\
\:0442\:044b \:043d\:0430 \:043e\:0441\:043d\:043e\:0432\:0435 \:044d\:0442\
\:0438\:0445 \:0441\:0432\:043e\:0439\:0441\:0442\:0432. \:0412\:043e\:0441\
\:043f\:043e\:043b\:044c\:0437\:0443\:0435\:043c\:0441\:044f \:0441\:0432\
\:043e\:0439\:0441\:0442\:0432\:043e\:043c ",
 Cell[BoxData["\<\"ParameterPValues\"\>"], "InlineFormula"],
 " \:0434\:043b\:044f ",
 Cell[BoxData[
  ButtonBox["FittedModel",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/FittedModel"]], "InlineFormula"],
 " \:0434\:043b\:044f \:0432\:044b\:0432\:043e\:0434\:0430 \:0442\:043e\:043b\
\:044c\:043a\:043e ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]], "InlineMath"],
 "\[Hyphen]\:0437\:043d\:0430\:0447\:0435\:043d\:0438\:0439:"
}], "HowToText",
 CellID->437611161],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"lm", "[", "\"\<ParameterPValues\>\"", "]"}]], "Input",
 CellLabel->"In[7]:=",
 CellID->888529300],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.01916090273121248`", ",", "2.4227830037256`*^-6"}], 
  "}"}]], "Output",
 ImageSize->{177, 18},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[7]=",
 CellID->1766081534]
}, Open  ]],

Cell[TextData[{
 "\:041e\:0442\:043e\:0431\:0440\:0430\:0437\:0438\:043c \:043d\:0435\:0441\
\:043a\:043e\:043b\:044c\:043a\:043e \:0441\:0432\:043e\:0439\:0441\:0442\
\:0432 \:0441\:0440\:0430\:0437\:0443, \:0437\:0430\:0434\:0430\:0432 \:0441\
\:043f\:0438\:0441\:043e\:043a \:0441\:0432\:043e\:0439\:0441\:0442\:0432. \
\:0412\:044b\:0432\:0435\:0434\:0435\:043c ",
 Cell[BoxData[
  FormBox["t", TraditionalForm]], "InlineMath"],
 "-\:0441\:0442\:0430\:0442\:0438\:0441\:0442\:0438\:043a\:0443 \:0438 ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]], "InlineMath"],
 "\[Hyphen]\:0437\:043d\:0430\:0447\:0435\:043d\:0438\:044f \
\:0432\:043c\:0435\:0441\:0442\:0435:"
}], "HowToText",
 CellID->851221982],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"lm", "[", 
  RowBox[{"{", 
   RowBox[{"\"\<ParameterTStatistics\>\"", ",", "\"\<ParameterPValues\>\""}], 
   "}"}], "]"}]], "Input",
 CellLabel->"In[10]:=",
 CellID->201677425],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "2.9244280322484135`"}], ",", "11.8088023998543`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"0.01916090273121226`", ",", "2.4227830037255902`*^-6"}], "}"}]}],
   "}"}]], "Output",
 ImageSize->{333, 18},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[10]=",
 CellID->23655885]
}, Open  ]],

Cell["\<\
\:041a\:0440\:043e\:043c\:0435 \:0442\:043e\:0433\:043e, \:043c\:043e\:0436\
\:043d\:043e \:0442\:0430\:043a\:0436\:0435 \:043f\:043e\:043b\:0443\:0447\
\:0438\:0442\:044c \:0434\:043e\:0432\:0435\:0440\:0438\:0442\:0435\:043b\
\:044c\:043d\:044b\:0435 \:043e\:0431\:043b\:0430\:0441\:0442\:0438 \:0434\
\:043b\:044f \:043f\:0430\:0440\:0430\:043c\:0435\:0442\:0440\:043e\:0432:\
\>", "HowToText",
 CellID->415880261],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"lm", "[", "\"\<ParameterConfidenceIntervals\>\"", "]"}]], "Input",
 CellLabel->"In[11]:=",
 CellID->57102216],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "15.086410565518456`"}], ",", 
     RowBox[{"-", "1.7837525687444993`"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4.412788553815929`", ",", "6.554454275740165`"}], "}"}]}], 
  "}"}]], "Output",
 ImageSize->{291, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[11]=",
 CellID->852093708]
}, Open  ]],

Cell[TextData[{
 "\:041f\:043e \:0443\:043c\:043e\:043b\:0447\:0430\:043d\:0438\:044e, \:0432\
\:043e\:0437\:0432\:0440\:0430\:0449\:0430\:044e\:0442\:0441\:044f 95% \:0434\
\:043e\:0432\:0435\:0440\:0438\:0442\:0435\:043b\:044c\:043d\:044b\:0435 \
\:043e\:0431\:043b\:0430\:0441\:0442\:0438. \:041e\:0434\:043d\:0430\:043a\
\:043e, \:043c\:043e\:0436\:043d\:043e \:043f\:043e\:043b\:0443\:0447\:0438\
\:0442\:044c \:0438 \:0434\:0440\:0443\:0433\:0438\:0435 \:043e\:0431\:043b\
\:0430\:0441\:0442\:0438, \:0441 \:0434\:0440\:0443\:0433\:0438\:043c\:0438 \
\:0443\:0440\:043e\:0432\:043d\:044f\:043c\:0438 \:0434\:043e\:0432\:0435\
\:0440\:0438\:0442\:0435\:043b\:044c\:043d\:043e\:0441\:0442\:0438, \:0438\
\:0441\:043f\:043e\:043b\:044c\:0437\:0443\:044f \:043e\:043f\:0446\:0438\
\:044e ",
 Cell[BoxData[
  ButtonBox["ConfidenceLevel",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/ConfidenceLevel"]], "InlineFormula"],
 "."
}], "HowToText",
 CellID->438776831],

Cell["\:0412\:044b\:0432\:0435\:0434\:0435\:043c 99% \:0434\:043e\:0432\:0435\
\:0440\:0438\:0442\:0435\:043b\:044c\:043d\:044b\:0435 \:043e\:0431\:043b\
\:0430\:0441\:0442\:0438 \:0434\:043b\:044f \:043f\:0430\:0440\:0430\:043c\
\:0435\:0442\:0440\:043e\:0432:", "HowToText",
 CellID->578163253],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"lm", "[", 
  RowBox[{"\"\<ParameterConfidenceIntervals\>\"", ",", 
   RowBox[{"ConfidenceLevel", "\[Rule]", ".99"}]}], "]"}]], "Input",
 CellLabel->"In[12]:=",
 CellID->280761658],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "18.11320170447553`"}], ",", "1.2430385702125708`"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"3.9254893365241346`", ",", "7.041753493031959`"}], "}"}]}], 
  "}"}]], "Output",
 ImageSize->{283, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[12]=",
 CellID->180239820]
}, Open  ]],

Cell[TextData[{
 "\:041a\:0440\:043e\:043c\:0435 \:0443\:043a\:0430\:0437\:0430\:043d\:043d\
\:043e\:0433\:043e \:0432\:044b\:0448\:0435, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " \:0434\:043e\:043f\:043e\:043b\:043d\:0438\:0442\:0435\:043b\:044c\:043d\
\:043e \:043f\:0440\:0435\:0434\:043b\:0430\:0433\:0430\:0435\:0442 \:043f\
\:043e\:0442\:043e\:0447\:0435\:0447\:043d\:0443\:044e \:0434\:0438\:0430\
\:0433\:043d\:043e\:0441\:0442\:0438\:0447\:0435\:0441\:043a\:0443\:044e \
\:0441\:0442\:0430\:0442\:0438\:0441\:0442\:0438\:043a\:0443, \:043a\:0430\
\:043a \:043d\:0430\:043f\:0440\:0438\:043c\:0435\:0440 \:043e\:0441\:0442\
\:0430\:0442\:043a\:0438."
}], "HowToText",
 CellID->704180568],

Cell[TextData[{
 "\:0417\:0434\:0435\:0441\:044c \:0432\:044b\:0447\:0438\:0441\:043b\:0435\
\:043d\:044b \:0438 \:0441\:043e\:0445\:0440\:0430\:043d\:0435\:043d\:044b \
\:043f\:043e\:0434 \:0438\:043c\:0435\:043d\:0435\:043c ",
 Cell[BoxData["resids"], "InlineFormula"],
 " \:043e\:0441\:0442\:0430\:0442\:043a\:0438 \:0434\:043b\:044f \:043f\:043e\
\:0434\:043e\:0431\:0440\:0430\:043d\:043d\:043e\:0439 \:043c\:043e\:0434\
\:0435\:043b\:0438:"
}], "HowToText",
 CellID->521615316],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"resids", "=", 
  RowBox[{"lm", "[", "\"\<FitResiduals\>\"", "]"}]}]], "Input",
 CellLabel->"In[13]:=",
 CellID->369509882],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"5.2547358693978214`", ",", "3.3129251620087983`", ",", 
   RowBox[{"-", "0.4190583942470525`"}], ",", 
   RowBox[{"-", "3.944490516414122`"}], ",", 
   RowBox[{"-", "4.086301223803144`"}], ",", 
   RowBox[{"-", "4.018284780059005`"}], ",", 
   RowBox[{"-", "2.1437169022260747`"}], ",", 
   RowBox[{"-", "2.288803326659483`"}], ",", "1.5308509756068531`", ",", 
   "6.802143136395401`"}], "}"}]], "Output",
 ImageSize->{386, 33},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[13]=",
 CellID->839756941]
}, Open  ]],

Cell[TextData[{
 "\:041e\:0442\:043e\:0431\:0440\:0430\:0437\:0438\:043c \:043e\:0441\:0442\
\:0430\:0442\:043a\:0438 \:043f\:0440\:0438 \:043f\:043e\:043c\:043e\:0449\
\:0438 \:0444\:0443\:043d\:043a\:0446\:0438\:0438 ",
 Cell[BoxData[
  ButtonBox["ListPlot",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/ListPlot"]], "InlineFormula"],
 ":"
}], "HowToText",
 CellID->129497841],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", "resids", "]"}]], "Input",
 CellLabel->"In[14]:=",
 CellID->136313857],

Cell[BoxData[
 GraphicsBox[
  {Hue[0.67, 0.6, 0.6], 
   PointBox[{{1., 5.2547358693978214`}, {2., 3.3129251620087983`}, {
    3., -0.4190583942470525}, {4., -3.944490516414122}, {
    5., -4.086301223803144}, {6., -4.018284780059005}, {
    7., -2.1437169022260747`}, {8., -2.288803326659483}, {9., 
    1.5308509756068531`}, {10., 6.802143136395401}}]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, Automatic},
  PlotRange->Automatic,
  PlotRangeClipping->True]], "Output",
 ImageSize->{184, 106},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[14]=",
 CellID->625211867]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\t", "HowToDelimiter",
 Editable->False,
 CellID->38965223],

Cell[TextData[{
 "\:041d\:0435\:0441\:043c\:043e\:0442\:0440\:044f \:043d\:0430 \:0442\:043e, \
\:0447\:0442\:043e \:0438\:0445 \:0434\:043e\:0441\:0442\:0443\:043f\:043d\
\:044b\:0435 \:0441\:0432\:043e\:0439\:0441\:0442\:0432\:0430 \:043d\:0435\
\:0441\:043a\:043e\:043b\:044c\:043a\:043e \:0440\:0430\:0437\:043d\:044f\
\:0442\:0441\:044f, \:0440\:0435\:0437\:0443\:043b\:044c\:0442\:0430\:0442\
\:044b \:0438 \:0434\:0438\:0430\:0433\:043d\:043e\:0441\:0442\:0438\:043a\
\:0430 \:0434\:043b\:044f \:043d\:0435\:043b\:0438\:043d\:0435\:0439\:043d\
\:043e\:0439 \:0438 \:043e\:0431\:043e\:0431\:0449\:0435\:043d\:043d\:043e\
\:0439 \:043b\:0438\:043d\:0435\:0439\:043d\:043e\:0439 \:043c\:043e\:0434\
\:0435\:043b\:0438 \:043c\:043e\:0433\:0443\:0442 \:0431\:044b\:0442\:044c \
\:043f\:043e\:043b\:0443\:0447\:0435\:043d\:044b \:043e\:0434\:043d\:0438\
\:043c \:0438 \:0442\:0435\:043c \:0436\:0435 \:0441\:043f\:043e\:0441\:043e\
\:0431\:043e\:043c.  \:041c\:043e\:0436\:043d\:043e \:043f\:0440\:043e\:0432\
\:043e\:0434\:0438\:0442\:044c \:043f\:043e\:0434\:0431\:043e\:0440 \:043c\
\:043e\:0434\:0435\:043b\:0435\:0439 \:044d\:0442\:0438\:0445 \:0432\:0438\
\:0434\:043e\:0432 \:043f\:0440\:0438 \:043f\:043e\:043c\:043e\:0449\:0438 \
\:0444\:0443\:043d\:043a\:0446\:0438\:0439  ",
 Cell[BoxData[
  ButtonBox["NonlinearModelFit",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/NonlinearModelFit"]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  ButtonBox["GeneralizedLinearModelFit",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/GeneralizedLinearModelFit"]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  ButtonBox["LogitModelFit",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/LogitModelFit"]], "InlineFormula"],
 " \:0438\:043b\:0438 ",
 Cell[BoxData[
  ButtonBox["ProbitModelFit",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/ProbitModelFit"]], "InlineFormula"],
 "."
}], "HowToText",
 CellID->16364313],

Cell["\:0417\:0430\:0434\:0430\:0434\:0438\:043c \:0434\:0440\:0443\:0433\
\:043e\:0439 \:043d\:0430\:0431\:043e\:0440 \:0434\:0430\:043d\:043d\:044b\
\:0445 \:0434\:043b\:044f \:043f\:043e\:0441\:043b\:0435\:0434\:0443\:044e\
\:0449\:0435\:0439 \:043e\:0431\:0440\:0430\:0431\:043e\:0442\:043a\:0438:", \
"HowToText",
 CellID->172471107],

Cell[BoxData[
 RowBox[{
  RowBox[{"data2", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3.9", ",", "75.3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.5", ",", "6.8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3.5", ",", "37.9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3.9", ",", "48.8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2.2", ",", "9.7"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.6", ",", "6.1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.", ",", "3.4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.6", ",", "2.2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2.1", ",", "11.4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2.1", ",", "8.1"}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellLabel->"In[15]:=",
 CellID->299022243],

Cell[TextData[{
 "\:0418\:0441\:043f\:043e\:043b\:044c\:0437\:0443\:0435\:043c \:0444\:0443\
\:043d\:043a\:0446\:0438\:044e ",
 Cell[BoxData[
  ButtonBox["NonlinearModelFit",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/NonlinearModelFit"]], "InlineFormula"],
 " \:0434\:043b\:044f \:043f\:043e\:0434\:0431\:043e\:0440\:0430 \:044d\:043a\
\:0441\:043f\:043e\:043d\:0435\:043d\:0446\:0438\:0430\:043b\:044c\:043d\:043e\
\:0439 \:043c\:043e\:0434\:0435\:043b\:0438 \:043f\:043e \:0442\:043e\:0447\
\:043a\:0430\:043c \:043d\:0430\:0431\:043e\:0440\:0430 \:0434\:0430\:043d\
\:043d\:044b\:0445:"
}], "HowToText",
 CellID->210684085],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"nlm", "=", 
  RowBox[{"NonlinearModelFit", "[", 
   RowBox[{"data2", ",", 
    RowBox[{"a", " ", 
     RowBox[{"Exp", "[", 
      RowBox[{"b", " ", "x"}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b"}], "}"}], ",", "x"}], "]"}]}]], "Input",
 CellLabel->"In[16]:=",
 CellID->454023941],

Cell[BoxData[
 RowBox[{"FittedModel", "[", 
  PanelBox[
   TagBox[
    RowBox[{"1.0275933697449777`", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"1.0486755138078538`", " ", "x"}]]}],
    Short],
   FrameMargins->5], "]"}]], "Output",
 ImageSize->{199, 36},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[16]=",
 CellID->86791284]
}, Open  ]],

Cell[TextData[{
 "\:0422\:0430\:043a \:0436\:0435, \:043a\:0430\:043a \:0438 \:0432 \:0441\
\:043b\:0443\:0447\:0430\:0435 \:0441 \:043b\:0438\:043d\:0435\:0439\:043d\
\:043e\:0439 \:043c\:043e\:0434\:0435\:043b\:044c\:044e, \:043f\:0440\:0438\
\:043c\:0435\:043d\:0438\:043c \:0444\:0443\:043d\:043a\:0446\:0438\:044e ",
 Cell[BoxData[
  ButtonBox["Show",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Show"]], "InlineFormula"],
 " \:0434\:043b\:044f \:0441\:043e\:0432\:043c\:0435\:0449\:0435\:043d\:0438\
\:044f \:0433\:0440\:0430\:0444\:0438\:043a\:043e\:0432 \:0442\:043e\:0447\
\:0435\:043a \:043d\:0430\:0431\:043e\:0440\:0430 \:0434\:0430\:043d\:043d\
\:044b\:0445 \:0438 \:043f\:043e\:043b\:0443\:0447\:0435\:043d\:043d\:043e\
\:0439 \:043c\:043e\:0434\:0435\:043b\:0438:"
}], "HowToText",
 CellID->76696085],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"ListPlot", "[", "data2", "]"}], ",", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"nlm", "[", "x", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "4"}], "}"}]}], "]"}]}], "]"}]], "Input",
 CellLabel->"In[17]:=",
 CellID->66007681],

Cell[BoxData[
 GraphicsBox[{
   {Hue[0.67, 0.6, 0.6], 
    PointBox[{{3.9, 75.3}, {1.5, 6.8}, {3.5, 37.9}, {3.9, 48.8}, {2.2, 9.7}, {
     1.6, 6.1}, {1., 3.4}, {0.6, 2.2}, {2.1, 11.4}, {2.1, 8.1}}]}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVjX0803kcwDe2LJqfxapZqmkqj5Vz0uP3E4nQ7bctUXl6eUoqISVdjnWm
UDd355xuFkWpE6vMw+vSw+Fk3eJESmXuWJGHTGiW2k5/vF/vf96v15sVfoQX
ZUAgEHbO8sU+UYPtD94e2wJR+7vICWpE8rCM72XsQjlnkifij6vRV0UFhVWM
SOTz5/Xunm/VyPfxs9sSRhIa82ozvJupRgGRmrs/MTKQE/NKb26hGvWsPuNx
npGHfI7wN4ha1KiYzsnMZpQikb38xhBrHAkoVSuzGDK09xpes+XFOArcc0mq
Hm9C4h6taDJjApnoBUFeS9rQzcDqMu91U8iG+26wMacTqWvGPevIGpTcuh4V
THYj/W3GgHalFi2U0ZREYi9Sm3m4BPFnUE2fh6JtUx+iU9vfJfZ/Rg2xEuae
ERVqUc+4VHEJMLViM1ZxeABF7yC/X1FLBANtuRnTZght+VGP9gcbgqs+rIZf
OYI4EUxPAxMyKDJcWpvtxlCqEB/x6pwDS3OHtdffqdGe1IqCODUFhjW9yqdr
3qOnu8vXhNJNoHToziPTHyaQW3RqdpeECqZWZWMq1SRqdkr6TmZnBucOVEcX
sz+glsOdf93PocEHKFfFpGmQ40Bjk9zBHJKcm2QLGqeRZ0N23mCnBfRWNuW0
sz4iwjXO9Jh8AczEdoptT84gC8nJlsL+RWC/1UgXfecTGh0+VqcgM8HrMmv/
rYU65Bzhv5uYYwXJVqHW/wXp0ems4rI26jJwGPE3ebaTAG+GlhXxD7LAHFNT
mj4SoCjtYNxaynIg3RdLlxcSQfE+/1J/ORsOutzpnutrAKWe058qxSugfEd4
8b0PBnCqYe+5fOkqmBq2NHuTbwjFx2n9FX/bQTXfyzBvGwlwevjrGzscIc1b
WCR7Q4JjlmJ+xZPVwOrxeV4iJEODvXXtbfe1sGFdRh7DeQ6ss7SQX33hDEFL
2rTEjjlwVqAQO6S4wNSj833xAiNQRMdd6A53hQJSSBKPTYGHSv90rr8bmCur
Lxs0UUD30pZMj9kA5FTBrvUJc+H1S6/T1JebgHA9RNo33xhknyhncgMRJP4m
PT+/wRi+TwhO72Jvhbv2Zym0OBMY1bGtVHXuQPNJdDhtOg8OTDS+9eRvg1eO
/3Sk1M8Di1v3DKlu2+HmRcRWhVAhbeN0DM/GG4KlrjQrHRWkkezEKGcfSBde
Erz63RSMQrhPSi76QcWgldjUD4Pq0jAnYzoHzkqEYcpvMOivp42kL+NAJG/U
ppKLgTbcVjVjz4HF9fU3dwZgUPBQnqVz50C2aF/zuXAMzDdJulwTOBDjemHc
OAUDnsNAV1IrB6wzLLyNrmKQFVsnX7QdB53bKeqza7P9ocAAhh8O3aP9T66W
YzD3hZS5mIdDbkBV8PZbGJD3yX1XheCgt+MdFdZj8Etifti+4zi8ahddNOzA
IDPdnO5YhkNdpiai4ykGyteP47kVOORtDLUteT7bRySZnajCwfeKk8xdiQFT
2LNEcR+HP048lgveYlBZVSASPcch3/FrEXcEg6MUO+tmJQ4JfYW7WGOz//Wh
ep0Kh1V+h3ofTGJQO7lAkjyOA4nYWZqrwUBn5xtaq8Hh3+qNsWEfMZD8nHlE
+xmH+tiS1Ws+Y8BXXG7dTOLCr0tNpvR6DMwaU1IzjLnwP1TFNAw=
      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  PlotRange->Automatic,
  PlotRangeClipping->True]], "Output",
 ImageSize->{184, 117},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[17]=",
 CellID->221976821]
}, Open  ]],

Cell[TextData[{
 "\:041a\:0440\:043e\:043c\:0435 \:0442\:043e\:0433\:043e, \:043c\:043e\:0436\
\:043d\:043e \:043f\:0440\:043e\:0441\:043c\:043e\:0442\:0440\:0435\:0442\
\:044c \:0432 \:0442\:0430\:0431\:043b\:0438\:0447\:043d\:043e\:0439 \:0444\
\:043e\:0440\:043c\:0435 \:0440\:0435\:0437\:0443\:043b\:044c\:0442\:0430\
\:0442\:044b \:043e\:0446\:0435\:043d\:043e\:043a \:0434\:043b\:044f \:043a\
\:0430\:0436\:0434\:043e\:0439 \:043a\:043e\:043d\:043a\:0440\:0435\:0442\
\:043d\:043e\:0439 \:0442\:043e\:0447\:043a\:0438. \:0412\:043e\:0441\:043f\
\:043e\:043b\:044c\:0437\:0443\:0435\:043c\:0441\:044f \:0441\:0432\:043e\
\:0439\:0441\:0442\:0432\:043e\:043c ",
 Cell[BoxData["\<\"SinglePredictionConfidenceIntervalTable\"\>"], 
  "InlineFormula"],
 " \:0434\:043b\:044f ",
 Cell[BoxData[
  ButtonBox["FittedModel",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/FittedModel"]], "InlineFormula"],
 ", \:0447\:0442\:043e\:0431\:044b \:0432\:044b\:0432\:0435\:0441\:0442\:0438 \
\:0442\:0430\:0431\:043b\:0438\:0446\:0443 \:0432\:044b\:0447\:0438\:0441\
\:043b\:0435\:043d\:043d\:044b\:0445 \:0437\:043d\:0430\:0447\:0435\:043d\
\:0438\:0439 \:0441 \:043e\:0446\:0435\:043d\:043a\:0430\:043c\:0438 \:043f\
\:043e\:0433\:0440\:0435\:0448\:043d\:043e\:0441\:0442\:0438 \:0438 \:0434\
\:043e\:0432\:0435\:0440\:0438\:0442\:0435\:043b\:044c\:043d\:044b\:043c\:0438\
 \:0438\:043d\:0442\:0435\:0440\:0432\:0430\:043b\:0430\:043c\:0438:"
}], "HowToText",
 CellID->5728552],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"nlm", "[", "\"\<SinglePredictionConfidenceIntervalTable\>\"", 
  "]"}]], "Input",
 CellLabel->"In[18]:=",
 CellID->51301078],

Cell[BoxData[
 StyleBox[
  TagBox[GridBox[{
     {"\<\"Observed\"\>", "\<\"Predicted\"\>", "\<\"Standard Error\"\>", \
"\<\"Confidence Interval\"\>"},
     {"75.3`", "61.37815793508015`", "8.166716424289536`", 
      RowBox[{"{", 
       RowBox[{"42.54567608962868`", ",", "80.21063978053161`"}], "}"}]},
     {"6.8`", "4.954185648200114`", "7.099714097715986`", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "11.41778441990028`"}], ",", "21.326155716300505`"}], 
       "}"}]},
     {"37.9`", "40.349694861110606`", "7.5967888499213405`", 
      RowBox[{"{", 
       RowBox[{"22.83146835891908`", ",", "57.86792136330213`"}], "}"}]},
     {"48.8`", "61.37815793508015`", "8.166716424289536`", 
      RowBox[{"{", 
       RowBox[{"42.54567608962868`", ",", "80.21063978053161`"}], "}"}]},
     {"9.7`", "10.322290307323799`", "7.439563814290201`", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "6.833374612544697`"}], ",", "27.477955227192297`"}], 
       "}"}]},
     {"6.1`", "5.501937792802784`", "7.139446133257715`", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "10.961654513556912`"}], ",", "21.965530099162482`"}], 
       "}"}]},
     {"3.4`", "2.9326165584001904`", "6.949899818192377`", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "13.093881161606127`"}], ",", "18.95911427840651`"}], 
       "}"}]},
     {"2.2`", "1.9278874970677071`", "6.878646662593867`", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "13.934300151482098`"}], ",", "17.790075145617514`"}], 
       "}"}]},
     {"11.4`", "9.294642073924257`", "7.384307741944233`", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "7.733602114619297`"}], ",", "26.32288626246781`"}], 
       "}"}]},
     {"8.1`", "9.294642073924257`", "7.384307741944233`", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "7.733602114619297`"}], ",", "26.32288626246781`"}], 
       "}"}]}
    },
    AutoDelete->False,
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Automatic}}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "RowsIndexed" -> {2 -> GrayLevel[0.7]}},
    GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
    GridBoxSpacings->{
     "Columns" -> {{Automatic}}, "RowsIndexed" -> {2 -> 0.75}}],
   "Grid"], "DialogStyle",
  StripOnInput->False]], "Output",
 ImageSize->{306, 209},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[18]=",
 CellID->353826475]
}, Open  ]],

Cell["\<\
\:0414\:043e\:043f\:043e\:043b\:043d\:0438\:0442\:0435\:043b\:044c\:043d\:043e\
, \:043c\:043e\:0436\:043d\:043e \:043e\:0442\:043e\:0431\:0440\:0430\:0437\
\:0438\:0442\:044c \:0441\:043e\:043e\:0442\:0432\:0435\:0442\:0441\:0442\
\:0432\:0443\:044e\:0449\:0438\:0435 \:043f\:0440\:043e\:0433\:043d\:043e\
\:0437\:043d\:044b\:0435 \:043e\:0431\:043b\:0430\:0441\:0442\:0438.\
\>", "HowToText",
 CellID->140166572],

Cell["\<\
\:0412 \:043f\:0435\:0440\:0432\:0443\:044e \:043e\:0447\:0435\:0440\:0435\
\:0434\:044c, \:043e\:043f\:0440\:0435\:0434\:0435\:043b\:0438\:043c \:0444\
\:0443\:043d\:043a\:0446\:0438\:0438 \:0434\:043b\:044f 80%, 90%, 95% \:0438 \
99% \:043f\:0440\:043e\:0433\:043d\:043e\:0437\:043d\:044b\:0445 \:043e\:0431\
\:043b\:0430\:0441\:0442\:0435\:0439 \:043f\:043e\:0434\:043e\:0431\:0440\
\:0430\:043d\:043d\:043e\:0439 \:0444\:0443\:043d\:043a\:0446\:0438\:0438:\
\>", "HowToText",
 CellID->409680302],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"bands80", "[", "x_", "]"}], ",", 
     RowBox[{"bands90", "[", "x_", "]"}], ",", 
     RowBox[{"bands95", "[", "x_", "]"}], ",", 
     RowBox[{"bands99", "[", "x_", "]"}]}], "}"}], "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"nlm", "[", 
      RowBox[{"\"\<SinglePredictionBands\>\"", ",", 
       RowBox[{"ConfidenceLevel", "\[Rule]", "cl"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"cl", ",", 
       RowBox[{"{", 
        RowBox[{".8", ",", ".9", ",", ".95", ",", ".99"}], "}"}]}], "}"}]}], 
    "]"}]}], ";"}]], "Input",
 CellLabel->"In[19]:=",
 CellID->27857943],

Cell[TextData[{
 "\:041e\:0442\:043e\:0431\:0440\:0430\:0437\:0438\:043c \:0437\:043e\:043d\
\:044b, \:043e\:0433\:0440\:0430\:043d\:0438\:0447\:0435\:043d\:043d\:044b\
\:0435 \:043f\:0440\:043e\:0433\:043d\:043e\:0437\:043d\:044b\:043c\:0438 \
\:043e\:0431\:043b\:0430\:0441\:0442\:044f\:043c\:0438 \:0432\:0434\:043e\
\:043b\:044c \:043f\:043e\:0434\:043e\:0431\:0440\:0430\:043d\:043d\:043e\
\:0439 \:0444\:0443\:043d\:043a\:0446\:0438\:0438, \:0438 \:0438\:0441\:043f\
\:043e\:043b\:044c\:0437\:0443\:0435\:043c \:043a\:043e\:043c\:0430\:043d\
\:0434\:0443 ",
 Cell[BoxData[
  ButtonBox["Filling",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Filling"]], "InlineFormula"],
 " \:0434\:043b\:044f \:0431\:043e\:043b\:0435\:0435 \:043b\:0435\:0433\:043a\
\:043e\:0433\:043e \:0432\:0438\:0437\:0443\:0430\:043b\:044c\:043d\:043e\
\:0433\:043e \:0432\:043e\:0441\:043f\:0440\:0438\:044f\:0442\:0438\:044f \
\:0437\:043e\:043d \:0441 \:0440\:0430\:0437\:043d\:044b\:043c \:0443\:0440\
\:043e\:0432\:043d\:0435\:043c \:0434\:043e\:0432\:0435\:0440\:0438\:0442\
\:0435\:043b\:044c\:043d\:043e\:0441\:0442\:0438:"
}], "HowToText",
 CellID->332390244],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"nlm", "[", "x", "]"}], ",", 
     RowBox[{"bands80", "[", "x", "]"}], ",", 
     RowBox[{"bands90", "[", "x", "]"}], ",", 
     RowBox[{"bands95", "[", "x", "]"}], ",", 
     RowBox[{"bands99", "[", "x", "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "0", ",", "4"}], "}"}], ",", 
   RowBox[{"Filling", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"2", "\[Rule]", 
       RowBox[{"{", "1", "}"}]}], ",", 
      RowBox[{"3", "\[Rule]", 
       RowBox[{"{", "2", "}"}]}], ",", 
      RowBox[{"4", "\[Rule]", 
       RowBox[{"{", "3", "}"}]}], ",", 
      RowBox[{"5", "\[Rule]", 
       RowBox[{"{", "4", "}"}]}]}], "}"}]}]}], "]"}]], "Input",
 CellLabel->"In[20]:=",
 CellID->109751728],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJztXftTW2d69rT9of9Bf2w7025nOtsftj+1O/V0nG4ab9bb0GTYDQtZYy92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    "], {{0, 110}, {180, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{180, 110},
  PlotRange->{{0, 180}, {0, 110}}]], "Output",
 ImageSize->{184, 110},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"RasterizedOutput",
 CellLabel->"Out[20]=",
 CellID->25299140]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  InterpretationBox[
   StyleBox[
    GraphicsBox[{},
     BaselinePosition->Baseline,
     ImageSize->{6, 0}],
    CacheGraphics->False],
   Spacer[6]]]],
 "\:0423\:0447\:0435\:0431\:043d\:044b\:0435 \:043c\:0430\:0442\:0435\:0440\
\:0438\:0430\:043b\:044b"
}], "TutorialsSection",
 WholeCellGroupOpener->True,
 CellID->250839057],

Cell["", "SectionHeaderSpacer"],

Cell[BoxData[
 TemplateBox[{
  Cell["Statistical Model Analysis"],
   "paclet:tutorial/StatisticalModelAnalysis"},
  "RefLink",
  BaseStyle->"Tutorials"]], "Tutorials",
 CellID->341631938],

Cell[BoxData[
 TemplateBox[{
  Cell["Plotting Lists of Data"],"paclet:tutorial/PlottingListsOfData"},
  "RefLink",
  BaseStyle->"Tutorials"]], "Tutorials",
 CellID->138898779],

Cell[BoxData[
 TemplateBox[{Cell["Options for Graphics"],"paclet:tutorial/Options"},
  "RefLink",
  BaseStyle->"Tutorials"]], "Tutorials",
 CellID->21439481],

Cell[BoxData[
 TemplateBox[{Cell["Basic Plotting"],"paclet:tutorial/BasicPlotting"},
  "RefLink",
  BaseStyle->"Tutorials"]], "Tutorials",
 CellID->966876880],

Cell["", "SectionFooterSpacer"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\:0421\:043e\:043f\:0443\:0442\:0441\:0442\:0432\:0443\:044e\:0449\:0438\
\:0435 \:0434\:0435\:043c\:043e\:043d\:0441\:0442\:0440\:0430\:0446\:0438\
\:043e\:043d\:043d\:044b\:0435 \:043c\:043e\:0434\:0435\:043b\:0438", \
"RelatedDemonstrationsSection",
 CellID->1268215905],

Cell[TextData[Cell[BoxData[
 TemplateBox[{Cell[
    TextData["Fitting Primes to a Linear Model"]],
   "http://demonstrations.wolfram.com/FittingPrimesToALinearModel/"},
  "WebLink",
  BaseStyle->{"RelatedDemonstrations"}]]]], "RelatedDemonstrations",
 CellID->1129518860],

Cell[TextData[Cell[BoxData[
 TemplateBox[{Cell[
    TextData["Comparing Some Residuals for Generalized Linear Models"]],
   "http://demonstrations.wolfram.com/\
ComparingSomeResidualsForGeneralizedLinearModels/"},
  "WebLink",
  BaseStyle->{"RelatedDemonstrations"}]]]], "RelatedDemonstrations",
 CellID->12274091],

Cell[TextData[Cell[BoxData[
 TemplateBox[{Cell[
    TextData["Comparing Binomial Generalized Linear Models"]],
   "http://demonstrations.wolfram.com/\
ComparingBinomialGeneralizedLinearModels/"},
  "WebLink",
  BaseStyle->{"RelatedDemonstrations"}]]]], "RelatedDemonstrations",
 CellID->274339963],

Cell[TextData[Cell[BoxData[
 TemplateBox[{Cell[
    TextData["Logit and Probit Models for O-Ring Failure Data"]],
   "http://demonstrations.wolfram.com/LogitAndProbitModelsForORingFailureData/\
"},
  "WebLink",
  BaseStyle->{"RelatedDemonstrations"}]]]], "RelatedDemonstrations",
 CellID->530850663],

Cell[TextData[Cell[BoxData[
 TemplateBox[{Cell[
    TextData["Maximum Likelihood Estimators for Binary Outcomes"]],
   "http://demonstrations.wolfram.com/\
MaximumLikelihoodEstimatorsForBinaryOutcomes/"},
  "WebLink",
  BaseStyle->{"RelatedDemonstrations"}]]]], "RelatedDemonstrations",
 CellID->288157728],

Cell[TextData[Cell[BoxData[
 TemplateBox[{Cell[
    TextData["Mean and Single Prediction Bands for a Nonlinear Model"]],
   "http://demonstrations.wolfram.com/\
MeanAndSinglePredictionBandsForANonlinearModel/"},
  "WebLink",
  BaseStyle->{"RelatedDemonstrations"}]]]], "RelatedDemonstrations",
 CellID->371495079]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  InterpretationBox[
   StyleBox[
    GraphicsBox[{},
     BaselinePosition->Baseline,
     ImageSize->{6, 0}],
    CacheGraphics->False],
   Spacer[6]]]],
 "\:0421\:043e\:043f\:0443\:0442\:0441\:0442\:0432\:0443\:044e\:0449\:0438\
\:0435 \:0440\:0430\:0437\:0434\:0435\:043b\:044b \:043a\:0440\:0430\:0442\
\:043a\:043e\:0433\:043e \:043a\:0443\:0440\:0441\:0430"
}], "RelatedLinksSection",
 WholeCellGroupOpener->True,
 CellID->1584193535],

Cell["", "SectionHeaderSpacer"],

Cell[TextData[ButtonBox["\:041a\:0440\:0430\:0442\:043a\:0438\:0439 \:043a\
\:0443\:0440\:0441: \:0413\:0440\:0430\:0444\:0438\:0447\:0435\:0441\:043a\
\:0438\:0435 \:0438\:043d\:0441\:0442\:0440\:0443\:043c\:0435\:043d\:0442\
\:044b \:043f\:0440\:043e\:0432\:0435\:0440\:043a\:0438 \:043a\:043e\:0440\
\:0440\:0435\:043a\:0442\:043d\:043e\:0441\:0442\:0438 \:043f\:043e\:0434\
\:0431\:043e\:0440\:0430 \:043c\:043e\:0434\:0435\:043b\:0438 \:043f\:043e \
\:0442\:043e\:0447\:043a\:0430\:043c",
 BaseStyle->"Hyperlink",
 ButtonData->{"PlotDiagnosticsForFittedModelsRU.nb", None}]], "RelatedLinks",
 FontFamily->"Verdana",
 FontSize->11,
 CellID->405226890],

Cell[TextData[ButtonBox["\:041a\:0440\:0430\:0442\:043a\:0438\:0439 \:043a\
\:0443\:0440\:0441: \:0421\:0442\:0430\:0442\:0438\:0441\:0442\:0438\:0447\
\:0435\:0441\:043a\:0438\:0439 \:0430\:043d\:0430\:043b\:0438\:0437",
 BaseStyle->"Hyperlink",
 ButtonData->{"DoStatisticalAnalysisRU.nb", None}]], "RelatedLinks",
 FontFamily->"Verdana",
 FontSize->11,
 CellID->953192995],

Cell["", "SectionFooterSpacer"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  InterpretationBox[
   StyleBox[
    GraphicsBox[{},
     BaselinePosition->Baseline,
     ImageSize->{6, 0}],
    CacheGraphics->False],
   Spacer[6]]]],
 "\:0421\:043c\:043e\:0442\:0440\:0438 \:0442\:0430\:043a\:0436\:0435"
}], "SeeAlsoSection",
 WholeCellGroupOpener->True,
 CellID->1255426704],

Cell[TextData[{
 Cell[BoxData[
  TemplateBox[{Cell["LinearModelFit"],"paclet:ref/LinearModelFit"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  TemplateBox[{Cell["FittedModel"],"paclet:ref/FittedModel"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  TemplateBox[{Cell["NonlinearModelFit"],"paclet:ref/NonlinearModelFit"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  TemplateBox[{
   Cell["GeneralizedLinearModelFit"],"paclet:ref/GeneralizedLinearModelFit"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  TemplateBox[{Cell["Plot"],"paclet:ref/Plot"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  TemplateBox[{Cell["ListPlot"],"paclet:ref/ListPlot"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  TemplateBox[{Cell["Show"],"paclet:ref/Show"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"]
}], "SeeAlso",
 CellID->929782353]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  InterpretationBox[
   StyleBox[
    GraphicsBox[{},
     BaselinePosition->Baseline,
     ImageSize->{6, 0}],
    CacheGraphics->False],
   Spacer[6]]]],
 "\:0423\:0437\:043d\:0430\:0442\:044c \:0431\:043e\:043b\:044c\:0448\:0435"
}], "MoreAboutSection",
 WholeCellGroupOpener->True,
 CellID->38303248],

Cell["", "SectionHeaderSpacer"],

Cell[BoxData[
 TemplateBox[{Cell["Statistics"],"paclet:guide/Statistics"},
  "RefLink",
  BaseStyle->"MoreAbout"]], "MoreAbout",
 CellID->164248854],

Cell[BoxData[
 TemplateBox[{
  Cell["Statistical Model Analysis"],"paclet:guide/StatisticalModelAnalysis"},
  "RefLink",
  BaseStyle->"MoreAbout"]], "MoreAbout",
 CellID->54545674],

Cell[BoxData[
 TemplateBox[{Cell["Data Visualization"],"paclet:guide/DataVisualization"},
  "RefLink",
  BaseStyle->"MoreAbout"]], "MoreAbout",
 CellID->1665078683],

Cell[BoxData[
 TemplateBox[{Cell["\"How to\" Topics"],"paclet:guide/HowToTopics"},
  "RefLink",
  BaseStyle->"MoreAbout"]], "MoreAbout",
 CellID->749557856]
}, Open  ]]
}, Open  ]],

Cell[" ", "FooterCell"]
},
FileChangeProtection->None,
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{Automatic, 510},
WindowMargins->{{312, Automatic}, {Automatic, 0}},
WindowFrame->"Normal",
WindowTitle->"Get Results for Fitted Models - Wolfram Mathematica",
DockedCells->FEPrivate`FrontEndResource["FEExpressions", "HelpViewerToolbar"],
TaggingRules->{
 "ModificationHighlight" -> False, "ColorType" -> "TutorialColor", 
  "LinkTrails" -> "", "ExampleCounter" -> 1, "ExamplePageLinks" -> {}, 
  "RootCaptions" -> "", 
  "Metadata" -> {
   "built" -> "{2013, 1, 24, 22, 47, 48.9906335}", 
    "history" -> {"8", "", "", ""}, "context" -> "System`", 
    "keywords" -> {
     "fitted model", "diagnostic", "diagnostic plot", "residual plot", 
      "linear model", "linear regression", "nonlinear regression", 
      "nonlinear model", "generalized linear model", "probit model", 
      "probit regression", "logit model", "logit regression", "glm", "lm", 
      "model diagnostics", "leverage plot", "influence diagnostics", 
      "residual", "Cook distance", "Cook's distance", "Cook's d", 
      "model diagnostics", "influence measures", "Covratio", "Dfbetas", 
      "Dffits", "fit residuals", "raw residuals", "hat diagonal", 
      "predicted response", "fitted values", "response", "response vector", 
      "StandardizedResiduals", "standardized residuals", 
      "StudentizedResiduals", "Studentized residuals", 
      "VarianceInflationFactors", "variance inflation factors", 
      "variance inflation", "Anscombe residuals", "Anscombe's residuals", 
      "likelihood residuals", "Pearson residuals", "Pearson's residuals", 
      "standardized deviance residuals", "standardized Pearson residuals", 
      "standardized Pearson's residuals", "working residuals", 
      "deviance residuals", "deviances"}, "specialkeywords" -> {}, 
    "tutorialcollectionlinks" -> {}, "index" -> True, "label" -> 
    "Mathematica How To", "language" -> "en", "paclet" -> "Mathematica", 
    "status" -> "None", "summary" -> 
    "When fitting data to a model, it is often important to obtain additional \
results to compare the data to the fitted function. You may wish to check the \
significance of parameters and assess the assumptions of the model, the \
influence of data points, and the goodness of fit. In Mathematica you can \
obtain these results directly from FittedModel objects returned by model \
fitting functions such as LinearModelFit , NonlinearModelFit , and \
GeneralizedLinearModelFit .", "synonyms" -> {}, "title" -> 
    "Get Results for Fitted Models", "titlemodifier" -> "", "windowtitle" -> 
    "Get Results for Fitted Models", "type" -> "HowTo", "uri" -> 
    "howto/GetResultsForFittedModels"}, "SearchTextTranslated" -> ""},
Magnification->1.,
FrontEndVersion->"10.1 for Microsoft Windows (64-bit) (March 23, 2015)",
StyleDefinitions->FrontEnd`FileName[{"Wolfram"}, "Reference.nb", 
  CharacterEncoding -> "WindowsANSI"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "RasterizedOutput"->{
  Cell[56451, 1422, 9437, 163, 131, "Output",
   CellTags->"RasterizedOutput",
   CellID->25299140]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"RasterizedOutput", 77319, 1922}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[622, 21, 5247, 125, 48, "AnchorBarGrid",
 CellID->1],
Cell[CellGroupData[{
Cell[5894, 150, 488, 9, 91, "HowToTitle",
 CellID->509267359],
Cell[CellGroupData[{
Cell[6407, 163, 2785, 52, 110, "HowToAbstract",
 CellID->1045883471],
Cell[9195, 217, 359, 5, 38, "HowToText",
 CellID->1009846402],
Cell[9557, 224, 821, 26, 47, "Input",
 CellID->827466675],
Cell[10381, 252, 621, 13, 40, "HowToText",
 CellID->1389965763],
Cell[CellGroupData[{
Cell[11027, 269, 173, 5, 28, "Input",
 CellID->411630083],
Cell[11203, 276, 359, 13, 56, "Output",
 CellID->147115952]
}, Open  ]],
Cell[11577, 292, 1195, 20, 76, "HowToText",
 CellID->160271121],
Cell[12775, 314, 597, 13, 40, "HowToText",
 CellID->812217608],
Cell[CellGroupData[{
Cell[13397, 331, 105, 3, 28, "Input",
 CellID->1398028897],
Cell[13505, 336, 257, 8, 36, "Output",
 CellID->113312487]
}, Open  ]],
Cell[13777, 347, 422, 7, 38, "HowToText",
 CellID->503057640],
Cell[14202, 356, 553, 11, 40, "HowToText",
 CellID->1445501569],
Cell[CellGroupData[{
Cell[14780, 371, 98, 3, 28, "Input",
 CellID->89859940],
Cell[14881, 376, 256, 8, 36, "Output",
 CellID->88375730]
}, Open  ]],
Cell[15152, 387, 756, 14, 57, "HowToText",
 CellID->1611208941],
Cell[CellGroupData[{
Cell[15933, 405, 102, 3, 28, "Input",
 CellID->1967366364],
Cell[16038, 410, 174, 5, 36, "Output",
 CellID->8883197]
}, Open  ]],
Cell[16227, 418, 879, 19, 60, "HowToText",
 CellID->84424557],
Cell[CellGroupData[{
Cell[17131, 441, 242, 8, 28, "Input",
 CellID->146308799],
Cell[17376, 451, 2177, 44, 174, "Output",
 CellID->858141887]
}, Open  ]],
Cell[19568, 498, 1314, 25, 78, "HowToText",
 CellID->58727254],
Cell[CellGroupData[{
Cell[20907, 527, 164, 5, 28, "Input",
 CellID->71688609],
Cell[21074, 534, 2237, 44, 168, "Output",
 CellID->90140410]
}, Open  ]],
Cell[23326, 581, 1930, 34, 96, "HowToText",
 CellID->438571833],
Cell[25259, 617, 662, 13, 58, "HowToText",
 CellID->223094117],
Cell[CellGroupData[{
Cell[25946, 634, 145, 4, 28, "Input",
 CellID->187861414],
Cell[26094, 640, 160, 5, 36, "Output",
 CellID->374649664]
}, Open  ]],
Cell[26269, 648, 2753, 47, 113, "HowToText",
 CellID->626748087],
Cell[29025, 697, 957, 20, 59, "HowToText",
 CellID->301606275],
Cell[CellGroupData[{
Cell[30007, 721, 120, 3, 28, "Input",
 CellID->281808015],
Cell[30130, 726, 1011, 25, 74, "Output",
 CellID->350168195]
}, Open  ]],
Cell[31156, 754, 1729, 33, 77, "HowToText",
 CellID->437611161],
Cell[CellGroupData[{
Cell[32910, 791, 121, 3, 28, "Input",
 CellID->888529300],
Cell[33034, 796, 246, 8, 39, "Output",
 CellID->1766081534]
}, Open  ]],
Cell[33295, 807, 708, 14, 39, "HowToText",
 CellID->851221982],
Cell[CellGroupData[{
Cell[34028, 825, 200, 6, 28, "Input",
 CellID->201677425],
Cell[34231, 833, 405, 14, 39, "Output",
 CellID->23655885]
}, Open  ]],
Cell[34651, 850, 427, 7, 38, "HowToText",
 CellID->415880261],
Cell[CellGroupData[{
Cell[35103, 861, 133, 3, 28, "Input",
 CellID->57102216],
Cell[35239, 866, 418, 14, 36, "Output",
 CellID->852093708]
}, Open  ]],
Cell[35672, 883, 967, 18, 58, "HowToText",
 CellID->438776831],
Cell[36642, 903, 296, 4, 38, "HowToText",
 CellID->578163253],
Cell[CellGroupData[{
Cell[36963, 911, 203, 5, 28, "Input",
 CellID->280761658],
Cell[37169, 918, 401, 14, 36, "Output",
 CellID->180239820]
}, Open  ]],
Cell[37585, 935, 708, 13, 56, "HowToText",
 CellID->704180568],
Cell[38296, 950, 483, 9, 40, "HowToText",
 CellID->521615316],
Cell[CellGroupData[{
Cell[38804, 963, 146, 4, 28, "Input",
 CellID->369509882],
Cell[38953, 969, 578, 14, 54, "Output",
 CellID->839756941]
}, Open  ]],
Cell[39546, 986, 382, 10, 40, "HowToText",
 CellID->129497841],
Cell[CellGroupData[{
Cell[39953, 1000, 110, 3, 28, "Input",
 CellID->136313857],
Cell[40066, 1005, 655, 17, 163, "Output",
 CellID->625211867]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[40770, 1028, 65, 2, 15, "HowToDelimiter",
 CellID->38965223],
Cell[40838, 1032, 1916, 39, 96, "HowToText",
 CellID->16364313],
Cell[42757, 1073, 338, 5, 38, "HowToText",
 CellID->172471107],
Cell[43098, 1080, 817, 26, 47, "Input",
 CellID->299022243],
Cell[43918, 1108, 633, 13, 58, "HowToText",
 CellID->210684085],
Cell[CellGroupData[{
Cell[44576, 1125, 323, 10, 28, "Input",
 CellID->454023941],
Cell[44902, 1137, 381, 13, 57, "Output",
 CellID->86791284]
}, Open  ]],
Cell[45298, 1153, 820, 15, 58, "HowToText",
 CellID->76696085],
Cell[CellGroupData[{
Cell[46143, 1172, 316, 10, 28, "Input",
 CellID->66007681],
Cell[46462, 1184, 2248, 43, 175, "Output",
 CellID->221976821]
}, Open  ]],
Cell[48725, 1230, 1470, 25, 94, "HowToText",
 CellID->5728552],
Cell[CellGroupData[{
Cell[50220, 1259, 148, 4, 28, "Input",
 CellID->51301078],
Cell[50371, 1265, 2473, 63, 240, "Output",
 CellID->353826475]
}, Open  ]],
Cell[52859, 1331, 424, 7, 38, "HowToText",
 CellID->140166572],
Cell[53286, 1340, 509, 8, 56, "HowToText",
 CellID->409680302],
Cell[53798, 1350, 668, 20, 47, "Input",
 CellID->27857943],
Cell[54469, 1372, 1150, 20, 58, "HowToText",
 CellID->332390244],
Cell[CellGroupData[{
Cell[55644, 1396, 804, 24, 47, "Input",
 CellID->109751728],
Cell[56451, 1422, 9437, 163, 131, "Output",
 CellTags->"RasterizedOutput",
 CellID->25299140]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[65937, 1591, 362, 13, 31, "TutorialsSection",
 CellID->250839057],
Cell[66302, 1606, 31, 0, 14, "SectionHeaderSpacer"],
Cell[66336, 1608, 188, 6, 19, "Tutorials",
 CellID->341631938],
Cell[66527, 1616, 175, 5, 19, "Tutorials",
 CellID->138898779],
Cell[66705, 1623, 157, 4, 19, "Tutorials",
 CellID->21439481],
Cell[66865, 1629, 158, 4, 19, "Tutorials",
 CellID->966876880],
Cell[67026, 1635, 31, 0, 29, "SectionFooterSpacer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[67094, 1640, 279, 4, 30, "RelatedDemonstrationsSection",
 CellID->1268215905],
Cell[67376, 1646, 271, 6, 29, "RelatedDemonstrations",
 CellID->1129518860],
Cell[67650, 1654, 314, 7, 29, "RelatedDemonstrations",
 CellID->12274091],
Cell[67967, 1663, 297, 7, 29, "RelatedDemonstrations",
 CellID->274339963],
Cell[68267, 1672, 299, 7, 29, "RelatedDemonstrations",
 CellID->530850663],
Cell[68569, 1681, 306, 7, 29, "RelatedDemonstrations",
 CellID->288157728],
Cell[68878, 1690, 313, 7, 29, "RelatedDemonstrations",
 CellID->371495079]
}, Open  ]],
Cell[CellGroupData[{
Cell[69228, 1702, 472, 14, 31, "RelatedLinksSection",
 CellID->1584193535],
Cell[69703, 1718, 31, 0, 14, "SectionHeaderSpacer"],
Cell[69737, 1720, 655, 11, 18, "RelatedLinks",
 CellID->405226890],
Cell[70395, 1733, 374, 7, 18, "RelatedLinks",
 CellID->953192995],
Cell[70772, 1742, 31, 0, 29, "SectionFooterSpacer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[70840, 1747, 329, 12, 31, "SeeAlsoSection",
 CellID->1255426704],
Cell[71172, 1761, 1962, 55, 74, "SeeAlso",
 CellID->929782353]
}, Open  ]],
Cell[CellGroupData[{
Cell[73171, 1821, 335, 12, 31, "MoreAboutSection",
 CellID->38303248],
Cell[73509, 1835, 31, 0, 14, "SectionHeaderSpacer"],
Cell[73543, 1837, 148, 4, 19, "MoreAbout",
 CellID->164248854],
Cell[73694, 1843, 180, 5, 19, "MoreAbout",
 CellID->54545674],
Cell[73877, 1850, 164, 4, 19, "MoreAbout",
 CellID->1665078683],
Cell[74044, 1856, 156, 4, 19, "MoreAbout",
 CellID->749557856]
}, Open  ]]
}, Open  ]],
Cell[74227, 1864, 23, 0, 41, "FooterCell"]
}
]
*)

(* End of internal cache information *)
