(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    113419,       2698]
NotebookOptionsPosition[    101024,       2319]
NotebookOutlinePosition[    106501,       2451]
CellTagsIndexPosition[    106313,       2441]
WindowTitle->Naming and Finding Files - Wolfram Mathematica
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[GridBox[{
   {Cell["MATHEMATICA TUTORIAL", "PacletNameCell"], Cell[TextData[{
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "Related Tutorials",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"Related Tutorials", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->False], {"\<\"Files and Streams\"\>":>
       Documentation`HelpLookup[
       "paclet:tutorial/FilesAndStreams"], "\<\"External Programs\"\>":>
       Documentation`HelpLookup[
       "paclet:tutorial/ExternalPrograms"], "\<\"Mathematica File \
Organization\"\>":>Documentation`HelpLookup[
       "paclet:tutorial/MathematicaFileOrganization"], "\<\"Files, Streams, \
and External Operations\"\>":>Documentation`HelpLookup[
       "paclet:tutorial/FilesStreamsAndExternalOperationsOverview"]},
       Appearance->None,
       MenuAppearance->Automatic,
       MenuStyle->"RelatedTutorialsSection"]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "Related Guides",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"Related Guides", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->False], {"\<\"Operations on File Names\"\>":>
       Documentation`HelpLookup["paclet:guide/OperationsOnFileNames"]},
       Appearance->None,
       MenuAppearance->Automatic,
       MenuStyle->"TutorialMoreAboutSection"]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "Functions",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"Functions", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->False], {"\<\"Directory\"\>":>Documentation`HelpLookup[
       "paclet:ref/Directory"], "\<\"DirectoryName\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/DirectoryName"], "\<\"DumpSave\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/DumpSave"], "\<\"FileBaseName\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/FileBaseName"], "\<\"FileExistsQ\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/FileExistsQ"], "\<\"FileExtension\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/FileExtension"], "\<\"FileNameDepth\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/FileNameDepth"], "\<\"FileNameDrop\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/FileNameDrop"], "\<\"FileNameJoin\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/FileNameJoin"], "\<\"FileNames\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/FileNames"], "\<\"FileNameSplit\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/FileNameSplit"], "\<\"FileNameTake\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/FileNameTake"], "\<\"FindFile\"\>":>
       Documentation`HelpLookup["paclet:ref/FindFile"], "\<\"Get\"\>":>
       Documentation`HelpLookup["paclet:ref/Get"], "\<\"Infinity\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/Infinity"], "\<\"ParentDirectory\"\>":>
       Documentation`HelpLookup["paclet:ref/ParentDirectory"], "\<\"Path\"\>":>
       Documentation`HelpLookup["paclet:ref/Path"], "\<\"ResetDirectory\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/ResetDirectory"], "\<\"SetDirectory\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/SetDirectory"], "\<\"$BaseDirectory\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/$BaseDirectory"], "\<\"$HomeDirectory\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/$HomeDirectory"], "\<\"$InitialDirectory\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/$InitialDirectory"], "\<\"$InputFileName\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/$InputFileName"], "\<\"$InstallationDirectory\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/$InstallationDirectory"], "\<\"$Path\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/$Path"], "\<\"$PathnameSeparator\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/$PathnameSeparator"], "\<\"$UserBaseDirectory\"\>":>
       Documentation`HelpLookup["paclet:ref/$UserBaseDirectory"]},
       Appearance->None,
       MenuAppearance->Automatic,
       MenuStyle->"TutorialFunction"]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "URL",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"URL", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->False], {"\<\"tutorial/NamingAndFindingFiles\"\>":>
       None, "\<\"Copy Mathematica URL\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell["tutorial/NamingAndFindingFiles"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; Null], 
       Delimiter, "\<\"Copy web URL\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell[
              BoxData[
               MakeBoxes[
                Hyperlink[
                "http://reference.wolfram.com/mathematica/tutorial/\
NamingAndFindingFiles.html"], StandardForm]], "Input", TextClipboardType -> 
              "PlainText"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; 
        Null], "\<\"Go to web URL\"\>":>FrontEndExecute[{
         NotebookLocate[{
           URL[
            StringJoin[
            "http://reference.wolfram.com/mathematica/", 
             "tutorial/NamingAndFindingFiles", ".html"]], None}]}]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}]
    }], "AnchorBar"]}
  }]], "AnchorBarGrid",
 CellID->1],

Cell[CellGroupData[{

Cell["\:041f\:0440\:0438\:0441\:0432\:043e\:0435\:043d\:0438\:0435 \:0438\
\:043c\:0435\:043d \:0438 \:043f\:043e\:0438\:0441\:043a \:0444\:0430\:0439\
\:043b\:043e\:0432", "Title",
 CellTags->"1.0",
 CellID->12068],

Cell[BoxData[GridBox[{
   {Cell[BoxData[
     ButtonBox[
      RowBox[{
      "\[RightGuillemet]", " ", 
       "\:041e\:043f\:0435\:0440\:0430\:0446\:0438\:0438", " ", "\:0441", " ",
        "\:043a\:0430\:0442\:0430\:043b\:043e\:0433\:0430\:043c\:0438"}],
      BaseStyle->"Hyperlink",
      ButtonData->{"NamingAndFindingFilesRU.nb", "1.1"}]],
     FontFamily->"Arial",
     FontSize->13,
     FontWeight->Bold], Cell[BoxData[
     ButtonBox[
      RowBox[{
      "\[RightGuillemet]", " ", 
       "\:0421\:043e\:0441\:0442\:0430\:0432\:043b\:0435\:043d\:0438\:0435", 
       " ", "\:0438\:043c\:0435\:043d\:0438", " ", 
       "\:0444\:0430\:0439\:043b\:0430"}],
      BaseStyle->"Hyperlink",
      ButtonData->{"NamingAndFindingFilesRU.nb", "4.1"}]],
     FontFamily->"Arial",
     FontSize->13,
     FontWeight->Bold]},
   {Cell[BoxData[
     ButtonBox[
      RowBox[{
      "\[RightGuillemet]", " ", "\:041f\:043e\:0438\:0441\:043a", " ", 
       "\:0444\:0430\:0439\:043b\:0430"}],
      BaseStyle->"Hyperlink",
      ButtonData->{"NamingAndFindingFilesRU.nb", "2.1"}]],
     FontFamily->"Arial",
     FontSize->13,
     FontWeight->Bold], Cell[BoxData[
     ButtonBox[
      RowBox[{
      "\[RightGuillemet]", " ", 
       "\:0421\:0442\:0430\:043d\:0434\:0430\:0440\:0442\:043d\:044b\:0435", 
       " ", "\:0440\:0430\:0441\:0448\:0438\:0440\:0435\:043d\:0438\:044f", 
       " ", "\:0438\:043c\:0435\:043d", " ", 
       "\:0444\:0430\:0439\:043b\:043e\:0432"}],
      BaseStyle->"Hyperlink",
      ButtonData->{"NamingAndFindingFilesRU.nb", "5.1"}]],
     FontFamily->"Arial",
     FontSize->13,
     FontWeight->Bold]},
   {Cell[BoxData[
     ButtonBox[
      RowBox[{
      "\[RightGuillemet]", " ", 
       "\:041f\:0440\:043e\:0441\:043c\:043e\:0442\:0440", " ", 
       "\:0441\:043e\:0434\:0435\:0440\:0436\:0438\:043c\:043e\:0433\:043e", 
       " ", "\:043a\:0430\:0442\:0430\:043b\:043e\:0433\:043e\:0432"}],
      BaseStyle->"Hyperlink",
      ButtonData->{"NamingAndFindingFilesRU.nb", "3.1"}]],
     FontFamily->"Arial",
     FontSize->13,
     FontWeight->Bold], ""}
  }]], "TutorialJumpBox",
 CellID->328837780],

Cell[CellGroupData[{

Cell["\:041e\:043f\:0435\:0440\:0430\:0446\:0438\:0438 \:0441 \:043a\:0430\
\:0442\:0430\:043b\:043e\:0433\:0430\:043c\:0438", "Section",
 CellTags->"1.1",
 CellID->90379007],

Cell[TextData[{
 "\:041a\:043e\:043d\:043a\:0440\:0435\:0442\:043d\:044b\:0435 \:043e\:0441\
\:043e\:0431\:0435\:043d\:043d\:043e\:0441\:0442\:0438 \:043f\:0440\:0438\
\:0441\:0432\:043e\:0435\:043d\:0438\:044f \:0438\:043c\:0435\:043d \:0444\
\:0430\:0439\:043b\:0430\:043c \:043e\:0442\:043b\:0438\:0447\:0430\:044e\
\:0442\:0441\:044f \:043e\:0442 \:043e\:0434\:043d\:043e\:0439 \:043a\:043e\
\:043c\:043f\:044c\:044e\:0442\:0435\:0440\:043d\:043e\:0439 \:0441\:0438\
\:0441\:0442\:0435\:043c\:044b \:043a \:0434\:0440\:0443\:0433\:043e\:0439. \
\:0422\:0435\:043c \:043d\:0435 \:043c\:0435\:043d\:0435\:0435, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " \:043f\:0440\:0435\:0434\:043b\:0430\:0433\:0430\:0435\:0442 \:043e\:0442\
\:0434\:0435\:043b\:044c\:043d\:044b\:0435, \:0434\:043e\:0441\:0442\:0430\
\:0442\:043e\:0447\:043d\:043e \:0443\:043d\:0438\:0432\:0435\:0440\:0441\
\:0430\:043b\:044c\:043d\:044b\:0435 \:043c\:0435\:0445\:0430\:043d\:0438\
\:0437\:043c\:044b, \:043a\:043e\:0442\:043e\:0440\:044b\:0435 \:0440\:0430\
\:0431\:043e\:0442\:0430\:044e\:0442 \:043d\:0430 \:0432\:0441\:0435\:0445 \
\:0441\:0438\:0441\:0442\:0435\:043c\:0430\:0445."
}], "Text",
 CellID->18985],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " \:043f\:0440\:0435\:0434\:043f\:043e\:043b\:0430\:0433\:0430\:0435\:0442, \
\:0447\:0442\:043e \:0432\:0441\:0435 \:0432\:0430\:0448\:0438 \:0444\:0430\
\:0439\:043b\:044b \:0440\:0430\:0441\:043f\:043e\:043b\:043e\:0436\:0435\
\:043d\:044b \:0432 \:0438\:0435\:0440\:0430\:0440\:0445\:0438\:0447\:0435\
\:0441\:043a\:043e\:0439 \:0441\:0442\:0440\:0443\:043a\:0442\:0443\:0440\
\:0435 ",
 StyleBox["\:043a\:0430\:0442\:0430\:043b\:043e\:0433\:043e\:0432",
  FontSlant->"Italic"],
 ". \:0427\:0442\:043e\:0431\:044b \:043d\:0430\:0439\:0442\:0438 \
\:043a\:043e\:043d\:043a\:0440\:0435\:0442\:043d\:044b\:0439 \:0444\:0430\
\:0439\:043b, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " \:0434\:043e\:043b\:0436\:043d\:0430 \:0437\:043d\:0430\:0442\:044c \:0438\
\:043c\:044f \:0444\:0430\:0439\:043b\:0430, \:0430 \:0442\:0430\:043a\:0436\
\:0435, \:0432 \:043a\:0430\:043a\:043e\:0439 \:043f\:043e\:0441\:043b\:0435\
\:0434\:043e\:0432\:0430\:0442\:0435\:043b\:044c\:043d\:043e\:0441\:0442\:0438\
 \:043a\:0430\:0442\:0430\:043b\:043e\:0433\:043e\:0432 \:043d\:0430\:0445\
\:043e\:0434\:0438\:0442\:0441\:044f \:0444\:0430\:0439\:043b."
}], "Text",
 CellID->30524],

Cell[TextData[{
 "\:041d\:0443\:0436\:043d\:043e \:043e\:0442\:0434\:0430\:0432\:0430\:0442\
\:044c \:0441\:0435\:0431\:0435 \:043e\:0442\:0447\:0435\:0442, \:0447\:0442\
\:043e \:0432 \:043b\:044e\:0431\:043e\:0439 \:043c\:043e\:043c\:0435\:043d\
\:0442 \:0432\:0440\:0435\:043c\:0435\:043d\:0438, \:0443 \:0432\:0430\:0441 \
\:0435\:0441\:0442\:044c ",
 StyleBox["\:0442\:0435\:043a\:0443\:0449\:0438\:0439 \
\:0440\:0430\:0431\:043e\:0447\:0438\:0439 \:043a\:0430\:0442\:0430\:043b\
\:043e\:0433",
  FontSlant->"Italic"],
 ", \:0438 \:0432\:044b \:043c\:043e\:0436\:0435\:0442\:0435 \:043e\:0431\
\:0440\:0430\:0449\:0430\:0442\:044c\:0441\:044f \:043a \:0444\:0430\:0439\
\:043b\:0430\:043c \:0438\:043b\:0438 \:0434\:0440\:0443\:0433\:0438\:043c \
\:043a\:0430\:0442\:0430\:043b\:043e\:0433\:0430\:043c, \:0443\:043a\:0430\
\:0437\:044b\:0432\:0430\:044f, \:0433\:0434\:0435 \:043e\:043d\:0438 \:043d\
\:0430\:0445\:043e\:0434\:044f\:0442\:0441\:044f \:043e\:0442\:043d\:043e\
\:0441\:0438\:0442\:0435\:043b\:044c\:043d\:043e \:044d\:0442\:043e\:0433\
\:043e ",
 StyleBox["\:0442\:0435\:043a\:0443\:0449\:0435\:0433\:043e \
\:0440\:0430\:0431\:043e\:0447\:0435\:0433\:043e \:043a\:0430\:0442\:0430\
\:043b\:043e\:0433\:0430",
  FontSlant->"Italic"],
 ". \:041e\:0431\:044b\:0447\:043d\:043e, \:043a \:0444\:0430\:0439\:043b\
\:0430\:043c \:0438\:043b\:0438 \:043a\:0430\:0442\:0430\:043b\:043e\:0433\
\:0430\:043c, \:043d\:0430\:0445\:043e\:0434\:044f\:0449\:0438\:043c\:0441\
\:044f \:0432\:043d\:0443\:0442\:0440\:0438 ",
 StyleBox["\:0442\:0435\:043a\:0443\:0449\:0435\:0433\:043e \
\:0440\:0430\:0431\:043e\:0447\:0435\:0433\:043e \:043a\:0430\:0442\:0430\
\:043b\:043e\:0433\:0430",
  FontSlant->"Italic"],
 ", \:043c\:043e\:0436\:043d\:043e \:043e\:0431\:0440\:0430\:0442\:0438\:0442\
\:044c\:0441\:044f \:043f\:0440\:043e\:0441\:0442\:043e \:0443\:043a\:0430\
\:0437\:044b\:0432\:0430\:044f \:0438\:0445 \:0438\:043c\:0435\:043d\:0430, \
\:0431\:0435\:0437 \:0443\:043a\:0430\:0437\:0430\:043d\:0438\:044f \:043f\
\:0443\:0442\:0438 \:043a \:043d\:0438\:043c."
}], "Text",
 CellID->10764],

Cell[BoxData[GridBox[{
   {
    RowBox[{
     ButtonBox["Directory",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/Directory"], "[", "]"}], Cell[
    "\:0432\:0430\:0448 \:0442\:0435\:043a\:0443\:0449\:0438\:0439 \:0440\
\:0430\:0431\:043e\:0447\:0438\:0439 \:043a\:0430\:0442\:0430\:043b\:043e\
\:0433", "TableText"]},
   {
    RowBox[{
     ButtonBox["SetDirectory",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/SetDirectory"], "[", "\"\<\!\(\*
StyleBox[\"\:043a\:0430\:0442\:0430\:043b\:043e\:0433\", \"TI\"]\)\>\"", 
     "]"}], Cell[
    "\:0437\:0430\:0434\:0430\:043d\:0438\:0435 \
\:0442\:0435\:043a\:0443\:0449\:0435\:0433\:043e \:0440\:0430\:0431\:043e\
\:0447\:0435\:0433\:043e \:043a\:0430\:0442\:0430\:043b\:043e\:0433\:0430", 
     "TableText"]},
   {
    RowBox[{
     ButtonBox["ResetDirectory",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/ResetDirectory"], "[", "]"}], Cell[
    "\:0432\:043e\:0437\:0432\:0440\:0430\:0442 \:043a \:043f\:0440\:0435\
\:0434\:044b\:0434\:0443\:0449\:0435\:043c\:0443 \:0440\:0430\:0431\:043e\
\:0447\:0435\:043c\:0443 \:043a\:0430\:0442\:0430\:043b\:043e\:0433\:0443", 
     "TableText"]}
  }]], "DefinitionBox",
 CellID->1587],

Cell["\:041e\:043f\:0435\:0440\:0430\:0446\:0438\:0438 \:0441 \:043a\:0430\
\:0442\:0430\:043b\:043e\:0433\:0430\:043c\:0438.", "Caption",
 CellID->27629],

Cell["\<\
\:042d\:0442\:0430 \:043a\:043e\:043c\:0430\:043d\:0434\:0430 \:0432\:043e\
\:0437\:0432\:0440\:0430\:0449\:0430\:0435\:0442 \:0442\:0435\:043a\:0441\
\:0442\:043e\:0432\:044b\:0439 \:0444\:0440\:0430\:0433\:043c\:0435\:043d\
\:0442, \:043e\:0442\:043e\:0431\:0440\:0430\:0436\:0430\:044e\:0449\:0438\
\:0439 \:0442\:0435\:043a\:0443\:0449\:0438\:0439 \:0440\:0430\:0431\:043e\
\:0447\:0438\:0439 \:043a\:0430\:0442\:0430\:043b\:043e\:0433.\
\>", "MathCaption",
 CellID->1118],

Cell[BoxData[
 RowBox[{"Directory", "[", "]"}]], "Input", "ConversionLockdown",
 CellGroupingRules->{$CellContext`GroupTogetherGrouping, 10000.},
 CellLabel->"In[1]:= ",
 CellID->30111],

Cell["/users/sw", "Output", "ConversionLockdown",
 CellGroupingRules->{$CellContext`GroupTogetherGrouping, 10000.},
 ImageSize->{63, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[1]= ",
 CellID->27602],

Cell[TextData[{
 "\:0422\:0430\:043a \:043f\:043e\:0434\:043a\:0430\:0442\:0430\:043b\:043e\
\:0433 ",
 Cell[BoxData["Examples"], "InlineFormula"],
 " \:0437\:0430\:0434\:0430\:0435\:0442\:0441\:044f \:0432 \:043a\:0430\:0447\
\:0435\:0441\:0442\:0432\:0435 \:0442\:0435\:043a\:0443\:0449\:0435\:0433\
\:043e \:0440\:0430\:0431\:043e\:0447\:0435\:0433\:043e \:043a\:0430\:0442\
\:0430\:043b\:043e\:0433\:0430. "
}], "MathCaption",
 CellID->32322],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SetDirectory", "[", "\"\<Examples\>\"", "]"}]], "Input", \
"ConversionLockdown",
 CellLabel->"In[2]:= ",
 CellID->12796],

Cell["/users/sw/Examples", "Output", "ConversionLockdown",
 ImageSize->{126, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[2]= ",
 CellID->10312]
}, Open  ]],

Cell["\:0422\:0435\:043f\:0435\:0440\:044c \:0443 \:0432\:0430\:0441 \:0434\
\:0440\:0443\:0433\:043e\:0439 \:0442\:0435\:043a\:0443\:0449\:0438\:0439 \
\:0440\:0430\:0431\:043e\:0447\:0438\:0439 \:043a\:0430\:0442\:0430\:043b\
\:043e\:0433.", "MathCaption",
 CellID->22942],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Directory", "[", "]"}]], "Input", "ConversionLockdown",
 CellLabel->"In[3]:= ",
 CellID->14497],

Cell["/users/sw/Examples", "Output", "ConversionLockdown",
 GeneratedCell->False,
 ImageSize->{126, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[3]= ",
 CellID->9188]
}, Open  ]],

Cell["\:0422\:0430\:043a \:0432\:044b\:043f\:043e\:043b\:043d\:044f\:0435\
\:0442\:0441\:044f \:0432\:043e\:0437\:0432\:0440\:0430\:0442 \:043a \:043f\
\:0440\:0435\:0434\:044b\:0434\:0443\:0449\:0435\:043c\:0443 \:0440\:0430\
\:0431\:043e\:0447\:0435\:043c\:0443 \:043a\:0430\:0442\:0430\:043b\:043e\
\:0433\:0443.", "MathCaption",
 CellID->30372],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ResetDirectory", "[", "]"}]], "Input", "ConversionLockdown",
 CellLabel->"In[4]:= ",
 CellID->30838],

Cell["/users/sw", "Output", "ConversionLockdown",
 ImageSize->{63, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[4]= ",
 CellID->7613]
}, Open  ]],

Cell[TextData[{
 "\:041f\:0440\:0438 \:0438\:0441\:043f\:043e\:043b\:044c\:0437\:043e\:0432\
\:0430\:043d\:0438\:0438 \:043a\:043e\:043c\:0430\:043d\:0434\:044b ",
 Cell[BoxData[
  TemplateBox[{Cell["SetDirectory"],"paclet:ref/SetDirectory"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 ", \:0432\:044b \:043c\:043e\:0436\:0435\:0442\:0435 \
\:0443\:043a\:0430\:0437\:0430\:0442\:044c \:0438\:043c\:044f \:043a\:0430\
\:0442\:0430\:043b\:043e\:0433\:0430 \:043b\:044e\:0431\:044b\:043c \:0441\
\:043f\:043e\:0441\:043e\:0431\:043e\:043c, \:043a\:043e\:0442\:043e\:0440\
\:044b\:0439 \:0440\:0430\:0441\:043f\:043e\:0437\:043d\:0430\:0435\:0442\
\:0441\:044f \:043e\:043f\:0435\:0440\:0430\:0446\:0438\:043e\:043d\:043d\
\:043e\:0439 \:0441\:0438\:0441\:0442\:0435\:043c\:043e\:0439. \:0422\:0430\
\:043a, \:043d\:0430\:043f\:0440\:0438\:043c\:0435\:0440, \:0432 Unix-\:0441\
\:0438\:0441\:0442\:0435\:043c\:0430\:0445 \:0432\:044b \:043c\:043e\:0436\
\:0435\:0442\:0435 \:0443\:043a\:0430\:0437\:0430\:0442\:044c \:043a\:0430\
\:0442\:0430\:043b\:043e\:0433 \:043d\:0430 \:043e\:0434\:0438\:043d \:0443\
\:0440\:043e\:0432\:0435\:043d\:044c \:0432\:044b\:0448\:0435 \:0432 \:0438\
\:0435\:0440\:0430\:0440\:0445\:0438\:0438, \:0432\:043e\:0441\:043f\:043e\
\:043b\:044c\:0437\:043e\:0432\:0430\:0432\:0448\:0438\:0441\:044c \:043d\
\:043e\:0442\:0430\:0446\:0438\:0435\:0439 ",
 Cell[BoxData[".."], "InlineFormula"],
 ", \:0430 \:0442\:0430\:043a\:0436\:0435 \
\:0443\:043a\:0430\:0437\:0430\:0442\:044c \:0441\:0432\:043e\:0439 \"\:0434\
\:043e\:043c\:0430\:0448\:043d\:0438\:0439\" \:043a\:0430\:0442\:0430\:043b\
\:043e\:0433 \:043f\:0440\:0438 \:043f\:043e\:043c\:043e\:0449\:0438 ",
 Cell[BoxData["~"], "InlineFormula"],
 ". "
}], "Text",
 CellID->8933],

Cell[TextData[{
 "\:0412\:0441\:044f\:043a\:0438\:0439 \:0440\:0430\:0437, \:043f\:0440\:0438 \
\:043f\:0435\:0440\:0435\:0445\:043e\:0434\:0435 \:043a \:043d\:043e\:0432\
\:043e\:043c\:0443 \:043a\:0430\:0442\:0430\:043b\:043e\:0433\:0443 \:0441 \
\:0438\:0441\:043f\:043e\:043b\:044c\:0437\:043e\:0432\:0430\:043d\:0438\:0435\
\:043c ",
 Cell[BoxData[
  TemplateBox[{Cell["SetDirectory"],"paclet:ref/SetDirectory"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 ", ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " \:0432\:0441\:0435\:0433\:0434\:0430 \:0437\:0430\:043f\:043e\:043c\:0438\
\:043d\:0430\:0435\:0442, \:043a\:0430\:043a\:0438\:043c \:0431\:044b\:043b \
\:043f\:0440\:0435\:0434\:044b\:0434\:0443\:0449\:0438\:0439 \:043a\:0430\
\:0442\:0430\:043b\:043e\:0433. \:041a \:044d\:0442\:043e\:043c\:0443 \:043f\
\:0440\:0435\:0434\:044b\:0434\:0443\:0449\:0435\:043c\:0443 \:043a\:0430\
\:0442\:0430\:043b\:043e\:0433\:0443 \:0432\:044b \:043c\:043e\:0436\:0435\
\:0442\:0435 \:0432\:0435\:0440\:043d\:0443\:0442\:044c\:0441\:044f \:043f\
\:0440\:0438 \:043f\:043e\:043c\:043e\:0449\:0438 \:043a\:043e\:043c\:0430\
\:043d\:0434\:044b ",
 Cell[BoxData[
  TemplateBox[{Cell["ResetDirectory"],"paclet:ref/ResetDirectory"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 ". \:0424\:0430\:043a\:0442\:0438\:0447\:0435\:0441\:043a\:0438, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " \:043f\:043e\:0434\:0434\:0435\:0440\:0436\:0438\:0432\:0430\:0435\:0442 \
\:0441\:0442\:0435\:043a \:043a\:0430\:0442\:0430\:043b\:043e\:0433\:043e\
\:0432, \:0440\:0435\:0430\:043b\:0438\:0437\:043e\:0432\:0430\:043d\:043d\
\:044b\:0439 \:043f\:043e\:0441\:0440\:0435\:0434\:0441\:0442\:0432\:043e\
\:043c ",
 Cell[BoxData[
  RowBox[{
   TemplateBox[{Cell["DirectoryStack"],"paclet:ref/DirectoryStack"},
    "RefLink",
    BaseStyle->"InlineFormula"], "[", "]"}]], "InlineFormula"],
 ". \:041a\:0430\:0436\:0434\:044b\:0439 \:0440\:0430\:0437 \
\:043f\:0440\:0438 \:0432\:044b\:0437\:043e\:0432\:0435 \:043a\:043e\:043c\
\:0430\:043d\:0434\:044b ",
 Cell[BoxData[
  TemplateBox[{Cell["SetDirectory"],"paclet:ref/SetDirectory"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 ", \:043d\:043e\:0432\:044b\:0439 \:043a\:0430\:0442\:0430\:043b\:043e\:0433 \
\:0434\:043e\:0431\:0430\:0432\:043b\:044f\:0435\:0442\:0441\:044f \:0432 \
\:0441\:0442\:0435\:043a, \:0430 \:0441 \:043a\:0430\:0436\:0434\:044b\:043c \
\:0432\:044b\:0437\:043e\:0432\:043e\:043c \:043a\:043e\:043c\:0430\:043d\
\:0434\:044b ",
 Cell[BoxData[
  TemplateBox[{Cell["ResetDirectory"],"paclet:ref/ResetDirectory"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 ", \:043a\:0430\:0442\:0430\:043b\:043e\:0433 \:0443\:0434\:0430\:043b\:044f\
\:0435\:0442\:0441\:044f \:0438\:0437 \:0441\:0442\:0435\:043a\:0430."
}], "Text",
 CellID->5348],

Cell[BoxData[GridBox[{
   {
    RowBox[{
     ButtonBox["ParentDirectory",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/ParentDirectory"], "[", "]"}], Cell[
    "\:0432\:044b\:0448\:0435\:0441\:0442\:043e\:044f\:0449\:0438\:0439 \
\:043a\:0430\:0442\:0430\:043b\:043e\:0433 \:043f\:043e \:043e\:0442\:043d\
\:043e\:0448\:0435\:043d\:0438\:044e \:0442\:0435\:043a\:0443\:0449\:0435\
\:043c\:0443 \:0440\:0430\:0431\:043e\:0447\:0435\:043c\:0443", "TableText"]},
   {
    ButtonBox["$InitialDirectory",
     BaseStyle->"Link",
     ButtonData->"paclet:ref/$InitialDirectory"], Cell[TextData[{
     "\:0438\:0441\:0445\:043e\:0434\:043d\:0430\:044f \:0434\:0438\:0440\
\:0435\:043a\:0442\:043e\:0440\:0438\:044f \:043f\:0440\:0438 \:0437\:0430\
\:043f\:0443\:0441\:043a\:0435 ",
     StyleBox["Mathematica",
      FontSlant->"Italic"]
    }], "TableText"]},
   {
    ButtonBox["$HomeDirectory",
     BaseStyle->"Link",
     ButtonData->"paclet:ref/$HomeDirectory"], Cell[
    "\:0432\:0430\:0448 \"\:0434\:043e\:043c\:0430\:0448\:043d\:0438\:0439\" \
\:043a\:0430\:0442\:0430\:043b\:043e\:0433, \:0435\:0441\:043b\:0438 \:0442\
\:0430\:043a\:043e\:0432\:043e\:0439 \:043e\:043f\:0440\:0435\:0434\:0435\
\:043b\:0435\:043d", "TableText"]},
   {
    ButtonBox["$BaseDirectory",
     BaseStyle->"Link",
     ButtonData->"paclet:ref/$BaseDirectory"], Cell[TextData[{
     "\:0431\:0430\:0437\:043e\:0432\:044b\:0439 \:043a\:0430\:0442\:0430\
\:043b\:043e\:0433 \:0434\:043b\:044f \:0441\:0438\:0441\:0442\:0435\:043c\
\:043d\:044b\:0445 \:0444\:0430\:0439\:043b\:043e\:0432, \:043a\:043e\:0442\
\:043e\:0440\:044b\:0435 \:0437\:0430\:0433\:0440\:0443\:0436\:0430\:044e\
\:0442\:0441\:044f  ",
     StyleBox["Mathematica",
      FontSlant->"Italic"]
    }], "TableText"]},
   {
    ButtonBox["$UserBaseDirectory",
     BaseStyle->"Link",
     ButtonData->"paclet:ref/$UserBaseDirectory"], Cell[TextData[{
     "\:0431\:0430\:0437\:043e\:0432\:044b\:0439 \:043a\:0430\:0442\:0430\
\:043b\:043e\:0433 \:0434\:043b\:044f \:0444\:0430\:0439\:043b\:043e\:0432 \
\:043f\:043e\:043b\:044c\:0437\:043e\:0432\:0430\:0442\:0435\:043b\:044f, \
\:043a\:043e\:0442\:043e\:0440\:044b\:0435 \:0437\:0430\:0433\:0440\:0443\
\:0436\:0430\:044e\:0442\:0441\:044f  ",
     StyleBox["Mathematica",
      FontSlant->"Italic"]
    }], "TableText"]},
   {
    ButtonBox["$InstallationDirectory",
     BaseStyle->"Link",
     ButtonData->"paclet:ref/$InstallationDirectory"], Cell[TextData[{
     "\:043a\:0430\:0442\:0430\:043b\:043e\:0433 \:0432\:0435\:0440\:0445\
\:043d\:0435\:0433\:043e \:0443\:0440\:043e\:0432\:043d\:044f, \:0432 \:043a\
\:043e\:0442\:043e\:0440\:043e\:043c \:0443\:0441\:0442\:0430\:043d\:043e\
\:0432\:043b\:0435\:043d\:0430 \:0441\:0438\:0441\:0442\:0435\:043c\:0430 ",
     StyleBox["Mathematica",
      FontSlant->"Italic"]
    }], "TableText"]}
  }]], "DefinitionBox",
 CellID->22831],

Cell["\:0421\:043f\:0435\:0446\:0438\:0430\:043b\:044c\:043d\:044b\:0435 \
\:043a\:0430\:0442\:0430\:043b\:043e\:0433\:0438. ", "Caption",
 CellID->8550]
}, Open  ]],

Cell[CellGroupData[{

Cell["\:041f\:043e\:0438\:0441\:043a \:0444\:0430\:0439\:043b\:0430", \
"Section",
 CellTags->"2.1",
 CellID->267216843],

Cell[TextData[{
 "\:0412\:0441\:044f\:043a\:0438\:0439 \:0440\:0430\:0437, \:043a\:043e\:0433\
\:0434\:0430 \:0432\:044b \:0437\:0430\:043f\:0440\:0430\:0448\:0438\:0432\
\:0430\:0435\:0442\:0435 \:043a\:043e\:043d\:043a\:0440\:0435\:0442\:043d\
\:044b\:0439 \:0444\:0430\:0439\:043b, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", \:043e\:0431\:044b\:0447\:043d\:043e, \
\:043f\:0440\:043e\:0445\:043e\:0434\:0438\:0442 \:0447\:0435\:0440\:0435\
\:0437 \:043d\:0435\:0441\:043a\:043e\:043b\:044c\:043a\:043e \:044d\:0442\
\:0430\:043f\:043e\:0432, \:043f\:044b\:0442\:0430\:044f\:0441\:044c \:043d\
\:0430\:0439\:0442\:0438 \:0442\:0440\:0435\:0431\:0443\:0435\:043c\:044b\
\:0439 \:0444\:0430\:0439\:043b. \:041f\:0435\:0440\:0432\:044b\:043c \:0448\
\:0430\:0433\:043e\:043c \:044f\:0432\:043b\:044f\:0435\:0442\:0441\:044f \
\:0438\:0441\:043f\:043e\:043b\:044c\:0437\:043e\:0432\:0430\:043d\:0438\:0435\
 \:043b\:044e\:0431\:043e\:0433\:043e \:0441\:0442\:0430\:043d\:0434\:0430\
\:0440\:0442\:043d\:043e\:0433\:043e \:043c\:0435\:0445\:0430\:043d\:0438\
\:0437\:043c\:0430 \:0438\:043c\:0435\:044e\:0449\:0435\:0433\:043e\:0441\
\:044f \:0432 \:0432\:0430\:0448\:0435\:0439 \:043e\:043f\:0435\:0440\:0430\
\:0446\:0438\:043e\:043d\:043d\:043e\:0439 \:0441\:0438\:0441\:0442\:0435\
\:043c\:0435 \:0438\:043b\:0438 \:043e\:0431\:043e\:043b\:043e\:0447\:043a\
\:0435."
}], "Text",
 CellID->7596],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " \:0441\:043a\:0430\:043d\:0438\:0440\:0443\:0435\:0442 \:0443\:043a\:0430\
\:0437\:0430\:043d\:043d\:043e\:0435 \:0432\:0430\:043c\:0438 \:043f\:043e\
\:043b\:043d\:043e\:0435 \:0438\:043c\:044f \:0444\:0430\:0439\:043b\:0430, \
\:0438 \:0441\:0442\:0430\:0440\:0430\:0435\:0442\:0441\:044f \:0432\:044b\
\:044f\:0441\:043d\:0438\:0442\:044c, \:0441\:043e\:0434\:0435\:0440\:0436\
\:0438\:0442 \:043b\:0438 \:043e\:043d\:043e \:043a\:0430\:043a\:043e\:0439-\
\:043b\:0438\:0431\:043e \:0438\:0437 \"\:043c\:0435\:0442\:0430\:0441\:0438\
\:043c\:0432\:043e\:043b\:043e\:0432\" ",
 Cell[BoxData["*"], "InlineFormula"],
 ", ",
 Cell[BoxData["$"], "InlineFormula"],
 ", ",
 Cell[BoxData["~"], "InlineFormula"],
 ", ",
 Cell[BoxData["?"], "InlineFormula"],
 ", ",
 Cell[BoxData["["], "InlineFormula"],
 ", ",
 Cell[BoxData["\"\<\>"], "InlineFormula"],
 ", ",
 Cell[BoxData["\[Backslash]"], "InlineFormula"],
 " \:0438 ",
 Cell[BoxData["'"], "InlineFormula"],
 ". \:0415\:0441\:043b\:0438 \:043e\:043d\:0430 \
\:043d\:0430\:0445\:043e\:0434\:0438\:0442 \:0442\:0430\:043a\:0438\:0435 \
\:0441\:0438\:043c\:0432\:043e\:043b\:044b, \:0442\:043e\:0433\:0434\:0430 \
\:043e\:043d\:0430 \:043f\:0435\:0440\:0435\:0434\:0430\:0435\:0442 \:043f\
\:043e\:043b\:043d\:043e\:0435 \:0438\:043c\:044f \:043e\:043f\:0435\:0440\
\:0430\:0446\:0438\:043e\:043d\:043d\:043e\:0439 \:0441\:0438\:0441\:0442\
\:0435\:043c\:0435 \:0438\:043b\:0438 \:043e\:0431\:043e\:043b\:043e\:0447\
\:043a\:0435 \:0434\:043b\:044f \:0438\:043d\:0442\:0435\:0440\:043f\:0440\
\:0435\:0442\:0430\:0446\:0438\:0438. \:0422\:043e \:0435\:0441\:0442\:044c, \
\:0435\:0441\:043b\:0438 \:0432\:044b \:0438\:0441\:043f\:043e\:043b\:044c\
\:0437\:0443\:0435\:0442\:0435 \
Unix-\:0441\:0438\:0441\:0442\:0435\:043c\:0443, \:0442\:043e \:043a\:043e\
\:043d\:0441\:0442\:0440\:0443\:043a\:0446\:0438\:0438 \:0442\:0438\:043f\
\:0430 ",
 Cell[BoxData[
  RowBox[{
   StyleBox["\:0438\:043c\:044f", "TI"], "*"}]], "InlineFormula"],
 " \:0438 ",
 Cell[BoxData[
  StyleBox[
   RowBox[{"$", 
    StyleBox["VAR", "TI"]}]]], "InlineFormula"],
 " \:043d\:0430 \:044d\:0442\:043e\:0439 \:0441\:0442\:0430\:0434\:0438\:0438 \
\:0431\:0443\:0434\:0443\:0442 \:0440\:0430\:0437\:0432\:0435\:0440\:043d\
\:0443\:0442\:044b. \:041d\:043e \:0432 \:0446\:0435\:043b\:043e\:043c, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " \:043f\:0440\:0438\:043d\:0438\:043c\:0430\:0435\:0442 \:043b\:044e\:0431\
\:043e\:0435 \:0437\:043d\:0430\:0447\:0435\:043d\:0438\:0435, \:0432\:043e\
\:0437\:0432\:0440\:0430\:0449\:0430\:0435\:043c\:043e\:0435 \:043e\:043f\
\:0435\:0440\:0430\:0446\:0438\:043e\:043d\:043d\:043e\:0439 \:0441\:0438\
\:0441\:0442\:0435\:043c\:043e\:0439 \:0438\:043b\:0438 \:043e\:0431\:043e\
\:043b\:043e\:0447\:043a\:043e\:0439, \:0438 \:0442\:0440\:0430\:043a\:0442\
\:0443\:0435\:0442 \:044d\:0442\:043e \:043a\:0430\:043a \:043f\:043e\:043b\
\:043d\:043e\:0435 \:0438\:043c\:044f \:0444\:0430\:0439\:043b\:0430."
}], "Text",
 CellID->11659],

Cell[TextData[{
 "\:0414\:043b\:044f \:0444\:0430\:0439\:043b\:043e\:0432 \:0432\:044b\:0432\
\:043e\:0434\:0430, \:044d\:0442\:043e \:043e\:0437\:043d\:0430\:0447\:0430\
\:0435\:0442 \:043e\:043a\:043e\:043d\:0447\:0430\:043d\:0438\:0435 \:0432\
\:044b\:043f\:043e\:043b\:043d\:044f\:0435\:043c\:043e\:0439 ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " \:043e\:0431\:0440\:0430\:0431\:043e\:0442\:043a\:0438. \:0415\:0441\:043b\
\:0438 ",
 StyleBox["Mathematica ",
  FontSlant->"Italic"],
 "\:043d\:0435 \:043c\:043e\:0436\:0435\:0442 \:043d\:0430\:0439\:0442\:0438 \
\:0443\:043d\:0438\:043a\:0430\:043b\:044c\:043d\:044b\:0439 \:0444\:0430\
\:0439\:043b \:0441 \:0443\:043a\:0430\:0437\:0430\:043d\:043d\:044b\:043c \
\:0438\:043c\:0435\:043d\:0435\:043c, \:043e\:043d\:0430 \:043f\:0440\:0438\
\:0441\:0442\:0443\:043f\:0438\:0442 \:043a \:0441\:043e\:0437\:0434\:0430\
\:043d\:0438\:044e \:0444\:0430\:0439\:043b\:0430."
}], "Text",
 CellID->9609],

Cell[TextData[{
 "\:041e\:0434\:043d\:0430\:043a\:043e, \:043a\:043e\:0433\:0434\:0430 \:0440\
\:0435\:0447\:044c \:0438\:0434\:0435\:0442 \:043e \:043f\:043e\:043b\:0443\
\:0447\:0435\:043d\:0438\:0438 \:0434\:0430\:043d\:043d\:044b\:0445 \:0438\
\:0437 \:0444\:0430\:0439\:043b\:0430, \:0438\:043c\:0435\:0435\:0442 \:043c\
\:0435\:0441\:0442\:043e \:0435\:0449\:0435 \:043e\:0434\:0438\:043d \:044d\
\:0442\:0430\:043f \:043e\:0431\:0440\:0430\:0431\:043e\:0442\:043a\:0438, \
\:0432\:044b\:043f\:043e\:043b\:043d\:044f\:0435\:043c\:044b\:0439 ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ". \:0417\:0434\:0435\:0441\:044c ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " \:0430\:043d\:0430\:043b\:0438\:0437\:0438\:0440\:0443\:0435\:0442, \:043a\
\:0430\:043a\:043e\:0435, \:0434\:043b\:044f \:0432\:044b\:043f\:043e\:043b\
\:043d\:044f\:0435\:043c\:043e\:0439 \:0444\:0443\:043d\:043a\:0446\:0438\
\:0438, \:0438\:0441\:043f\:043e\:043b\:044c\:0437\:0443\:0435\:0442\:0441\
\:044f \:0437\:043d\:0430\:0447\:0435\:043d\:0438\:0435 \:043e\:043f\:0446\
\:0438\:0438 ",
 Cell[BoxData[
  TemplateBox[{Cell["Path"],"paclet:ref/Path"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 ", \:0434\:043b\:044f \:043e\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\
\:0438\:044f \:0438\:043c\:0435\:043d \:043a\:0430\:0442\:0430\:043b\:043e\
\:0433\:043e\:0432, \:043e\:0442\:043d\:043e\:0441\:0438\:0442\:0435\:043b\
\:044c\:043d\:043e \:043a\:043e\:0442\:043e\:0440\:044b\:0445 \:0434\:043e\
\:043b\:0436\:0435\:043d \:0432\:044b\:043f\:043e\:043b\:043d\:044f\:0442\
\:044c\:0441\:044f \:043f\:043e\:0438\:0441\:043a \:0444\:0430\:0439\:043b\
\:0430. \:0417\:043d\:0430\:0447\:0435\:043d\:0438\:0435\:043c \:043f\:043e \
\:0443\:043c\:043e\:043b\:0447\:0430\:043d\:0438\:044e \:0434\:043b\:044f \
\:043e\:043f\:0446\:0438\:0438 ",
 Cell[BoxData[
  TemplateBox[{Cell["Path"],"paclet:ref/Path"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " \:044f\:0432\:043b\:044f\:0435\:0442\:0441\:044f \:0433\:043b\:043e\:0431\
\:0430\:043b\:044c\:043d\:0430\:044f \:043f\:0435\:0440\:0435\:043c\:0435\
\:043d\:043d\:0430\:044f ",
 Cell[BoxData[
  TemplateBox[{Cell["$Path"],"paclet:ref/$Path"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 "."
}], "Text",
 CellID->26029],

Cell[BoxData[GridBox[{
   {
    RowBox[{
     ButtonBox["Get",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/Get"], "[", 
     RowBox[{"\"\<\!\(\*
StyleBox[\"\:0444\:0430\:0439\:043b\", \"TI\"]\)\>\"", ",", 
      RowBox[{
       ButtonBox["Path",
        BaseStyle->"Link",
        ButtonData->"paclet:ref/Path"], "->", 
       RowBox[{"{", 
        RowBox[{"\"\<\!\(\*SubscriptBox[
StyleBox[\"\:043a\:0430\:0442\:0430\:043b\:043e\:0433\", \"TI\"], 
StyleBox[\"1\", \"TR\"]]\)\>\"", ",", "\"\<\!\(\*SubscriptBox[
StyleBox[\"\:043a\:0430\:0442\:0430\:043b\:043e\:0433\", \"TI\"], 
StyleBox[\"2\", \"TR\"]]\)\>\"", ",", 
         StyleBox["\[Ellipsis]", "TR"]}], "}"}]}]}], "]"}], Cell[TextData[{
     "\:043f\:043e\:043b\:0443\:0447\:0435\:043d\:0438\:0435 \:0444\:0430\
\:0439\:043b\:0430 \:043f\:0443\:0442\:0435\:043c \:0435\:0433\:043e \:043f\
\:043e\:0438\:0441\:043a\:0430 \:0441\:0440\:0435\:0434\:0438 \:043a\:0430\
\:0442\:0430\:043b\:043e\:0433\:043e\:0432 ",
     Cell[BoxData[
      SubscriptBox[
       StyleBox["\:043a\:0430\:0442\:0430\:043b\:043e\:0433", "TI"], 
       StyleBox["i", "TI"]]], "InlineFormula"]
    }], "TableText"]},
   {
    ButtonBox["$Path",
     BaseStyle->"Link",
     ButtonData->"paclet:ref/$Path"], Cell["\<\
\:0438\:0441\:043f\:043e\:043b\:044c\:0437\:0443\:0435\:043c\:044b\:0439 \
\:043f\:043e \:0443\:043c\:043e\:043b\:0447\:0430\:043d\:0438\:044e \:0441\
\:043f\:0438\:0441\:043e\:043a \:043a\:0430\:0442\:0430\:043b\:043e\:0433\
\:043e\:0432, \:0441\:0440\:0435\:0434\:0438 \:043a\:043e\:0442\:043e\:0440\
\:044b\:0445 \:0432\:044b\:043f\:043e\:043b\:043d\:044f\:0435\:0442\:0441\
\:044f \:043f\:043e\:0438\:0441\:043a \:0444\:0430\:0439\:043b\:043e\:0432 \
\:0434\:043b\:044f \:0432\:0432\:043e\:0434\:0430 \:0434\:0430\:043d\:043d\
\:044b\:0445\
\>", "TableText"]}
  }]], "DefinitionBox",
 CellID->4117],

Cell["\:041f\:0443\:0442\:044c \:043f\:043e\:0438\:0441\:043a\:0430 \:0434\
\:043b\:044f \:0444\:0430\:0439\:043b\:043e\:0432.", "Caption",
 CellID->26324],

Cell[TextData[{
 "\:041f\:043e \:0441\:0443\:0442\:0438, \:0433\:043b\:043e\:0431\:0430\:043b\
\:044c\:043d\:0430\:044f \:043f\:0435\:0440\:0435\:043c\:0435\:043d\:043d\
\:0430\:044f ",
 Cell[BoxData[
  TemplateBox[{Cell["$Path"],"paclet:ref/$Path"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " \:0437\:0430\:0434\:0430\:0435\:0442\:0441\:044f \:043a\:0430\:043a \:0441\
\:043f\:0438\:0441\:043e\:043a \:0442\:0435\:043a\:0441\:0442\:043e\:0432\
\:044b\:0445 \:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442\:043e\:0432, \
\:043a\:0430\:0436\:0434\:044b\:0439 \:0438\:0437 \:043a\:043e\:0442\:043e\
\:0440\:044b\:0445 \:043f\:0440\:0435\:0434\:0441\:0442\:0430\:0432\:043b\
\:044f\:0435\:0442 \:043a\:0430\:0442\:0430\:043b\:043e\:0433. \:0412\:0441\
\:044f\:043a\:0438\:0439 \:0440\:0430\:0437, \:043a\:043e\:0433\:0434\:0430 \
\:0432\:044b \:0437\:0430\:043f\:0440\:0430\:0448\:0438\:0432\:0430\:0435\
\:0442\:0435 \:0444\:0430\:0439\:043b \:0434\:043b\:044f \:0432\:0432\:043e\
\:0434\:0430 \:0434\:0430\:043d\:043d\:044b\:0445, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", \:0432 \:0434\:0435\:0439\:0441\:0442\:0432\:0438\:0442\:0435\:043b\:044c\
\:043d\:043e\:0441\:0442\:0438, \:0432\:0440\:0435\:043c\:0435\:043d\:043d\
\:043e \:0434\:0435\:043b\:0430\:0435\:0442 \:043a\:0430\:0436\:0434\:044b\
\:0439 \:0438\:0437 \:044d\:0442\:0438\:0445 \:043a\:0430\:0442\:0430\:043b\
\:043e\:0433\:043e\:0432 \:0442\:0435\:043a\:0443\:0449\:0438\:043c \:0440\
\:0430\:0431\:043e\:0447\:0438\:043c \:043a\:0430\:0442\:0430\:043b\:043e\
\:0433\:043e\:043c, \:043f\:044b\:0442\:0430\:044f\:0441\:044c \:043d\:0430\
\:0439\:0442\:0438 \:0432 \:043d\:0435\:043c \:0444\:0430\:0439\:043b, \:043a\
\:043e\:0442\:043e\:0440\:044b\:0439 \:0432\:044b \:0437\:0430\:043f\:0440\
\:043e\:0441\:0438\:043b\:0438."
}], "Text",
 CellID->23906],

Cell[TextData[{
 "\:0412\:043e\:0442 \:0442\:0438\:043f\:0438\:0447\:043d\:043e\:0435 \:0437\
\:043d\:0430\:0447\:0435\:043d\:0438\:0435 \:043f\:0430\:0440\:0430\:043c\
\:0435\:0442\:0440\:0430 \:0434\:043b\:044f ",
 Cell[BoxData[
  TemplateBox[{Cell["$Path"],"paclet:ref/$Path"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 ". \:0422\:0435\:043a\:0443\:0449\:0438\:0439 \:043a\:0430\:0442\:0430\:043b\
\:043e\:0433 (",
 Cell[BoxData["."], "InlineFormula"],
 ") \:0438 \"\:0434\:043e\:043c\:0430\:0448\:043d\:0438\:0439\" \:043a\:0430\
\:0442\:0430\:043b\:043e\:0433 (",
 Cell[BoxData["~"], "InlineFormula"],
 ") \:0443\:043a\:0430\:0437\:044b\:0432\:0430\:044e\:0442\:0441\:044f \:043f\
\:0435\:0440\:0432\:044b\:043c\:0438 \:0432 \:0441\:043f\:0438\:0441\:043a\
\:0435."
}], "MathCaption",
 CellID->21321],

Cell[CellGroupData[{

Cell[BoxData["$Path"], "Input", "ConversionLockdown",
 CellLabel->"In[5]:= ",
 CellID->18189],

Cell["{., ~, /users/math/bin, /users/math/Packages}", "Output", "ConversionLockdown",
 ImageSize->{315, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[5]= ",
 CellID->1225]
}, Open  ]],

Cell[TextData[{
 "\:0414\:043b\:044f \:043f\:043e\:0438\:0441\:043a\:0430 \:0444\:0430\:0439\
\:043b\:0430 \:043c\:043e\:0436\:043d\:043e \:0442\:0430\:043a\:0436\:0435 \
\:0432\:043e\:0441\:043f\:043e\:043b\:044c\:0437\:043e\:0432\:0430\:0442\:044c\
\:0441\:044f \:043a\:043e\:043c\:0430\:043d\:0434\:043e\:0439 ",
 Cell[BoxData[
  TemplateBox[{Cell["FindFile"],"paclet:ref/FindFile"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 "."
}], "Text",
 CellID->558888231],

Cell[BoxData[GridBox[{
   {
    RowBox[{
     ButtonBox["FindFile",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/FindFile"], "[", "\"\<\!\(\*
StyleBox[\"\:0438\:043c\:044f\", \"TI\"]\)\>\"", "]"}], Cell[TextData[{
     "\:043f\:043e\:0438\:0441\:043a \:0444\:0430\:0439\:043b\:0430 \:0441 \
\:0443\:043a\:0430\:0437\:0430\:043d\:043d\:044b\:043c \:0438\:043c\:0435\
\:043d\:0435\:043c, \:043a\:043e\:0442\:043e\:0440\:044b\:0439 \:0437\:0430\
\:0433\:0440\:0443\:0436\:0430\:0435\:0442\:0441\:044f ",
     Cell[BoxData[
      TemplateBox[{Cell["Get"],"paclet:ref/Get"},
       "RefLink",
       BaseStyle->"InlineFormula"]], "InlineFormula"],
     " \:0438 \:043f\:043e\:0434\:043e\:0431\:043d\:044b\:043c\:0438 \:0444\
\:0443\:043d\:043a\:0446\:0438\:044f\:043c\:0438"
    }], "TableText"]},
   {
    RowBox[{
     ButtonBox["FileExistsQ",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/FileExistsQ"], "[", "\"\<\!\(\*
StyleBox[\"\:0438\:043c\:044f\", \"TI\"]\)\>\"", "]"}], Cell[
    "\:0437\:0430\:043f\:0440\:043e\:0441, \:0441\:0443\:0449\:0435\:0441\
\:0442\:0432\:0443\:0435\:0442 \:043b\:0438 \:0444\:0430\:0439\:043b \:0441 \
\:0443\:043a\:0430\:0437\:0430\:043d\:043d\:044b\:043c \:0438\:043c\:0435\
\:043d\:0435\:043c", "TableText"]}
  }]], "DefinitionBox",
 CellID->58252748],

Cell[TextData[{
 "\:041f\:043e\:0438\:0441\:043a \:0444\:0430\:0439\:043b\:043e\:0432 \:0432 \
\:043a\:0430\:0442\:0430\:043b\:043e\:0433\:0430\:0445, \:043f\:0435\:0440\
\:0435\:0447\:0438\:0441\:043b\:0435\:043d\:043d\:044b\:0445 \:0432 ",
 Cell[BoxData[
  TemplateBox[{Cell["$Path"],"paclet:ref/$Path"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 ". "
}], "Caption",
 CellID->417255879],

Cell[TextData[{
 Cell[BoxData[
  TemplateBox[{Cell["FindFile"],"paclet:ref/FindFile"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " \:0432\:044b\:043f\:043e\:043b\:043d\:044f\:0435\:0442 \:043f\:043e\:0438\
\:0441\:043a \:0444\:0430\:0439\:043b\:043e\:0432 \:0432\:043e \:0432\:0441\
\:0435\:0445 \:043a\:0430\:0442\:0430\:043b\:043e\:0433\:0430\:0445, \:043f\
\:0435\:0440\:0435\:0447\:0438\:0441\:043b\:0435\:043d\:043d\:044b\:0445 \
\:0432 ",
 Cell[BoxData[
  TemplateBox[{Cell["$Path"],"paclet:ref/$Path"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 ", \:0438 \:0432\:043e\:0437\:0432\:0440\:0430\:0449\:0430\:0435\:0442 \
\:0430\:0431\:0441\:043e\:043b\:044e\:0442\:043d\:043e\:0435 \:0438\:043c\
\:044f \:0444\:0430\:0439\:043b\:0430, \:043a\:043e\:0442\:043e\:0440\:044b\
\:0439 \:043c\:043e\:0436\:0435\:0442 \:0431\:044b\:0442\:044c \:0437\:0430\
\:0433\:0440\:0443\:0436\:0435\:043d \:0444\:0443\:043d\:043a\:0446\:0438\
\:044f\:043c\:0438 ",
 Cell[BoxData[
  TemplateBox[{Cell["Get"],"paclet:ref/Get"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  TemplateBox[{Cell["Needs"],"paclet:ref/Needs"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " \:0438 \:0434\:0440\:0443\:0433\:0438\:043c\:0438. ",
 Cell[BoxData[
  TemplateBox[{Cell["FileExistsQ"],"paclet:ref/FileExistsQ"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " \:043f\:0440\:043e\:0432\:0435\:0440\:044f\:0435\:0442, \:0441\:0443\:0449\
\:0435\:0441\:0442\:0432\:0443\:0435\:0442 \:043b\:0438 \:0444\:0430\:0439\
\:043b \:0441 \:0443\:043a\:0430\:0437\:0430\:043d\:043d\:044b\:043c \:0438\
\:043c\:0435\:043d\:0435\:043c."
}], "Text",
 CellID->22324288],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FindFile", "[", "\"\<init.m\>\"", "]"}]], "Input", "ConversionLockdown",
 CellLabel->"In[5]:= ",
 CellID->52849],

Cell["\<\
\"C:\\\\Documents and Settings\\\\sw\\\\Application
Data\\\\Mathematica\\\\Kernel\\\\init.m\"\
\>", "Output", "ConversionLockdown",
 GeneratedCell->False,
 ImageSize->{308, 31},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[5]= ",
 CellID->622793840]
}, Open  ]],

Cell[TextData[{
 Cell[BoxData[
  TemplateBox[{Cell["FindFile"],"paclet:ref/FindFile"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 ", \:043a\:043e\:0442\:043e\:0440\:043e\:0439 \:0437\:0430\:0434\:0430\:043d\
\:043e \:0438\:043c\:044f \:043f\:0430\:043a\:0435\:0442\:0430, \:0432\:043e\
\:0437\:0432\:0440\:0430\:0449\:0430\:0435\:0442 \:0430\:0431\:0441\:043e\
\:043b\:044e\:0442\:043d\:043e\:0435 \:0438\:043c\:044f \:0444\:0430\:0439\
\:043b\:0430 ",
 Cell[BoxData[
  StyleBox[
   RowBox[{"init", ".", "m"}], "TI"]], "InlineFormula"],
 " \:0438\:0437 \:044d\:0442\:043e\:0433\:043e \:043f\:0430\:043a\:0435\:0442\
\:0430."
}], "Text",
 CellID->332194946],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FindFile", "[", "\"\<Combinatorica`\>\"", "]"}]], "Input", \
"ConversionLockdown",
 CellLabel->"In[5]:= ",
 CellID->644855583],

Cell["\<\
\"C:\\\\Program Files\\\\Wolfram 
Research\\\\Mathematica\\\\9.0\\\\AddOns\\\\Packages\\\\Combinatorica\\\\\
Kernel\\\\init.m\"\
\>", "Output", "ConversionLockdown",
 GeneratedCell->False,
 ImageSize->{532, 31},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[5]= ",
 CellID->898425175]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\:041f\:0440\:043e\:0441\:043c\:043e\:0442\:0440 \:0441\:043e\:0434\
\:0435\:0440\:0436\:0438\:043c\:043e\:0433\:043e \:043a\:0430\:0442\:0430\
\:043b\:043e\:0433\:043e\:0432", "Section",
 CellTags->"3.1",
 CellID->50025874],

Cell[BoxData[GridBox[{
   {
    RowBox[{
     ButtonBox["FileNames",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/FileNames"], "[", "]"}], Cell[
    "\:0441\:043f\:0438\:0441\:043e\:043a \:0432\:0441\:0435\:0445 \:0444\
\:0430\:0439\:043b\:043e\:0432 \:0432 \:0442\:0435\:043a\:0443\:0449\:0435\
\:043c \:0440\:0430\:0431\:043e\:0447\:0435\:043c \:043a\:0430\:0442\:0430\
\:043b\:043e\:0433\:0435", "TableText"]},
   {
    RowBox[{
     ButtonBox["FileNames",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/FileNames"], "[", "\"\<\!\(\*
StyleBox[\"\:0448\:0430\:0431\:043b\:043e\:043d\", \"TI\"]\)\>\"", "]"}], 
    Cell[TextData[{
     "\:0441\:043f\:0438\:0441\:043e\:043a \:0432\:0441\:0435\:0445 \:0444\
\:0430\:0439\:043b\:043e\:0432 \:0432 \:0442\:0435\:043a\:0443\:0449\:0435\
\:043c \:0440\:0430\:0431\:043e\:0447\:0435\:043c \:043a\:0430\:0442\:0430\
\:043b\:043e\:0433\:0435, \:0447\:044c\:0438 \:0438\:043c\:0435\:043d\:0430 \
\:0441\:043e\:043e\:0442\:0432\:0435\:0442\:0441\:0442\:0432\:0443\:044e\:0442\
 \:0442\:0435\:043a\:0441\:0442\:043e\:0432\:043e\:043c\:0443 ",
     Cell[BoxData[
      StyleBox["\:0448\:0430\:0431\:043b\:043e\:043d\:0443", "TI"]], 
      "InlineFormula"]
    }], "TableText"]},
   {
    RowBox[{
     ButtonBox["FileNames",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/FileNames"], "[", 
     RowBox[{"{", 
      RowBox[{"\"\<\!\(\*SubscriptBox[
StyleBox[\"\:0448\:0430\:0431\:043b\:043e\:043d\", \"TI\"], 
StyleBox[\"1\", \"TR\"]]\)\>\"", ",", "\"\<\!\(\*SubscriptBox[
StyleBox[\"\:0448\:0430\:0431\:043b\:043e\:043d\", \"TI\"], 
StyleBox[\"2\", \"TR\"]]\)\>\"", ",", 
       StyleBox["\[Ellipsis]", "TR"]}], "}"}], "]"}], Cell[TextData[{
     "\:0441\:043f\:0438\:0441\:043e\:043a \:0432\:0441\:0435\:0445 \:0444\
\:0430\:0439\:043b\:043e\:0432, \:0438\:043c\:0435\:043d\:0430 \:043a\:043e\
\:0442\:043e\:0440\:044b\:0445 \:0441\:043e\:043e\:0442\:0432\:0435\:0442\
\:0441\:0442\:0432\:0443\:044e\:0442 \:043b\:044e\:0431\:043e\:043c\:0443 \
\:0438\:0437 ",
     Cell[BoxData[
      SubscriptBox[
       StyleBox["\:0448\:0430\:0431\:043b\:043e\:043d\:043e\:0432", "TI"], 
       StyleBox["i", "TI"]]], "InlineFormula"]
    }], "TableText"]},
   {
    RowBox[{
     ButtonBox["FileNames",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/FileNames"], "[", 
     RowBox[{
      StyleBox["\:0448\:0430\:0431\:043b\:043e\:043d", "TI"], ",", 
      RowBox[{"{", 
       RowBox[{"\"\<\!\(\*SubscriptBox[
StyleBox[\"\:043a\:0430\:0442\:0430\:043b\:043e\:0433\", \"TI\"], 
StyleBox[\"1\", \"TR\"]]\)\>\"", ",", "\"\<\!\(\*SubscriptBox[
StyleBox[\"\:043a\:0430\:0442\:0430\:043b\:043e\:0433\", \"TI\"], 
StyleBox[\"2\", \"TR\"]]\)\>\"", ",", 
        StyleBox["\[Ellipsis]", "TR"]}], "}"}]}], "]"}], Cell[TextData[{
     "\:0432\:043e\:0437\:0432\:0440\:0430\:0449\:0430\:0435\:0442 \:043f\
\:043e\:043b\:043d\:044b\:0435 \:0438\:043c\:0435\:043d\:0430 \:0432\:0441\
\:0435\:0445 \:0444\:0430\:0439\:043b\:043e\:0432, \:0447\:044c\:0438 \:0438\
\:043c\:0435\:043d\:0430 \:0441\:043e\:043e\:0442\:0432\:0435\:0442\:0441\
\:0442\:0432\:0443\:044e\:0442 ",
     Cell[BoxData[
      StyleBox["\:0448\:0430\:0431\:043b\:043e\:043d\:0443", "TI"]], 
      "InlineFormula"],
     ", \:0440\:0430\:0441\:043f\:043e\:043b\:043e\:0436\:0435\:043d\:043d\
\:044b\:0445 \:0432 \:043a\:0430\:043a\:043e\:043c \:043b\:0438\:0431\:043e ",
     Cell[BoxData[
      SubscriptBox[
       StyleBox["\:043a\:0430\:0442\:0430\:043b\:043e\:0433\:0435", "TI"], 
       StyleBox["i", "TI"]]], "InlineFormula"]
    }], "TableText"]},
   {
    RowBox[{
     ButtonBox["FileNames",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/FileNames"], "[", 
     RowBox[{
      StyleBox["\:0448\:0430\:0431\:043b\:043e\:043d", "TI"], ",", 
      StyleBox["\:043a\:0430\:0442\:0430\:043b\:043e\:0433", "TI"], ",", 
      StyleBox["n", "TI"]}], "]"}], Cell[TextData[{
     "\:0432\:043a\:043b\:044e\:0447\:0430\:044f \:0444\:0430\:0439\:043b\
\:044b, \:0440\:0430\:0441\:043f\:043e\:043b\:043e\:0436\:0435\:043d\:043d\
\:044b\:0435 \:0432 \:043f\:043e\:0434\:043a\:0430\:0442\:0430\:043b\:043e\
\:0433\:0430\:0445 \:0434\:043e ",
     Cell[BoxData[
      StyleBox["n", "TI"]], "InlineFormula"],
     "-\:0433\:043e \:0443\:0440\:043e\:0432\:043d\:044f \:0432\:043d\:0438\
\:0437"
    }], "TableText"]},
   {
    RowBox[{
     ButtonBox["FileNames",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/FileNames"], "[", 
     RowBox[{
      StyleBox["\:0448\:0430\:0431\:043b\:043e\:043d", "TI"], ",", 
      StyleBox["\:043a\:0430\:0442\:0430\:043b\:043e\:0433", "TI"], ",", 
      ButtonBox["Infinity",
       BaseStyle->"Link",
       ButtonData->"paclet:ref/Infinity"]}], "]"}], Cell[
    "\:0432\:043a\:043b\:044e\:0447\:0430\:044f \
\:0444\:0430\:0439\:043b\:044b \:0438\:0437 \:0432\:0441\:0435\:0445 \:043f\
\:043e\:0434\:043a\:0430\:0442\:0430\:043b\:043e\:0433\:043e\:0432", 
     "TableText"]},
   {
    RowBox[{
     ButtonBox["FileNames",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/FileNames"], "[", 
     RowBox[{
      StyleBox["\:0448\:0430\:0431\:043b\:043e\:043d", "TI"], ",", 
      ButtonBox["$Path",
       BaseStyle->"Link",
       ButtonData->"paclet:ref/$Path"], ",", 
      ButtonBox["Infinity",
       BaseStyle->"Link",
       ButtonData->"paclet:ref/Infinity"]}], "]"}], Cell[TextData[{
     "\:0432\:043e\:0437\:0432\:0440\:0430\:0449\:0430\:0435\:0442 \:0432\
\:0441\:0435 \:0444\:0430\:0439\:043b\:044b, \:0447\:044c\:0438 \:0438\:043c\
\:0435\:043d\:0430 \:0441\:043e\:043e\:0442\:0432\:0435\:0442\:0441\:0442\
\:0432\:0443\:044e\:0442 ",
     Cell[BoxData[
      StyleBox["\:0448\:0430\:0431\:043b\:043e\:043d\:0443", "TI"]], 
      "InlineFormula"],
     ", \:0440\:0430\:0441\:043f\:043e\:043b\:043e\:0436\:0435\:043d\:043d\
\:044b\:0435 \:0432 \:043b\:044e\:0431\:043e\:043c \:0438\:0437 \:043f\:043e\
\:0434\:043a\:0430\:0442\:0430\:043b\:043e\:0433\:043e\:0432 \:043a\:0430\
\:0442\:0430\:043b\:043e\:0433\:043e\:0432, \:0443\:043a\:0430\:0437\:0430\
\:043d\:043d\:044b\:0445 \:0432 ",
     Cell[BoxData[
      TemplateBox[{Cell["$Path"],"paclet:ref/$Path"},
       "RefLink",
       BaseStyle->"InlineFormula"]], "InlineFormula"]
    }], "TableText"]}
  }]], "DefinitionBox",
 CellID->29738],

Cell["\<\
\:041f\:043e\:043b\:0443\:0447\:0435\:043d\:0438\:0435 \:0441\:043f\:0438\
\:0441\:043a\:043e\:0432 \:0444\:0430\:0439\:043b\:043e\:0432, \:0440\:0430\
\:0441\:043f\:043e\:043b\:0430\:0433\:0430\:044e\:0449\:0438\:0445\:0441\:044f\
 \:0432 \:043e\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\:043d\:044b\
\:0445 \:043a\:0430\:0442\:0430\:043b\:043e\:0433\:0430\:0445.\
\>", "Caption",
 CellID->4409],

Cell[TextData[{
 Cell[BoxData[
  TemplateBox[{Cell["FileNames"],"paclet:ref/FileNames"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " \:0432\:043e\:0437\:0432\:0440\:0430\:0449\:0430\:0435\:0442 \:0441\:043f\
\:0438\:0441\:043e\:043a \:0442\:0435\:043a\:0441\:0442\:043e\:0432\:044b\
\:0445 \:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442\:043e\:0432, \:0441\
\:043e\:043e\:0442\:0432\:0435\:0442\:0441\:0442\:0432\:0443\:044e\:0449\:0438\
\:0445 \:0438\:043c\:0435\:043d\:0430\:043c \:0444\:0430\:0439\:043b\:043e\
\:0432. \:041a\:043e\:0433\:0434\:0430 \:043e\:043d\:0430 \:0432\:043e\:0437\
\:0432\:0440\:0430\:0449\:0430\:0435\:0442 \:0444\:0430\:0439\:043b, \:0440\
\:0430\:0441\:043f\:043e\:043b\:0430\:0433\:0430\:044e\:0449\:0438\:0439\:0441\
\:044f \:043d\:0435 \:0432 \:0442\:0435\:043a\:0443\:0449\:0435\:043c \:043a\
\:0430\:0442\:0430\:043b\:043e\:0433\:0435, \:043e\:043d\:0430 \:0432\:043e\
\:0437\:0432\:0440\:0430\:0449\:0430\:0435\:0442 \:0438\:043c\:044f \:0444\
\:0430\:0439\:043b\:0430 \:043e\:0442\:043d\:043e\:0441\:0438\:0442\:0435\
\:043b\:044c\:043d\:043e \:0442\:0435\:043a\:0443\:0449\:0435\:0433\:043e \
\:043a\:0430\:0442\:0430\:043b\:043e\:0433\:0430. \:041e\:0431\:0440\:0430\
\:0442\:0438\:0442\:0435 \:0432\:043d\:0438\:043c\:0430\:043d\:0438\:0435, \
\:0447\:0442\:043e \:0432\:0441\:0435 \:0438\:043c\:0435\:043d\:0430 \:0434\
\:0430\:044e\:0442\:0441\:044f \:0432 \:0441\:043e\:043e\:0442\:0432\:0435\
\:0442\:0441\:0442\:0432\:0443\:044e\:0449\:0435\:043c \:0444\:043e\:0440\
\:043c\:0430\:0442\:0435 \:0438\:0441\:043f\:043e\:043b\:044c\:0437\:0443\
\:0435\:043c\:043e\:0439 \:043a\:043e\:043c\:043f\:044c\:044e\:0442\:0435\
\:0440\:043d\:043e\:0439 \:0441\:0438\:0441\:0442\:0435\:043c\:044b."
}], "Text",
 CellID->154],

Cell[TextData[{
 "\:0412\:043e\:0442 \:0441\:043f\:0438\:0441\:043e\:043a \:0432\:0441\:0435\
\:0445 \:0444\:0430\:0439\:043b\:043e\:0432 \:0432 \:0442\:0435\:043a\:0443\
\:0449\:0435\:043c \:0440\:0430\:0431\:043e\:0447\:0435\:043c \:043a\:0430\
\:0442\:0430\:043b\:043e\:0433\:0435, \:0447\:044c\:0438 \:0438\:043c\:0435\
\:043d\:0430 \:0437\:0430\:043a\:0430\:043d\:0447\:0438\:0432\:0430\:044e\
\:0442\:0441\:044f \:043d\:0430 ",
 Cell[BoxData[
  RowBox[{".", "m"}]], "InlineFormula"],
 "."
}], "MathCaption",
 CellID->2469],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FileNames", "[", "\"\<*.m\>\"", "]"}]], "Input", "ConversionLockdown",
 CellLabel->"In[6]:= ",
 CellID->15881],

Cell["{alpha.m, control.m, signals.m, test.m}", "Output", "ConversionLockdown",
 ImageSize->{273, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[6]= ",
 CellID->25239]
}, Open  ]],

Cell[TextData[{
 "\:042d\:0442\:043e \:0441\:043f\:0438\:0441\:043e\:043a \:0444\:0430\:0439\
\:043b\:043e\:0432 \:0438\:0437 \:0442\:0435\:043a\:0443\:0449\:0435\:0433\
\:043e \:043a\:0430\:0442\:0430\:043b\:043e\:0433\:0430, \:0438\:043c\:0435\
\:043d\:0430 \:043a\:043e\:0442\:043e\:0440\:044b\:0445 \:043d\:0430\:0447\
\:0438\:043d\:0430\:044e\:0442\:0441\:044f \:0441 ",
 Cell[BoxData["a"], "InlineFormula"],
 ", \:0432\:043c\:0435\:0441\:0442\:0435 \:0441 \:0442\:0435\:043c\:0438, \
\:0447\:0442\:043e \:0440\:0430\:0441\:043f\:043e\:043b\:043e\:0436\:0435\
\:043d\:044b \:0432 \:043f\:043e\:0434\:043a\:0430\:0442\:0430\:043b\:043e\
\:0433\:0430\:0445, \:0438 \:0447\:044c\:0438 \:0438\:043c\:0435\:043d\:0430 \
\:043d\:0430\:0447\:0438\:043d\:0430\:044e\:0442\:0441\:044f \:0441 ",
 Cell[BoxData["P"], "InlineFormula"],
 "."
}], "MathCaption",
 CellID->8107],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FileNames", "[", 
  RowBox[{"\"\<a*\>\"", ",", 
   RowBox[{"{", 
    RowBox[{"\"\<.\>\"", ",", "\"\<P*\>\""}], "}"}]}], "]"}]], "Input", \
"ConversionLockdown",
 CellLabel->"In[7]:= ",
 CellID->22629],

Cell["\<\
{alpha.m, Packages/astrodata, Packages/astro.m, Previous/atmp}\
\>", "Output", "ConversionLockdown",
 GeneratedCell->False,
 ImageSize->{434, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[7]= ",
 CellID->19913]
}, Open  ]],

Cell[TextData[{
 "\:0412 \:0438\:0441\:043f\:043e\:043b\:044c\:0437\:0443\:0435\:043c\:043e\
\:043c ",
 Cell[BoxData[
  TemplateBox[{Cell["FileNames"],"paclet:ref/FileNames"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " \:0448\:0430\:0431\:043b\:043e\:043d\:0435 \:0434\:043b\:044f \:0438\:043c\
\:0435\:043d\:0438 \:0444\:0430\:0439\:043b\:0430 \:043c\:043e\:0436\:043d\
\:043e \:043f\:0440\:0438\:043c\:0435\:043d\:044f\:0442\:044c \:043b\:044e\
\:0431\:044b\:0435 \:043e\:0431\:044a\:0435\:043a\:0442\:044b \:0448\:0430\
\:0431\:043b\:043e\:043d\:043e\:0432 ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " \:0434\:043b\:044f \:0442\:0435\:043a\:0441\:0442\:043e\:0432\:044b\:0445 \
\:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442\:043e\:0432, \:043a\:0430\
\:043a \:043f\:0440\:0430\:0432\:0438\:043b\:043e, \:0441\:043e\:0435\:0434\
\:0438\:043d\:044f\:0435\:043c\:044b\:0435 \:043e\:043f\:0435\:0440\:0430\
\:0442\:043e\:0440\:043e\:043c ~~."
}], "Text",
 CellID->250707282],

Cell[TextData[{
 "\:042d\:0442\:043e \:0434\:0430\:0435\:0442 \:0441\:043f\:0438\:0441\:043e\
\:043a \:0432\:0441\:0435\:0445 \:0444\:0430\:0439\:043b\:043e\:0432 \:0432 \
\:0442\:0435\:043a\:0443\:0449\:0435\:043c \:0440\:0430\:0431\:043e\:0447\
\:0435\:043c \:043a\:0430\:0442\:0430\:043b\:043e\:0433\:0435, \:0447\:044c\
\:0438 \:0438\:043c\:0435\:043d\:0430 \:0441\:043e\:043e\:0442\:0432\:0435\
\:0442\:0441\:0442\:0432\:0443\:044e\:0442 \:0448\:0430\:0431\:043b\:043e\
\:043d\:0443 ",
 Cell[BoxData[
  RowBox[{"Test", "*", 
   RowBox[{".", "m"}]}]], "InlineFormula"],
 ". "
}], "MathCaption",
 CellID->7262],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FileNames", "[", "\"\<Test*.m\>\"", "]"}]], "Input",
 CellLabel->"In[3]:= ",
 CellID->25052],

Cell["{Test1.m, Test2.m, TestFinal.m}", "Output",
 ImageSize->{217, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[3]= ",
 CellID->30731]
}, Open  ]],

Cell[TextData[{
 "\:0412 \:044d\:0442\:043e\:0442 \:0441\:043f\:0438\:0441\:043e\:043a \:043f\
\:043e\:043f\:0430\:0434\:0430\:044e\:0442 \:043b\:0438\:0448\:044c \:0444\
\:0430\:0439\:043b\:044b \:0441 \:0438\:043c\:0435\:043d\:0430\:043c\:0438 \
\:0432\:0438\:0434\:0430 ",
 Cell[BoxData[
  RowBox[{"Test", " ", 
   RowBox[{
    StyleBox["d", "TI"], ".", "m"}]}]], "InlineFormula"],
 ", \:0433\:0434\:0435 ",
 Cell[BoxData[
  StyleBox["d", "TI"]], "InlineFormula"],
 " \:043f\:0440\:0435\:0434\:0441\:0442\:0430\:0432\:043b\:044f\:0435\:0442 \
\:0441\:043e\:0431\:043e\:0439 \:043f\:043e\:0441\:043b\:0435\:0434\:043e\
\:0432\:0430\:0442\:0435\:043b\:044c\:043d\:043e\:0441\:0442\:044c \:0438\
\:0437 \:043e\:0434\:043d\:043e\:0439 \:0438\:043b\:0438 \:0431\:043e\:043b\
\:0435\:0435 \:0446\:0438\:0444\:0440."
}], "MathCaption",
 CellID->722345794],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FileNames", "[", 
  RowBox[{"\"\<Test\>\"", "~~", 
   RowBox[{"DigitCharacter", ".."}], "~~", "\"\<.m\>\""}], "]"}]], "Input",
 CellLabel->"In[3]:= ",
 CellID->459991907],

Cell["{Test1.m, Test2.m}", "Output",
 GeneratedCell->False,
 ImageSize->{126, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[3]= ",
 CellID->146532095]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\:0421\:043e\:0441\:0442\:0430\:0432\:043b\:0435\:043d\:0438\:0435 \
\:0438\:043c\:0435\:043d\:0438 \:0444\:0430\:0439\:043b\:0430", "Section",
 CellTags->"4.1",
 CellID->840619645],

Cell[BoxData[GridBox[{
   {
    RowBox[{
     ButtonBox["DirectoryName",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/DirectoryName"], "[", "\"\<\!\(\*
StyleBox[\"\:0444\:0430\:0439\:043b\", \"TI\"]\)\>\"", "]"}], Cell[
    "\:0438\:0437\:0432\:043b\:0435\:043a\:0430\:0435\:0442 \
\:043d\:0430\:0437\:0432\:0430\:043d\:0438\:0435 \:043a\:0430\:0442\:0430\
\:043b\:043e\:0433\:0430 \:0438\:0437 \:0438\:043c\:0435\:043d\:0438 \:0444\
\:0430\:0439\:043b\:0430", "TableText"]},
   {
    RowBox[{
     ButtonBox["FileNameJoin",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/FileNameJoin"], "[", 
     RowBox[{"{", 
      RowBox[{"\"\<\!\(\*
StyleBox[\"\:043a\:0430\:0442\:0430\:043b\:043e\:0433\", \"TI\"]\)\>\"", ",", 
       "\"\<\!\(\*
StyleBox[\"\:0438\:043c\:044f\", \"TI\"]\)\>\""}], "}"}], "]"}], Cell[
    "\:0441\:043e\:0441\:0442\:0430\:0432\:043b\:044f\:0435\:0442 \
\:043f\:043e\:043b\:043d\:043e\:0435 \:0438\:043c\:044f \:0444\:0430\:0439\
\:043b\:0430 \:0438\:0437 \:0438\:043c\:0435\:043d\:0438 \:043a\:0430\:0442\
\:0430\:043b\:043e\:0433\:0430 \:0438 \:0438\:043c\:0435\:043d\:0438 \:0444\
\:0430\:0439\:043b\:0430", "TableText"]},
   {
    RowBox[{
     ButtonBox["ParentDirectory",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/ParentDirectory"], "[", "\"\<\!\(\*
StyleBox[\"\:043a\:0430\:0442\:0430\:043b\:043e\:0433\", \"TI\"]\)\>\"", 
     "]"}], Cell[
    "\:0432\:043e\:0437\:0432\:0440\:0430\:0449\:0430\:0435\:0442 \
\:043a\:0430\:0442\:0430\:043b\:043e\:0433, \:0441\:0442\:043e\:044f\:0449\
\:0438\:0439 \:0432\:044b\:0448\:0435 \:0443\:043a\:0430\:0437\:0430\:043d\
\:043d\:043e\:0433\:043e", "TableText"]},
   {
    RowBox[{
     ButtonBox["FileNameJoin",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/FileNameJoin"], "[", 
     RowBox[{"{", 
      RowBox[{"\"\<\!\(\*SubscriptBox[
StyleBox[\"\:043a\:0430\:0442\:0430\:043b\:043e\:0433\", \"TI\"], 
StyleBox[\"1\", \"TR\"]]\)\>\"", ",", "\"\<\!\(\*SubscriptBox[
StyleBox[\"\:043a\:0430\:0442\:0430\:043b\:043e\:0433\", \"TI\"], 
StyleBox[\"2\", \"TR\"]]\)\>\"", ",", 
       StyleBox["\[Ellipsis]", "TR"], ",", "\"\<\!\(\*
StyleBox[\"\:0438\:043c\:044f\", \"TI\"]\)\>\""}], "}"}], "]"}], Cell["\<\
\:0441\:043e\:0441\:0442\:0430\:0432\:043b\:044f\:0435\:0442 \:043f\:043e\
\:043b\:043d\:043e\:0435 \:0438\:043c\:044f, \:0441\:043b\:0435\:0434\:0443\
\:044f \:0438\:0435\:0440\:0430\:0440\:0445\:0438\:0447\:0435\:0441\:043a\
\:043e\:0439 \:043f\:043e\:0441\:043b\:0435\:0434\:043e\:0432\:0430\:0442\
\:0435\:043b\:044c\:043d\:043e\:0441\:0442\:0438 \:043d\:0430\:0437\:0432\
\:0430\:043d\:0438\:0439 \:043a\:0430\:0442\:0430\:043b\:043e\:0433\:043e\
\:0432\
\>", "TableText"]},
   {
    RowBox[{
     ButtonBox["FileNameJoin",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/FileNameJoin"], "[", 
     RowBox[{"{", 
      RowBox[{"\"\<\!\(\*SubscriptBox[
StyleBox[\"\:043a\:0430\:0442\:0430\:043b\:043e\:0433\", \"TI\"], 
StyleBox[\"1\", \"TR\"]]\)\>\"", ",", "\"\<\!\(\*SubscriptBox[
StyleBox[\"\:043a\:0430\:0442\:0430\:043b\:043e\:0433\", \"TI\"], 
StyleBox[\"2\", \"TR\"]]\)\>\"", ",", 
       StyleBox["\[Ellipsis]", "TR"]}], "}"}], "]"}], Cell["\<\
\:0441\:043e\:0441\:0442\:0430\:0432\:043b\:044f\:0435\:0442 \:043f\:043e\
\:043b\:043d\:043e\:0435 \:043d\:0430\:0437\:0432\:0430\:043d\:0438\:0435 \
\:043a\:0430\:0442\:0430\:043b\:043e\:0433\:0430, \:0441\:043b\:0435\:0434\
\:0443\:044f \:0438\:0435\:0440\:0430\:0440\:0445\:0438\:0447\:0435\:0441\
\:043a\:043e\:0439 \:043f\:043e\:0441\:043b\:0435\:0434\:043e\:0432\:0430\
\:0442\:0435\:043b\:044c\:043d\:043e\:0441\:0442\:0438 \:043d\:0430\:0437\
\:0432\:0430\:043d\:0438\:0439 \:043a\:0430\:0442\:0430\:043b\:043e\:0433\
\:043e\:0432\
\>", "TableText"]}
  }]], "DefinitionBox",
 CellID->6685],

Cell["\:041e\:043f\:0435\:0440\:0430\:0446\:0438\:0438 \:0441 \:0438\:043c\
\:0435\:043d\:0430\:043c\:0438 \:0444\:0430\:0439\:043b\:043e\:0432. ", \
"Caption",
 CellID->14050],

Cell[TextData[{
 "\:041d\:0443\:0436\:043d\:043e \:043e\:0442\:0434\:0430\:0432\:0430\:0442\
\:044c \:0441\:0435\:0431\:0435 \:043e\:0442\:0447\:0435\:0442, \:0447\:0442\
\:043e \:0440\:0430\:0437\:043d\:044b\:0435 \:043a\:043e\:043c\:043f\:044c\
\:044e\:0442\:0435\:0440\:043d\:044b\:0435 \:0441\:0438\:0441\:0442\:0435\
\:043c\:044b \:043c\:043e\:0433\:0443\:0442 \:043e\:0442\:043e\:0431\:0440\
\:0430\:0436\:0430\:0442\:044c \:0438\:043c\:0435\:043d\:0430 \:0444\:0430\
\:0439\:043b\:043e\:0432 \:0440\:0430\:0437\:043b\:0438\:0447\:043d\:044b\
\:043c\:0438 \:0441\:043f\:043e\:0441\:043e\:0431\:0430\:043c\:0438. \:0422\
\:0430\:043a \:043d\:0430\:043f\:0440\:0438\:043c\:0435\:0440, \:0441\:0438\
\:0441\:0442\:0435\:043c\:044b Windows, \:043a\:0430\:043a \:043f\:0440\:0430\
\:0432\:0438\:043b\:043e, \:043e\:0442\:043e\:0431\:0440\:0430\:0436\:0430\
\:044e\:0442 \:0438\:043c\:0435\:043d\:0430 \:0432 \:0432\:0438\:0434\:0435 ",
 Cell[BoxData[
  RowBox[{
   StyleBox["dir", "TI"], ":", 
   RowBox[{"\[Backslash]", 
    StyleBox["dir", "TI"], "\[Backslash]", 
    StyleBox["dir", "TI"], "\[Backslash]", 
    StyleBox["name", "TI"]}]}]], "InlineFormula"],
 ", \:0430 Unix-\:0441\:0438\:0441\:0442\:0435\:043c\:044b \:043e\:0442\:043e\
\:0431\:0440\:0430\:0436\:0430\:044e\:0442 \:0438\:043c\:0435\:043d\:0430 \
\:0432 \:0432\:0438\:0434\:0435 ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    StyleBox["dir", "TI"], "/", 
    StyleBox["dir", "TI"]}], "/", 
   StyleBox["name", "TI"]}]], "InlineFormula"],
 ". \:0424\:0443\:043d\:043a\:0446\:0438\:044f ",
 Cell[BoxData[
  TemplateBox[{Cell["FileNameJoin"],"paclet:ref/FileNameJoin"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " \:0441\:043e\:0441\:0442\:0430\:0432\:043b\:044f\:0435\:0442 \:0438\:043c\
\:0435\:043d\:0430 \:0444\:0430\:0439\:043b\:043e\:0432 \:0441\:0432\:043e\
\:0439\:0441\:0442\:0432\:0435\:043d\:043d\:044b\:043c \:043a\:043e\:043d\
\:043a\:0440\:0435\:0442\:043d\:043e\:0439 \:043a\:043e\:043c\:043f\:044c\
\:044e\:0442\:0435\:0440\:043d\:043e\:0439 \:0441\:0438\:0441\:0442\:0435\
\:043c\:0435 \:043e\:0431\:0440\:0430\:0437\:043e\:043c."
}], "Text",
 CellID->26393],

Cell["\<\
\:0422\:0430\:043a \:0438\:0437 \:0438\:043c\:0435\:043d\:0438 \:0444\:0430\
\:0439\:043b\:0430 \:0438\:0437\:0432\:043b\:0435\:043a\:0430\:0435\:0442\
\:0441\:044f \:0442\:0430 \:0447\:0430\:0441\:0442\:044c, \:043a\:043e\:0442\
\:043e\:0440\:0430\:044f \:0441\:043e\:0434\:0435\:0440\:0436\:0438\:0442 \
\:0438\:043c\:0435\:043d\:0430 \:043a\:0430\:0442\:0430\:043b\:043e\:0433\
\:043e\:0432. \
\>", "MathCaption",
 CellID->15249],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DirectoryName", "[", "\"\<Packages/Math/test.m\>\"", "]"}]], "Input",\
 "ConversionLockdown",
 CellLabel->"In[8]:= ",
 CellID->25794],

Cell[BoxData["\<\"Packages/Math/\"\>"], "Output", "ConversionLockdown",
 ImageSize->{102, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[8]= ",
 CellID->13202]
}, Open  ]],

Cell[TextData[{
 "\:0422\:0430\:043a \:0441\:043e\:0437\:0434\:0430\:0435\:0442\:0441\:044f \
\:043f\:043e\:043b\:043d\:043e\:0435 \:0438\:043c\:044f \:0434\:0440\:0443\
\:0433\:043e\:0433\:043e \:0444\:0430\:0439\:043b\:0430, \:0432 \:0442\:043e\
\:043c \:0436\:0435 \:0441\:0430\:043c\:043e\:043c \:043a\:0430\:0442\:0430\
\:043b\:043e\:0433\:0435, \:0447\:0442\:043e \:0438 ",
 Cell[BoxData[
  RowBox[{"test", ".", "m"}]], "InlineFormula"],
 ". "
}], "MathCaption",
 CellID->28008],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FileNameJoin", "[", 
  RowBox[{"{", 
   RowBox[{"%", ",", "\"\<abc.m\>\""}], "}"}], "]"}]], "Input", \
"ConversionLockdown",
 CellLabel->"In[9]:= ",
 CellID->31934],

Cell[BoxData["\<\"Packages/Math/abc.m\"\>"], "Output", "ConversionLockdown",
 ImageSize->{138, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[9]= ",
 CellID->18727]
}, Open  ]],

Cell[BoxData[GridBox[{
   {
    RowBox[{
     ButtonBox["FileNameSplit",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/FileNameSplit"], "[", "\"\<\!\(\*
StyleBox[\"\:0438\:043c\:044f\", \"TI\"]\)\>\"", "]"}], Cell["\<\
\:043f\:0440\:0435\:043e\:0431\:0440\:0430\:0437\:043e\:0432\:0430\:043d\:0438\
\:0435 \:0438\:043c\:0435\:043d\:0438 \:0444\:0430\:0439\:043b\:0430 \:0432 \
\:0441\:043f\:0438\:0441\:043e\:043a \:0438\:0437 \:0438\:043c\:0435\:043d \
\:043a\:0430\:0442\:0430\:043b\:043e\:0433\:043e\:0432 \:0438 \:0444\:0430\
\:0439\:043b\:0430\
\>", "TableText"]},
   {
    RowBox[{
     ButtonBox["FileNameTake",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/FileNameTake"], "[", 
     RowBox[{"\"\<\!\(\*
StyleBox[\"\:0438\:043c\:044f\", \"TI\"]\)\>\"", ",", 
      StyleBox["\[Ellipsis]", "TR"]}], "]"}], Cell[
    "\:0438\:0437\:0432\:043b\:0435\:0447\:0435\:043d\:0438\:0435 \
\:0447\:0430\:0441\:0442\:0438 \:0438\:043c\:0435\:043d\:0438 \:0444\:0430\
\:0439\:043b\:0430", "TableText"]},
   {
    RowBox[{
     ButtonBox["FileNameDrop",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/FileNameDrop"], "[", 
     RowBox[{"\"\<\!\(\*
StyleBox[\"\:0438\:043c\:044f\", \"TI\"]\)\>\"", ",", 
      StyleBox["\[Ellipsis]", "TR"]}], "]"}], Cell[
    "\:0443\:0434\:0430\:043b\:0435\:043d\:0438\:0435 \
\:0447\:0430\:0441\:0442\:0438 \:0438\:043c\:0435\:043d\:0438 \:0444\:0430\
\:0439\:043b\:0430", "TableText"]},
   {
    RowBox[{
     ButtonBox["FileNameDepth",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/FileNameDepth"], "[", "\"\<\!\(\*
StyleBox[\"\:0438\:043c\:044f\", \"TI\"]\)\>\"", "]"}], Cell[
    "\:043a\:043e\:043b\:0438\:0447\:0435\:0441\:0442\:0432\:043e \
\:044d\:043b\:0435\:043c\:0435\:043d\:0442\:043e\:0432 \:043f\:0443\:0442\
\:0438 \:0432 \:0438\:043c\:0435\:043d\:0438 \:0444\:0430\:0439\:043b\:0430", 
     "TableText"]},
   {
    ButtonBox["$PathnameSeparator",
     BaseStyle->"Link",
     ButtonData->"paclet:ref/$PathnameSeparator"], Cell["\<\
\:0441\:0438\:043c\:0432\:043e\:043b-\:0440\:0430\:0437\:0434\:0435\:043b\
\:0438\:0442\:0435\:043b\:044c \:043f\:0443\:0442\:0438, \:0438\:0441\:043f\
\:043e\:043b\:044c\:0437\:0443\:0435\:043c\:044b\:0439 \:0432\:0430\:0448\
\:0435\:0439 \:043e\:043f\:0435\:0440\:0430\:0446\:0438\:043e\:043d\:043d\
\:043e\:0439 \:0441\:0438\:0441\:0442\:0435\:043c\:043e\:0439\
\>", "TableText"]}
  }]], "DefinitionBox",
 CellID->436300292],

Cell["\:041e\:043f\:0435\:0440\:0430\:0446\:0438\:0438 \:0441 \:0438\:043c\
\:0435\:043d\:0430\:043c\:0438 \:0444\:0430\:0439\:043b\:043e\:0432. ", \
"Caption",
 CellID->452797221],

Cell[TextData[{
 "\:0422\:0430\:043a\:0438\:0435 \:0444\:0443\:043d\:043a\:0446\:0438\:0438, \
\:043a\:0430\:043a ",
 Cell[BoxData[
  TemplateBox[{Cell["FileNameSplit"],"paclet:ref/FileNameSplit"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " \:0438 ",
 Cell[BoxData[
  TemplateBox[{Cell["FileNameJoin"],"paclet:ref/FileNameJoin"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 ", \:043e\:0431\:0435\:0441\:043f\:0435\:0447\:0438\:0432\:0430\:044e\:0442 \
\:0434\:043e\:043f\:043e\:043b\:043d\:0438\:0442\:0435\:043b\:044c\:043d\:044b\
\:0435 \:043e\:043f\:0435\:0440\:0430\:0446\:0438\:0438 \:043d\:0430\:0434 \
\:0438\:043c\:0435\:043d\:0430\:043c \:0444\:0430\:0439\:043b\:043e\:0432. \
\:041e\:043d\:0438 \:0443\:0447\:0438\:0442\:044b\:0432\:0430\:044e\:0442 \
\:0438\:0441\:043f\:043e\:043b\:044c\:0437\:0443\:0435\:043c\:044b\:0439 \
\:043e\:043f\:0435\:0440\:0430\:0446\:0438\:043e\:043d\:043d\:043e\:0439 \
\:0441\:0438\:0441\:0442\:0435\:043c\:043e\:0439 \:0441\:0438\:043c\:0432\
\:043e\:043b-\:0440\:0430\:0437\:0434\:0435\:043b\:0438\:0442\:0435\:043b\
\:044c \:0438 \:043f\:0440\:0435\:043e\:0431\:0440\:0430\:0437\:043e\:0432\
\:044b\:0432\:0430\:044e\:0442 \:0432 \:0441\:043f\:0438\:0441\:043e\:043a \
\:0438\:043c\:044f \:0444\:0430\:0439\:043b\:0430 \:043d\:0430\:0434\:043b\
\:0435\:0436\:0430\:0449\:0438\:043c \:043e\:0431\:0440\:0430\:0437\:043e\
\:043c. ",
 Cell[BoxData[
  TemplateBox[{Cell["FileNameJoin"],"paclet:ref/FileNameJoin"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " \:0431\:0443\:0434\:0435\:0442 \:043f\:043e \:0443\:043c\:043e\:043b\:0447\
\:0430\:043d\:0438\:044e \:0438\:0441\:043f\:043e\:043b\:044c\:0437\:043e\
\:0432\:0430\:0442\:044c ",
 Cell[BoxData[
  TemplateBox[{Cell["$PathnameSeparator"],"paclet:ref/$PathnameSeparator"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 ", \:0447\:0442\:043e\:0431\:044b \:043f\:043e\:043b\:0443\:0447\:0438\:0442\
\:044c \:0438\:043c\:044f \:0432 \:043a\:0430\:043d\:043e\:043d\:0438\:0447\
\:0435\:0441\:043a\:043e\:0439 \:0444\:043e\:0440\:043c\:0435, \:043f\:043e\
\:0434\:0445\:043e\:0434\:044f\:0449\:0435\:0439 \:0434\:043b\:044f \:0432\
\:0430\:0448\:0435\:0439 \:043e\:043f\:0435\:0440\:0430\:0446\:0438\:043e\
\:043d\:043d\:043e\:0439 \:0441\:0438\:0441\:0442\:0435\:043c\:044b."
}], "Text",
 CellID->106178195],

Cell[TextData[{
 "\:0415\:0441\:043b\:0438 \:0442\:0440\:0435\:0431\:0443\:0435\:0442\:0441\
\:044f \:0441\:043e\:0437\:0434\:0430\:0442\:044c \:043d\:0430\:0431\:043e\
\:0440 \:0441\:0432\:044f\:0437\:0430\:043d\:043d\:044b\:0445 \:0444\:0430\
\:0439\:043b\:043e\:0432, \:0447\:0430\:0441\:0442\:043e \:0431\:044b\:0432\
\:0430\:0435\:0442 \:0443\:0434\:043e\:0431\:043d\:043e \:0438\:043c\:0435\
\:0442\:044c \:0432\:043e\:0437\:043c\:043e\:0436\:043d\:043e\:0441\:0442\
\:044c \:0441\:0441\:044b\:043b\:0430\:0442\:044c\:0441\:044f \:043d\:0430 \
\:043e\:0434\:0438\:043d \:0444\:0430\:0439\:043b \:043f\:0440\:0438 \:0441\
\:0447\:0438\:0442\:044b\:0432\:0430\:043d\:0438\:0438 \:0434\:0440\:0443\
\:0433\:043e\:0433\:043e. \:0413\:043b\:043e\:0431\:0430\:043b\:044c\:043d\
\:0430\:044f \:043f\:0435\:0440\:0435\:043c\:0435\:043d\:043d\:0430\:044f ",
 Cell[BoxData[
  TemplateBox[{Cell["$InputFileName"],"paclet:ref/$InputFileName"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " \:0432\:043e\:0437\:0432\:0440\:0430\:0449\:0430\:0435\:0442 \:0438\:043c\
\:044f \:0444\:0430\:0439\:043b\:0430, \:0438\:0437 \:043a\:043e\:0442\:043e\
\:0440\:043e\:0433\:043e \:0432 \:0442\:0435\:043a\:0443\:0449\:0438\:0439 \
\:043c\:043e\:043c\:0435\:043d\:0442 \:0441\:0447\:0438\:0442\:044b\:0432\
\:0430\:044e\:0442\:0441\:044f \:0434\:0430\:043d\:043d\:044b\:0435. \:0412 \
\:0440\:0435\:0437\:0443\:043b\:044c\:0442\:0430\:0442\:0435, \:0441 \:043f\
\:043e\:043c\:043e\:0449\:044c\:044e \:043a\:043e\:043c\:0430\:043d\:0434 ",
 Cell[BoxData[
  TemplateBox[{Cell["DirectoryName"],"paclet:ref/DirectoryName"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " \:0438 ",
 Cell[BoxData[
  TemplateBox[{Cell["ToFileName"],"paclet:ref/ToFileName"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " \:043c\:043e\:0436\:043d\:043e \:0431\:0435\:0441\:043f\:0440\:0435\:043f\
\:044f\:0442\:0441\:0442\:0432\:0435\:043d\:043d\:043e \:0437\:0430\:0434\
\:0430\:0442\:044c \:0438\:043c\:0435\:043d\:0430 \:0434\:0440\:0443\:0433\
\:0438\:0445 \:0441\:0432\:044f\:0437\:0430\:043d\:043d\:044b\:0445 \:0444\
\:0430\:0439\:043b\:043e\:0432."
}], "Text",
 CellID->8672],

Cell[BoxData[GridBox[{
   {
    ButtonBox["$InputFileName",
     BaseStyle->"Link",
     ButtonData->"paclet:ref/$InputFileName"], Cell[
    "\:0438\:043c\:044f \:0444\:0430\:0439\:043b\:0430, \:0438\:0437 \:043a\
\:043e\:0442\:043e\:0440\:043e\:0433\:043e \:0432 \:0442\:0435\:043a\:0443\
\:0449\:0438\:0439 \:043c\:043e\:043c\:0435\:043d\:0442 \:0432\:0432\:043e\
\:0434\:044f\:0442\:0441\:044f \:0434\:0430\:043d\:043d\:044b\:0435", 
     "TableText"]}
  }]], "DefinitionBox",
 CellID->5707],

Cell[TextData[{
 "\:041a\:0430\:043a \:0441\:0441\:044b\:043b\:0430\:0442\:044c\:0441\:044f \
\:043d\:0430 \:0444\:0430\:0439\:043b, \:043a\:043e\:0442\:043e\:0440\:044b\
\:0439 \:0432 \:0434\:0430\:043d\:043d\:044b\:0439 \:043c\:043e\:043c\:0435\
\:043d\:0442 \:0441\:0447\:0438\:0442\:044b\:0432\:0430\:0435\:0442\:0441\
\:044f ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "."
}], "Caption",
 CellID->21496],

Cell[TextData[{
 "\:041e\:0434\:043d\:043e\:0439 \:0438\:0437 \:043f\:0440\:043e\:0431\:043b\
\:0435\:043c \:043f\:0440\:0438 \:0440\:0430\:0431\:043e\:0442\:0435 \:0441 \
\:0444\:0430\:0439\:043b\:0430\:043c\:0438 \:0432 ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " \:044f\:0432\:043b\:044f\:0435\:0442\:0441\:044f \:0442\:043e, \
\:0447\:0442\:043e \:0444\:043e\:0440\:043c\:0430 \:0438\:043c\:0435\:043d \
\:0444\:0430\:0439\:043b\:043e\:0432 \:0438 \:043a\:0430\:0442\:0430\:043b\
\:043e\:0433\:043e\:0432 \:0432\:0430\:0440\:044c\:0438\:0440\:0443\:0435\
\:0442\:0441\:044f \:0432 \:0440\:0430\:0437\:043d\:044b\:0445 \:043e\:043f\
\:0435\:0440\:0430\:0446\:0438\:043e\:043d\:043d\:044b\:0445 \:0441\:0438\
\:0441\:0442\:0435\:043c\:0430\:0445. \:042d\:0442\:043e \:043e\:0437\:043d\
\:0430\:0447\:0430\:0435\:0442, \:043d\:0430\:043f\:0440\:0438\:043c\:0435\
\:0440, \:0447\:0442\:043e \:043f\:043e\:043b\:043d\:044b\:0435 \:0438\:043c\
\:0435\:043d\:0430 \:0444\:0430\:0439\:043b\:043e\:0432, \:0441\:043e\:0434\
\:0435\:0440\:0436\:0430\:0449\:0438\:0445 \:0441\:0442\:0430\:043d\:0434\
\:0430\:0440\:0442\:043d\:044b\:0435 \:043f\:0430\:043a\:0435\:0442\:044b ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", \:043c\:043e\:0433\:0443\:0442 \:0432\:0435\:0441\:044c\:043c\:0430 \
\:043e\:0442\:043b\:0438\:0447\:0430\:0442\:044c\:0441\:044f \:0432 \:0440\
\:0430\:0437\:043b\:0438\:0447\:043d\:044b\:0445 \:043e\:043f\:0435\:0440\
\:0430\:0446\:0438\:043e\:043d\:043d\:044b\:0445 \:0441\:0438\:0441\:0442\
\:0435\:043c\:0430\:0445. \:0422\:0435\:043c \:043d\:0435 \:043c\:0435\:043d\
\:0435\:0435, \:0441\:043b\:0435\:0434\:0443\:044f \:043e\:043f\:0440\:0435\
\:0434\:0435\:043b\:0435\:043d\:043d\:044b\:043c \:043f\:0440\:0430\:0432\
\:0438\:043b\:0430\:043c, \:043c\:043e\:0436\:043d\:043e \:0432\:044b\:043f\
\:043e\:043b\:043d\:044f\:0442\:044c \:0447\:0442\:0435\:043d\:0438\:0435 \
\:0441\:0442\:0430\:043d\:0434\:0430\:0440\:0442\:043d\:044b\:0445 \:043f\
\:0430\:043a\:0435\:0442\:043e\:0432 ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " \:043e\:0434\:043d\:043e\:0439 \:0438 \:0442\:043e\:0439 \:0436\:0435 \
\:043a\:043e\:043c\:0430\:043d\:0434\:043e\:0439 \:043d\:0430 \:0432\:0441\
\:0435\:0445 \:0441\:0438\:0441\:0442\:0435\:043c\:0430\:0445. \:041f\:0440\
\:0438\:043d\:0446\:0438\:043f \:0437\:0430\:043a\:043b\:044e\:0447\:0430\
\:0435\:0442\:0441\:044f \:0432 \:0442\:043e\:043c, \:0447\:0442\:043e \:043a\
\:0430\:0436\:0434\:044b\:0439 \:043f\:0430\:043a\:0435\:0442 \:0434\:0430\
\:0435\:0442 \:043e\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\:0438\
\:0435 \:0442\:0430\:043a \:043d\:0430\:0437\:044b\:0432\:0430\:0435\:043c\
\:043e\:043c\:0443 \:043a\:043e\:043d\:0442\:0435\:043a\:0441\:0442\:0443 ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", \:0432 \:0432\:0438\:0434\:0435 ",
 Cell[BoxData[
  StyleBox[
   RowBox[{
    StyleBox["\:0438\:043c\:044f", "TI"], "`", 
    StyleBox["\:0438\:043c\:044f", "TI"], "`"}]]], "InlineFormula"],
 ". \:0412 \:043a\:0430\:0436\:0434\:043e\:0439 \
\:043e\:043f\:0435\:0440\:0430\:0446\:0438\:043e\:043d\:043d\:043e\:0439 \
\:0441\:0438\:0441\:0442\:0435\:043c\:0435, \:0432\:0441\:0435 \:0444\:0430\
\:0439\:043b\:044b \:0438\:043c\:0435\:043d\:0443\:044e\:0442\:0441\:044f \
\:0432 \:0441\:043e\:043e\:0442\:0432\:0435\:0442\:0441\:0442\:0432\:0438\
\:0438 \:0441 \:043e\:043f\:0440\:0435\:0434\:0435\:043b\:044f\:0435\:043c\
\:044b\:043c\:0438 \:0438\:043c\:0438 \:043a\:043e\:043d\:0442\:0435\:043a\
\:0441\:0442\:0430\:043c\:0438. \:041f\:043e\:044d\:0442\:043e\:043c\:0443, \
\:043f\:0440\:0438 \:0438\:0441\:043f\:043e\:043b\:044c\:0437\:043e\:0432\
\:0430\:043d\:0438\:0438 \:043a\:043e\:043c\:0430\:043d\:0434\:044b ",
 Cell[BoxData[
  RowBox[{"<<", 
   StyleBox[
    RowBox[{
     StyleBox["\:0438\:043c\:044f", "TI"], "`", 
     StyleBox["\:0438\:043c\:044f", "TI"], "`"}]]}]], "InlineFormula"],
 ", ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " \:0430\:0432\:0442\:043e\:043c\:0430\:0442\:0438\:0447\:0435\:0441\:043a\
\:0438 \:043f\:0440\:0435\:043e\:0431\:0440\:0430\:0437\:0443\:0435\:0442 \
\:0438\:043c\:044f \:043a\:043e\:043d\:0442\:0435\:043a\:0441\:0442\:0430 \
\:0432 \:0438\:043c\:044f \:0444\:0430\:0439\:043b\:0430, \:043f\:043e\:0434\
\:0445\:043e\:0434\:044f\:0449\:0435\:0435 \:0434\:043b\:044f \:043a\:043e\
\:043d\:043a\:0440\:0435\:0442\:043d\:043e\:0439 \:043e\:043f\:0435\:0440\
\:0430\:0446\:0438\:043e\:043d\:043d\:043e\:0439 \:0441\:0438\:0441\:0442\
\:0435\:043c\:044b."
}], "Text",
 CellID->24464]
}, Open  ]],

Cell[CellGroupData[{

Cell["\:0421\:0442\:0430\:043d\:0434\:0430\:0440\:0442\:043d\:044b\:0435 \
\:0440\:0430\:0441\:0448\:0438\:0440\:0435\:043d\:0438\:044f \:0438\:043c\
\:0435\:043d \:0444\:0430\:0439\:043b\:043e\:0432", "Section",
 CellTags->"5.1",
 CellID->253043088],

Cell[BoxData[GridBox[{
   {
    RowBox[{
     StyleBox["file", "TI"], ".", 
     StyleBox["m", "MR"]}], Cell[TextData[{
     "\:0444\:0430\:0439\:043b \:0441 \:0432\:044b\:0440\:0430\:0436\:0435\
\:043d\:0438\:044f\:043c\:0438 ",
     StyleBox["Mathematica ",
      FontSlant->"Italic"],
     "\:0432 \:0442\:0435\:043a\:0441\:0442\:043e\:0432\:043e\:043c \:0444\
\:043e\:0440\:043c\:0430\:0442\:0435"
    }], "TableText"]},
   {
    RowBox[{
     StyleBox["file", "TI"], ".", 
     StyleBox["nb", "MR"]}], Cell[TextData[{
     "\:0444\:0430\:0439\:043b \:0431\:043b\:043e\:0435\:043d\:043e\:0442\
\:0430",
     StyleBox[" Mathematica",
      FontSlant->"Italic"]
    }], "TableText"]},
   {
    RowBox[{
     StyleBox["file", "TI"], ".", 
     StyleBox["mx", "MR"]}], Cell[TextData[{
     "\:043e\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\:0438\:044f ",
     StyleBox["Mathematica",
      FontSlant->"Italic"],
     " \:0432 \:0444\:043e\:0440\:043c\:0430\:0442\:0435 ",
     Cell[BoxData[
      TemplateBox[{Cell["DumpSave"],"paclet:ref/DumpSave"},
       "RefLink",
       BaseStyle->"InlineFormula"]], "InlineFormula"]
    }], "TableText"]}
  }]], "DefinitionBox",
 CellID->10396],

Cell[TextData[{
 "\:0422\:0438\:043f\:0438\:0447\:043d\:044b\:0435 \:0438\:043c\:0435\:043d\
\:0430 \:0444\:0430\:0439\:043b\:043e\:0432 ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ". "
}], "Caption",
 CellID->15460],

Cell[TextData[{
 "\:041f\:0440\:0438 \:0438\:0441\:043f\:043e\:043b\:044c\:0437\:043e\:0432\
\:0430\:043d\:0438\:0438 ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " \:0432 \:0438\:043d\:0442\:0435\:0440\:0444\:0435\:0439\:0441\:0435 \:0431\
\:043b\:043e\:043a\:043d\:043e\:0442\:0430, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " \:0434\:0430\:0435\:0442 \:043f\:043e\:043b\:044c\:0437\:043e\:0432\:0430\
\:0442\:0435\:043b\:044e \:0432\:043e\:0437\:043c\:043e\:0436\:043d\:043e\
\:0441\:0442\:044c \:0441\:043e\:0445\:0440\:0430\:043d\:044f\:0442\:044c \
\:043f\:043e\:043b\:043d\:044b\:0435 \:0431\:043b\:043e\:043a\:043d\:043e\
\:0442\:044b, \:0441\:043e\:0434\:0435\:0440\:0436\:0430\:0449\:0438\:0435 \
\:043d\:0435 \:0442\:043e\:043b\:044c\:043a\:043e \:0432\:044b\:0440\:0430\
\:0436\:0435\:043d\:0438\:044f \:0432\:0432\:043e\:0434\:0430 \:0438 \:0432\
\:044b\:0432\:043e\:0434\:0430, \:043d\:043e \:0438 \:0442\:0435\:043a\:0441\
\:0442, \:0433\:0440\:0430\:0444\:0438\:043a\:0443, \:0430 \:0442\:0430\:043a\
\:0436\:0435 \:0434\:0440\:0443\:0433\:0438\:0435 \:043c\:0430\:0442\:0435\
\:0440\:0438\:0430\:043b\:044b."
}], "Text",
 CellID->20615],

Cell[TextData[{
 "\:041e\:0431\:0449\:0435\:043f\:0440\:0438\:043d\:044f\:0442\:043e \:0434\
\:0430\:0432\:0430\:0442\:044c \:0431\:043b\:043e\:043a\:043d\:043e\:0442\
\:0430\:043c ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " \:0438\:043c\:0435\:043d\:0430, \:043a\:043e\:0442\:043e\:0440\:044b\:0435 \
\:0437\:0430\:043a\:0430\:043d\:0447\:0438\:0432\:0430\:044e\:0442\:0441\:044f\
 \:043d\:0430 .nb, \:0438 \:0431\:043e\:043b\:044c\:0448\:0438\:043d\:0441\
\:0442\:0432\:043e \:0432\:0435\:0440\:0441\:0438\:0439 ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " \:0442\:0440\:0435\:0431\:0443\:044e\:0442 \:0441\:043e\:0431\:043b\:044e\
\:0434\:0435\:043d\:0438\:044f \:044d\:0442\:043e\:0433\:043e \:043f\:0440\
\:0430\:0432\:0438\:043b\:0430."
}], "Text",
 CellID->10904],

Cell[BoxData[GridBox[{
   {
    RowBox[{
     ButtonBox["FileBaseName",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/FileBaseName"], "[", "\"\<\!\(\*
StyleBox[\"\:0438\:043c\:044f\", \"TI\"]\)\>\"", "]"}], Cell[
    "\:0438\:043c\:044f \:0444\:0430\:0439\:043b\:0430 \:0431\:0435\:0437 \
\:0440\:0430\:0441\:0448\:0438\:0440\:0435\:043d\:0438\:044f", "TableText"]},
   {
    RowBox[{
     ButtonBox["FileExtension",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/FileExtension"], "[", "\"\<\!\(\*
StyleBox[\"\:0438\:043c\:044f\", \"TI\"]\)\>\"", "]"}], Cell[
    "\:0440\:0430\:0441\:0448\:0438\:0440\:0435\:043d\:0438\:0435 \
\:0434\:043b\:044f \:0438\:043c\:0435\:043d\:0438 \:0444\:0430\:0439\:043b\
\:0430", "TableText"]}
  }]], "DefinitionBox",
 CellID->200984640],

Cell["\:0418\:043c\:044f \:0438 \:0440\:0430\:0441\:0448\:0438\:0440\:0435\
\:043d\:0438\:0435 \:0444\:0430\:0439\:043b\:0430.", "Caption",
 CellID->671587873],

Cell[TextData[{
 "\:041a\:043e\:043c\:0430\:043d\:0434\:044b ",
 Cell[BoxData[
  TemplateBox[{Cell["FileBaseName"],"paclet:ref/FileBaseName"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " \:0438 ",
 Cell[BoxData[
  TemplateBox[{Cell["FileExtension"],"paclet:ref/FileExtension"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " \:043c\:043e\:0436\:043d\:043e \:0438\:0441\:043f\:043e\:043b\:044c\:0437\
\:043e\:0432\:0430\:0442\:044c \:0434\:043b\:044f \:0438\:0437\:0432\:043b\
\:0435\:0447\:0435\:043d\:0438\:044f \:0438\:043c\:0435\:043d\:0438 \:0444\
\:0430\:0439\:043b\:0430 \:0438 \:0435\:0433\:043e \:0440\:0430\:0441\:0448\
\:0438\:0440\:0435\:043d\:0438\:044f."
}], "Text",
 CellID->570290897],

Cell[TextData[{
 "\:041f\:0440\:0438 \:043e\:0442\:043a\:0440\:044b\:0442\:0438\:0438 \:0431\
\:043b\:043e\:043a\:043d\:043e\:0442\:0430 \:0432 \:0438\:043d\:0442\:0435\
\:0440\:0444\:0435\:0439\:0441\:0435 ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " \:043d\:0435\:043c\:0435\:0434\:043b\:0435\:043d\:043d\:043e \:043e\:0442\
\:043e\:0431\:0440\:0430\:0436\:0430\:0435\:0442 \:0435\:0433\:043e \:0441\
\:043e\:0434\:0435\:0440\:0436\:0438\:043c\:043e\:0435, \:043d\:043e \:043e\
\:0431\:044b\:0447\:043d\:043e \:043d\:0435 \:043d\:0430\:043f\:0440\:0430\
\:0432\:043b\:044f\:0435\:0442 \:0447\:0442\:043e-\:043b\:0438\:0431\:043e \
\:0438\:0437 \:044d\:0442\:043e\:0433\:043e \:0441\:043e\:0434\:0435\:0440\
\:0436\:0438\:043c\:043e\:0433\:043e \:0432 \:0432\:044b\:0447\:0438\:0441\
\:043b\:0438\:0442\:0435\:043b\:044c\:043d\:043e\:0435 \:044f\:0434\:0440\
\:043e \:0434\:043b\:044f \:043e\:0431\:0440\:0430\:0431\:043e\:0442\:043a\
\:0438, \:043f\:043e\:043a\:0430 \:043f\:043e\:043b\:044c\:0437\:043e\:0432\
\:0430\:0442\:0435\:043b\:044c \:044f\:0432\:043d\:043e \:043d\:0435 \:0443\
\:043a\:0430\:0436\:0435\:0442 \:0441\:0434\:0435\:043b\:0430\:0442\:044c \
\:044d\:0442\:043e."
}], "Text",
 CellID->2599],

Cell[TextData[{
 "\:041e\:0434\:043d\:0430\:043a\:043e, \:0432 \:0431\:043b\:043e\:043a\:043d\
\:043e\:0442\:0435 ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " \:043c\:043e\:0436\:043d\:043e \:0432\:043e\:0441\:043f\:043e\:043b\:044c\
\:0437\:043e\:0432\:0430\:0442\:044c\:0441\:044f \:043c\:0435\:043d\:044e ",
 StyleBox[ButtonBox["Cell",
  BaseStyle->{"Link", "MenuName"},
  ButtonData->"paclet:guide/CellMenu"], "MenuName"],
 " \:0438\:043d\:0442\:0435\:0440\:0444\:0435\:0439\:0441\:0430, \:0447\:0442\
\:043e\:0431\:044b \:043e\:0442\:043c\:0435\:0442\:0438\:0442\:044c \:043e\
\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\:043d\:044b\:0435 \:044f\
\:0447\:0435\:0439\:043a\:0438 \:043a\:0430\:043a ",
 StyleBox["\:044f\:0447\:0435\:0439\:043a\:0438 \
\:0438\:043d\:0438\:0446\:0438\:0430\:043b\:0438\:0437\:0430\:0446\:0438\:0438\
",
  FontSlant->"Italic"],
 ". \:0415\:0441\:043b\:0438 \:044d\:0442\:043e \
\:0441\:0434\:0435\:043b\:0430\:043d\:043e, \:0441\:043e\:0434\:0435\:0440\
\:0436\:0438\:043c\:043e\:0435 \:0442\:0430\:043a\:0438\:0445 \:044f\:0447\
\:0435\:0435\:043a \:0431\:0443\:0434\:0435\:0442 \:0430\:0432\:0442\:043e\
\:043c\:0430\:0442\:0438\:0447\:0435\:0441\:043a\:0438 \:0432\:044b\:0447\
\:0438\:0441\:043b\:0435\:043d\:043e \:043f\:0440\:0438 \:043e\:0442\:043a\
\:0440\:044b\:0442\:0438\:0438 \:0431\:043b\:043e\:043a\:043d\:043e\:0442\
\:0430."
}], "Text",
 CellID->20136],

Cell[TextData[{
 "\:0417\:043d\:0430\:0447\:043e\:043a ",
 Cell[BoxData[
  TemplateBox[{Cell["I"],"paclet:ref/menuitem/InitializationCell"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " \:0432 \:0441\:043a\:043e\:0431\:043a\:0435 \:044f\:0447\:0435\:0439\:043a\
\:0438 \:0443\:043a\:0430\:0437\:044b\:0432\:0430\:0435\:0442 \:043d\:0430 \
\:0442\:043e, \:0447\:0442\:043e \:0432\:0442\:043e\:0440\:0430\:044f \:044f\
\:0447\:0435\:0439\:043a\:0430 \:044f\:0432\:043b\:044f\:0435\:0442\:0441\
\:044f \:044f\:0447\:0435\:0439\:043a\:043e\:0439 \:0438\:043d\:0438\:0446\
\:0438\:0430\:043b\:0438\:0437\:0430\:0446\:0438\:0438 \:0438 \:0431\:0443\
\:0434\:0435\:0442 \:0432\:044b\:0447\:0438\:0441\:043b\:0435\:043d\:0430 \
\:043f\:0440\:0438 \:043e\:0442\:043a\:0440\:044b\:0442\:0438\:0438 \:0431\
\:043b\:043e\:043a\:043d\:043e\:0442\:0430."
}], "MathCaption",
 CellID->4680],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzt3E+LJOUdwPEhySFvwBeQ+76CvYRk2dPeDIJXhcxtWTCBRXwBYmJgjO4h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    "], {{0, 165}, {575, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> ColorProfileData[CompressedData["
1:eJydlndUVNcWxs+9d3qhzTAUKUPvXWAA6b1Jr6IyzAwwlAGGGRDEhogKRBQR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      "], "RGB", "XYZ"], Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Magnification[1],
  ImageSizeRaw->{575, 165},
  PlotRange->{{0, 575}, {0, 165}}]], "Picture",
 CellID->210650304],

Cell[TextData[{
 "\:041f\:043e\:0440\:043e\:0439 \:0431\:044b\:0432\:0430\:0435\:0442 \:0443\
\:0434\:043e\:0431\:043d\:043e \:0445\:0440\:0430\:043d\:0438\:0442\:044c \
\:043c\:0430\:0442\:0435\:0440\:0438\:0430\:043b\:044b ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " \:043a\:0430\:043a \:0432 \
\:0431\:043b\:043e\:043a\:043d\:043e\:0442\:0435, \:0441\:043e\:0434\:0435\
\:0440\:0436\:0430\:0449\:0435\:043c \:0442\:0430\:043a\:0436\:0435 \:043f\
\:043e\:044f\:0441\:043d\:0438\:0442\:0435\:043b\:044c\:043d\:044b\:0439 \
\:0442\:0435\:043a\:0441\:0442, \:0442\:0430\:043a \:0438 \:0432 \:043f\:0430\
\:043a\:0435\:0442\:0435, \:043a\:043e\:0442\:043e\:0440\:044b\:0439 \:0441\
\:043e\:0434\:0435\:0440\:0436\:0438\:0442 \:0438\:0441\:043a\:043b\:044e\
\:0447\:0438\:0442\:0435\:043b\:044c\:043d\:043e \:0432\:044b\:0440\:0430\
\:0436\:0435\:043d\:0438\:044f ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ". \:042d\:0442\:043e \:0440\:0435\:0430\:043b\:0438\:0437\:0443\:0435\:0442\
\:0441\:044f \:043f\:0443\:0442\:0435\:043c \:0440\:0430\:0437\:043c\:0435\
\:0449\:0435\:043d\:0438\:044f \:0432\:044b\:0440\:0430\:0436\:0435\:043d\
\:0438\:0439 ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " \:0432 \:044f\:0447\:0435\:0439\:043a\:0430\:0445 \:0438\:043d\:0438\:0446\
\:0438\:0430\:043b\:0438\:0437\:0430\:0446\:0438\:0438 \:0431\:043b\:043e\
\:043a\:043d\:043e\:0442\:0430. \:041a\:0430\:0436\:0434\:044b\:0439 \:0440\
\:0430\:0437 \:043f\:0440\:0438 \:0441\:043e\:0445\:0440\:0430\:043d\:0435\
\:043d\:0438\:0438 \:0431\:043b\:043e\:043a\:043d\:043e\:0442\:0430, \:0438\
\:043d\:0442\:0435\:0440\:0444\:0435\:0439\:0441 \:043f\:0440\:0435\:0434\
\:043e\:0441\:0442\:0430\:0432\:0438\:0442 \:0432\:043e\:0437\:043c\:043e\
\:0436\:043d\:043e\:0441\:0442\:044c \:0441\:043e\:0445\:0440\:0430\:043d\
\:0438\:0442\:044c \:0441\:0432\:044f\:0437\:0430\:043d\:043d\:044b\:0439 .m \
\:0444\:0430\:0439\:043b, \:0441\:043e\:0434\:0435\:0440\:0436\:0430\:0449\
\:0438\:0439 \:0438\:0441\:043a\:043b\:044e\:0447\:0438\:0442\:0435\:043b\
\:044c\:043d\:043e \:0432\:044b\:0440\:0430\:0436\:0435\:043d\:0438\:044f ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellID->27032]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  InterpretationBox[
   StyleBox[
    GraphicsBox[{},
     BaselinePosition->Baseline,
     ImageSize->{6, 0}],
    CacheGraphics->False],
   Spacer[6]]]],
 "\:0423\:0437\:043d\:0430\:0442\:044c \:0431\:043e\:043b\:044c\:0448\:0435"
}], "TutorialMoreAboutSection",
 WholeCellGroupOpener->True,
 CellID->33089523],

Cell["", "SectionHeaderSpacer"],

Cell[TextData[ButtonBox["Operations on File Names",
 BaseStyle->"Link",
 ButtonData->"paclet:guide/OperationsOnFileNames"]], "TutorialMoreAbout",
 CellID->207696369],

Cell["", "SectionFooterSpacer"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  InterpretationBox[
   StyleBox[
    GraphicsBox[{},
     BaselinePosition->Baseline,
     ImageSize->{6, 0}],
    CacheGraphics->False],
   Spacer[6]]]],
 "\:0421\:043e\:043f\:0443\:0442\:0441\:0442\:0432\:0443\:044e\:0449\:0438\
\:0435 \:0443\:0447\:0435\:0431\:043d\:044b\:0435 \:043c\:0430\:0442\:0435\
\:0440\:0438\:0430\:043b\:044b"
}], "RelatedTutorialsSection",
 WholeCellGroupOpener->True,
 CellID->91859868],

Cell["", "SectionHeaderSpacer"],

Cell[TextData[ButtonBox["\:0424\:0430\:0439\:043b\:044b \:0438 \:043f\:043e\
\:0442\:043e\:043a\:0438",
 BaseStyle->"Hyperlink",
 ButtonData->{"FilesAndStreamsRU.nb", None}]], "Tutorials",
 CellID->594965642],

Cell[TextData[ButtonBox["\:0412\:043d\:0435\:0448\:043d\:0438\:0435 \:043f\
\:0440\:043e\:0433\:0440\:0430\:043c\:043c\:044b",
 BaseStyle->"Hyperlink",
 ButtonData->{"ExternalProgramsRU.nb", None}]], "RelatedTutorials",
 CellID->405226890],

Cell[BoxData[
 TemplateBox[{Cell[
    TextData[{
      StyleBox["Mathematica", FontSlant -> "Italic"], " File Organization"}]],
   "paclet:tutorial/WolframSystemFileOrganization"},
  "RefLink",
  BaseStyle->"Tutorials"]], "Tutorials",
 CellID->61163727],

Cell[TextData[ButtonBox["\:0424\:0430\:0439\:043b\:044b, \:043f\:043e\:0442\
\:043e\:043a\:0438 \:0438 \:0432\:043d\:0435\:0448\:043d\:0438\:0435 \:043e\
\:043f\:0435\:0440\:0430\:0446\:0438\:0438",
 BaseStyle->"Hyperlink",
 ButtonData->{
  "FilesStreamsAndExternalOperationsOverviewRU.nb", None}]], "Tutorials",
 CellID->58033046]
}, Open  ]]
}, Open  ]],

Cell[" ", "FooterCell"]
},
FileChangeProtection->None,
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{Automatic, 510},
WindowMargins->{{312, Automatic}, {Automatic, 0}},
WindowFrame->"Normal",
WindowTitle->"Naming and Finding Files - Wolfram Mathematica",
DockedCells->FEPrivate`FrontEndResource["FEExpressions", "HelpViewerToolbar"],
TaggingRules->{
 "ModificationHighlight" -> False, "ColorType" -> "TutorialColor", 
  "LinkTrails" -> GridBox[{{
      RowBox[{
        ButtonBox[
        "Virtual Book", ButtonData -> "paclet:tutorial/VirtualBookOverview", 
         BaseStyle -> {"Link", "DockedLinkTrail"}], 
        Cell[">", "DockedLinkTrailSeparator"], 
        ButtonBox[
        "Data Manipulation", ButtonData -> 
         "paclet:tutorial/DataManipulationOverview", 
         BaseStyle -> {"Link", "DockedLinkTrail"}], 
        Cell[">", "DockedLinkTrailSeparator"], 
        ButtonBox[
        "Files, Streams, and External Operations", ButtonData -> 
         "paclet:tutorial/FilesStreamsAndExternalOperationsOverview", 
         BaseStyle -> {"Link", "DockedLinkTrail"}], 
        Cell[">", "DockedLinkTrailSeparator"], 
        ButtonBox[
        "Naming and Finding Files", ButtonData -> 
         "paclet:tutorial/NamingAndFindingFiles", 
         BaseStyle -> {"Link", "DockedLinkTrail"}]}]}}, ColumnAlignments -> 
    Left], "ExampleCounter" -> 1, "ExamplePageLinks" -> {}, "RootCaptions" -> 
  "", "Metadata" -> {
   "built" -> "{2013, 1, 25, 2, 38, 3.8359303}", 
    "history" -> {"XX", "", "", ""}, "context" -> "System`", 
    "keywords" -> {
     "~", "..", "application directory", "bin directory", "cd", 
      "change directory", "dir", "directories", "directory", "DirectoryName", 
      "directory name", "DirectoryStack", "directory stack", "file", 
      "file names", "FileNames", "files", "find in Unix", "folders", 
      "directories", "history", "home directory", "input", 
      "library directory", "ls", "machine dependence", "main directory", 
      "meta characters", "names", "packages", "parent directory", 
      "ParentDirectory", "path", "patterns", "portability", 
      "preferences directory", "pwd", "ResetDirectory", "return to directory",
       "search", "search path", "SetDirectory", "share directory", "source", 
      "stack", "startup directory", "system dependence", "ToFileName", 
      "users directory", "BaseDirectory", "HomeDirectory", "InitialDirectory",
       "input", "InstallationDirectory", "LaunchDirectory", "path", 
      "UserBaseDirectory"}, "specialkeywords" -> {}, 
    "tutorialcollectionlinks" -> {{
      "Data Manipulation", 
       "http://www.wolfram.com/learningcenter/tutorialcollection/\
DataManipulation/"}}, "index" -> True, "label" -> "Mathematica Tutorial", 
    "language" -> "en", "paclet" -> "Mathematica", "status" -> "None", 
    "summary" -> 
    "The precise details of the naming of files differ from one computer \
system to another. Nevertheless, Mathematica provides some fairly general \
mechanisms that work on all systems. Mathematica assumes that all your files \
are arranged in a hierarchy of directories. To find a particular file, \
Mathematica must know both what the name of the file is, and what sequence of \
directories it is in. At any given time, however, you have a current working \
directory, and you can refer to files or other directories by specifying \
where they are relative to this directory. Typically you can refer to files \
or directories that are actually in this directory simply by giving their \
names, with no directory information.", "synonyms" -> {"2.12.4"}, "title" -> 
    "Naming and Finding Files", "titlemodifier" -> "", "windowtitle" -> 
    "Naming and Finding Files", "type" -> "Tutorial", "uri" -> 
    "tutorial/NamingAndFindingFiles"}, "SearchTextTranslated" -> ""},
Magnification->1.,
FrontEndVersion->"10.1 for Microsoft Windows (64-bit) (March 23, 2015)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[
    StyleDefinitions -> FrontEnd`FileName[{"Wolfram"}, "Reference.nb"]]], 
   Cell[
    StyleData["Input"], CellContext -> Notebook], 
   Cell[
    StyleData["Output"], CellContext -> Notebook], 
   Cell[
    StyleData["TutorialMoreAboutSection"], 
    CellGroupingRules -> {"SectionGrouping", 30}], 
   Cell[
    StyleData["RelatedTutorialsSection"], 
    CellGroupingRules -> {"SectionGrouping", 30}], 
   Cell[
    StyleData["TutorialRelatedLinksSection"], 
    CellGroupingRules -> {"SectionGrouping", 30}]}, Visible -> False, 
  FrontEndVersion -> "10.1 for Microsoft Windows (64-bit) (March 23, 2015)", 
  StyleDefinitions -> "Default.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "1.0"->{
  Cell[7540, 183, 215, 4, 47, "Title",
   CellTags->"1.0",
   CellID->12068]},
 "1.1"->{
  Cell[9922, 251, 174, 3, 62, "Section",
   CellTags->"1.1",
   CellID->90379007]},
 "2.1"->{
  Cell[26848, 636, 120, 3, 62, "Section",
   CellTags->"2.1",
   CellID->267216843]},
 "3.1"->{
  Cell[45486, 1070, 230, 4, 62, "Section",
   CellTags->"3.1",
   CellID->50025874]},
 "4.1"->{
  Cell[59785, 1418, 187, 3, 62, "Section",
   CellTags->"4.1",
   CellID->840619645]},
 "5.1"->{
  Cell[80594, 1866, 250, 4, 62, "Section",
   CellTags->"5.1",
   CellID->253043088]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"1.0", 105731, 2414},
 {"1.1", 105820, 2418},
 {"2.1", 105914, 2422},
 {"3.1", 106010, 2426},
 {"4.1", 106106, 2430},
 {"5.1", 106203, 2434}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[617, 21, 6898, 158, 48, "AnchorBarGrid",
 CellID->1],
Cell[CellGroupData[{
Cell[7540, 183, 215, 4, 47, "Title",
 CellTags->"1.0",
 CellID->12068],
Cell[7758, 189, 2139, 58, 88, "TutorialJumpBox",
 CellID->328837780],
Cell[CellGroupData[{
Cell[9922, 251, 174, 3, 62, "Section",
 CellTags->"1.1",
 CellID->90379007],
Cell[10099, 256, 1201, 19, 66, "Text",
 CellID->18985],
Cell[11303, 277, 1240, 23, 66, "Text",
 CellID->30524],
Cell[12546, 302, 2100, 36, 84, "Text",
 CellID->10764],
Cell[14649, 340, 1206, 30, 103, "DefinitionBox",
 CellID->1587],
Cell[15858, 372, 154, 2, 31, "Caption",
 CellID->27629],
Cell[16015, 376, 486, 8, 31, "MathCaption",
 CellID->1118],
Cell[16504, 386, 185, 4, 28, "Input",
 CellGroupingRules->{$CellContext`GroupTogetherGrouping, 10000.},
 CellID->30111],
Cell[16692, 392, 242, 6, 36, "Output",
 CellGroupingRules->{$CellContext`GroupTogetherGrouping, 10000.},
 CellID->27602],
Cell[16937, 400, 446, 9, 33, "MathCaption",
 CellID->32322],
Cell[CellGroupData[{
Cell[17408, 413, 144, 4, 28, "Input",
 CellID->12796],
Cell[17555, 419, 186, 5, 36, "Output",
 CellID->10312]
}, Open  ]],
Cell[17756, 427, 274, 4, 31, "MathCaption",
 CellID->22942],
Cell[CellGroupData[{
Cell[18055, 435, 119, 3, 28, "Input",
 CellID->14497],
Cell[18177, 440, 208, 6, 36, "Output",
 CellID->9188]
}, Open  ]],
Cell[18400, 449, 348, 5, 31, "MathCaption",
 CellID->30372],
Cell[CellGroupData[{
Cell[18773, 458, 124, 3, 28, "Input",
 CellID->30838],
Cell[18900, 463, 175, 5, 36, "Output",
 CellID->7613]
}, Open  ]],
Cell[19090, 471, 1780, 30, 92, "Text",
 CellID->8933],
Cell[20873, 503, 2887, 58, 136, "Text",
 CellID->5348],
Cell[23763, 563, 2892, 64, 208, "DefinitionBox",
 CellID->22831],
Cell[26658, 629, 153, 2, 31, "Caption",
 CellID->8550]
}, Open  ]],
Cell[CellGroupData[{
Cell[26848, 636, 120, 3, 62, "Section",
 CellTags->"2.1",
 CellID->267216843],
Cell[26971, 641, 1407, 23, 66, "Text",
 CellID->7596],
Cell[28381, 666, 3064, 62, 124, "Text",
 CellID->11659],
Cell[31448, 730, 961, 18, 48, "Text",
 CellID->9609],
Cell[32412, 750, 2330, 45, 114, "Text",
 CellID->26029],
Cell[34745, 797, 1860, 42, 115, "DefinitionBox",
 CellID->4117],
Cell[36608, 841, 155, 2, 31, "Caption",
 CellID->26324],
Cell[36766, 845, 1859, 31, 88, "Text",
 CellID->23906],
Cell[38628, 878, 829, 18, 49, "MathCaption",
 CellID->21321],
Cell[CellGroupData[{
Cell[39482, 900, 93, 2, 28, "Input",
 CellID->18189],
Cell[39578, 904, 212, 5, 36, "Output",
 CellID->1225]
}, Open  ]],
Cell[39805, 912, 488, 11, 34, "Text",
 CellID->558888231],
Cell[40296, 925, 1305, 29, 97, "DefinitionBox",
 CellID->58252748],
Cell[41604, 956, 412, 10, 35, "Caption",
 CellID->417255879],
Cell[42019, 968, 1756, 39, 78, "Text",
 CellID->22324288],
Cell[CellGroupData[{
Cell[43800, 1011, 136, 3, 28, "Input",
 CellID->52849],
Cell[43939, 1016, 296, 9, 52, "Output",
 CellID->622793840]
}, Open  ]],
Cell[44250, 1028, 679, 16, 34, "Text",
 CellID->332194946],
Cell[CellGroupData[{
Cell[44954, 1048, 150, 4, 28, "Input",
 CellID->644855583],
Cell[45107, 1054, 330, 10, 52, "Output",
 CellID->898425175]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[45486, 1070, 230, 4, 62, "Section",
 CellTags->"3.1",
 CellID->50025874],
Cell[45719, 1076, 6279, 142, 303, "DefinitionBox",
 CellID->29738],
Cell[52001, 1220, 412, 7, 31, "Caption",
 CellID->4409],
Cell[52416, 1229, 1783, 27, 88, "Text",
 CellID->154],
Cell[54202, 1258, 528, 11, 33, "MathCaption",
 CellID->2469],
Cell[CellGroupData[{
Cell[54755, 1273, 134, 3, 28, "Input",
 CellID->15881],
Cell[54892, 1278, 207, 5, 36, "Output",
 CellID->25239]
}, Open  ]],
Cell[55114, 1286, 867, 15, 49, "MathCaption",
 CellID->8107],
Cell[CellGroupData[{
Cell[56006, 1305, 224, 7, 28, "Input",
 CellID->22629],
Cell[56233, 1314, 261, 8, 36, "Output",
 CellID->19913]
}, Open  ]],
Cell[56509, 1325, 1011, 20, 52, "Text",
 CellID->250707282],
Cell[57523, 1347, 613, 13, 33, "MathCaption",
 CellID->7262],
Cell[CellGroupData[{
Cell[58161, 1364, 116, 3, 28, "Input",
 CellID->25052],
Cell[58280, 1369, 177, 5, 36, "Output",
 CellID->30731]
}, Open  ]],
Cell[58472, 1377, 851, 18, 47, "MathCaption",
 CellID->722345794],
Cell[CellGroupData[{
Cell[59348, 1399, 194, 5, 28, "Input",
 CellID->459991907],
Cell[59545, 1406, 191, 6, 36, "Output",
 CellID->146532095]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[59785, 1418, 187, 3, 62, "Section",
 CellTags->"4.1",
 CellID->840619645],
Cell[59975, 1423, 3775, 80, 181, "DefinitionBox",
 CellID->6685],
Cell[63753, 1505, 176, 3, 31, "Caption",
 CellID->14050],
Cell[63932, 1510, 2164, 41, 92, "Text",
 CellID->26393],
Cell[66099, 1553, 442, 8, 31, "MathCaption",
 CellID->15249],
Cell[CellGroupData[{
Cell[66566, 1565, 157, 4, 28, "Input",
 CellID->25794],
Cell[66726, 1571, 199, 5, 36, "Output",
 CellID->13202]
}, Open  ]],
Cell[66940, 1579, 484, 10, 33, "MathCaption",
 CellID->28008],
Cell[CellGroupData[{
Cell[67449, 1593, 188, 6, 28, "Input",
 CellID->31934],
Cell[67640, 1601, 204, 5, 36, "Output",
 CellID->18727]
}, Open  ]],
Cell[67859, 1609, 2439, 56, 174, "DefinitionBox",
 CellID->436300292],
Cell[70301, 1667, 180, 3, 31, "Caption",
 CellID->452797221],
Cell[70484, 1672, 2391, 44, 114, "Text",
 CellID->106178195],
Cell[72878, 1718, 2206, 38, 92, "Text",
 CellID->8672],
Cell[75087, 1758, 494, 11, 59, "DefinitionBox",
 CellID->5707],
Cell[75584, 1771, 417, 10, 31, "Caption",
 CellID->21496],
Cell[76004, 1783, 4553, 78, 180, "Text",
 CellID->24464]
}, Open  ]],
Cell[CellGroupData[{
Cell[80594, 1866, 250, 4, 62, "Section",
 CellTags->"5.1",
 CellID->253043088],
Cell[80847, 1872, 1190, 35, 102, "DefinitionBox",
 CellID->10396],
Cell[82040, 1909, 225, 7, 31, "Caption",
 CellID->15460],
Cell[82268, 1918, 1172, 21, 66, "Text",
 CellID->20615],
Cell[83443, 1941, 791, 16, 48, "Text",
 CellID->10904],
Cell[84237, 1959, 787, 19, 81, "DefinitionBox",
 CellID->200984640],
Cell[85027, 1980, 159, 2, 31, "Caption",
 CellID->671587873],
Cell[85189, 1984, 744, 17, 52, "Text",
 CellID->570290897],
Cell[85936, 2003, 1279, 23, 66, "Text",
 CellID->2599],
Cell[87218, 2028, 1417, 27, 66, "Text",
 CellID->20136],
Cell[88638, 2057, 897, 16, 49, "MathCaption",
 CellID->4680],
Cell[89538, 2075, 7034, 121, 173, "Picture",
 CellID->210650304],
Cell[96575, 2198, 2216, 39, 102, "Text",
 CellID->27032]
}, Open  ]],
Cell[CellGroupData[{
Cell[98828, 2242, 343, 12, 31, "TutorialMoreAboutSection",
 CellID->33089523],
Cell[99174, 2256, 31, 0, 14, "SectionHeaderSpacer"],
Cell[99208, 2258, 165, 3, 18, "TutorialMoreAbout",
 CellID->207696369],
Cell[99376, 2263, 31, 0, 29, "SectionFooterSpacer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[99444, 2268, 449, 14, 31, "RelatedTutorialsSection",
 CellID->91859868],
Cell[99896, 2284, 31, 0, 14, "SectionHeaderSpacer"],
Cell[99930, 2286, 208, 4, 18, "Tutorials",
 CellID->594965642],
Cell[100141, 2292, 239, 4, 18, "RelatedTutorials",
 CellID->405226890],
Cell[100383, 2298, 253, 7, 19, "Tutorials",
 CellID->61163727],
Cell[100639, 2307, 331, 6, 18, "Tutorials",
 CellID->58033046]
}, Open  ]]
}, Open  ]],
Cell[100997, 2317, 23, 0, 41, "FooterCell"]
}
]
*)

(* End of internal cache information *)
