(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     86816,       2182]
NotebookOptionsPosition[     77538,       1909]
NotebookOutlinePosition[     82899,       2050]
CellTagsIndexPosition[     82610,       2036]
WindowTitle->Patterns and Transformation Rules - Wolfram Mathematica
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[GridBox[{
   {Cell["MATHEMATICA TUTORIAL", "PacletNameCell"], Cell[TextData[{
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "Related Tutorials",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"Related Tutorials", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->False], {"\<\"Introduction to Patterns\"\>":>
       Documentation`HelpLookup[
       "paclet:tutorial/Introduction-Patterns"], "\<\"Pattern Sequences\"\>":>
       Documentation`HelpLookup[
       "paclet:tutorial/PatternSequences"], "\<\"Verbatim Patterns\"\>":>
       Documentation`HelpLookup[
       "paclet:tutorial/VerbatimPatterns"], "\<\"Optional and Default \
Arguments\"\>":>Documentation`HelpLookup[
       "paclet:tutorial/OptionalAndDefaultArguments"]},
       Appearance->None,
       MenuAppearance->Automatic,
       MenuStyle->"RelatedTutorialsSection"]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "Related Guides",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"Related Guides", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->False], {"\<\"Patterns\"\>":>Documentation`HelpLookup[
       "paclet:guide/Patterns"], "\<\"Rules & Patterns\"\>":>
       Documentation`HelpLookup["paclet:guide/RulesAndPatterns"]},
       Appearance->None,
       MenuAppearance->Automatic,
       MenuStyle->"TutorialMoreAboutSection"]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "Functions",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"Functions", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->False], {"\<\"Attributes\"\>":>Documentation`HelpLookup[
       "paclet:ref/Attributes"], "\<\"Clear\"\>":>Documentation`HelpLookup[
       "paclet:ref/Clear"], "\<\"ClearAll\"\>":>Documentation`HelpLookup[
       "paclet:ref/ClearAll"], "\<\"Default\"\>":>Documentation`HelpLookup[
       "paclet:ref/Default"], "\<\"DownValues\"\>":>Documentation`HelpLookup[
       "paclet:ref/DownValues"], "\<\"Except\"\>":>Documentation`HelpLookup[
       "paclet:ref/Except"], "\<\"Flat\"\>":>Documentation`HelpLookup[
       "paclet:ref/Flat"], "\<\"HoldPattern\"\>":>Documentation`HelpLookup[
       "paclet:ref/HoldPattern"], "\<\"Longest\"\>":>Documentation`HelpLookup[
       "paclet:ref/Longest"], "\<\"Messages\"\>":>Documentation`HelpLookup[
       "paclet:ref/Messages"], "\<\"OneIdentity\"\>":>
       Documentation`HelpLookup["paclet:ref/OneIdentity"], "\<\"Optional\"\>":>
       Documentation`HelpLookup["paclet:ref/Optional"], "\<\"Options\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/Options"], "\<\"OptionsPattern\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/OptionsPattern"], "\<\"Orderless\"\>":>
       Documentation`HelpLookup["paclet:ref/Orderless"], "\<\"OwnValues\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/OwnValues"], "\<\"PatternSequence\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/PatternSequence"], "\<\"Remove\"\>":>
       Documentation`HelpLookup["paclet:ref/Remove"], "\<\"Repeated\"\>":>
       Documentation`HelpLookup["paclet:ref/Repeated"], "\<\"Shortest\"\>":>
       Documentation`HelpLookup["paclet:ref/Shortest"], "\<\"True\"\>":>
       Documentation`HelpLookup["paclet:ref/True"], "\<\"UpValues\"\>":>
       Documentation`HelpLookup["paclet:ref/UpValues"], "\<\"Verbatim\"\>":>
       Documentation`HelpLookup["paclet:ref/Verbatim"]},
       Appearance->None,
       MenuAppearance->Automatic,
       MenuStyle->"TutorialFunction"]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "URL",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"URL", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->
         False], {"\<\"tutorial/PatternsAndTransformationRules\"\>":>
       None, "\<\"Copy Mathematica URL\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell["tutorial/PatternsAndTransformationRules"]}, Visible -> 
            False]]; SelectionMove[
         DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; Null], 
       Delimiter, "\<\"Copy web URL\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell[
              BoxData[
               MakeBoxes[
                Hyperlink[
                "http://reference.wolfram.com/mathematica/tutorial/\
PatternsAndTransformationRules.html"], StandardForm]], "Input", 
              TextClipboardType -> "PlainText"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; 
        Null], "\<\"Go to web URL\"\>":>FrontEndExecute[{
         NotebookLocate[{
           URL[
            StringJoin[
            "http://reference.wolfram.com/mathematica/", 
             "tutorial/PatternsAndTransformationRules", ".html"]], None}]}]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}]
    }], "AnchorBar"]}
  }]], "AnchorBarGrid",
 CellID->1],

Cell[CellGroupData[{

Cell["\:0428\:0430\:0431\:043b\:043e\:043d\:044b \:0438 \:043f\:0440\:0430\
\:0432\:0438\:043b\:0430 \:043f\:0440\:0435\:043e\:0431\:0440\:0430\:0437\
\:043e\:0432\:0430\:043d\:0438\:044f", "Title",
 CellID->1292728359],

Cell[BoxData[GridBox[{
   {Cell[BoxData[
     ButtonBox[
      RowBox[{
      "\[RightGuillemet]", " ", "\:0428\:0430\:0431\:043b\:043e\:043d\:044b"}],
      BaseStyle->"Hyperlink",
      ButtonData->{"PatternsAndTransformationRulesRU.nb", "1.1"}]],
     FontFamily->"Arial",
     FontSize->13,
     FontWeight->Bold], Cell[BoxData[
     ButtonBox[
      RowBox[{
      "\[RightGuillemet]", " ", "\:041e\:0447\:0438\:0441\:0442\:043a\:0430", 
       " ", "\:0438", " ", "\:0443\:0434\:0430\:043b\:0435\:043d\:0438\:0435",
        " ", "\:043e\:0431\:044a\:0435\:043a\:0442\:043e\:0432"}],
      BaseStyle->"Hyperlink",
      ButtonData->{"PatternsAndTransformationRulesRU.nb", "4.1"}]],
     FontFamily->"Arial",
     FontSize->13,
     FontWeight->Bold]},
   {Cell[BoxData[
     ButtonBox[
      RowBox[{
      "\[RightGuillemet]", " ", 
       "\:041e\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\:0438\:044f"}],
      BaseStyle->"Hyperlink",
      ButtonData->{"PatternsAndTransformationRulesRU.nb", "2.1"}]],
     FontFamily->"Arial",
     FontSize->13,
     FontWeight->Bold], Cell[BoxData[
     ButtonBox[
      RowBox[{
      "\[RightGuillemet]", " ", "\:041f\:0440\:0430\:0432\:0438\:043b\:0430", 
       " ", "\:043f\:0440\:0435\:043e\:0431\:0440\:0430\:0437\:043e\:0432\
\:0430\:043d\:0438\:044f"}],
      BaseStyle->"Hyperlink",
      ButtonData->{"PatternsAndTransformationRulesRU.nb", "5.1"}]],
     FontFamily->"Arial",
     FontSize->13,
     FontWeight->Bold]},
   {Cell[BoxData[
     ButtonBox[
      RowBox[{
      "\[RightGuillemet]", " ", "\:0422\:0438\:043f\:044b", " ", 
       "\:0437\:043d\:0430\:0447\:0435\:043d\:0438\:0439"}],
      BaseStyle->"Hyperlink",
      ButtonData->{"PatternsAndTransformationRulesRU.nb", "3.1"}]],
     FontFamily->"Arial",
     FontSize->13,
     FontWeight->Bold], ""}
  }]], "TutorialJumpBox",
 CellID->328837780],

Cell[CellGroupData[{

Cell["\:0428\:0430\:0431\:043b\:043e\:043d\:044b", "Section",
 CellTags->{"SA.5.1", "1.1"},
 CellID->8519],

Cell[TextData[{
 StyleBox["\:0428\:0430\:0431\:043b\:043e\:043d\:044b",
  FontSlant->"Italic"],
 " \:043f\:0440\:0438\:043c\:0435\:043d\:044f\:044e\:0442\:0441\:044f \:0434\
\:043b\:044f \:043e\:0431\:043e\:0437\:043d\:0430\:0447\:0435\:043d\:0438\
\:044f \:0433\:0440\:0443\:043f\:043f (\:043a\:043b\:0430\:0441\:0441\:043e\
\:0432) \:0432\:044b\:0440\:0430\:0436\:0435\:043d\:0438\:0439. \:041e\:043d\
\:0438 \:0441\:043e\:0434\:0435\:0440\:0436\:0430\:0442 ",
 StyleBox["\:043e\:0431\:044a\:0435\:043a\:0442\:044b \
\:0448\:0430\:0431\:043b\:043e\:043d\:043e\:0432",
  FontSlant->"Italic"],
 ", \:043a\:043e\:0442\:043e\:0440\:044b\:0435 \:043f\:0440\:0435\:0434\:0441\
\:0442\:0430\:0432\:043b\:044f\:044e\:0442 \:0441\:043e\:0431\:043e\:0439 \
\:043d\:0430\:0431\:043e\:0440\:044b \:0432\:043e\:0437\:043c\:043e\:0436\
\:043d\:044b\:0445 \:0432\:044b\:0440\:0430\:0436\:0435\:043d\:0438\:0439."
}], "Text",
 CellID->13985],

Cell[BoxData[GridBox[{
   {"_", Cell[
    "\:043b\:044e\:0431\:043e\:0435 \
\:0432\:044b\:0440\:0430\:0436\:0435\:043d\:0438\:0435", "TableText"]},
   {
    RowBox[{
     StyleBox["x", "TI"], "_"}], Cell[TextData[{
     "\:043b\:044e\:0431\:043e\:0435 \:0432\:044b\:0440\:0430\:0436\:0435\
\:043d\:0438\:0435, \:0441 \:043f\:0440\:0438\:0441\:0432\:043e\:0435\:043d\
\:0438\:0435\:043c \:0435\:043c\:0443 \:0438\:043c\:0435\:043d\:0438 ",
     Cell[BoxData[
      StyleBox["x", "TI"]], "InlineFormula"]
    }], "TableText"]},
   {
    RowBox[{
     StyleBox["x", "TI"], ":", 
     StyleBox["\:0448\:0430\:0431\:043b\:043e\:043d", "TI"]}], Cell[TextData[{
     "\:0448\:0430\:0431\:043b\:043e\:043d, \:043a\:043e\:0442\:043e\:0440\
\:043e\:043c\:0443 \:043f\:0440\:0438\:0441\:0432\:043e\:0435\:043d\:043e \
\:0438\:043c\:044f ",
     Cell[BoxData[
      StyleBox["x", "TI"]], "InlineFormula"]
    }], "TableText"]},
   {
    RowBox[{
     StyleBox["\:0448\:0430\:0431\:043b\:043e\:043d", "TI"], "?", 
     StyleBox["\:0442\:0435\:0441\:0442", "TI"]}], Cell[TextData[{
     "\:0448\:0430\:0431\:043b\:043e\:043d, \:0432\:044b\:0431\:0438\:0440\
\:0430\:044e\:0449\:0438\:0439 \:0438\:0437 \:0441\:043e\:0432\:043f\:0430\
\:0434\:0435\:043d\:0438\:0439 \:043b\:0438\:0448\:044c \:0442\:0435, \:0434\
\:043b\:044f \:043a\:043e\:0442\:043e\:0440\:044b\:0445 ",
     Cell[BoxData[
      StyleBox["\:0442\:0435\:0441\:0442", "TI"]], "InlineFormula"],
     " \:0432\:043e\:0437\:0432\:0440\:0430\:0449\:0430\:0435\:0442 ",
     Cell[BoxData[
      TemplateBox[{Cell["True"],"paclet:ref/True"},
       "RefLink",
       BaseStyle->"InlineFormula"]], "InlineFormula"],
     " (\:0418\:0441\:0442\:0438\:043d\:0430)"
    }], "TableText"]},
   {
    RowBox[{"_", 
     StyleBox["h", "TI"]}], Cell[TextData[{
     "\:043b\:044e\:0431\:043e\:0435 \:0432\:044b\:0440\:0430\:0436\:0435\
\:043d\:0438\:0435 \:0441 \:0437\:0430\:0433\:043e\:043b\:043e\:0432\:043a\
\:043e\:043c ",
     Cell[BoxData[
      StyleBox["h", "TI"]], "InlineFormula"]
    }], "TableText"]},
   {
    RowBox[{
     StyleBox["x", "TI"], "_", 
     StyleBox["h", "TI"]}], Cell[TextData[{
     "\:043b\:044e\:0431\:043e\:0435 \:0432\:044b\:0440\:0430\:0436\:0435\
\:043d\:0438\:0435 \:0441 \:0437\:0430\:0433\:043e\:043b\:043e\:0432\:043a\
\:043e\:043c ",
     Cell[BoxData[
      StyleBox["h", "TI"]], "InlineFormula"],
     ", \:0441 \:043f\:0440\:0438\:0441\:0432\:043e\:0435\:043d\:0438\:0435\
\:043c \:0435\:043c\:0443 \:0438\:043c\:0435\:043d\:0438 ",
     Cell[BoxData[
      StyleBox["x", "TI"]], "InlineFormula"]
    }], "TableText"]},
   {"__", Cell[
    "\:043b\:044e\:0431\:0430\:044f \
\:043f\:043e\:0441\:043b\:0435\:0434\:043e\:0432\:0430\:0442\:0435\:043b\:044c\
\:043d\:043e\:0441\:0442\:044c \:0438\:0437 \:043e\:0434\:043d\:043e\:0433\
\:043e \:0438\:043b\:0438 \:0431\:043e\:043b\:0435\:0435 \:0432\:044b\:0440\
\:0430\:0436\:0435\:043d\:0438\:0439", "TableText"]},
   {"___", Cell[
    "\:043b\:044e\:0431\:0430\:044f \
\:043f\:043e\:0441\:043b\:0435\:0434\:043e\:0432\:0430\:0442\:0435\:043b\:044c\
\:043d\:043e\:0441\:0442\:044c \:0438\:0437 \:043d\:0443\:043b\:044f \:0438\
\:043b\:0438 \:0431\:043e\:043b\:0435\:0435 \:0432\:044b\:0440\:0430\:0436\
\:0435\:043d\:0438\:0439", "TableText"]},
   {
    RowBox[{
     StyleBox["x", "TI"], "__", Cell[
     " \[ThinSpace]\:0438 \[ThinSpace]", "TableText"], 
     StyleBox["x", "TI"], "___"}], Cell[TextData[{
     "\:043f\:043e\:0441\:043b\:0435\:0434\:043e\:0432\:0430\:0442\:0435\:043b\
\:044c\:043d\:043e\:0441\:0442\:044c \:0432\:044b\:0440\:0430\:0436\:0435\
\:043d\:0438\:0439 \:0441 \:043f\:0440\:0438\:0441\:0432\:043e\:0435\:043d\
\:0438\:0435\:043c \:0435\:0439 \:0438\:043c\:0435\:043d\:0438 ",
     Cell[BoxData[
      StyleBox["x", "TI"]], "InlineFormula"]
    }], "TableText"]},
   {
    RowBox[{"__", 
     StyleBox["h", "TI"], Cell[" \:0438 \[ThinSpace]", "TableText"], "___", 
     StyleBox["h", "TI"]}], Cell[TextData[{
     "\:043f\:043e\:0441\:043b\:0435\:0434\:043e\:0432\:0430\:0442\:0435\:043b\
\:044c\:043d\:043e\:0441\:0442\:044c \:0432\:044b\:0440\:0430\:0436\:0435\
\:043d\:0438\:0439, \:043a\:0430\:0436\:0434\:043e\:0435 \:0438\:0437 \:043a\
\:043e\:0442\:043e\:0440\:044b\:0445 \:0438\:043c\:0435\:0435\:0442 \:0437\
\:0430\:0433\:043e\:043b\:043e\:0432\:043e\:043a ",
     Cell[BoxData[
      StyleBox["h", "TI"]], "InlineFormula"]
    }], "TableText"]},
   {
    RowBox[{
     StyleBox["x", "TI"], "__", 
     StyleBox["h", "TI"], Cell[" \:0438 \[ThinSpace]", "TableText"], 
     StyleBox["x", "TI"], "___", 
     StyleBox["h", "TI"]}], Cell[TextData[{
     "\:043f\:043e\:0441\:043b\:0435\:0434\:043e\:0432\:0430\:0442\:0435\:043b\
\:044c\:043d\:043e\:0441\:0442\:044c \:0432\:044b\:0440\:0430\:0436\:0435\
\:043d\:0438\:0439, \:043a\:0430\:0436\:0434\:043e\:0435 \:0438\:0437 \:043a\
\:043e\:0442\:043e\:0440\:044b\:0445 \:0438\:043c\:0435\:0435\:0442 \:0437\
\:0430\:0433\:043e\:043b\:043e\:0432\:043e\:043a ",
     Cell[BoxData[
      StyleBox["h", "TI"]], "InlineFormula"],
     ", \:0441 \:043f\:0440\:0438\:0441\:0432\:043e\:0435\:043d\:0438\:0435\
\:043c \:0435\:0439 \:0438\:043c\:0435\:043d\:0438 ",
     Cell[BoxData[
      StyleBox["x", "TI"]], "InlineFormula"]
    }], "TableText"]},
   {
    RowBox[{
     ButtonBox["PatternSequence",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/PatternSequence"], "[", 
     RowBox[{
      SubscriptBox[
       StyleBox["p", "TI"], 
       StyleBox["1", "TR"]], ",", 
      SubscriptBox[
       StyleBox["p", "TI"], 
       StyleBox["2", "TR"]], ",", 
      StyleBox["\[Ellipsis]", "TR"]}], "]"}], Cell[
    "\:043f\:043e\:0441\:043b\:0435\:0434\:043e\:0432\:0430\:0442\:0435\:043b\
\:044c\:043d\:043e\:0441\:0442\:044c \:0448\:0430\:0431\:043b\:043e\:043d\
\:043e\:0432", "TableText"]},
   {
    RowBox[{
     StyleBox["x", "TI"], 
     StyleBox["_", "MR"], 
     StyleBox[":", "MR"], 
     StyleBox["v", "TI"]}], Cell[TextData[{
     "\:0432\:044b\:0440\:0430\:0436\:0435\:043d\:0438\:0435 \:0441\:043e \
\:0437\:043d\:0430\:0447\:0435\:043d\:0438\:0435\:043c \:043f\:043e \:0443\
\:043c\:043e\:043b\:0447\:0430\:043d\:0438\:044e ",
     Cell[BoxData[
      StyleBox["v", "TI"]], "InlineFormula"]
    }], "TableText"]},
   {
    RowBox[{
     StyleBox["x", "TI"], 
     StyleBox["_", "MR"], 
     StyleBox["h", "TI"], 
     StyleBox[":", "MR"], 
     StyleBox["v", "TI"]}], Cell[TextData[{
     "\:0432\:044b\:0440\:0430\:0436\:0435\:043d\:0438\:0435 \:0441 \:0437\
\:0430\:0433\:043e\:043b\:043e\:0432\:043a\:043e\:043c ",
     Cell[BoxData[
      StyleBox["h", "TI"]], "InlineFormula"],
     " \:0438 \:0437\:043d\:0430\:0447\:0435\:043d\:0438\:0435\:043c \:043f\
\:043e \:0443\:043c\:043e\:043b\:0447\:0430\:043d\:0438\:044e ",
     Cell[BoxData[
      StyleBox["v", "TI"]], "InlineFormula"]
    }], "TableText"]},
   {
    RowBox[{
     StyleBox["x", "TI"], 
     StyleBox["_.", "MR"]}], Cell[
    "\:0432\:044b\:0440\:0430\:0436\:0435\:043d\:0438\:0435, \:0447\:044c\
\:0435 \:0437\:043d\:0430\:0447\:0435\:043d\:0438\:0435 \:043f\:043e \:0443\
\:043c\:043e\:043b\:0447\:0430\:043d\:0438\:044e \:043e\:043f\:0440\:0435\
\:0434\:0435\:043b\:0435\:043d\:043e \:0433\:043b\:043e\:0431\:0430\:043b\
\:044c\:043d\:043e", "TableText"]},
   {
    RowBox[{
     ButtonBox["Optional",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/Optional"], "[", 
     StyleBox["x", "TI"], 
     StyleBox["_", "MR"], 
     StyleBox["h", "TI"], "]"}], Cell[TextData[{
     "\:0432\:044b\:0440\:0430\:0436\:0435\:043d\:0438\:0435 \:0441 \:0437\
\:0430\:0433\:043e\:043b\:043e\:0432\:043a\:043e\:043c ",
     Cell[BoxData[
      StyleBox["h", "TI"]], "InlineFormula"],
     " \:0438 \:0433\:043b\:043e\:0431\:0430\:043b\:044c\:043d\:043e \:043e\
\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\:043d\:044b\:043c \:0437\
\:043d\:0430\:0447\:0435\:043d\:0438\:0435\:043c \:043f\:043e \:0443\:043c\
\:043e\:043b\:0447\:0430\:043d\:0438\:044e"
    }], "TableText"]},
   {
    RowBox[{
     ButtonBox["Except",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/Except"], "[", 
     StyleBox["c", "TI"], "]"}], Cell[TextData[{
     "\:043b\:044e\:0431\:043e\:0435 \:0432\:044b\:0440\:0430\:0436\:0435\
\:043d\:0438\:0435, \:0438\:0441\:043a\:043b\:044e\:0447\:0430\:044f \:0442\
\:0435, \:0447\:0442\:043e \:0441\:043e\:043e\:0442\:0432\:0435\:0442\:0441\
\:0442\:0432\:0443\:044e\:0442 ",
     Cell[BoxData[
      StyleBox["c", "TI"]], "InlineFormula"]
    }], "TableText"]},
   {
    RowBox[{
     ButtonBox["Except",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/Except"], "[", 
     RowBox[{
      StyleBox["c", "TI"], ",", 
      StyleBox["\:0448\:0430\:0431\:043b\:043e\:043d", "TI"]}], "]"}], Cell[
    TextData[{
     "\:043b\:044e\:0431\:043e\:0435 \:0441\:043e\:043e\:0442\:0432\:0435\
\:0442\:0441\:0442\:0432\:0443\:044e\:0449\:0435\:0435 ",
     Cell[BoxData[
      StyleBox["\:0448\:0430\:0431\:043b\:043e\:043d\:0443", "TI"]], 
      "InlineFormula"],
     " \:0432\:044b\:0440\:0430\:0436\:0435\:043d\:0438\:0435, \:0437\:0430 \
\:0438\:0441\:043a\:043b\:044e\:0447\:0435\:043d\:0438\:0435\:043c \:0442\
\:0435\:0445, \:0447\:0442\:043e \:0441\:043e\:043e\:0442\:0432\:0435\:0442\
\:0441\:0442\:0432\:0443\:044e\:0442 ",
     Cell[BoxData[
      StyleBox["c", "TI"]], "InlineFormula"]
    }], "TableText"]},
   {
    RowBox[{
     StyleBox["\:0448\:0430\:0431\:043b\:043e\:043d", "TI"], ".."}], Cell[
    "\:0448\:0430\:0431\:043b\:043e\:043d, \:043f\:043e\:0432\:0442\:043e\
\:0440\:044f\:0435\:043c\:044b\:0439 \:043e\:0434\:0438\:043d \:0438\:043b\
\:0438 \:0431\:043e\:043b\:0435\:0435 \:0440\:0430\:0437", "TableText"]},
   {
    RowBox[{
     StyleBox["\:0448\:0430\:0431\:043b\:043e\:043d", "TI"], "..."}], Cell[
    "\:0448\:0430\:0431\:043b\:043e\:043d, \:043f\:043e\:0432\:0442\:043e\
\:0440\:044f\:0435\:043c\:044b\:0439 \:043d\:043e\:043b\:044c \:0438\:043b\
\:0438 \:0431\:043e\:043b\:0435\:0435 \:0440\:0430\:0437", "TableText"]},
   {
    RowBox[{
     ButtonBox["Repeated",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/Repeated"], "[", 
     RowBox[{
      StyleBox["\:0448\:0430\:0431\:043b\:043e\:043d", "TI"], ",", " ", 
      StyleBox[
       "\:0441\:043f\:0435\:0446\:0438\:0444\:0438\:043a\:0430\:0446\:0438\
\:044f", "TI"]}], "]"}], Cell[TextData[{
     "\:0448\:0430\:0431\:043b\:043e\:043d, \:043f\:043e\:0432\:0442\:043e\
\:0440\:044f\:0435\:043c\:044b\:0439 \:0441\:043e\:0433\:043b\:0430\:0441\
\:043d\:043e ",
     Cell[BoxData[
      StyleBox[
       "\:0441\:043f\:0435\:0446\:0438\:0444\:0438\:043a\:0430\:0446\:0438\
\:0438", "TI"]], "InlineFormula"]
    }], "TableText"]},
   {
    RowBox[{
     SubscriptBox[
      StyleBox["\:0448\:0430\:0431\:043b\:043e\:043d", "TI"], 
      StyleBox["1",
       FontFamily->"Times",
       FontSize->9]], "|", 
     SubscriptBox[
      StyleBox["\:0448\:0430\:0431\:043b\:043e\:043d", "TI"], 
      StyleBox["2",
       FontFamily->"Times",
       FontSize->9]], "|", 
     StyleBox["\[Ellipsis]", "TR"], " "}], Cell[TextData[{
     "\:0448\:0430\:0431\:043b\:043e\:043d, \:043a\:043e\:0442\:043e\:0440\
\:043e\:043c\:0443 \:0441\:043e\:043e\:0442\:0432\:0435\:0442\:0441\:0442\
\:0432\:0443\:0435\:0442 \:0445\:043e\:0442\:044f \:0431\:044b \:043e\:0434\
\:0438\:043d \:0438\:0437 ",
     Cell[BoxData[
      SubscriptBox[
       StyleBox["\:0448\:0430\:0431\:043b\:043e\:043d", "TI"], 
       StyleBox["i", "TI"]]], "InlineFormula"]
    }], "TableText"]},
   {
    RowBox[{
     StyleBox["\:0448\:0430\:0431\:043b\:043e\:043d", "TI"], "/;", 
     StyleBox["\:0443\:0441\:043b\:043e\:0432\:0438\:0435", "TI"]}], Cell[
    TextData[{
     "\:0448\:0430\:0431\:043b\:043e\:043d, \:0441\:0440\:0430\:0431\:0430\
\:0442\:044b\:0432\:0430\:044e\:0449\:0438\:0439 \:0435\:0441\:043b\:0438 \
\:0432\:044b\:0447\:0438\:0441\:043b\:0435\:043d\:0438\:0435 ",
     Cell[BoxData[
      StyleBox["\:0443\:0441\:043b\:043e\:0432\:0438\:044f", "TI"]], 
      "InlineFormula"],
     " \:0434\:0430\:0435\:0442 \:0440\:0435\:0437\:0443\:043b\:044c\:0442\
\:0430\:0442 ",
     Cell[BoxData[
      TemplateBox[{Cell["True"],"paclet:ref/True"},
       "RefLink",
       BaseStyle->"InlineFormula"]], "InlineFormula"]
    }], "TableText"]},
   {
    RowBox[{
     ButtonBox["HoldPattern",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/HoldPattern"], "[", 
     StyleBox["\:0448\:0430\:0431\:043b\:043e\:043d", "TI"], "]"}], Cell[
    "\:0448\:0430\:0431\:043b\:043e\:043d, \:043a\:043e\:0442\:043e\:0440\
\:044b\:0439 \:043d\:0435 \:0432\:044b\:0447\:0438\:0441\:043b\:044f\:0435\
\:0442\:0441\:044f", "TableText"]},
   {
    RowBox[{
     ButtonBox["Verbatim",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/Verbatim"], "[", 
     StyleBox["\:0432\:044b\:0440\:0430\:0436\:0435\:043d\:0438\:0435", "TI"],
      "]"}], Cell[
    "\:0432\:044b\:0440\:0430\:0436\:0435\:043d\:0438\:0435, \:0441\:043e\
\:043e\:0442\:0432\:0435\:0442\:0441\:0442\:0432\:0438\:0435 \:043a\:043e\
\:0442\:043e\:0440\:043e\:043c\:0443 \:0434\:043e\:043b\:0436\:043d\:043e \
\:0431\:044b\:0442\:044c \:0434\:043e\:0441\:043b\:043e\:0432\:043d\:044b\
\:043c", "TableText"]},
   {
    RowBox[{
     ButtonBox["OptionsPattern",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/OptionsPattern"], "[", "]"}], Cell[
    "\:043f\:043e\:0441\:043b\:0435\:0434\:043e\:0432\:0430\:0442\:0435\:043b\
\:044c\:043d\:043e\:0441\:0442\:044c \:043e\:043f\:0446\:0438\:0439", 
     "TableText"]},
   {
    RowBox[{
     ButtonBox["Longest",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/Longest"], "[", 
     StyleBox["\:0448\:0430\:0431\:043b\:043e\:043d", "TI"], "]"}], Cell[
    TextData[{
     "\:0441\:0430\:043c\:0430\:044f \:0434\:043b\:0438\:043d\:043d\:0430\
\:044f \:043f\:043e\:0441\:043b\:0435\:0434\:043e\:0432\:0430\:0442\:0435\
\:043b\:044c\:043d\:043e\:0441\:0442\:044c, \:0441\:043e\:043e\:0442\:0432\
\:0435\:0442\:0441\:0442\:0432\:0443\:044e\:0449\:0430\:044f ",
     Cell[BoxData[
      StyleBox["\:0448\:0430\:0431\:043b\:043e\:043d\:0443", "TI"]], 
      "InlineFormula"]
    }], "TableText"]},
   {
    RowBox[{
     ButtonBox["Shortest",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/Shortest"], "[", 
     StyleBox["\:0448\:0430\:0431\:043b\:043e\:043d", "TI"], "]"}], Cell[
    TextData[{
     "\:0441\:0430\:043c\:0430\:044f \:043a\:043e\:0440\:043e\:0442\:043a\
\:0430\:044f \:043f\:043e\:0441\:043b\:0435\:0434\:043e\:0432\:0430\:0442\
\:0435\:043b\:044c\:043d\:043e\:0441\:0442\:044c, \:0441\:043e\:043e\:0442\
\:0432\:0435\:0442\:0441\:0442\:0432\:0443\:044e\:0449\:0430\:044f ",
     Cell[BoxData[
      StyleBox["\:0448\:0430\:0431\:043b\:043e\:043d\:0443", "TI"]], 
      "InlineFormula"]
    }], "TableText"]}
  }]], "DefinitionBox",
 CellID->28289],

Cell["\:041e\:0431\:044a\:0435\:043a\:0442\:044b \:0448\:0430\:0431\:043b\
\:043e\:043d\:043e\:0432.", "Caption",
 CellID->15944],

Cell[TextData[{
 "\:041a\:043e\:0433\:0434\:0430 \:043d\:0435\:0441\:043a\:043e\:043b\:044c\
\:043a\:043e \:043e\:0431\:044a\:0435\:043a\:0442\:043e\:0432 \:0448\:0430\
\:0431\:043b\:043e\:043d\:043e\:0432 \:0441 \:043e\:0434\:043d\:0438\:043c \
\:0438 \:0442\:0435\:043c \:0436\:0435 \:0438\:043c\:0435\:043d\:0435\:043c \
\:043f\:0440\:0438\:0441\:0443\:0442\:0441\:0442\:0432\:0443\:044e\:0442 \
\:0432 \:043e\:0434\:043d\:043e\:043c \:0448\:0430\:0431\:043b\:043e\:043d\
\:0435, \:0432\:0441\:0435\:043c \:043e\:0431\:044a\:0435\:043a\:0442\:0430\
\:043c \:0434\:043e\:043b\:0436\:043d\:043e \:0441\:043e\:043e\:0442\:0432\
\:0435\:0442\:0441\:0442\:0432\:043e\:0432\:0430\:0442\:044c \:043e\:0434\
\:043d\:043e \:0438 \:0442\:043e \:0436\:0435 \:0432\:044b\:0440\:0430\:0436\
\:0435\:043d\:0438\:0435. \:042d\:0442\:043e \:043e\:0437\:043d\:0430\:0447\
\:0430\:0435\:0442, \:0447\:0442\:043e \:0448\:0430\:0431\:043b\:043e\:043d\
\:0443 ",
 Cell[BoxData[
  RowBox[{"f", "[", 
   RowBox[{"x_", ",", "x_"}], "]"}]], "InlineFormula"],
 " \:043c\:043e\:0436\:0435\:0442 \:0441\:043e\:043e\:0442\:0432\:0435\:0442\
\:0441\:0442\:0432\:043e\:0432\:0430\:0442\:044c ",
 Cell[BoxData[
  RowBox[{"f", "[", 
   RowBox[{"2", ",", "2"}], "]"}]], "InlineFormula"],
 " \:043d\:043e \:043d\:0435 ",
 Cell[BoxData[
  RowBox[{"f", "[", 
   RowBox[{"2", ",", "3"}], "]"}]], "InlineFormula"],
 ". "
}], "Text",
 CellID->2865],

Cell[TextData[{
 "\:0412 \:043e\:0431\:044a\:0435\:043a\:0442\:0435 \:0448\:0430\:0431\:043b\
\:043e\:043d\:0430 \:0432\:0438\:0434\:0430  ",
 Cell[BoxData[
  StyleBox[
   RowBox[{"_", 
    StyleBox["h", "TI"]}]]], "InlineFormula"],
 ", \:0437\:0430\:0433\:043e\:043b\:043e\:0432\:043e\:043a ",
 Cell[BoxData[
  StyleBox["h", "TI"]], "InlineFormula"],
 " \:043c\:043e\:0436\:0435\:0442 \:0431\:044b\:0442\:044c \:043b\:044e\:0431\
\:044b\:043c \:0432\:044b\:0440\:0430\:0436\:0435\:043d\:0438\:0435\:043c, \
\:043d\:043e \:043e\:043d \:0441\:0430\:043c \:043d\:0435 \:043c\:043e\:0436\
\:0435\:0442 \:0431\:044b\:0442\:044c \:0448\:0430\:0431\:043b\:043e\:043d\
\:043e\:043c. "
}], "Text",
 CellID->18540],

Cell[TextData[{
 "\:041e\:0431\:044a\:0435\:043a\:0442\:0443 \:0448\:0430\:0431\:043b\:043e\
\:043d\:0430 \:0432\:0438\:0434\:0430 ",
 Cell[BoxData[
  StyleBox[
   RowBox[{
    StyleBox["x", "TI"], "__"}]]], "InlineFormula"],
 " \:0441\:043e\:043e\:0442\:0432\:0435\:0442\:0441\:0442\:0432\:0443\:0435\
\:0442 ",
 StyleBox["\:043f\:043e\:0441\:043b\:0435\:0434\:043e\:0432\:0430\:0442\:0435\
\:043b\:044c\:043d\:043e\:0441\:0442\:044c",
  FontSlant->"Italic"],
 " \:0432\:044b\:0440\:0430\:0436\:0435\:043d\:0438\:0439. \
\:0422\:0430\:043a, \:043d\:0430\:043f\:0440\:0438\:043c\:0435\:0440, \:0448\
\:0430\:0431\:043b\:043e\:043d\:0443 ",
 Cell[BoxData[
  RowBox[{"f", "[", "x__", "]"}]], "InlineFormula"],
 " \:043c\:043e\:0436\:0435\:0442 \:0441\:043e\:043e\:0442\:0432\:0435\:0442\
\:0441\:0442\:0432\:043e\:0432\:0430\:0442\:044c ",
 Cell[BoxData[
  RowBox[{"f", "[", 
   RowBox[{"a", ",", "b", ",", "c"}], "]"}]], "InlineFormula"],
 ", \:0433\:0434\:0435 ",
 Cell[BoxData["x"], "InlineFormula"],
 " \:043f\:0440\:0435\:0434\:0441\:0442\:0430\:0432\:043b\:044f\:0435\:0442 \
\:0441\:043e\:0431\:043e\:0439 ",
 Cell[BoxData[
  RowBox[{
   TemplateBox[{Cell["Sequence"],"paclet:ref/Sequence"},
    "RefLink",
    BaseStyle->"InlineFormula"], "[", 
   RowBox[{"a", ",", "b", ",", "c"}], "]"}]], "InlineFormula"],
 ". \:0415\:0441\:043b\:0438 \:043f\:043e\:0434\:0441\:0442\:0430\:0432\:0438\
\:0442\:044c ",
 Cell[BoxData["x"], "InlineFormula"],
 ", \:0441\:043a\:0430\:0436\:0435\:043c, \:0432 \:0440\:0435\:0437\:0443\
\:043b\:044c\:0442\:0430\:0442 \:043f\:0440\:0430\:0432\:0438\:043b\:0430 \
\:043f\:0440\:0435\:043e\:0431\:0440\:0430\:0437\:043e\:0432\:0430\:043d\:0438\
\:044f, \:043f\:043e\:0441\:043b\:0435\:0434\:043e\:0432\:0430\:0442\:0435\
\:043b\:044c\:043d\:043e\:0441\:0442\:044c \:0431\:0443\:0434\:0435\:0442 \
\:0432\:043d\:0435\:0434\:0440\:0435\:043d\:0430 \:0432 \:0444\:0443\:043d\
\:043a\:0446\:0438\:044e, \:0432 \:043a\:043e\:0442\:043e\:0440\:043e\:0439 \
\:043f\:0440\:0438\:0441\:0443\:0442\:0441\:0442\:0432\:0443\:0435\:0442 ",
 Cell[BoxData["x"], "InlineFormula"],
 ". \:0422\:0430\:043a\:0438\:043c \
\:043e\:0431\:0440\:0430\:0437\:043e\:043c, ",
 Cell[BoxData[
  RowBox[{"g", "[", 
   RowBox[{"u", ",", "x", ",", "u"}], "]"}]], "InlineFormula"],
 " \:0442\:0440\:0430\:043d\:0441\:0444\:043e\:0440\:043c\:0438\:0440\:0443\
\:0435\:0442\:0441\:044f \:0432 ",
 Cell[BoxData[
  RowBox[{"g", "[", 
   RowBox[{"u", ",", "a", ",", "b", ",", "c", ",", "u"}], "]"}]], 
  "InlineFormula"],
 ". "
}], "Text",
 CellID->23245],

Cell[TextData[{
 "\:0415\:0441\:043b\:0438 \:0432 \:043a\:0430\:0447\:0435\:0441\:0442\:0432\
\:0435 \:0430\:0440\:0433\:0443\:043c\:0435\:043d\:0442\:043e\:0432 \:0444\
\:0443\:043d\:043a\:0446\:0438\:0439 \:043f\:0440\:0438\:0441\:0443\:0442\
\:0441\:0442\:0432\:0443\:044e\:0442 \:043e\:0431\:044a\:0435\:043a\:0442\
\:044b \:0448\:0430\:0431\:043b\:043e\:043d\:043e\:0432 ",
 Cell[BoxData[
  RowBox[{
   StyleBox[
    RowBox[{
     StyleBox["x", "TI"], "_:"}]], 
   StyleBox["v", "TI"]}]], "InlineFormula"],
 " \:0438 ",
 Cell[BoxData[
  StyleBox[
   RowBox[{
    StyleBox["x", "TI"], "_."}]]], "InlineFormula"],
 " , \:043e\:043d\:0438 \
\:043f\:0440\:0435\:0434\:0441\:0442\:0430\:0432\:043b\:044f\:044e\:0442 \
\:0430\:0440\:0433\:0443\:043c\:0435\:043d\:0442\:044b, \:043a\:043e\:0442\
\:043e\:0440\:044b\:0435 \:043c\:043e\:0433\:0443\:0442 \:0431\:044b\:0442\
\:044c \:043e\:043f\:0443\:0449\:0435\:043d\:044b. \:0415\:0441\:043b\:0438 \
\:043e\:043f\:0443\:0441\:043a\:0430\:0435\:0442\:0441\:044f \:0430\:0440\
\:0433\:0443\:043c\:0435\:043d\:0442 \:0441\:043e\:043e\:0442\:0432\:0435\
\:0442\:0441\:0442\:0432\:0443\:044e\:0449\:0438\:0439 ",
 Cell[BoxData[
  RowBox[{
   StyleBox[
    RowBox[{
     StyleBox["x", "TI"], "_:"}]], 
   StyleBox["v", "TI"]}]], "InlineFormula"],
 " , \:0442\:043e\:0433\:0434\:0430 ",
 Cell[BoxData[
  StyleBox["x", "TI"]], "InlineFormula"],
 " \:043f\:0440\:0438\:043d\:0438\:043c\:0430\:0435\:0442 \:0437\:043d\:0430\
\:0447\:0435\:043d\:0438\:0435 ",
 Cell[BoxData[
  StyleBox["v", "TI"]], "InlineFormula"],
 ". \:0415\:0441\:043b\:0438 \:043e\:043f\:0443\:0441\:043a\:0430\:0435\:0442\
\:0441\:044f \:0430\:0440\:0433\:0443\:043c\:0435\:043d\:0442 \:0441\:043e\
\:043e\:0442\:0432\:0435\:0442\:0441\:0442\:0432\:0443\:044e\:0449\:0438\:0439\
 ",
 Cell[BoxData[
  StyleBox[
   RowBox[{
    StyleBox["x", "TI"], "_."}]]], "InlineFormula"],
 " , \:0442\:043e\:0433\:0434\:0430 ",
 Cell[BoxData[
  StyleBox["x", "TI"]], "InlineFormula"],
 " \:043f\:0440\:0438\:043d\:0438\:043c\:0430\:0435\:0442 ",
 StyleBox["\:0437\:043d\:0430\:0447\:0435\:043d\:0438\:0435 \:043f\:043e \
\:0443\:043c\:043e\:043b\:0447\:0430\:043d\:0438\:044e",
  FontSlant->"Italic"],
 ", \:0441\:0432\:044f\:0437\:0430\:043d\:043d\:043e\:0435 \:0441 \
\:0444\:0443\:043d\:043a\:0446\:0438\:0435\:0439, \:0432 \:043a\:043e\:0442\
\:043e\:0440\:043e\:0439 ",
 Cell[BoxData[
  StyleBox[
   RowBox[{
    StyleBox["x", "TI"], "_."}]]], "InlineFormula"],
 " \:043f\:0440\:0438\:0441\:0443\:0442\:0441\:0442\:0432\:0443\:0435\:0442. \
\:042d\:0442\:043e \:0437\:043d\:0430\:0447\:0435\:043d\:0438\:0435 \:043f\
\:043e \:0443\:043c\:043e\:043b\:0447\:0430\:043d\:0438\:044e \:043c\:043e\
\:0436\:0435\:0442 \:0431\:044b\:0442\:044c \:0437\:0430\:0434\:0430\:043d\
\:043e \:043f\:0443\:0442\:0435\:043c \:0432\:044b\:043f\:043e\:043b\:043d\
\:0435\:043d\:0438\:044f \:043e\:043f\:0440\:0435\:0434\:0435\:043b\:0435\
\:043d\:0438\:044f \:0434\:043b\:044f ",
 Cell[BoxData[
  RowBox[{
   TemplateBox[{Cell["Default"],"paclet:ref/Default"},
    "RefLink",
    BaseStyle->"InlineFormula"], "[", 
   StyleBox["f", "TI"], "]"}]], "InlineFormula"],
 ", \:0438 \:0442\:0430\:043a \:0434\:0430\:043b\:0435\:0435. "
}], "Text",
 CellID->25508],

Cell[BoxData[GridBox[{
   {
    RowBox[{
     ButtonBox["Default",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/Default"], "[", 
     StyleBox["f", "TI"], "]"}], Cell[TextData[{
     "\:0437\:043d\:0430\:0447\:0435\:043d\:0438\:0435 \:043f\:043e \:0443\
\:043c\:043e\:043b\:0447\:0430\:043d\:0438\:044e \:0434\:043b\:044f ",
     Cell[BoxData[
      RowBox[{
       StyleBox["x", "TI"], 
       StyleBox["_.", "MR"]}]], "InlineFormula"],
     ", \:0435\:0441\:043b\:0438 ",
     Cell[BoxData[
      RowBox[{
       StyleBox["x", "TI"], 
       StyleBox["_.", "MR"]}]], "InlineFormula"],
     " \:043f\:0440\:0438\:0441\:0443\:0442\:0441\:0442\:0432\:0443\:0435\
\:0442 \:0432 \:043a\:0430\:0447\:0435\:0441\:0442\:0432\:0435 \:043b\:044e\
\:0431\:043e\:0433\:043e \:0430\:0440\:0433\:0443\:043c\:0435\:043d\:0442\
\:0430 \:0444\:0443\:043d\:043a\:0446\:0438\:0438 ",
     Cell[BoxData[
      StyleBox["f", "TI"]], "InlineFormula"]
    }], "TableText"]},
   {
    RowBox[{
     ButtonBox["Default",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/Default"], "[", 
     StyleBox["f", "TI"], ",", 
     StyleBox["n", "TI"], "]"}], Cell[TextData[{
     "\:0437\:043d\:0430\:0447\:0435\:043d\:0438\:0435 \:043f\:043e \:0443\
\:043c\:043e\:043b\:0447\:0430\:043d\:0438\:044e \:0434\:043b\:044f ",
     Cell[BoxData[
      RowBox[{
       StyleBox["x", "TI"], 
       StyleBox["_.", "MR"]}]], "InlineFormula"],
     ", \:0435\:0441\:043b\:0438 ",
     Cell[BoxData[
      RowBox[{
       StyleBox["x", "TI"], 
       StyleBox["_.", "MR"]}]], "InlineFormula"],
     " \:043f\:0440\:0438\:0441\:0443\:0442\:0441\:0442\:0432\:0443\:0435\
\:0442 \:0432 \:043a\:0430\:0447\:0435\:0441\:0442\:0432\:0435 ",
     Cell[BoxData[
      StyleBox["n", "TI"]], "InlineFormula"],
     Cell[BoxData[
      FormBox[
       SuperscriptBox["\[Null]", "\:0433\:043e"], TraditionalForm]]],
     " \:0430\:0440\:0433\:0443\:043c\:0435\:043d\:0442\:0430 (\:043f\:0440\
\:0438 \:043e\:0442\:0440\:0438\:0446\:0430\:0442\:0435\:043b\:044c\:043d\
\:043e\:043c ",
     Cell[BoxData[
      StyleBox["n", "TI"]], "InlineFormula"],
     " \:043e\:0442\:0441\:0447\:0435\:0442 \:0432\:0435\:0434\:0435\:0442\
\:0441\:044f \:0441 \:043a\:043e\:043d\:0446\:0430)"
    }], "TableText"]},
   {
    RowBox[{
     ButtonBox["Default",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/Default"], "[", 
     StyleBox["f", "TI"], ",", 
     StyleBox["n", "TI"], ",", 
     StyleBox["tot", "TI"], "]"}], Cell[TextData[{
     "\:0437\:043d\:0430\:0447\:0435\:043d\:0438\:0435 \:043f\:043e \:0443\
\:043c\:043e\:043b\:0447\:0430\:043d\:0438\:044e \:0434\:043b\:044f ",
     Cell[BoxData[
      StyleBox["n", "TI"]], "InlineFormula"],
     Cell[BoxData[
      FormBox[
       SuperscriptBox["\[Null]", "\:0433\:043e"], TraditionalForm]]],
     " \:0430\:0440\:0433\:0443\:043c\:0435\:043d\:0442\:0430 \:043f\:0440\
\:0438 \:043e\:0431\:0449\:0435\:043c \:043a\:043e\:043b\:0438\:0447\:0435\
\:0441\:0442\:0432\:0435 \:0430\:0440\:0433\:0443\:043c\:0435\:043d\:0442\
\:043e\:0432 \:0440\:0430\:0432\:043d\:043e\:043c ",
     Cell[BoxData[
      StyleBox["tot", "TI"]], "InlineFormula"]
    }], "TableText"]}
  }]], "DefinitionBox",
 CellID->28318],

Cell[TextData[{
 "\:0417\:043d\:0430\:0447\:0435\:043d\:0438\:044f \:043f\:043e \:0443\:043c\
\:043e\:043b\:0447\:0430\:043d\:0438\:044e (",
 Cell[BoxData[
  TemplateBox[{Cell["Default"],"paclet:ref/Default"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 "). "
}], "Caption",
 CellID->27870],

Cell[TextData[{
 "\:0422\:0430\:043a\:043e\:043c\:0443 \:0448\:0430\:0431\:043b\:043e\:043d\
\:0443 \:043a\:0430\:043a ",
 Cell[BoxData[
  RowBox[{"f", "[", 
   RowBox[{"x__", ",", "y__", ",", "z__"}], "]"}]], "InlineFormula"],
 ", \:0432\:044b\:0440\:0430\:0436\:0435\:043d\:0438\:0435 \:0432\:0438\:0434\
\:0430 ",
 Cell[BoxData[
  RowBox[{"f", "[", 
   RowBox[{"a", ",", "b", ",", "c", ",", "d", ",", "e"}], "]"}]], 
  "InlineFormula"],
 " \:043c\:043e\:0436\:0435\:0442 \:0441\:043e\:043e\:0442\:0432\:0435\:0442\
\:0441\:0442\:0432\:043e\:0432\:0430\:0442\:044c \:043f\:0440\:0438 \:0440\
\:0430\:0437\:043b\:0438\:0447\:043d\:044b\:0445 \:043a\:043e\:043c\:0431\
\:0438\:043d\:0430\:0446\:0438\:044f\:0445 \:0437\:043d\:0430\:0447\:0435\
\:043d\:0438\:0439 \:0434\:043b\:044f ",
 Cell[BoxData["x"], "InlineFormula"],
 ", ",
 Cell[BoxData["y"], "InlineFormula"],
 " \:0438 ",
 Cell[BoxData["z"], "InlineFormula"],
 ". \:041a\:043e\:043c\:0431\:0438\:043d\:0430\:0446\:0438\:0438 \:0441 \
\:043c\:0438\:043d\:0438\:043c\:0430\:043b\:044c\:043d\:043e\:0439 \:0434\
\:043b\:0438\:043d\:043e\:0439 \:0437\:043d\:0430\:0447\:0435\:043d\:0438\
\:0439 \:0434\:043b\:044f ",
 Cell[BoxData["x"], "InlineFormula"],
 " \:0438 ",
 Cell[BoxData["y"], "InlineFormula"],
 " \:043d\:0430\:0445\:043e\:0434\:044f\:0442\:0441\:044f \:0432 \:043f\:0435\
\:0440\:0432\:0443\:044e \:043e\:0447\:0435\:0440\:0435\:0434\:044c. \:041f\
\:043e \:043e\:0431\:0449\:0435\:043c\:0443 \:043f\:0440\:0430\:0432\:0438\
\:043b\:0443, \:043f\:0440\:0438 \:043d\:0430\:043b\:0438\:0447\:0438\:0438 \
\:043d\:0435\:0441\:043a\:043e\:043b\:044c\:043a\:0438\:0445 ",
 Cell[BoxData["__"], "InlineFormula"],
 " \:0438\:043b\:0438 ",
 Cell[BoxData["___"], "InlineFormula"],
 " \:0432 \:043e\:0434\:043d\:043e\:0439 \:0444\:0443\:043d\:043a\:0446\:0438\
\:0438, \:0432 \:043f\:0435\:0440\:0432\:0443\:044e \:043e\:0447\:0435\:0440\
\:0435\:0434\:044c \:043f\:043e\:0434\:0431\:0438\:0440\:0430\:0435\:0442\
\:0441\:044f \:043a\:043e\:043c\:0431\:0438\:043d\:0430\:0446\:0438\:044f, \
\:0433\:0434\:0435 \:043e\:0431\:044a\:0435\:043a\:0442\:0430\:043c ",
 Cell[BoxData["__"], "InlineFormula"],
 " \:0438 ",
 Cell[BoxData["___"], "InlineFormula"],
 " \:0441\:043e\:043e\:0442\:0432\:0435\:0442\:0441\:0442\:0432\:0443\:044e\
\:0442 \:043f\:043e\:0441\:043b\:0435\:0434\:043e\:0432\:0430\:0442\:0435\
\:043b\:044c\:043d\:043e\:0441\:0442\:0438 \:043c\:0438\:043d\:0438\:043c\
\:0430\:043b\:044c\:043d\:043e\:0439 \:0434\:043b\:0438\:043d\:044b, \:0437\
\:0430 \:0438\:0441\:043a\:043b\:044e\:0447\:0435\:043d\:0438\:0435\:043c \
\:043f\:043e\:0441\:043b\:0435\:0434\:043d\:0435\:0433\:043e, \:043a\:043e\
\:0442\:043e\:0440\:043e\:043c\:0443 \:0441\:043e\:043e\:0442\:0432\:0435\
\:0442\:0441\:0442\:0432\:0443\:0435\:0442 \"\:043e\:0441\:0442\:0430\:043b\
\:044c\:043d\:0430\:044f \:0447\:0430\:0441\:0442\:044c\" \:0430\:0440\:0433\
\:0443\:043c\:0435\:043d\:0442\:043e\:0432."
}], "Text",
 CellID->9601],

Cell[TextData[{
 "\:041f\:0440\:0438 \:043d\:0430\:043b\:0438\:0447\:0438\:0438 ",
 Cell[BoxData[
  RowBox[{
   StyleBox[
    RowBox[{
     StyleBox["x", "TI"], "_:"}]], 
   StyleBox["v", "TI"]}]], "InlineFormula"],
 " \:0438\:043b\:0438 ",
 Cell[BoxData[
  StyleBox[
   RowBox[{
    StyleBox["x", "TI"], "_."}]]], "InlineFormula"],
 " , \:043f\:0435\:0440\:0432\:043e\:0439 \
\:043f\:043e\:0434\:0431\:0438\:0440\:0430\:0435\:0442\:0441\:044f \:043a\
\:043e\:043c\:0431\:0438\:043d\:0430\:0446\:0438\:044f, \:0433\:0434\:0435 \
\:043d\:0438 \:043e\:0434\:043d\:043e\:043c\:0443 \:0438\:0437 \:044d\:0442\
\:0438\:0445 \:043e\:0431\:044a\:0435\:043a\:0442\:043e\:0432 \:043d\:0435 \
\:0441\:043e\:043e\:0442\:0432\:0435\:0442\:0441\:0442\:0432\:0443\:044e\:0442\
 \:043f\:0440\:043e\:043f\:0443\:0449\:0435\:043d\:043d\:044b\:0435 \:0430\
\:0440\:0433\:0443\:043c\:0435\:043d\:0442\:044b. \:041b\:0438\:0448\:044c \
\:043f\:043e\:0441\:043b\:0435 \:044d\:0442\:043e\:0433\:043e \:043f\:043e\
\:0434\:0431\:0438\:0440\:0430\:044e\:0442\:0441\:044f \:043a\:043e\:043c\
\:0431\:0438\:043d\:0430\:0446\:0438\:0438 \:0441 \:043f\:0440\:043e\:043f\
\:0443\:0449\:0435\:043d\:043d\:044b\:043c\:0438 \:0430\:0440\:0433\:0443\
\:043c\:0435\:043d\:0442\:0430\:043c\:0438."
}], "Text",
 CellID->28323],

Cell[TextData[{
 "\:041f\:043e\:0440\:044f\:0434\:043e\:043a, \:0432 \:043a\:043e\:0442\:043e\
\:0440\:043e\:043c \:0440\:0430\:0441\:0441\:043c\:0430\:0442\:0440\:0438\
\:0432\:0430\:044e\:0442\:0441\:044f \:0440\:0430\:0437\:043b\:0438\:0447\
\:043d\:044b\:0435 \:043a\:043e\:043c\:0431\:0438\:043d\:0430\:0446\:0438\
\:0438, \:043c\:043e\:0436\:0435\:0442 \:0431\:044b\:0442\:044c \:0438\:0437\
\:043c\:0435\:043d\:0435\:043d \:0441 \:043f\:043e\:043c\:043e\:0449\:044c\
\:044e ",
 Cell[BoxData[
  TemplateBox[{Cell["Shortest"],"paclet:ref/Shortest"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " \:0438 ",
 Cell[BoxData[
  TemplateBox[{Cell["Longest"],"paclet:ref/Longest"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 ". "
}], "Text",
 CellID->358929610],

Cell[BoxData[GridBox[{
   {
    ButtonBox["Orderless",
     BaseStyle->"Link",
     ButtonData->"paclet:ref/Orderless"], Cell[TextData[{
     Cell[BoxData[
      RowBox[{
       StyleBox["f", "TI"], "[", 
       RowBox[{
        StyleBox["x", "TI"], ",", 
        StyleBox["y", "TI"]}], "]"}]], "InlineFormula"],
     " \:0438 ",
     Cell[BoxData[
      RowBox[{
       StyleBox["f", "TI"], "[", 
       RowBox[{
        StyleBox["y", "TI"], ",", 
        StyleBox["x", "TI"]}], "]"}]], "InlineFormula"],
     " \:044d\:043a\:0432\:0438\:0432\:0430\:043b\:0435\:043d\:0442\:043d\
\:044b"
    }], "TableText"]},
   {
    ButtonBox["Flat",
     BaseStyle->"Link",
     ButtonData->"paclet:ref/Flat"], Cell[TextData[{
     Cell[BoxData[
      RowBox[{
       StyleBox["f", "TI"], "[", 
       RowBox[{
        RowBox[{
         StyleBox["f", "TI"], "[", 
         StyleBox["x", "TI"], "]"}], ",", 
        StyleBox["y", "TI"]}], "]"}]], "InlineFormula"],
     " \:0438 ",
     Cell[BoxData[
      RowBox[{
       StyleBox["f", "TI"], "[", 
       RowBox[{
        StyleBox["x", "TI"], ",", 
        StyleBox["y", "TI"]}], "]"}]], "InlineFormula"],
     " \:044d\:043a\:0432\:0438\:0432\:0430\:043b\:0435\:043d\:0442\:043d\
\:044b"
    }], "TableText"]},
   {
    ButtonBox["OneIdentity",
     BaseStyle->"Link",
     ButtonData->"paclet:ref/OneIdentity"], Cell[TextData[{
     Cell[BoxData[
      RowBox[{
       StyleBox["f", "TI"], "[", 
       StyleBox["x", "TI"], "]"}]], "InlineFormula"],
     " \:0438 ",
     Cell[BoxData[
      StyleBox["x", "TI"]], "InlineFormula"],
     " \:044d\:043a\:0432\:0438\:0432\:0430\:043b\:0435\:043d\:0442\:043d\
\:044b"
    }], "TableText"]}
  }]], "DefinitionBox",
 CellID->21132],

Cell["\:0410\:0442\:0440\:0438\:0431\:0443\:0442\:044b, \:0438\:0441\:043f\
\:043e\:043b\:044c\:0437\:0443\:0435\:043c\:044b\:0435 \:043f\:0440\:0438 \
\:0441\:043e\:043f\:043e\:0441\:0442\:0430\:0432\:043b\:0435\:043d\:0438\:0438\
 \:0432\:044b\:0440\:0430\:0436\:0435\:043d\:0438\:0439 \:0448\:0430\:0431\
\:043b\:043e\:043d\:0430\:043c.", "Caption",
 CellID->24472],

Cell[TextData[{
 "\:041e\:0431\:044a\:0435\:043a\:0442 \:0448\:0430\:0431\:043b\:043e\:043d\
\:0430 \:0432\:0438\:0434\:0430 ",
 Cell[BoxData[
  StyleBox[
   RowBox[{
    StyleBox["x", "TI"], "_"}]]], "InlineFormula"],
 " \:043c\:043e\:0436\:0435\:0442 \:043f\:0440\:0435\:0434\:0441\:0442\:0430\
\:0432\:043b\:044f\:0442\:044c \:043b\:044e\:0431\:0443\:044e \:043f\:043e\
\:0441\:043b\:0435\:0434\:043e\:0432\:0430\:0442\:0435\:043b\:044c\:043d\:043e\
\:0441\:0442\:044c \:0430\:0440\:0433\:0443\:043c\:0435\:043d\:0442\:043e\
\:0432 \:0432 \:0444\:0443\:043d\:043a\:0446\:0438\:0438 ",
 Cell[BoxData[
  StyleBox["f", "TI"]], "InlineFormula"],
 " \:0441 \:0430\:0442\:0440\:0438\:0431\:0443\:0442\:043e\:043c ",
 Cell[BoxData[
  TemplateBox[{Cell["Flat"],"paclet:ref/Flat"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 ". \:0412 \:044d\:0442\:043e\:043c \:0441\:043b\:0443\:0447\:0430\:0435, \
\:0437\:043d\:0430\:0447\:0435\:043d\:0438\:0435\:043c ",
 Cell[BoxData[
  StyleBox["x", "TI"]], "InlineFormula"],
 " \:044f\:0432\:043b\:044f\:0435\:0442\:0441\:044f ",
 Cell[BoxData[
  StyleBox["f", "TI"]], "InlineFormula"],
 " , \:043f\:0440\:0438\:043c\:0435\:043d\:0435\:043d\:043d\:0430\:044f \
\:043a \:043f\:043e\:0441\:043b\:0435\:0434\:043e\:0432\:0430\:0442\:0435\
\:043b\:044c\:043d\:043e\:0441\:0442\:0438 \:0430\:0440\:0433\:0443\:043c\
\:0435\:043d\:0442\:043e\:0432. \:0415\:0441\:043b\:0438 ",
 Cell[BoxData[
  StyleBox["f", "TI"]], "InlineFormula"],
 " \:0438\:043c\:0435\:0435\:0442 \:0430\:0442\:0440\:0438\:0431\:0443\:0442 ",
 Cell[BoxData[
  TemplateBox[{Cell["OneIdentity"],"paclet:ref/OneIdentity"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 ", \:0430 ",
 Cell[BoxData[
  StyleBox["x", "TI"]], "InlineFormula"],
 " \:0441\:043e\:043e\:0442\:0432\:0435\:0442\:0441\:0442\:0432\:0443\:0435\
\:0442 \:043f\:043e\:0441\:043b\:0435\:0434\:043e\:0432\:0430\:0442\:0435\
\:043b\:044c\:043d\:043e\:0441\:0442\:0438 \:043b\:0438\:0448\:044c \:0438\
\:0437 \:043e\:0434\:043d\:043e\:0433\:043e \:0430\:0440\:0433\:0443\:043c\
\:0435\:043d\:0442\:0430, \:0442\:043e\:0433\:0434\:0430 \:0432\:043c\:0435\
\:0441\:0442\:043e ",
 Cell[BoxData[
  RowBox[{
   StyleBox["f", "TI"], "[", 
   StyleBox["e", "TI"], "]"}]], "InlineFormula"],
 " \:0438\:0441\:043f\:043e\:043b\:044c\:0437\:0443\:0435\:0442\:0441\:044f ",
 Cell[BoxData[
  StyleBox["e", "TI"]], "InlineFormula"],
 ". "
}], "Text",
 CellID->27152]
}, Open  ]],

Cell[CellGroupData[{

Cell["\:041e\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\:0438\:044f", \
"Section",
 CellTags->{"SA.5.2", "2.1"},
 CellID->4182],

Cell[BoxData[GridBox[{
   {
    RowBox[{
     StyleBox["lhs", "TI"], "=", 
     StyleBox["rhs", "TI"]}], Cell[TextData[{
     "\:043d\:0435\:043c\:0435\:0434\:043b\:0435\:043d\:043d\:043e\:0435 \
\:043e\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\:0438\:0435: ",
     Cell[BoxData[
      StyleBox["rhs", "TI"]], "InlineFormula"],
     " \:0432\:044b\:0447\:0438\:0441\:043b\:044f\:0435\:0442\:0441\:044f \
\:0432 \:043c\:043e\:043c\:0435\:043d\:0442 \:043e\:043f\:0440\:0435\:0434\
\:0435\:043b\:0435\:043d\:0438\:044f"
    }], "TableText"]},
   {
    RowBox[{
     StyleBox["lhs", "TI"], ":=", 
     StyleBox["rhs", "TI"]}], Cell[TextData[{
     "\:043e\:0442\:043b\:043e\:0436\:0435\:043d\:043d\:043e\:0435 \:043e\
\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\:0438\:0435: ",
     Cell[BoxData[
      StyleBox["rhs", "TI"]], "InlineFormula"],
     " \:0432\:044b\:0447\:0438\:0441\:043b\:044f\:0435\:0442\:0441\:044f \
\:0442\:043e\:0433\:0434\:0430, \:043a\:043e\:0433\:0434\:0430 \:0432\:043e\
\:0437\:043d\:0438\:043a\:0430\:0435\:0442 \:043f\:043e\:0442\:0440\:0435\
\:0431\:043d\:043e\:0441\:0442\:044c \:0432 \:0437\:043d\:0430\:0447\:0435\
\:043d\:0438\:0438 ",
     Cell[BoxData[
      StyleBox["lhs", "TI"]], "InlineFormula"]
    }], "TableText"]}
  }]], "DefinitionBox",
 CellID->25391],

Cell[TextData[{
 "\:0414\:0432\:0430 \:043e\:0441\:043d\:043e\:0432\:043d\:044b\:0445 \:0432\
\:0438\:0434\:0430 \:043e\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\
\:0438\:0439 \:0432 ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ". "
}], "Caption",
 CellID->15495],

Cell[TextData[{
 "\:0412 ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", \:043e\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\:0438\:044f \:0440\
\:0435\:0433\:043b\:0430\:043c\:0435\:043d\:0442\:0438\:0440\:0443\:044e\:0442\
 \:043f\:0440\:0430\:0432\:0438\:043b\:0430 \:043f\:0440\:0435\:043e\:0431\
\:0440\:0430\:0437\:043e\:0432\:0430\:043d\:0438\:044f \:0434\:043b\:044f \
\:0432\:044b\:0440\:0430\:0436\:0435\:043d\:0438\:0439. \:041a\:0430\:0436\
\:0434\:043e\:0435 \:0432\:044b\:043f\:043e\:043b\:043d\:044f\:0435\:043c\
\:043e\:0435 \:043f\:043e\:043b\:044c\:0437\:043e\:0432\:0430\:0442\:0435\
\:043b\:0435\:043c \:043e\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\
\:0438\:0435 \:0434\:043e\:043b\:0436\:043d\:043e \:0431\:044b\:0442\:044c \
\:0441\:0432\:044f\:0437\:0430\:043d\:043e \:0441 \:043a\:043e\:043d\:043a\
\:0440\:0435\:0442\:043d\:044b\:043c \:0441\:0438\:043c\:0432\:043e\:043b\
\:043e\:043c ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellID->5764],

Cell[BoxData[GridBox[{
   {
    RowBox[{
     RowBox[{
      StyleBox["f", "TI"], "[", 
      StyleBox["\:0430\:0440\:0433\:0443\:043c\:0435\:043d\:0442\:044b", "TI"],
       "]"}], "=", 
     StyleBox["rhs", "TI"]}], Cell[TextData[{
     "\:043e\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\:0438\:0435 \
\:0441\:0432\:044f\:0437\:0430\:043d\:043e \:0441 ",
     Cell[BoxData[
      StyleBox["f", "TI"]], "InlineFormula"],
     " (\:043e\:043f\:0440\:0435\:0434\:0435\:043b\:044f\:0435\:043c\:043e\
\:0435 \:0437\:043d\:0430\:0447\:0435\:043d\:0438\:0435)"
    }], "TableText"]},
   {
    RowBox[{
     StyleBox["t", "TI"], "/:", 
     RowBox[{
      StyleBox["f", "TI"], "[", 
      StyleBox["\:0430\:0440\:0433\:0443\:043c\:0435\:043d\:0442\:044b", "TI"],
       "]"}], "=", 
     StyleBox["rhs", "TI"]}], Cell[TextData[{
     "\:043e\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\:0438\:0435 \
\:0441\:0432\:044f\:0437\:0430\:043d\:043e \:0441 ",
     Cell[BoxData[
      StyleBox["t", "TI"]], "InlineFormula"],
     " (\:043e\:043f\:0440\:0435\:0434\:0435\:043b\:044f\:044e\:0449\:0435\
\:0435 \:0437\:043d\:0430\:0447\:0435\:043d\:0438\:0435)"
    }], "TableText"]},
   {
    RowBox[{
     RowBox[{
      StyleBox["f", "TI"], "[", 
      RowBox[{
       StyleBox["g", "TI"], "[", 
       StyleBox["\:0430\:0440\:0433\:0443\:043c\:0435\:043d\:0442\:044b", 
        "TI"], "]"}], "]"}], "^=", 
     StyleBox["rhs", "TI"]}], Cell[TextData[{
     "\:043e\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\:0438\:0435 \
\:0441\:0432\:044f\:0437\:0430\:043d\:043e \:0441 ",
     Cell[BoxData[
      StyleBox["g", "TI"]], "InlineFormula"],
     " (\:043e\:043f\:0440\:0435\:0434\:0435\:043b\:044f\:044e\:0449\:0435\
\:0435 \:0437\:043d\:0430\:0447\:0435\:043d\:0438\:0435)"
    }], "TableText"]}
  }]], "DefinitionBox",
 CellID->874],

Cell["\:041e\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\:0438\:044f, \
\:0441\:0432\:044f\:0437\:044b\:0432\:0430\:0435\:043c\:044b\:0435 \:0441 \
\:0440\:0430\:0437\:043d\:044b\:043c\:0438 \:0441\:0438\:043c\:0432\:043e\
\:043b\:0430\:043c\:0438. ", "Caption",
 CellID->1364],

Cell[TextData[{
 "\:0412 \:0441\:043b\:0443\:0447\:0430\:0435 \:0442\:0430\:043a\:043e\:0433\
\:043e \:043e\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\:0438\:044f \
\:043a\:0430\:043a ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    StyleBox["f", "TI"], "[", 
    StyleBox["args", "TI"], "]"}], "=", 
   StyleBox["rhs", "TI"]}]], "InlineFormula"],
 ", ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " \:043f\:0440\:043e\:0441\:043c\:0430\:0442\:0440\:0438\:0432\:0430\:0435\
\:0442 ",
 Cell[BoxData[
  StyleBox["f", "TI"]], "InlineFormula"],
 ", \:0437\:0430\:0442\:0435\:043c \:0437\:0430\:0433\:043e\:043b\:043e\:0432\
\:043e\:043a ",
 Cell[BoxData[
  StyleBox["f", "TI"]], "InlineFormula"],
 ", \:0437\:0430\:0442\:0435\:043c \:043f\:0440\:043e\:0432\:0435\:0440\:044f\
\:0435\:0442 \:043d\:0430\:043b\:0438\:0447\:0438\:0435 \:0437\:0430\:0433\
\:043e\:043b\:043e\:0432\:043a\:0430 \:0443 \:0437\:0430\:0433\:043e\:043b\
\:043e\:0432\:043a\:0430 ",
 Cell[BoxData[
  StyleBox["f", "TI"]], "InlineFormula"],
 ", \:0438 \:0442\:0430\:043a \:0434\:0430\:043b\:0435\:0435, \:043f\:043e\
\:043a\:0430 \:043d\:0435 \:043d\:0430\:0439\:0434\:0435\:0442 \:0441\:0438\
\:043c\:0432\:043e\:043b, \:0441 \:043a\:043e\:0442\:043e\:0440\:044b\:043c \
\:0431\:0443\:0434\:0435\:0442 \:0441\:0432\:044f\:0437\:0430\:043d\:043e \
\:043e\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\:0438\:0435."
}], "Text",
 CellID->14902],

Cell[TextData[{
 "\:041f\:0440\:0438 \:0432\:044b\:043f\:043e\:043b\:043d\:0435\:043d\:0438\
\:0438 \:0442\:0430\:043a\:043e\:0433\:043e \:043e\:043f\:0440\:0435\:0434\
\:0435\:043b\:0435\:043d\:0438\:044f \:043a\:0430\:043a ",
 Cell[BoxData[
  RowBox[{
   StyleBox["lhs", "TI"], "^=", 
   StyleBox["rhs", "TI"]}]], "InlineFormula"],
 ", ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " \:0431\:0443\:0434\:0435\:0442 \:043f\:043e\:0440\:043e\:0436\:0434\:0430\
\:0442\:044c \:043f\:0440\:0430\:0432\:0438\:043b\:0430 \:043f\:0440\:0435\
\:043e\:0431\:0440\:0430\:0437\:043e\:0432\:0430\:043d\:0438\:044f, \:0441\
\:0432\:044f\:0437\:0430\:043d\:043d\:044b\:0435 \:0441 \:043a\:0430\:0436\
\:0434\:044b\:043c \:043e\:0442\:0434\:0435\:043b\:044c\:043d\:044b\:043c \
\:0441\:0438\:043c\:0432\:043e\:043b\:043e\:043c, \:043a\:043e\:0442\:043e\
\:0440\:044b\:0439 \:043f\:0440\:0438\:0441\:0443\:0442\:0441\:0442\:0432\
\:0443\:0435\:0442 \:043b\:0438\:0431\:043e \:0432 \:043a\:0430\:0447\:0435\
\:0441\:0442\:0432\:0435 \:0430\:0440\:0433\:0443\:043c\:0435\:043d\:0442\
\:0430 ",
 Cell[BoxData[
  StyleBox["lhs", "TI"]], "InlineFormula"],
 ", \:043b\:0438\:0431\:043e \:0432 \
\:043a\:0430\:0447\:0435\:0441\:0442\:0432\:0435 \:0437\:0430\:0433\:043e\
\:043b\:043e\:0432\:043a\:0430 \:0430\:0440\:0433\:0443\:043c\:0435\:043d\
\:0442\:0430 ",
 Cell[BoxData[
  StyleBox["lhs", "TI"]], "InlineFormula"],
 "."
}], "Text",
 CellID->28255],

Cell[TextData[{
 "\:041f\:0440\:0430\:0432\:0438\:043b\:0430 \:043f\:0440\:0435\:043e\:0431\
\:0440\:0430\:0437\:043e\:0432\:0430\:043d\:0438\:044f, \:0441\:0432\:044f\
\:0437\:0430\:043d\:043d\:044b\:0435 \:0441 \:043a\:043e\:043d\:043a\:0440\
\:0435\:0442\:043d\:044b\:043c \:0441\:0438\:043c\:0432\:043e\:043b\:043e\
\:043c ",
 Cell[BoxData[
  StyleBox["s", "TI"]], "InlineFormula"],
 ", \:0432\:0441\:0435\:0433\:0434\:0430 \:0445\:0440\:0430\:043d\:044f\:0442\
\:0441\:044f \:0432 \:043e\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\
\:043d\:043e\:043c \:043f\:043e\:0440\:044f\:0434\:043a\:0435, \:0438 \:043f\
\:0440\:043e\:0441\:043c\:0430\:0442\:0440\:0438\:0432\:0430\:044e\:0442\:0441\
\:044f \:0432 \:0442\:043e\:043c \:0436\:0435 \:043f\:043e\:0440\:044f\:0434\
\:043a\:0435 \:043f\:0440\:0438 \:0438\:0445 \:0438\:0441\:043f\:043e\:043b\
\:044c\:0437\:043e\:0432\:0430\:043d\:0438\:0438. \:041a\:0430\:0436\:0434\
\:044b\:0439 \:0440\:0430\:0437, \:043a\:043e\:0433\:0434\:0430 \:043f\:043e\
\:043b\:044c\:0437\:043e\:0432\:0430\:0442\:0435\:043b\:044c \:0432\:044b\
\:043f\:043e\:043b\:043d\:044f\:0435\:0442 \:043e\:043f\:0440\:0435\:0434\
\:0435\:043b\:0435\:043d\:0438\:0435, \:0441\:043e\:043e\:0442\:0432\:0435\
\:0442\:0441\:0442\:0432\:0443\:044e\:0449\:0435\:0435 \:043f\:0440\:0430\
\:0432\:0438\:043b\:043e \:043f\:0440\:0435\:043e\:0431\:0440\:0430\:0437\
\:043e\:0432\:0430\:043d\:0438\:044f \:0434\:043e\:0431\:0430\:0432\:043b\
\:044f\:0435\:0442\:0441\:044f \:0432 \:043a\:043e\:043d\:0435\:0446 \:0441\
\:043f\:0438\:0441\:043a\:0430 \:043f\:0440\:0430\:0432\:0438\:043b \:043f\
\:0440\:0435\:043e\:0431\:0440\:0430\:0437\:043e\:0432\:0430\:043d\:0438\:044f\
, \:0441\:0432\:044f\:0437\:0430\:043d\:043d\:044b\:0445 \:0441  ",
 Cell[BoxData[
  StyleBox["s", "TI"]], "InlineFormula"],
 ", \:0437\:0430 \:0438\:0441\:043a\:043b\:044e\:0447\:0435\:043d\:0438\:0435\
\:043c \:0441\:043b\:0435\:0434\:0443\:044e\:0449\:0438\:0445 \:0441\:043b\
\:0443\:0447\:0430\:0435\:0432:"
}], "Text",
 CellID->4460],

Cell["\<\
\:041b\:0435\:0432\:0430\:044f \:0441\:0442\:043e\:0440\:043e\:043d\:0430 \
\:043f\:0440\:0430\:0432\:0438\:043b\:0430 \:043f\:0440\:0435\:043e\:0431\
\:0440\:0430\:0437\:043e\:0432\:0430\:043d\:0438\:044f \:0438\:0434\:0435\
\:043d\:0442\:0438\:0447\:043d\:0430 \:0443\:0436\:0435 \:0441\:043e\:0445\
\:0440\:0430\:043d\:0435\:043d\:043d\:043e\:043c\:0443 \:043f\:0440\:0430\
\:0432\:0438\:043b\:0443 \:043f\:0440\:0435\:043e\:0431\:0440\:0430\:0437\
\:043e\:0432\:0430\:043d\:0438\:044f, \:0438 \:043a\:0430\:043a\:0438\:0435-\
\:043b\:0438\:0431\:043e /; \:0443\:0441\:043b\:043e\:0432\:0438\:044f \:0432 \
\:043f\:0440\:0430\:0432\:043e\:0439 \:0441\:0442\:043e\:0440\:043e\:043d\
\:0435 \:0442\:0430\:043a\:0436\:0435 \:0441\:043e\:0432\:043f\:0430\:0434\
\:0430\:044e\:0442. \:0412 \:044d\:0442\:043e\:043c \:0441\:043b\:0443\:0447\
\:0430\:0435, \:043d\:043e\:0432\:043e\:0435 \:043f\:0440\:0430\:0432\:0438\
\:043b\:043e \:043f\:0440\:0435\:043e\:0431\:0440\:0430\:0437\:043e\:0432\
\:0430\:043d\:0438\:044f \:0432\:0441\:0442\:0430\:0432\:043b\:044f\:0435\
\:0442\:0441\:044f \:0432\:043c\:0435\:0441\:0442\:043e \:0441\:0442\:0430\
\:0440\:043e\:0433\:043e.\
\>", "Notes",
 CellID->474],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " \:043e\:0431\:043d\:0430\:0440\:0443\:0436\:0438\:0432\:0430\:0435\:0442, \
\:0447\:0442\:043e \:043d\:043e\:0432\:043e\:0435 \:043f\:0440\:0430\:0432\
\:0438\:043b\:043e \:043f\:0440\:0435\:043e\:0431\:0440\:0430\:0437\:043e\
\:0432\:0430\:043d\:0438\:044f \:0431\:043e\:043b\:0435\:0435 \:0438\:0437\
\:0431\:0438\:0440\:0430\:0442\:0435\:043b\:044c\:043d\:043e, \:0447\:0435\
\:043c \:0441\:0443\:0449\:0435\:0441\:0442\:0432\:0443\:044e\:0449\:0435\
\:0435 \:043f\:0440\:0430\:0432\:0438\:043b\:043e, \:0438 \:043f\:043e\:043f\
\:0440\:043e\:0441\:0442\:0443 \:043d\:0435 \:0431\:0443\:0434\:0435\:0442 \
\:0440\:0430\:0431\:043e\:0442\:0430\:0442\:044c, \:0431\:0443\:0434\:0443\
\:0447\:0438 \:043f\:043e\:043c\:0435\:0449\:0435\:043d\:043d\:044b\:043c \
\:0437\:0430 \:0441\:0443\:0449\:0435\:0441\:0442\:0432\:0443\:044e\:0449\
\:0438\:043c \:043f\:0440\:0430\:0432\:0438\:043b\:043e\:043c. \:0412 \:044d\
\:0442\:043e\:043c \:0441\:043b\:0443\:0447\:0430\:0435, \:043d\:043e\:0432\
\:043e\:0435 \:043f\:0440\:0430\:0432\:0438\:043b\:043e \:043f\:043e\:043c\
\:0435\:0449\:0430\:0435\:0442\:0441\:044f \:043f\:0435\:0440\:0435\:0434 \
\:0441\:0442\:0430\:0440\:044b\:043c. \:041d\:0443\:0436\:043d\:043e \:0437\
\:0430\:043c\:0435\:0442\:0438\:0442\:044c, \:0447\:0442\:043e \:0432\:043e \
\:043c\:043d\:043e\:0433\:0438\:0445 \:0441\:043b\:0443\:0447\:0430\:044f\
\:0445 \:043d\:0435 \:043f\:0440\:0435\:0434\:0441\:0442\:0430\:0432\:043b\
\:044f\:0435\:0442\:0441\:044f \:0432\:043e\:0437\:043c\:043e\:0436\:043d\
\:044b\:043c \:043e\:043f\:0440\:0435\:0434\:0435\:043b\:0438\:0442\:044c, \
\:044f\:0432\:043b\:044f\:0435\:0442\:0441\:044f \:043b\:0438 \:043e\:0434\
\:043d\:043e \:043f\:0440\:0430\:0432\:0438\:043b\:043e \:0431\:043e\:043b\
\:0435\:0435 \:0438\:0437\:0431\:0438\:0440\:0430\:0442\:0435\:043b\:044c\
\:043d\:044b\:043c, \:0447\:0435\:043c \:0434\:0440\:0443\:0433\:043e\:0435; \
\:0432 \:0442\:0430\:043a\:0438\:0445 \:0441\:043b\:0443\:0447\:0430\:044f\
\:0445, \:043d\:043e\:0432\:043e\:0435 \:043f\:0440\:0430\:0432\:0438\:043b\
\:043e \:0432\:0441\:0435\:0433\:0434\:0430 \:0432\:0441\:0442\:0430\:0432\
\:043b\:044f\:0435\:0442\:0441\:044f \:0432 \:043a\:043e\:043d\:0446\:0435."
}], "Notes",
 CellID->193657617]
}, Open  ]],

Cell[CellGroupData[{

Cell["\:0422\:0438\:043f\:044b \:0437\:043d\:0430\:0447\:0435\:043d\:0438\
\:0439", "Section",
 CellTags->{"SA.5.3", "3.1"},
 CellID->6025],

Cell[BoxData[GridBox[{
   {
    RowBox[{
     ButtonBox["Attributes",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/Attributes"], "[", 
     StyleBox["f", "TI"], Cell["\[ThinSpace]", "TableText"], "]"}], Cell[
    TextData[{
     "\:0430\:0442\:0440\:0438\:0431\:0443\:0442\:044b ",
     Cell[BoxData[
      StyleBox["f", "TI"]], "InlineFormula"]
    }], "TableText"]},
   {
    RowBox[{"DefaultValues", "[", 
     RowBox[{
      StyleBox["f", "TI"], Cell["\[ThinSpace]", "TableText"]}], "]"}], Cell[
    TextData[{
     "\:0437\:043d\:0430\:0447\:0435\:043d\:0438\:044f \:043f\:043e \:0443\
\:043c\:043e\:043b\:0447\:0430\:043d\:0438\:044e \:0434\:043b\:044f \:0430\
\:0440\:0433\:0443\:043c\:0435\:043d\:0442\:043e\:0432 ",
     Cell[BoxData[
      StyleBox["f", "TI"]], "InlineFormula"]
    }], "TableText"]},
   {
    RowBox[{
     ButtonBox["DownValues",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/DownValues"], "[", 
     StyleBox["f", "TI"], Cell["\[ThinSpace]", "TableText"], "]"}], Cell[
    TextData[{
     "\:0437\:043d\:0430\:0447\:0435\:043d\:0438\:044f \:0434\:043b\:044f ",
     Cell[BoxData[
      RowBox[{
       StyleBox["f", "TI"], "[", 
       StyleBox["\[Ellipsis]", "TR"], "]"}]], "InlineFormula"],
     ", ",
     Cell[BoxData[
      RowBox[{
       StyleBox["f", "TI"], "[", 
       StyleBox["\[Ellipsis]", "TR"], "]", "[", 
       StyleBox["\[Ellipsis]", "TR"], "]"}]], "InlineFormula"],
     ", \:0438 \:0442. \:0434."
    }], "TableText"]},
   {
    RowBox[{"FormatValues", "[", 
     RowBox[{
      StyleBox["f", "TI"], Cell["\[ThinSpace]", "TableText"]}], "]"}], Cell[
    TextData[{
     "\:043f\:0435\:0447\:0430\:0442\:043d\:044b\:0435 \:0444\:043e\:0440\
\:043c\:044b, \:0441\:0432\:044f\:0437\:0430\:043d\:043d\:044b\:0435 \:0441 ",
     Cell[BoxData[
      StyleBox["f", "TI"]], "InlineFormula"]
    }], "TableText"]},
   {
    RowBox[{
     ButtonBox["Messages",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/Messages"], "[", 
     StyleBox["f", "TI"], Cell["\[ThinSpace]", "TableText"], "]"}], Cell[
    TextData[{
     "\:0441\:043e\:043e\:0431\:0449\:0435\:043d\:0438\:044f, \:0441\:0432\
\:044f\:0437\:0430\:043d\:043d\:044b\:0435 \:0441 ",
     Cell[BoxData[
      StyleBox["f", "TI"]], "InlineFormula"]
    }], "TableText"]},
   {
    RowBox[{"NValues", "[", 
     RowBox[{
      StyleBox["f", "TI"], Cell["\[ThinSpace]", "TableText"]}], "]"}], Cell[
    TextData[{
     "\:0447\:0438\:0441\:043b\:0435\:043d\:043d\:044b\:0435 \:0437\:043d\
\:0430\:0447\:0435\:043d\:0438\:044f, \:0441\:0432\:044f\:0437\:0430\:043d\
\:043d\:044b\:0435 \:0441 ",
     Cell[BoxData[
      StyleBox["f", "TI"]], "InlineFormula"]
    }], "TableText"]},
   {
    RowBox[{
     ButtonBox["Options",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/Options"], "[", 
     StyleBox["f", "TI"], Cell["\[ThinSpace]", "TableText"], "]"}], Cell[
    TextData[{
     "\:0443\:043c\:043e\:043b\:0447\:0430\:043d\:0438\:044f \:0434\:043b\
\:044f \:043e\:043f\:0446\:0438\:0439, \:0441\:0432\:044f\:0437\:0430\:043d\
\:043d\:044b\:0445 \:0441 ",
     Cell[BoxData[
      StyleBox["f", "TI"]], "InlineFormula"]
    }], "TableText"]},
   {
    RowBox[{
     ButtonBox["OwnValues",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/OwnValues"], "[", 
     StyleBox["f", "TI"], Cell["\[ThinSpace]", "TableText"], "]"}], Cell[
    TextData[{
     "\:0441\:043e\:0431\:0441\:0442\:0432\:0435\:043d\:043d\:044b\:0435 \
\:0437\:043d\:0430\:0447\:0435\:043d\:0438\:044f \:0434\:043b\:044f ",
     Cell[BoxData[
      StyleBox["f", "TI"]], "InlineFormula"]
    }], "TableText"]},
   {
    RowBox[{
     ButtonBox["UpValues",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/UpValues"], "[", 
     StyleBox["f", "TI"], Cell["\[ThinSpace]", "TableText"], "]"}], Cell[
    TextData[{
     "\:0437\:043d\:0430\:0447\:0435\:043d\:0438\:044f \:0434\:043b\:044f  ",
     Cell[BoxData[
      RowBox[{
       StyleBox["\[Ellipsis]", "TR"], "[", 
       RowBox[{
        StyleBox["\[Ellipsis]", "TR"], ",", 
        RowBox[{
         StyleBox["f", "TI"], "[", 
         StyleBox["\[Ellipsis]", "TR"], "]"}], ",", 
        StyleBox["\[Ellipsis]", "TR"]}], "]"}]], "InlineFormula"]
    }], "TableText"]}
  }]], "DefinitionBox",
 CellID->1534],

Cell["\:0422\:0438\:043f\:044b \:0437\:043d\:0430\:0447\:0435\:043d\:0438\
\:0439, \:0441\:0432\:044f\:0437\:0430\:043d\:043d\:044b\:0445 \:0441 \:0441\
\:0438\:043c\:0432\:043e\:043b\:0430\:043c\:0438. ", "Caption",
 CellID->5821]
}, Open  ]],

Cell[CellGroupData[{

Cell["\:041e\:0447\:0438\:0441\:0442\:043a\:0430 \:0438 \:0443\:0434\:0430\
\:043b\:0435\:043d\:0438\:0435 \:043e\:0431\:044a\:0435\:043a\:0442\:043e\
\:0432", "Section",
 CellTags->{"SA.5.4", "4.1"},
 CellID->26819],

Cell[BoxData[GridBox[{
   {
    RowBox[{
     StyleBox["\:0432\:044b\:0440\:0430\:0436\:0435\:043d\:0438\:0435", "TI"],
      "=."}], Cell[TextData[{
     "\:043e\:0447\:0438\:0441\:0442\:043a\:0430 \:0437\:043d\:0430\:0447\
\:0435\:043d\:0438\:044f, \:043e\:043f\:0440\:0435\:0434\:0435\:043b\:0435\
\:043d\:043d\:043e\:0433\:043e \:0434\:043b\:044f ",
     Cell[BoxData[
      StyleBox["\:0432\:044b\:0440\:0430\:0436\:0435\:043d\:0438\:044f", 
       "TI"]], "InlineFormula"]
    }], "TableText"]},
   {
    RowBox[{
     StyleBox["f", "TI"], "/:", 
     RowBox[{
      StyleBox["\:0432\:044b\:0440\:0430\:0436\:0435\:043d\:0438\:0435", "TI"],
       "=."}]}], Cell[TextData[{
     "\:043e\:0447\:0438\:0441\:0442\:043a\:0430 \:0437\:043d\:0430\:0447\
\:0435\:043d\:0438\:044f, \:0441\:0432\:044f\:0437\:0430\:043d\:043d\:043e\
\:0433\:043e \:0441 ",
     Cell[BoxData[
      StyleBox["f", "TI"]], "InlineFormula"],
     ", \:043e\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\:043d\:043e\
\:0433\:043e \:0434\:043b\:044f ",
     Cell[BoxData[
      StyleBox["\:0432\:044b\:0440\:0430\:0436\:0435\:043d\:0438\:044f", 
       "TI"]], "InlineFormula"]
    }], "TableText"]},
   {
    RowBox[{
     ButtonBox["Clear",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/Clear"], "[", 
     SubscriptBox[
      StyleBox["s", "TI"], 
      StyleBox["1", "TR"]], ",", 
     SubscriptBox[
      StyleBox["s", "TI"], 
      StyleBox["2", "TR"]], ",", 
     StyleBox["\[Ellipsis]", "TR"], "]"}], Cell[TextData[{
     "\:043e\:0447\:0438\:0441\:0442\:043a\:0430 \:0432\:0441\:0435\:0445 \
\:0437\:043d\:0430\:0447\:0435\:043d\:0438\:0439 \:0434\:043b\:044f \:0441\
\:0438\:043c\:0432\:043e\:043b\:043e\:0432 ",
     Cell[BoxData[
      FormBox[
       SubscriptBox["s", "i"], $CellContext`TI]], "InlineFormula"],
     ", \:0437\:0430 \:0438\:0441\:043a\:043b\:044e\:0447\:0435\:043d\:0438\
\:0435\:043c \:0430\:0442\:0440\:0438\:0431\:0443\:0442\:043e\:0432, \:0441\
\:043e\:043e\:0431\:0449\:0435\:043d\:0438\:0439 \:0438 \:0443\:043c\:043e\
\:043b\:0447\:0430\:043d\:0438\:0439"
    }], "TableText"]},
   {
    RowBox[{
     ButtonBox["ClearAll",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/ClearAll"], "[", 
     SubscriptBox[
      StyleBox["s", "TI"], 
      StyleBox["1", "TR"]], ",", 
     SubscriptBox[
      StyleBox["s", "TI"], 
      StyleBox["2", "TR"]], ",", 
     StyleBox["\[Ellipsis]", "TR"], "]"}], Cell[TextData[{
     "\:043e\:0447\:0438\:0441\:0442\:043a\:0430 \:0432\:0441\:0435\:0445 \
\:0437\:043d\:0430\:0447\:0435\:043d\:0438\:0439 \:0434\:043b\:044f \:0441\
\:0438\:043c\:0432\:043e\:043b\:043e\:0432 ",
     Cell[BoxData[
      FormBox[
       SubscriptBox["s", "i"], $CellContext`TI]], "InlineFormula"],
     ", \:0432\:043a\:043b\:044e\:0447\:0430\:044f \:0430\:0442\:0440\:0438\
\:0431\:0443\:0442\:044b, \:0441\:043e\:043e\:0431\:0449\:0435\:043d\:0438\
\:044f \:0438 \:0443\:043c\:043e\:043b\:0447\:0430\:043d\:0438\:044f"
    }], "TableText"]},
   {
    RowBox[{
     ButtonBox["Remove",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/Remove"], "[", 
     SubscriptBox[
      StyleBox["s", "TI"], 
      StyleBox["1", "TR"]], ",", 
     SubscriptBox[
      StyleBox["s", "TI"], 
      StyleBox["2", "TR"]], ",", 
     StyleBox["\[Ellipsis]", "TR"], "]"}], Cell[TextData[{
     "\:043e\:0447\:0438\:0441\:0442\:043a\:0430 \:0437\:043d\:0430\:0447\
\:0435\:043d\:0438\:0439 \:0441 \:043f\:043e\:0441\:043b\:0435\:0434\:0443\
\:044e\:0449\:0438\:043c \:0443\:0434\:0430\:043b\:0435\:043d\:0438\:0435\
\:043c \:0438\:043c\:0435\:043d ",
     Cell[BoxData[
      FormBox[
       SubscriptBox["s", "i"], $CellContext`TI]], "InlineFormula"]
    }], "TableText"]}
  }]], "DefinitionBox",
 CellID->7975],

Cell["\:0421\:043f\:043e\:0441\:043e\:0431\:044b \:043e\:0447\:0438\:0441\
\:0442\:043a\:0438 \:0438 \:0443\:0434\:0430\:043b\:0435\:043d\:0438\:044f \
\:043e\:0431\:044a\:0435\:043a\:0442\:043e\:0432. ", "Caption",
 CellID->10556],

Cell[TextData[{
 "\:0412 \:0444\:0443\:043d\:043a\:0446\:0438\:044f\:0445 ",
 Cell[BoxData[
  TemplateBox[{Cell["Clear"],"paclet:ref/Clear"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  TemplateBox[{Cell["ClearAll"],"paclet:ref/ClearAll"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " \:0438 ",
 Cell[BoxData[
  TemplateBox[{Cell["Remove"],"paclet:ref/Remove"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 ", \:043a\:0430\:0436\:0434\:044b\:0439 \:0430\:0440\:0433\:0443\:043c\:0435\
\:043d\:0442 \:043c\:043e\:0436\:0435\:0442 \:0431\:044b\:0442\:044c \:043b\
\:0438\:0431\:043e \:0441\:0438\:043c\:0432\:043e\:043b\:043e\:043c, \:043b\
\:0438\:0431\:043e \:0438\:043c\:0435\:043d\:0435\:043c \:0441\:0438\:043c\
\:0432\:043e\:043b\:0430 \:0432 \:0432\:0438\:0434\:0435 \:0442\:0435\:043a\
\:0441\:0442\:043e\:0432\:043e\:0433\:043e \:0444\:0440\:0430\:0433\:043c\
\:0435\:043d\:0442\:0430. \:0410\:0440\:0433\:0443\:043c\:0435\:043d\:0442\
\:044b \:0442\:0435\:043a\:0441\:0442\:043e\:0432\:044b\:0445 \:0444\:0440\
\:0430\:0433\:043c\:0435\:043d\:0442\:043e\:0432 \:043c\:043e\:0433\:0443\
\:0442 \:0441\:043e\:0434\:0435\:0440\:0436\:0430\:0442\:044c \:043c\:0435\
\:0442\:0430\:0441\:0438\:043c\:0432\:043e\:043b\:044b * \:0438 @, \:0443\
\:043a\:0430\:0437\:044b\:0432\:0430\:044e\:0449\:0438\:0435 \:043d\:0430 \
\:0442\:043e, \:0447\:0442\:043e \:0434\:0435\:0439\:0441\:0442\:0432\:0438\
\:0435 \:043f\:0440\:0438\:043c\:0435\:043d\:044f\:0435\:0442\:0441\:044f \
\:043a\:043e \:0432\:0441\:0435\:043c \:0441\:0438\:043c\:0432\:043e\:043b\
\:0430\:043c, \:0447\:044c\:0438 \:0438\:043c\:0435\:043d\:0430 \:0441\:043e\
\:043e\:0442\:0432\:0435\:0442\:0441\:0442\:0432\:0443\:044e\:0442 \:0448\
\:0430\:0431\:043b\:043e\:043d\:0443."
}], "Text",
 CellID->7531],

Cell[TextData[{
 Cell[BoxData[
  TemplateBox[{Cell["Clear"],"paclet:ref/Clear"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  TemplateBox[{Cell["ClearAll"],"paclet:ref/ClearAll"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " \:0438 ",
 Cell[BoxData[
  TemplateBox[{Cell["Remove"],"paclet:ref/Remove"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " \:043d\:0435 \:0432\:043e\:0437\:0434\:0435\:0439\:0441\:0442\:0432\:0443\
\:044e\:0442 \:043d\:0430 \:0441\:0438\:043c\:0432\:043e\:043b\:044b \:0441 \
\:0430\:0442\:0440\:0438\:0431\:0443\:0442\:043e\:043c ",
 Cell[BoxData[
  TemplateBox[{Cell["Protected"],"paclet:ref/Protected"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 ". "
}], "Text",
 CellID->31495]
}, Open  ]],

Cell[CellGroupData[{

Cell["\:041f\:0440\:0430\:0432\:0438\:043b\:0430 \:043f\:0440\:0435\:043e\
\:0431\:0440\:0430\:0437\:043e\:0432\:0430\:043d\:0438\:044f", "Section",
 CellTags->{"SA.5.5", "5.1"},
 CellID->24290],

Cell[BoxData[GridBox[{
   {
    RowBox[{
     StyleBox["lhs", "TI"], "->", 
     StyleBox["rhs", "TI"]}], Cell[TextData[{
     "\:043d\:0435\:043c\:0435\:0434\:043b\:0435\:043d\:043d\:043e\:0435 \
\:043f\:0440\:0430\:0432\:0438\:043b\:043e: ",
     Cell[BoxData[
      StyleBox["rhs", "TI"]], "InlineFormula"],
     " \:0432\:044b\:0447\:0438\:0441\:043b\:044f\:0435\:0442\:0441\:044f \
\:043f\:0440\:0438 \:043f\:0435\:0440\:0432\:043e\:043c \:0432\:0432\:043e\
\:0434\:0435 \:043f\:0440\:0430\:0432\:0438\:043b\:0430"
    }], "TableText"]},
   {
    RowBox[{
     StyleBox["lhs", "TI"], ":>", 
     StyleBox["rhs", "TI"]}], Cell[TextData[{
     "\:043e\:0442\:043b\:043e\:0436\:0435\:043d\:043d\:043e\:0435 \:043f\
\:0440\:0430\:0432\:0438\:043b\:043e: ",
     Cell[BoxData[
      StyleBox["rhs", "TI"]], "InlineFormula"],
     " \:0432\:044b\:0447\:0438\:0441\:043b\:044f\:0435\:0442\:0441\:044f \
\:043a\:043e\:0433\:0434\:0430 \:043f\:0440\:0430\:0432\:0438\:043b\:043e \
\:043f\:0440\:0438\:043c\:0435\:043d\:044f\:0435\:0442\:0441\:044f"
    }], "TableText"]}
  }]], "DefinitionBox",
 CellID->29059],

Cell[TextData[{
 "\:0414\:0432\:0430 \:043e\:0441\:043d\:043e\:0432\:043d\:044b\:0445 \:0432\
\:0438\:0434\:0430 \:043f\:0440\:0430\:0432\:0438\:043b \:043f\:0440\:0435\
\:043e\:0431\:0440\:0430\:0437\:043e\:0432\:0430\:043d\:0438\:044f \:0432 ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ". "
}], "Caption",
 CellID->31684],

Cell[TextData[{
 "\:0417\:0430\:043c\:0435\:043d\:044b \:043f\:0435\:0440\:0435\:043c\:0435\
\:043d\:043d\:044b\:0445 \:0448\:0430\:0431\:043b\:043e\:043d\:043e\:0432, \
\:0438\:0441\:043f\:043e\:043b\:044c\:0437\:0443\:0435\:043c\:044b\:0445 \
\:0432 \:043f\:0440\:0430\:0432\:0438\:043b\:0430\:0445 \:043f\:0440\:0435\
\:043e\:0431\:0440\:0430\:0437\:043e\:0432\:0430\:043d\:0438\:044f, \:0432\
\:044b\:043f\:043e\:043b\:043d\:044f\:044e\:0442\:0441\:044f \:0441 \:043f\
\:043e\:043c\:043e\:0449\:044c\:044e \:0444\:0443\:043d\:043a\:0446\:0438\
\:0438 ",
 Cell[BoxData[
  TemplateBox[{Cell["ReplaceAll"],"paclet:ref/ReplaceAll"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " (\:043e\:043f\:0435\:0440\:0430\:0442\:043e\:0440 ",
 Cell[BoxData["/."], "InlineFormula"],
 "). "
}], "Text",
 CellID->4546]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  InterpretationBox[
   StyleBox[
    GraphicsBox[{},
     BaselinePosition->Baseline,
     ImageSize->{6, 0}],
    CacheGraphics->False],
   Spacer[6]]]],
 "\:0423\:0437\:043d\:0430\:0442\:044c \:0431\:043e\:043b\:044c\:0448\:0435"
}], "TutorialMoreAboutSection",
 WholeCellGroupOpener->True,
 CellID->912440811],

Cell["", "SectionHeaderSpacer"],

Cell[TextData[ButtonBox["Patterns",
 BaseStyle->"Link",
 ButtonData->"paclet:guide/Patterns"]], "TutorialMoreAbout",
 CellID->1782309996],

Cell[TextData[ButtonBox["Rules & Patterns",
 BaseStyle->"Link",
 ButtonData->"paclet:guide/RulesAndPatterns"]], "TutorialMoreAbout",
 CellID->99192249],

Cell["", "SectionFooterSpacer"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  InterpretationBox[
   StyleBox[
    GraphicsBox[{},
     BaselinePosition->Baseline,
     ImageSize->{6, 0}],
    CacheGraphics->False],
   Spacer[6]]]],
 "\:0421\:043e\:043f\:0443\:0442\:0441\:0442\:0432\:0443\:044e\:0449\:0438\
\:0435 \:0443\:0447\:0435\:0431\:043d\:044b\:0435 \:043c\:0430\:0442\:0435\
\:0440\:0438\:0430\:043b\:044b"
}], "RelatedTutorialsSection",
 WholeCellGroupOpener->True,
 CellID->424837465],

Cell["", "SectionHeaderSpacer"],

Cell[TextData[ButtonBox["\:0412\:0432\:0435\:0434\:0435\:043d\:0438\:0435 \
\:0432 \:0448\:0430\:0431\:043b\:043e\:043d\:044b",
 BaseStyle->"Hyperlink",
 ButtonData->{"Introduction-PatternsRU.nb", None}]], "RelatedTutorials",
 FontFamily->"Verdana",
 FontSize->11,
 CellID->405226890],

Cell[TextData[ButtonBox["\:0428\:0430\:0431\:043b\:043e\:043d \:0438\:0437 \
\:043f\:043e\:0441\:043b\:0435\:0434\:043e\:0432\:0430\:0442\:0435\:043b\:044c\
\:043d\:043e\:0433\:043e \:0440\:044f\:0434\:0430 \:0434\:0430\:043d\:043d\
\:044b\:0445",
 BaseStyle->"Hyperlink",
 ButtonData->{"PatternSequencesRU.nb", None}]], "RelatedTutorials",
 FontFamily->"Verdana",
 FontSize->11,
 CellID->602399777],

Cell[TextData[ButtonBox["\:0414\:043e\:0441\:043b\:043e\:0432\:043d\:044b\
\:0435 \:0448\:0430\:0431\:043b\:043e\:043d\:044b",
 BaseStyle->"Hyperlink",
 ButtonData->{"VerbatimPatternsRU.nb", None}]], "RelatedTutorials",
 FontFamily->"Verdana",
 FontSize->11,
 CellID->178988280],

Cell[TextData[ButtonBox["\:0417\:043d\:0430\:0447\:0435\:043d\:0438\:044f \
\:0430\:0440\:0433\:0443\:043c\:0435\:043d\:0442\:043e\:0432 \:043f\:043e \
\:0443\:043c\:043e\:043b\:0447\:0430\:043d\:0438\:044e. \:041e\:043f\:0446\
\:0438\:043e\:043d\:0430\:043b\:044c\:043d\:044b\:0435 \:0430\:0440\:0433\
\:0443\:043c\:0435\:043d\:0442\:044b",
 BaseStyle->"Hyperlink",
 ButtonData->{"OptionalAndDefaultArgumentsRU.nb", None}]], "RelatedTutorials",
 FontFamily->"Verdana",
 FontSize->11,
 CellID->725340173],

Cell["", "SectionFooterSpacer"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  InterpretationBox[
   StyleBox[
    GraphicsBox[{},
     BaselinePosition->Baseline,
     ImageSize->{6, 0}],
    CacheGraphics->False],
   Spacer[6]]]],
 "\:0423\:0447\:0435\:0431\:043d\:044b\:0435 \:043a\:0443\:0440\:0441\:044b \
Wolfram"
}], "TutorialRelatedLinksSection",
 WholeCellGroupOpener->True,
 CellID->48802176],

Cell["", "SectionHeaderSpacer"],

Cell[TextData[Cell[BoxData[
 TemplateBox[{Cell[
    TextData[
     StyleBox[{
       StyleBox["Mathematica", FontSlant -> "Italic"], 
       ": An Introduction"}]]],
   "http://www.wolfram.com/training/courses/gen101.html"},
  "WebLink",
  BaseStyle->{"TutorialRelatedLinks"}]]]], "TutorialRelatedLinks",
 CellID->801179965],

Cell[TextData[Cell[BoxData[
 TemplateBox[{Cell[
    TextData[
     StyleBox[{
       StyleBox["Mathematica", FontSlant -> "Italic"], ": Programming in ", 
       StyleBox["Mathematica", FontSlant -> "Italic"]}]]],
   "http://www.wolfram.com/training/courses/gen201.html"},
  "WebLink",
  BaseStyle->{"TutorialRelatedLinks"}]]]], "TutorialRelatedLinks",
 CellID->709205065]
}, Open  ]]
}, Open  ]],

Cell[" ", "FooterCell"]
},
FileChangeProtection->None,
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{Automatic, 510},
WindowMargins->{{312, Automatic}, {Automatic, 0}},
WindowFrame->"Normal",
WindowTitle->"Patterns and Transformation Rules - Wolfram Mathematica",
DockedCells->FEPrivate`FrontEndResource["FEExpressions", "HelpViewerToolbar"],
TaggingRules->{
 "ModificationHighlight" -> False, "ColorType" -> "TutorialColor", 
  "LinkTrails" -> GridBox[{{
      RowBox[{
        ButtonBox[
        "Virtual Book", ButtonData -> "paclet:tutorial/VirtualBookOverview", 
         BaseStyle -> {"Link", "DockedLinkTrail"}], 
        Cell[">", "DockedLinkTrailSeparator"], 
        ButtonBox[
        "Core Language", ButtonData -> "paclet:tutorial/CoreLanguageOverview",
          BaseStyle -> {"Link", "DockedLinkTrail"}], 
        Cell[">", "DockedLinkTrailSeparator"], 
        ButtonBox[
        "Mathematica Language Structure", ButtonData -> 
         "paclet:tutorial/LanguageStructureOverview", 
         BaseStyle -> {"Link", "DockedLinkTrail"}], 
        Cell[">", "DockedLinkTrailSeparator"], 
        ButtonBox[
        "Patterns and Transformation Rules", ButtonData -> 
         "paclet:tutorial/PatternsAndTransformationRules", 
         BaseStyle -> {"Link", "DockedLinkTrail"}]}]}}, ColumnAlignments -> 
    Left], "ExampleCounter" -> 1, "ExamplePageLinks" -> {}, "RootCaptions" -> 
  "", "Metadata" -> {
   "built" -> "{2012, 11, 20, 2, 9, 32.6706841}", 
    "history" -> {"XX", "", "", ""}, "context" -> "System`", 
    "keywords" -> {
     "arguments", "assignments", "attributes", "blanks", "clear", "ClearAll", 
      "clearing symbols", "clearing values", "default", "DefaultValues", 
      "deleting objects", "DownValues", "erasing objects", "erasing values", 
      "flat", "FormatValues", "functions", "killing", "matches", "matching", 
      "messages", "NValues", "OneIdentity", "options", "orderless", 
      "patterns", "protected", "remove", "removing objects", "sequences", 
      "set", "SetDelayed", "symbols", "TagSet", "TagUnset", 
      "transformation rules", "Undefining objects", "unset", "UpSet", 
      "UpValues", "values"}, "specialkeywords" -> {}, 
    "tutorialcollectionlinks" -> {{
      "Core Language", 
       "http://www.wolfram.com/learningcenter/tutorialcollection/CoreLanguage/\
"}}, "index" -> True, "label" -> "Mathematica Tutorial", "language" -> "en", 
    "paclet" -> "Mathematica", "status" -> "None", "summary" -> 
    "Patterns stand for classes of expressions. They contain pattern objects \
that represent sets of possible expressions. Pattern objects. When several \
pattern objects with the same name occur in a single pattern, all the objects \
must stand for the same expression. Thus f[x_,x_] can stand for f[2,2] but \
not f[2,3]. ", "synonyms" -> {"A.5.1", "A.5.2", "A.5.3", "A.5.4", "A.5.5"}, 
    "title" -> "Patterns and Transformation Rules", "titlemodifier" -> "", 
    "windowtitle" -> "Patterns and Transformation Rules", "type" -> 
    "Tutorial", "uri" -> "tutorial/PatternsAndTransformationRules"}, 
  "SearchTextTranslated" -> ""},
Magnification->1.,
FrontEndVersion->"10.1 for Microsoft Windows (64-bit) (March 23, 2015)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[
    StyleDefinitions -> FrontEnd`FileName[{"Wolfram"}, "Reference.nb"]]], 
   Cell[
    StyleData["Input"], CellContext -> Notebook], 
   Cell[
    StyleData["Output"], CellContext -> Notebook], 
   Cell[
    StyleData["TutorialMoreAboutSection"], 
    CellGroupingRules -> {"SectionGrouping", 30}], 
   Cell[
    StyleData["RelatedTutorialsSection"], 
    CellGroupingRules -> {"SectionGrouping", 30}], 
   Cell[
    StyleData["TutorialRelatedLinksSection"], 
    CellGroupingRules -> {"SectionGrouping", 30}]}, Visible -> False, 
  FrontEndVersion -> "10.1 for Microsoft Windows (64-bit) (March 23, 2015)", 
  StyleDefinitions -> "Default.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "SA.5.1"->{
  Cell[9124, 225, 106, 2, 62, "Section",
   CellTags->{"SA.5.1", "1.1"},
   CellID->8519]},
 "1.1"->{
  Cell[9124, 225, 106, 2, 62, "Section",
   CellTags->{"SA.5.1", "1.1"},
   CellID->8519]},
 "SA.5.2"->{
  Cell[46187, 1117, 132, 3, 62, "Section",
   CellTags->{"SA.5.2", "2.1"},
   CellID->4182]},
 "2.1"->{
  Cell[46187, 1117, 132, 3, 62, "Section",
   CellTags->{"SA.5.2", "2.1"},
   CellID->4182]},
 "SA.5.3"->{
  Cell[59508, 1401, 139, 3, 62, "Section",
   CellTags->{"SA.5.3", "3.1"},
   CellID->6025]},
 "3.1"->{
  Cell[59508, 1401, 139, 3, 62, "Section",
   CellTags->{"SA.5.3", "3.1"},
   CellID->6025]},
 "SA.5.4"->{
  Cell[64197, 1536, 216, 4, 62, "Section",
   CellTags->{"SA.5.4", "4.1"},
   CellID->26819]},
 "4.1"->{
  Cell[64197, 1536, 216, 4, 62, "Section",
   CellTags->{"SA.5.4", "4.1"},
   CellID->26819]},
 "SA.5.5"->{
  Cell[71113, 1710, 194, 3, 62, "Section",
   CellTags->{"SA.5.5", "5.1"},
   CellID->24290]},
 "5.1"->{
  Cell[71113, 1710, 194, 3, 62, "Section",
   CellTags->{"SA.5.5", "5.1"},
   CellID->24290]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"SA.5.1", 81545, 1993},
 {"1.1", 81647, 1997},
 {"SA.5.2", 81752, 2001},
 {"2.1", 81856, 2005},
 {"SA.5.3", 81963, 2009},
 {"3.1", 82067, 2013},
 {"SA.5.4", 82174, 2017},
 {"4.1", 82279, 2021},
 {"SA.5.5", 82387, 2025},
 {"5.1", 82492, 2029}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[626, 21, 6353, 140, 48, "AnchorBarGrid",
 CellID->1],
Cell[CellGroupData[{
Cell[7004, 165, 219, 3, 47, "Title",
 CellID->1292728359],
Cell[7226, 170, 1873, 51, 88, "TutorialJumpBox",
 CellID->328837780],
Cell[CellGroupData[{
Cell[9124, 225, 106, 2, 62, "Section",
 CellTags->{"SA.5.1", "1.1"},
 CellID->8519],
Cell[9233, 229, 927, 16, 48, "Text",
 CellID->13985],
Cell[10163, 247, 14779, 351, 753, "DefinitionBox",
 CellID->28289],
Cell[24945, 600, 129, 2, 31, "Caption",
 CellID->15944],
Cell[25077, 604, 1411, 28, 70, "Text",
 CellID->2865],
Cell[26491, 634, 705, 16, 50, "Text",
 CellID->18540],
Cell[27199, 652, 2551, 57, 114, "Text",
 CellID->23245],
Cell[29753, 711, 3238, 75, 130, "Text",
 CellID->25508],
Cell[32994, 788, 3219, 81, 170, "DefinitionBox",
 CellID->28318],
Cell[36216, 871, 312, 9, 35, "Caption",
 CellID->27870],
Cell[36531, 882, 2968, 56, 128, "Text",
 CellID->9601],
Cell[39502, 940, 1290, 27, 68, "Text",
 CellID->28323],
Cell[40795, 969, 804, 19, 52, "Text",
 CellID->358929610],
Cell[41602, 990, 1718, 58, 106, "DefinitionBox",
 CellID->21132],
Cell[43323, 1050, 368, 5, 31, "Caption",
 CellID->24472],
Cell[43694, 1057, 2456, 55, 96, "Text",
 CellID->27152]
}, Open  ]],
Cell[CellGroupData[{
Cell[46187, 1117, 132, 3, 62, "Section",
 CellTags->{"SA.5.2", "2.1"},
 CellID->4182],
Cell[46322, 1122, 1306, 30, 113, "DefinitionBox",
 CellID->25391],
Cell[47631, 1154, 277, 8, 31, "Caption",
 CellID->15495],
Cell[47911, 1164, 1013, 20, 48, "Text",
 CellID->5764],
Cell[48927, 1186, 1835, 47, 103, "DefinitionBox",
 CellID->874],
Cell[50765, 1235, 281, 4, 31, "Caption",
 CellID->1364],
Cell[51049, 1241, 1420, 33, 69, "Text",
 CellID->14902],
Cell[52472, 1276, 1439, 31, 69, "Text",
 CellID->28255],
Cell[53914, 1309, 2032, 32, 86, "Text",
 CellID->4460],
Cell[55949, 1343, 1206, 18, 57, "Notes",
 CellID->474],
Cell[57158, 1363, 2313, 33, 85, "Notes",
 CellID->193657617]
}, Open  ]],
Cell[CellGroupData[{
Cell[59508, 1401, 139, 3, 62, "Section",
 CellTags->{"SA.5.3", "3.1"},
 CellID->6025],
Cell[59650, 1406, 4276, 120, 253, "DefinitionBox",
 CellID->1534],
Cell[63929, 1528, 231, 3, 31, "Caption",
 CellID->5821]
}, Open  ]],
Cell[CellGroupData[{
Cell[64197, 1536, 216, 4, 62, "Section",
 CellTags->{"SA.5.4", "4.1"},
 CellID->26819],
Cell[64416, 1542, 3744, 95, 192, "DefinitionBox",
 CellID->7975],
Cell[68163, 1639, 231, 3, 31, "Caption",
 CellID->10556],
Cell[68397, 1644, 1857, 35, 88, "Text",
 CellID->7531],
Cell[70257, 1681, 819, 24, 34, "Text",
 CellID->31495]
}, Open  ]],
Cell[CellGroupData[{
Cell[71113, 1710, 194, 3, 62, "Section",
 CellTags->{"SA.5.5", "5.1"},
 CellID->24290],
Cell[71310, 1715, 1106, 26, 111, "DefinitionBox",
 CellID->29059],
Cell[72419, 1743, 332, 8, 31, "Caption",
 CellID->31684],
Cell[72754, 1753, 826, 17, 52, "Text",
 CellID->4546]
}, Open  ]],
Cell[CellGroupData[{
Cell[73617, 1775, 344, 12, 31, "TutorialMoreAboutSection",
 CellID->912440811],
Cell[73964, 1789, 31, 0, 14, "SectionHeaderSpacer"],
Cell[73998, 1791, 137, 3, 18, "TutorialMoreAbout",
 CellID->1782309996],
Cell[74138, 1796, 151, 3, 18, "TutorialMoreAbout",
 CellID->99192249],
Cell[74292, 1801, 31, 0, 29, "SectionFooterSpacer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[74360, 1806, 450, 14, 31, "RelatedTutorialsSection",
 CellID->424837465],
Cell[74813, 1822, 31, 0, 14, "SectionHeaderSpacer"],
Cell[74847, 1824, 284, 6, 18, "RelatedTutorials",
 CellID->405226890],
Cell[75134, 1832, 399, 8, 18, "RelatedTutorials",
 CellID->602399777],
Cell[75536, 1842, 278, 6, 18, "RelatedTutorials",
 CellID->178988280],
Cell[75817, 1850, 504, 9, 18, "RelatedTutorials",
 CellID->725340173],
Cell[76324, 1861, 31, 0, 29, "SectionFooterSpacer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[76392, 1866, 356, 13, 31, "TutorialRelatedLinksSection",
 CellID->48802176],
Cell[76751, 1881, 31, 0, 14, "SectionHeaderSpacer"],
Cell[76785, 1883, 324, 9, 18, "TutorialRelatedLinks",
 CellID->801179965],
Cell[77112, 1894, 372, 9, 18, "TutorialRelatedLinks",
 CellID->709205065]
}, Open  ]]
}, Open  ]],
Cell[77511, 1907, 23, 0, 41, "FooterCell"]
}
]
*)

(* End of internal cache information *)
