(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     68981,       1983]
NotebookOptionsPosition[     61756,       1757]
NotebookOutlinePosition[     63747,       1802]
CellTagsIndexPosition[     63704,       1799]
WindowTitle->Perform a Bootstrap Analysis - Wolfram Mathematica
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[GridBox[{
   {Cell["MATHEMATICA HOW TO", "PacletNameCell"], Cell[TextData[{
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "Tutorials",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"Tutorials", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->False], {"\<\"Numerical Operations on Data\"\>":>
       Documentation`HelpLookup[
       "paclet:tutorial/NumericalOperationsOnDataOverview"], \
"\<\"Pseudorandom Numbers\"\>":>Documentation`HelpLookup[
       "paclet:tutorial/PseudorandomNumbers"], "\<\"Random Number \
Generation\"\>":>Documentation`HelpLookup[
       "paclet:tutorial/RandomNumberGeneration"]},
       Appearance->None,
       MenuAppearance->Automatic,
       MenuStyle->"Tutorials"]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "See Also",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"See Also", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->False], {"\<\"RandomChoice\"\>":>
       Documentation`HelpLookup["paclet:ref/RandomChoice"], "\<\"Table\"\>":>
       Documentation`HelpLookup["paclet:ref/Table"], "\<\"Mean\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/Mean"], "\<\"StandardDeviation\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/StandardDeviation"], "\<\"Histogram\"\>":>
       Documentation`HelpLookup["paclet:ref/Histogram"], "\<\"Quantile\"\>":>
       Documentation`HelpLookup["paclet:ref/Quantile"], "\<\"Skewness\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/Skewness"], "\<\"FindDistributionParameters\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/FindDistributionParameters"], "\<\"Correlation\"\>":>
       Documentation`HelpLookup["paclet:ref/Correlation"]},
       Appearance->None,
       MenuAppearance->Automatic,
       MenuStyle->"SeeAlso"]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "Related Guides",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"Related Guides", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->False], {"\<\"Numerical Data\"\>":>
       Documentation`HelpLookup[
       "paclet:guide/NumericalData"], "\<\"Handling Arrays of Data\"\>":>
       Documentation`HelpLookup[
       "paclet:guide/HandlingArraysOfData"], "\<\"Statistics\"\>":>
       Documentation`HelpLookup[
       "paclet:guide/Statistics"], "\<\"Descriptive Statistics\"\>":>
       Documentation`HelpLookup[
       "paclet:guide/DescriptiveStatistics"], "\<\"Statistical Model Analysis\
\"\>":>Documentation`HelpLookup[
       "paclet:guide/StatisticalModelAnalysis"], "\<\"Random Number \
Generation\"\>":>Documentation`HelpLookup[
       "paclet:guide/RandomNumberGeneration"], "\<\"Data Visualization\"\>":>
       Documentation`HelpLookup[
       "paclet:guide/DataVisualization"], "\<\"\\\"How to\\\" Topics\"\>":>
       Documentation`HelpLookup["paclet:guide/HowToTopics"]},
       Appearance->None,
       MenuAppearance->Automatic,
       MenuStyle->"MoreAbout"]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "URL",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"URL", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->False], {"\<\"howto/PerformABootstrapAnalysis\"\>":>
       None, "\<\"Copy Mathematica URL\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell["howto/PerformABootstrapAnalysis"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; Null], 
       Delimiter, "\<\"Copy web URL\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell[
              BoxData[
               MakeBoxes[
                Hyperlink[
                "http://reference.wolfram.com/mathematica/howto/\
PerformABootstrapAnalysis.html"], StandardForm]], "Input", TextClipboardType -> 
              "PlainText"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; 
        Null], "\<\"Go to web URL\"\>":>FrontEndExecute[{
         NotebookLocate[{
           URL[
            StringJoin[
            "http://reference.wolfram.com/mathematica/", 
             "howto/PerformABootstrapAnalysis", ".html"]], None}]}]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}]
    }], "AnchorBar"]}
  }]], "AnchorBarGrid",
 CellID->1],

Cell[CellGroupData[{

Cell[TextData[{
 Cell["\:041a\:0440\:0430\:0442\:043a\:0438\:0439 \:043a\:0443\:0440\:0441 ", 
  "HowToTitlePrefix"],
 " ",
 "\:0412\:044b\:043f\:043e\:043b\:043d\:0435\:043d\:0438\:0435 \:0431\:0443\
\:0442\:0441\:0442\:0440\:0435\:043f-\:0430\:043d\:0430\:043b\:0438\:0437\
\:0430"
}], "HowToTitle",
 CellID->509267359],

Cell[CellGroupData[{

Cell[TextData[{
 "\:041f\:0440\:0435\:0434\:043f\:043e\:043b\:043e\:0436\:0438\:043c, \:0447\
\:0442\:043e \:0438\:043c\:0435\:0435\:0442\:0441\:044f \:043e\:0433\:0440\
\:0430\:043d\:0438\:0447\:0435\:043d\:043d\:043e\:0435 \:043a\:043e\:043b\
\:0438\:0447\:0435\:0441\:0442\:0432\:043e \:0434\:0430\:043d\:043d\:044b\
\:0445, \:0438\:0437 \:043a\:043e\:0442\:043e\:0440\:043e\:0433\:043e \:043d\
\:0443\:0436\:043d\:043e \:043f\:043e\:043b\:0443\:0447\:0438\:0442\:044c \
\:043f\:0440\:043e\:0433\:043d\:043e\:0437\:043d\:044b\:0435 \:0441\:0442\
\:0430\:0442\:0438\:0441\:0442\:0438\:0447\:0435\:0441\:043a\:0438\:0435 \
\:043e\:0446\:0435\:043d\:043a\:0438 \:0434\:043b\:044f \:0433\:0435\:043d\
\:0435\:0440\:0430\:043b\:044c\:043d\:043e\:0439 \:0441\:043e\:0432\:043e\
\:043a\:0443\:043f\:043d\:043e\:0441\:0442\:0438.  \:0412\:044b\:0431\:043e\
\:0440\:043e\:0447\:043d\:043e\:0435 \:0440\:0430\:0441\:043f\:0440\:0435\
\:0434\:0435\:043b\:0435\:043d\:0438\:0435 \:0434\:043b\:044f \:0442\:0430\
\:043a\:0438\:0445 \:043e\:0446\:0435\:043d\:043e\:043a \:043c\:043e\:0436\
\:0435\:0442 \:0431\:044b\:0442\:044c \:043f\:043e\:043b\:0443\:0447\:0435\
\:043d\:043e \:043f\:0440\:0438\:0431\:043b\:0438\:0436\:0435\:043d\:043d\
\:043e, \:043f\:0443\:0442\:0435\:043c \:0438\:0437\:0432\:043b\:0435\:0447\
\:0435\:043d\:0438\:044f \:043d\:043e\:0432\:044b\:0445 \:0432\:044b\:0431\
\:043e\:0440\:043e\:043a \:0438\:0437 \:0438\:0441\:0445\:043e\:0434\:043d\
\:044b\:0445 \:0434\:0430\:043d\:043d\:044b\:0445 \:0441 \:043f\:043e\:0441\
\:043b\:0435\:0434\:0443\:044e\:0449\:0438\:043c \:0432\:044b\:0447\:0438\
\:0441\:043b\:0435\:043d\:0438\:0435\:043c \:0441\:0442\:0430\:0442\:0438\
\:0441\:0442\:0438\:0447\:0435\:0441\:043a\:0438\:0445 \:043f\:043e\:043a\
\:0430\:0437\:0430\:0442\:0435\:043b\:0435\:0439 \:0434\:043b\:044f \:043a\
\:0430\:0436\:0434\:043e\:0439 \:0432\:044b\:0431\:043e\:0440\:043a\:0438. \
\:042d\:0442\:043e\:0442 \:043f\:0440\:043e\:0446\:0435\:0441\:0441 \:043d\
\:0430\:0437\:044b\:0432\:0430\:0435\:0442\:0441\:044f \"\:0432\:044b\:0442\
\:0430\:0441\:043a\:0438\:0432\:0430\:043d\:0438\:0435\:043c\" \:0438\:043b\
\:0438 \:0431\:0443\:0442\:0441\:0442\:0440\:0435\:043f\:043f\:0438\:043d\
\:0433\:043e\:043c, \:0438 \:043e\:043d \:043c\:043e\:0436\:0435\:0442 \:0431\
\:044b\:0442\:044c \:0432\:044b\:043f\:043e\:043b\:043d\:0435\:043d \:0432 ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " \:043f\:0440\:0438 \:043f\:043e\:043c\:043e\:0449\:0438 \:0444\:0443\:043d\
\:043a\:0446\:0438\:0438 ",
 Cell[BoxData[
  ButtonBox["RandomChoice",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/RandomChoice"]], "InlineFormula"],
 ". "
}], "HowToAbstract",
 CellID->840069076],

Cell["\:041d\:0430\:0447\:043d\:0435\:043c \:0441 \:043d\:0430\:0431\:043e\
\:0440\:0430 \:0434\:0430\:043d\:043d\:044b\:0445:", "HowToText",
 CellID->1009846402],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"data", "=", 
  RowBox[{"{", 
   RowBox[{
   "7.05", ",", "2.49", ",", "16.09", ",", "21.3", ",", "19.21", ",", "14.88",
     ",", "16.41", ",", "0.19", ",", "9.71", ",", "10.18", ",", "8.81", ",", 
    "2.93", ",", "18.11", ",", "22.2", ",", "9.79", ",", "14.74", ",", "4.54",
     ",", "16.76", ",", "8.46", ",", "24.9"}], "}"}]}]], "Input",
 CellLabel->"In[12]:=",
 CellID->827466675],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "7.05`", ",", "2.49`", ",", "16.09`", ",", "21.3`", ",", "19.21`", ",", 
   "14.88`", ",", "16.41`", ",", "0.19`", ",", "9.71`", ",", "10.18`", ",", 
   "8.81`", ",", "2.93`", ",", "18.11`", ",", "22.2`", ",", "9.79`", ",", 
   "14.74`", ",", "4.54`", ",", "16.76`", ",", "8.46`", ",", "24.9`"}], 
  "}"}]], "Output",
 ImageSize->{465, 33},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[12]=",
 CellID->861465440]
}, Open  ]],

Cell[TextData[{
 "\:041d\:043e\:0432\:0430\:044f \:0432\:044b\:0431\:043e\:0440\:043a\:0430 \
\:043c\:043e\:0436\:0435\:0442 \:0431\:044b\:0442\:044c \:0441\:043e\:0437\
\:0434\:0430\:043d\:0430 \:043f\:0443\:0442\:0435\:043c \:043f\:043e\:0434\
\:0441\:0442\:0430\:043d\:043e\:0432\:043a\:0438, \:043f\:0440\:0438 \:043f\
\:043e\:043c\:043e\:0449\:0438 \:0444\:0443\:043d\:043a\:0446\:0438\:0438  ",
 Cell[BoxData[
  ButtonBox["RandomChoice",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/RandomChoice"]], "InlineFormula"],
 ". \:041f\:0440\:0438\:043c\:0435\:043d\:0438\:0432 \:0432\:044b\:0440\:0430\
\:0436\:0435\:043d\:0438\:0435 ",
 Cell[BoxData[
  ButtonBox["Length",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Length"]], "InlineFormula"],
 Cell[BoxData[
  RowBox[{"[", "data", "]"}]], "InlineFormula"],
 " \:0432 \:043a\:0430\:0447\:0435\:0441\:0442\:0432\:0435 \:0432\:0442\:043e\
\:0440\:043e\:0433\:043e \:0430\:0440\:0433\:0443\:043c\:0435\:043d\:0442\
\:0430 \:0444\:0443\:043d\:043a\:0446\:0438\:0438 ",
 Cell[BoxData[
  ButtonBox["RandomChoice",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/RandomChoice"]], "InlineFormula"],
 ", \:043f\:043e\:043b\:0443\:0447\:0430\:0435\:043c \:043d\:043e\:0432\:0443\
\:044e \:0432\:044b\:0431\:043e\:0440\:043a\:0443 \:0442\:043e\:0433\:043e \
\:0436\:0435 \:0441\:0430\:043c\:043e\:0433\:043e \:0440\:0430\:0437\:043c\
\:0435\:0440\:0430, \:0447\:0442\:043e \:0438 \:0438\:0441\:0445\:043e\:0434\
\:043d\:044b\:0439 \:043d\:0430\:0431\:043e\:0440 \:0434\:0430\:043d\:043d\
\:044b\:0445:"
}], "HowToText",
 CellID->1389965763],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"smpl", "=", 
  RowBox[{"RandomChoice", "[", 
   RowBox[{"data", ",", 
    RowBox[{"Length", "[", "data", "]"}]}], "]"}]}]], "Input",
 CellLabel->"In[13]:=",
 CellID->411630083],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "2.93`", ",", "2.93`", ",", "10.18`", ",", "24.9`", ",", "4.54`", ",", 
   "9.71`", ",", "9.79`", ",", "22.2`", ",", "21.3`", ",", "14.74`", ",", 
   "14.74`", ",", "14.74`", ",", "16.76`", ",", "10.18`", ",", "18.11`", ",", 
   "22.2`", ",", "19.21`", ",", "22.2`", ",", "0.19`", ",", "2.49`"}], 
  "}"}]], "Output",
 ImageSize->{440, 33},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[13]=",
 CellID->72728370]
}, Open  ]],

Cell["\<\
\:041f\:0440\:0435\:0434\:043f\:043e\:043b\:0430\:0433\:0430\:044f, \:0447\
\:0442\:043e \:0438\:0441\:0445\:043e\:0434\:043d\:044b\:0439 \:043d\:0430\
\:0431\:043e\:0440 \:0434\:0430\:043d\:043d\:044b\:0445 \:044f\:0432\:043b\
\:044f\:0435\:0442\:0441\:044f \:0445\:0430\:0440\:0430\:043a\:0442\:0435\
\:0440\:043d\:044b\:043c \:0434\:043b\:044f \:0433\:0435\:043d\:0435\:0440\
\:0430\:043b\:044c\:043d\:043e\:0439 \:0441\:043e\:0432\:043e\:043a\:0443\
\:043f\:043d\:043e\:0441\:0442\:0438, \:043a\:043e\:0442\:043e\:0440\:0443\
\:044e \:043e\:043d \:043f\:0440\:0435\:0434\:0441\:0442\:0430\:0432\:043b\
\:044f\:0435\:0442, \:0437\:043d\:0430\:0447\:0435\:043d\:0438\:044f \:043d\
\:043e\:0432\:043e\:0439 \:0432\:044b\:0431\:043e\:0440\:043a\:0438 \:0434\
\:043e\:043b\:0436\:043d\:044b \:0432\:0435\:0441\:0442\:0438 \:0441\:0435\
\:0431\:044f \:0430\:043d\:0430\:043b\:043e\:0433\:0438\:0447\:043d\:043e \
\:0432\:044b\:0431\:043e\:0440\:043a\:0435 \:0438\:0437 \:0438\:0441\:0445\
\:043e\:0434\:043d\:043e\:0439 \:0441\:043e\:0432\:043e\:043a\:0443\:043f\
\:043d\:043e\:0441\:0442\:0438. \:0422\:0430\:043a\:0438\:043c \:043e\:0431\
\:0440\:0430\:0437\:043e\:043c, \:0441\:0442\:0430\:0442\:0438\:0441\:0442\
\:0438\:0447\:0435\:0441\:043a\:0438\:0435 \:043f\:043e\:043a\:0430\:0437\
\:0430\:0442\:0435\:043b\:0438 \:043a\:043e\:043c\:0431\:0438\:043d\:0430\
\:0446\:0438\:0438 \:0438\:0437 \:0438\:0441\:0445\:043e\:0434\:043d\:043e\
\:0433\:043e \:043d\:0430\:0431\:043e\:0440\:0430 \:0434\:0430\:043d\:043d\
\:044b\:0445 \:0434\:043e\:043b\:0436\:043d\:044b \:043f\:043e\:0445\:043e\
\:0434\:0438\:0442\:044c \:043d\:0430 \:043e\:0431\:0440\:0430\:0437\:0446\
\:043e\:0432\:044b\:0435 \:0441\:0442\:0430\:0442\:0438\:0441\:0442\:0438\
\:0447\:0435\:0441\:043a\:0438\:0435 \:043f\:043e\:043a\:0430\:0437\:0430\
\:0442\:0435\:043b\:0438 \:0433\:0435\:043d\:0435\:0440\:0430\:043b\:044c\
\:043d\:043e\:0439 \:0441\:043e\:0432\:043e\:043a\:0443\:043f\:043d\:043e\
\:0441\:0442\:0438. \
\>", "HowToText",
 CellID->17352728],

Cell[TextData[{
 "\:0412\:043e\:0441\:043f\:043e\:043b\:044c\:0437\:0443\:0435\:043c\:0441\
\:044f \:0444\:0443\:043d\:043a\:0446\:0438\:0435\:0439 ",
 Cell[BoxData[
  ButtonBox["Skewness",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Skewness"]], "InlineFormula"],
 " \:0434\:043b\:044f \:0432\:044b\:0447\:0438\:0441\:043b\:0435\:043d\:0438\
\:044f \:0430\:0441\:0438\:043c\:043c\:0435\:0442\:0440\:0438\:0438 \:0438\
\:0441\:0445\:043e\:0434\:043d\:044b\:0445 \:0434\:0430\:043d\:043d\:044b\
\:0445:"
}], "HowToText",
 CellID->812217608],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Skewness", "[", "data", "]"}]], "Input",
 CellLabel->"In[14]:=",
 CellID->1398028897],

Cell[BoxData[
 RowBox[{"-", "0.03331542185499268`"}]], "Output",
 ImageSize->{75, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[14]=",
 CellID->592279068]
}, Open  ]],

Cell["\:0420\:0430\:0441\:0441\:0447\:0438\:0442\:0430\:0435\:043c \:0430\
\:0441\:0438\:043c\:043c\:0435\:0442\:0440\:0438\:044e \:0437\:0430\:043d\
\:043e\:0432\:043e \:043f\:043e\:0434\:043e\:0431\:0440\:0430\:043d\:043d\
\:044b\:0445 \:0434\:0430\:043d\:043d\:044b\:0445:", "HowToText",
 CellID->239873537],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Skewness", "[", "smpl", "]"}]], "Input",
 CellLabel->"In[15]:=",
 CellID->17381088],

Cell[BoxData[
 RowBox[{"-", "0.19571977979837865`"}]], "Output",
 ImageSize->{61, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[15]=",
 CellID->536358353]
}, Open  ]],

Cell["\<\
\:041f\:0443\:0442\:0435\:043c \:043c\:043d\:043e\:0433\:043e\:043a\:0440\
\:0430\:0442\:043d\:043e\:0433\:043e \:043f\:043e\:0434\:0431\:043e\:0440\
\:0430 \:0438\:0437 \:0438\:0441\:0445\:043e\:0434\:043d\:043e\:0433\:043e \
\:043d\:0430\:0431\:043e\:0440\:0430 \:0434\:0430\:043d\:043d\:044b\:0445, \
\:0441 \:0432\:044b\:0447\:0438\:0441\:043b\:0435\:043d\:0438\:0435\:043c \
\:0430\:0441\:0438\:043c\:043c\:0435\:0442\:0440\:0438\:0438 \:0434\:043b\
\:044f \:043a\:0430\:0436\:0434\:043e\:0439 \:043a\:043e\:043c\:0431\:0438\
\:043d\:0430\:0446\:0438\:0438, \:043c\:043e\:0436\:043d\:043e \:043d\:0430\
\:0439\:0442\:0438 \:0432\:044b\:0431\:043e\:0440\:043e\:0447\:043d\:044b\
\:0435 \:0440\:0430\:0441\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\
\:0438\:044f \:0431\:043b\:0438\:0437\:043a\:043e \:0440\:0430\:0441\:043f\
\:043e\:043b\:043e\:0436\:0435\:043d\:043d\:044b\:0435 \:043a \:0438\:0441\
\:0445\:043e\:0434\:043d\:043e\:043c\:0443 \:043f\:043e \:043f\:043e\:043a\
\:0430\:0437\:0430\:0442\:0435\:043b\:044e \:0430\:0441\:0438\:043c\:043c\
\:0435\:0442\:0440\:0438\:0438. \
\>", "HowToText",
 CellID->83196217],

Cell[TextData[{
 "\:0417\:0434\:0435\:0441\:044c, \:0444\:0443\:043d\:043a\:0446\:0438\:044f ",
 Cell[BoxData[
  ButtonBox["Table",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Table"]], "InlineFormula"],
 " \:0438\:0441\:043f\:043e\:043b\:044c\:0437\:043e\:0432\:0430\:043d\:0430 \
\:0434\:043b\:044f \:043c\:043d\:043e\:0433\:043e\:043a\:0440\:0430\:0442\
\:043d\:043e\:0433\:043e \:0432\:044b\:0447\:0438\:0441\:043b\:0435\:043d\
\:0438\:044f \:043f\:043e\:043a\:0430\:0437\:0430\:0442\:0435\:043b\:0435\
\:0439 \:0430\:0441\:0438\:043c\:043c\:0435\:0442\:0440\:0438\:0438 1000 \
\:0432\:0442\:043e\:0440\:0438\:0447\:043d\:043e \:043f\:043e\:0434\:043e\
\:0431\:0440\:0430\:043d\:043d\:044b\:0445 \:043d\:0430\:0431\:043e\:0440\
\:043e\:0432 \:0434\:0430\:043d\:043d\:044b\:0445:"
}], "HowToText",
 CellID->758291895],

Cell[BoxData[
 RowBox[{
  RowBox[{"skews", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Skewness", "[", 
      RowBox[{"RandomChoice", "[", 
       RowBox[{"data", ",", 
        RowBox[{"Length", "[", "data", "]"}]}], "]"}], "]"}], ",", 
     RowBox[{"{", "1000", "}"}]}], "]"}]}], ";"}]], "Input",
 CellLabel->"In[16]:=",
 CellID->734056247],

Cell[TextData[{
 "\:0412\:043e\:0441\:043f\:043e\:043b\:044c\:0437\:0443\:0435\:043c\:0441\
\:044f \:0444\:0443\:043d\:043a\:0446\:0438\:0435\:0439 ",
 Cell[BoxData[
  ButtonBox["Histogram",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Histogram"]], "InlineFormula"],
 " \:0434\:043b\:044f \:0432\:0438\:0437\:0443\:0430\:043b\:0438\:0437\:0430\
\:0446\:0438\:0438 \:0432\:044b\:0431\:043e\:0440\:043e\:0447\:043d\:043e\
\:0433\:043e \:0440\:0430\:0441\:043f\:0440\:0435\:0434\:0435\:043b\:0435\
\:043d\:0438\:044f \:043f\:043e\:043a\:0430\:0437\:0430\:0442\:0435\:043b\
\:044f \:0430\:0441\:0438\:043c\:043c\:0435\:0442\:0440\:0438\:0438 \:0438\
\:0437 1000 \:0432\:0442\:043e\:0440\:0438\:0447\:043d\:043e \:043f\:043e\
\:0434\:043e\:0431\:0440\:0430\:043d\:043d\:044b\:0445 \:043d\:0430\:0431\
\:043e\:0440\:043e\:0432 \:0434\:0430\:043d\:043d\:044b\:0445:"
}], "HowToText",
 CellID->416325809],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Histogram", "[", "skews", "]"}]], "Input",
 CellLabel->"In[17]:=",
 CellID->254378789],

Cell[BoxData[
 GraphicsBox[
  {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
   EdgeForm[Opacity[0.7]], {}, 
   {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
    EdgeForm[Opacity[0.7]], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{
           Rational[-6, 5], 0}, {
           Rational[-11, 10], 2}]},
        ImageSizeCache->{{17.5, 25.522727272727266`}, {36.77882129415928, 
         39.07554816314748}}],
       StatusArea[#, 2]& ,
       TagBoxNote->"2"],
      StyleBox["2", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[2, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{
           Rational[-11, 10], 0}, {-1, 1}]},
        ImageSizeCache->{{24.522727272727266`, 32.54545454545455}, {
         37.42718472865338, 39.07554816314748}}],
       StatusArea[#, 1]& ,
       TagBoxNote->"1"],
      StyleBox["1", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[1, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{-1, 0}, {
           Rational[-9, 10], 4}]},
        ImageSizeCache->{{31.545454545454547`, 39.56818181818182}, {
         35.48209442517107, 39.07554816314748}}],
       StatusArea[#, 4]& ,
       TagBoxNote->"4"],
      StyleBox["4", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[4, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{
           Rational[-9, 10], 0}, {
           Rational[-4, 5], 7}]},
        ImageSizeCache->{{38.56818181818182, 46.590909090909086`}, {
         33.53700412168876, 39.07554816314748}}],
       StatusArea[#, 7]& ,
       TagBoxNote->"7"],
      StyleBox["7", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[7, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{
           Rational[-4, 5], 0}, {
           Rational[-7, 10], 16}]},
        ImageSizeCache->{{45.590909090909086`, 53.61363636363637}, {
         27.701733211241837`, 39.07554816314748}}],
       StatusArea[#, 16]& ,
       TagBoxNote->"16"],
      StyleBox["16", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[16, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{
           Rational[-7, 10], 0}, {
           Rational[-3, 5], 25}]},
        ImageSizeCache->{{52.61363636363637, 60.63636363636363}, {
         21.866462300794915`, 39.07554816314748}}],
       StatusArea[#, 25]& ,
       TagBoxNote->"25"],
      StyleBox["25", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[25, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{
           Rational[-3, 5], 0}, {
           Rational[-1, 2], 42}]},
        ImageSizeCache->{{59.63636363636363, 67.6590909090909}, {
         10.84428391439517, 39.07554816314748}}],
       StatusArea[#, 42]& ,
       TagBoxNote->"42"],
      StyleBox["42", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[42, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{
           Rational[-1, 2], 0}, {
           Rational[-2, 5], 59}]},
        ImageSizeCache->{{66.6590909090909, 
         74.68181818181817}, {-0.1778944720045743, 39.07554816314748}}],
       StatusArea[#, 59]& ,
       TagBoxNote->"59"],
      StyleBox["59", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[59, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{
           Rational[-2, 5], 0}, {
           Rational[-3, 10], 74}]},
        ImageSizeCache->{{73.68181818181817, 
         81.70454545454545}, {-9.90334598941611, 39.07554816314748}}],
       StatusArea[#, 74]& ,
       TagBoxNote->"74"],
      StyleBox["74", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[74, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{
           Rational[-3, 10], 0}, {
           Rational[-1, 5], 101}]},
        ImageSizeCache->{{80.70454545454545, 
         88.72727272727272}, {-27.409158720756885`, 39.07554816314748}}],
       StatusArea[#, 101]& ,
       TagBoxNote->"101"],
      StyleBox["101", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[101, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{
           Rational[-1, 5], 0}, {
           Rational[-1, 10], 117}]},
        ImageSizeCache->{{87.72727272727272, 95.75}, {-37.78297367266253, 
         39.07554816314748}}],
       StatusArea[#, 117]& ,
       TagBoxNote->"117"],
      StyleBox["117", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[117, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{
           Rational[-1, 10], 0}, {0, 135}]},
        ImageSizeCache->{{94.75, 102.77272727272727`}, {-49.453515493556374`, 
         39.07554816314748}}],
       StatusArea[#, 135]& ,
       TagBoxNote->"135"],
      StyleBox["135", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[135, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{0, 0}, {
           Rational[1, 10], 127}]},
        ImageSizeCache->{{101.77272727272727`, 
         109.79545454545453`}, {-44.26660801760355, 39.07554816314748}}],
       StatusArea[#, 127]& ,
       TagBoxNote->"127"],
      StyleBox["127", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[127, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{
           Rational[1, 10], 0}, {
           Rational[1, 5], 87}]},
        ImageSizeCache->{{108.79545454545453`, 
         116.81818181818181`}, {-18.332070637839443`, 39.07554816314748}}],
       StatusArea[#, 87]& ,
       TagBoxNote->"87"],
      StyleBox["87", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[87, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{
           Rational[1, 5], 0}, {
           Rational[3, 10], 72}]},
        ImageSizeCache->{{115.81818181818181`, 
         123.84090909090908`}, {-8.606619120427908, 39.07554816314748}}],
       StatusArea[#, 72]& ,
       TagBoxNote->"72"],
      StyleBox["72", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[72, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{
           Rational[3, 10], 0}, {
           Rational[2, 5], 61}]},
        ImageSizeCache->{{122.84090909090908`, 
         130.86363636363635`}, {-1.4746213409927762`, 39.07554816314748}}],
       StatusArea[#, 61]& ,
       TagBoxNote->"61"],
      StyleBox["61", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[61, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{
           Rational[2, 5], 0}, {
           Rational[1, 2], 25}]},
        ImageSizeCache->{{129.86363636363635`, 137.88636363636363`}, {
         21.866462300794915`, 39.07554816314748}}],
       StatusArea[#, 25]& ,
       TagBoxNote->"25"],
      StyleBox["25", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[25, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{
           Rational[1, 2], 0}, {
           Rational[3, 5], 18}]},
        ImageSizeCache->{{136.88636363636363`, 144.9090909090909}, {
         26.405006342253635`, 39.07554816314748}}],
       StatusArea[#, 18]& ,
       TagBoxNote->"18"],
      StyleBox["18", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[18, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{
           Rational[3, 5], 0}, {
           Rational[7, 10], 17}]},
        ImageSizeCache->{{143.9090909090909, 151.93181818181816`}, {
         27.053369776747736`, 39.07554816314748}}],
       StatusArea[#, 17]& ,
       TagBoxNote->"17"],
      StyleBox["17", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[17, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{
           Rational[7, 10], 0}, {
           Rational[4, 5], 3}]},
        ImageSizeCache->{{150.93181818181816`, 158.95454545454544`}, {
         36.13045785966517, 39.07554816314748}}],
       StatusArea[#, 3]& ,
       TagBoxNote->"3"],
      StyleBox["3", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[3, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{
           Rational[4, 5], 0}, {
           Rational[9, 10], 5}]},
        ImageSizeCache->{{157.95454545454544`, 165.97727272727272`}, {
         34.83373099067697, 39.07554816314748}}],
       StatusArea[#, 5]& ,
       TagBoxNote->"5"],
      StyleBox["5", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[5, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{
           Rational[9, 10], 0}, {1, 2}]},
        ImageSizeCache->{{164.97727272727272`, 173.}, {36.77882129415928, 
         39.07554816314748}}],
       StatusArea[#, 2]& ,
       TagBoxNote->"2"],
      StyleBox["2", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[2, {
        GrayLevel[0]}], "Tooltip"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesOrigin->NCache[{
     Rational[-6, 5], 0}, {-1.2, 0}],
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  PlotRange->NCache[{{
      Rational[-6, 5], 1}, {All, All}}, {{-1.2, 1}, {All, All}}],
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.1]}},
  Ticks->{Automatic, Automatic}]], "Output",
 ImageSize->{184, 114},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[17]=",
 CellID->185267540]
}, Open  ]],

Cell["\<\
\:0421\:043f\:0438\:0441\:043e\:043a \:0432\:0442\:043e\:0440\:0438\:0447\
\:043d\:043e \:043f\:043e\:0434\:043e\:0431\:0440\:0430\:043d\:043d\:044b\
\:0445 \:0437\:043d\:0430\:0447\:0435\:043d\:0438\:0439 \:043e\:0431\:0435\
\:0441\:043f\:0435\:0447\:0438\:0432\:0430\:0435\:0442 \:043f\:0440\:043e\
\:0441\:0442\:0440\:0430\:043d\:0441\:0442\:0432\:043e \:0432\:044b\:0431\
\:043e\:0440\:043a\:0438 \:0434\:043b\:044f \:0434\:0430\:043b\:044c\:043d\
\:0435\:0439\:0448\:0438\:0445 \:043e\:0446\:0435\:043d\:043e\:043a, \:0432 \
\:0434\:0430\:043d\:043d\:043e\:043c \:0441\:043b\:0443\:0447\:0430\:0435 \
\:043f\:043e \:043f\:043e\:043a\:0430\:0437\:0430\:0442\:0435\:043b\:044e \
\:0430\:0441\:0438\:043c\:043c\:0435\:0442\:0440\:0438\:0438, \:043f\:0440\
\:0435\:0434\:043e\:0441\:0442\:0430\:0432\:043b\:044f\:044e\:0449\:0435\:0435\
 \:0432\:043e\:0437\:043c\:043e\:0436\:043d\:043e\:0441\:0442\:044c \:0440\
\:0430\:0441\:0441\:0447\:0438\:0442\:0430\:0442\:044c \:0434\:043e\:043f\
\:043e\:043b\:043d\:0438\:0442\:0435\:043b\:044c\:043d\:044b\:0435 \:0441\
\:0442\:0430\:0442\:0438\:0441\:0442\:0438\:0447\:0435\:0441\:043a\:0438\:0435\
 \:043f\:043e\:043a\:0430\:0437\:0430\:0442\:0435\:043b\:0438.\
\>", "HowToText",
 CellID->342435841],

Cell["\<\
\:0420\:0430\:0441\:0441\:0447\:0438\:0442\:0430\:0435\:043c \:0441\:0442\
\:0430\:043d\:0434\:0430\:0440\:0442\:043d\:0443\:044e \:043e\:0448\:0438\
\:0431\:043a\:0443 \:0432 \:043e\:0446\:0435\:043d\:043a\:0435 \:0430\:0441\
\:0438\:043c\:043c\:0435\:0442\:0440\:0438\:0438. \:0421\:0442\:0430\:043d\
\:0434\:0430\:0440\:0442\:043d\:043e\:0435 \:043e\:0442\:043a\:043b\:043e\
\:043d\:0435\:043d\:0438\:0435 \:043e\:0446\:0435\:043d\:043e\:043a \:044f\
\:0432\:043b\:044f\:0435\:0442\:0441\:044f \:0441\:0442\:0430\:043d\:0434\
\:0430\:0440\:0442\:043d\:043e\:0439 \:043e\:0448\:0438\:0431\:043a\:043e\
\:0439:\
\>", "HowToText",
 CellID->378342759],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StandardDeviation", "[", "skews", "]"}]], "Input",
 CellLabel->"In[18]:=",
 CellID->335677854],

Cell[BoxData["0.33086779646776887`"], "Output",
 ImageSize->{60, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[18]=",
 CellID->846291685]
}, Open  ]],

Cell[TextData[{
 "\:0418\:0441\:043f\:043e\:043b\:044c\:0437\:0443\:0435\:043c \:0444\:0443\
\:043d\:043a\:0446\:0438\:044e ",
 Cell[BoxData[
  ButtonBox["Quantile",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Quantile"]], "InlineFormula"],
 " \:0434\:043b\:044f \:043f\:043e\:043b\:0443\:0447\:0435\:043d\:0438\:044f \
95% \:0434\:043e\:0432\:0435\:0440\:0438\:0442\:0435\:043b\:044c\:043d\:043e\
\:0433\:043e \:0438\:043d\:0442\:0435\:0440\:0432\:0430\:043b\:0430 \:0434\
\:043b\:044f \:0432\:044b\:0431\:043e\:0440\:043e\:0447\:043d\:043e\:0439 \
\:0430\:0441\:0438\:043c\:043c\:0435\:0442\:0440\:0438\:0438:"
}], "HowToText",
 CellID->585167324],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Quantile", "[", 
  RowBox[{"skews", ",", 
   RowBox[{"{", 
    RowBox[{".025", ",", ".975"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[19]:=",
 CellID->106458678],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.7267817526967469`"}], ",", "0.6119358349577512`"}], 
  "}"}]], "Output",
 ImageSize->{149, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[19]=",
 CellID->394067]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\t", "HowToDelimiter",
 Editable->False,
 CellID->1871769037],

Cell["\<\
\:042d\:0442\:043e\:0442 \:043c\:0435\:0442\:043e\:0434 \:0434\:0430\:0435\
\:0442 \:0432\:043e\:0437\:043c\:043e\:0436\:043d\:043e\:0441\:0442\:044c \"\
\:0432\:044b\:0442\:044f\:043d\:0443\:0442\:044c\" \:0438 \:0431\:043e\:043b\
\:0435\:0435 \:0441\:043b\:043e\:0436\:043d\:044b\:0435 \:0440\:0435\:0437\
\:0443\:043b\:044c\:0442\:0430\:0442\:044b, \:0442\:0430\:043a\:0438\:0435 \
\:043a\:0430\:043a \:043e\:0446\:0435\:043d\:043a\:0438 \:043f\:0430\:0440\
\:0430\:043c\:0435\:0442\:0440\:043e\:0432 \:0432 \:043f\:043e\:0441\:0442\
\:0440\:043e\:0435\:043d\:0438\:0438 \:043c\:0435\:0442\:043e\:0434\:043e\
\:043c \:043c\:0430\:043a\:0441\:0438\:043c\:0430\:043b\:044c\:043d\:043e\
\:0433\:043e \:043f\:0440\:0430\:0432\:0434\:043e\:043f\:043e\:0434\:043e\
\:0431\:0438\:044f.\
\>", "HowToText",
 CellID->334259956],

Cell["\<\
\:0421\:0433\:0435\:043d\:0435\:0440\:0438\:0440\:0443\:0435\:043c \:043d\
\:0435\:043a\:043e\:0442\:043e\:0440\:043e\:0435 \:043a\:043e\:043b\:0438\
\:0447\:0435\:0441\:0442\:0432\:043e \:0442\:043e\:0447\:0435\:043a \:0438\
\:0437 \:0433\:0430\:043c\:043c\:0430-\:0440\:0430\:0441\:043f\:0440\:0435\
\:0434\:0435\:043b\:0435\:043d\:0438\:044f \:0438 \:043e\:0442\:043e\:0431\
\:0440\:0430\:0437\:0438\:043c \:044d\:0442\:0438 \:0434\:0430\:043d\:043d\
\:044b\:0435 \:043d\:0430 \:0433\:0438\:0441\:0442\:043e\:0433\:0440\:0430\
\:043c\:043c\:0435:\
\>", "HowToText",
 CellID->1445501569],

Cell[BoxData[
 RowBox[{
  RowBox[{"gdata", "=", 
   RowBox[{"BlockRandom", "[", 
    RowBox[{
     RowBox[{"SeedRandom", "[", "1", "]"}], ";", 
     RowBox[{"RandomVariate", "[", 
      RowBox[{
       RowBox[{"GammaDistribution", "[", 
        RowBox[{"2", ",", "3"}], "]"}], ",", "100"}], "]"}]}], "]"}]}], 
  ";"}]], "Input",
 CellLabel->"In[20]:=",
 CellID->89859940],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Histogram", "[", "gdata", "]"}]], "Input",
 CellLabel->"In[21]:=",
 CellID->170354028],

Cell[BoxData[
 GraphicsBox[
  {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
   EdgeForm[Opacity[0.7]], {}, 
   {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
    EdgeForm[Opacity[0.7]], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{0, 0}, {5, 40}]},
        ImageSizeCache->{{12.5, 40.33333333333333}, {-44.671460828735285`, 
         41.176461192664995`}}],
       StatusArea[#, 40]& ,
       TagBoxNote->"40"],
      StyleBox["40", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[40, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{5, 0}, {10, 43}]},
        ImageSizeCache->{{39.33333333333333, 
         67.16666666666666}, {-51.0350549803403, 41.176461192664995`}}],
       StatusArea[#, 43]& ,
       TagBoxNote->"43"],
      StyleBox["43", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[43, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{10, 0}, {15, 11}]},
        ImageSizeCache->{{66.16666666666666, 94.}, {16.843282636779918`, 
         41.176461192664995`}}],
       StatusArea[#, 11]& ,
       TagBoxNote->"11"],
      StyleBox["11", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[11, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{15, 0}, {20, 2}]},
        ImageSizeCache->{{93., 120.83333333333333`}, {35.93406509159498, 
         41.176461192664995`}}],
       StatusArea[#, 2]& ,
       TagBoxNote->"2"],
      StyleBox["2", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[2, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{20, 0}, {25, 2}]},
        ImageSizeCache->{{119.83333333333333`, 147.66666666666666`}, {
         35.93406509159498, 41.176461192664995`}}],
       StatusArea[#, 2]& ,
       TagBoxNote->"2"],
      StyleBox["2", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[2, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{25, 0}, {30, 2}]},
        ImageSizeCache->{{146.66666666666666`, 174.5}, {35.93406509159498, 
         41.176461192664995`}}],
       StatusArea[#, 2]& ,
       TagBoxNote->"2"],
      StyleBox["2", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[2, {
        GrayLevel[0]}], "Tooltip"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesOrigin->{0, 0},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  PlotRange->{{0, 30}, {All, All}},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.1]}},
  Ticks->{Automatic, Automatic}]], "Output",
 ImageSize->{184, 118},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[21]=",
 CellID->443135780]
}, Open  ]],

Cell[TextData[{
 "\:0427\:0430\:0441\:0442\:043e \:0431\:044b\:0432\:0430\:0435\:0442 \:043f\
\:043e\:043b\:0435\:0437\:043d\:043e \:043f\:043e\:043b\:0443\:0447\:0438\
\:0442\:044c \:043e\:0446\:0435\:043d\:043a\:0443 \:043f\:0430\:0440\:0430\
\:043c\:0435\:0442\:0440\:043e\:0432 \:0438\:0437 \:043d\:0430\:0431\:043e\
\:0440\:0430 \:0434\:0430\:043d\:043d\:044b\:0445, \:043f\:0440\:0438 \:0443\
\:0441\:043b\:043e\:0432\:0438\:0438, \:0447\:0442\:043e \:043e\:043d \:0441\
\:043e\:043e\:0442\:0432\:0435\:0442\:0441\:0442\:0432\:0443\:0435\:0442 \
\:0437\:0430\:0434\:0430\:043d\:043d\:043e\:043c\:0443 \:0440\:0430\:0441\
\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\:0438\:044e. \:041d\:0430\
\:043f\:0440\:0438\:043c\:0435\:0440, \:043c\:043e\:0436\:043d\:043e \:0432\
\:043e\:0441\:043f\:043e\:043b\:044c\:0437\:043e\:0432\:0430\:0442\:044c\:0441\
\:044f \:043c\:0435\:0442\:043e\:0434\:043e\:043c \:043c\:0430\:043a\:0441\
\:0438\:043c\:0430\:043b\:044c\:043d\:043e\:0433\:043e \:043f\:0440\:0430\
\:0432\:0434\:043e\:043f\:043e\:0434\:043e\:0431\:0438\:044f \:043f\:0440\
\:0438 \:043e\:0446\:0435\:043d\:043a\:0435 ",
 StyleBox["\[Alpha]", "InlineMath"],
 " \:0438 ",
 StyleBox["\[Beta]", "InlineMath"],
 " \:043f\:0430\:0440\:0430\:043c\:0435\:0442\:0440\:043e\:0432 \:0434\:043b\
\:044f \:0434\:0430\:043d\:043d\:044b\:0445, \:043f\:043e\:043b\:0443\:0447\
\:0435\:043d\:043d\:044b\:0445 \:0438\:0437 \:0433\:0430\:043c\:043c\:0430-\
\:0440\:0430\:0441\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\:0438\:044f\
. "
}], "HowToText",
 CellID->62371672],

Cell[TextData[{
 "\:041c\:043e\:0436\:043d\:043e \:043f\:043e\:043b\:0443\:0447\:0438\:0442\
\:044c \:043b\:043e\:0433\:0430\:0440\:0438\:0444\:043c\:0438\:0447\:0435\
\:0441\:043a\:0443\:044e \:0444\:0443\:043d\:043a\:0446\:0438\:044e \:043f\
\:0440\:0430\:0432\:0434\:043e\:043f\:043e\:0434\:043e\:0431\:0438\:044f \
\:0434\:043b\:044f \:0432\:0441\:0435\:0433\:043e \:043d\:0430\:0431\:043e\
\:0440\:0430 \:0434\:0430\:043d\:043d\:044b\:0445, \:043f\:0440\:0438 \:043f\
\:043e\:043c\:043e\:0449\:0438 \:043a\:043e\:043c\:0430\:043d\:0434\:044b ",
 Cell[BoxData[
  ButtonBox["FindDistributionParameters",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/FindDistributionParameters"]], "InlineFormula"],
 ":"
}], "HowToText",
 CellID->730828722],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FindDistributionParameters", "[", 
  RowBox[{"gdata", ",", 
   RowBox[{"GammaDistribution", "[", 
    RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}]}], "]"}]], "Input",
 CellLabel->"In[22]:=",
 CellID->57108537],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Alpha]", "\[Rule]", "1.944475784649344`"}], ",", 
   RowBox[{"\[Beta]", "\[Rule]", "3.5626405864336754`"}]}], "}"}]], "Output",
 ImageSize->{175, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[22]=",
 CellID->226209441]
}, Open  ]],

Cell[TextData[{
 "\:0422\:0435\:043f\:0435\:0440\:044c, \:043f\:0443\:0442\:0435\:043c \:0432\
\:0442\:043e\:0440\:0438\:0447\:043d\:043e\:0433\:043e \:043f\:043e\:0434\
\:0431\:043e\:0440\:0430 \:0437\:043d\:0430\:0447\:0435\:043d\:0438\:0439 \
\:043d\:0430 \:043e\:0441\:043d\:043e\:0432\:0435 \:0438\:0441\:0445\:043e\
\:0434\:043d\:043e\:0433\:043e \:043d\:0430\:0431\:043e\:0440\:0430 \:0434\
\:0430\:043d\:043d\:044b\:0445, \:043c\:043e\:0436\:043d\:043e \:0441\:043e\
\:0437\:0434\:0430\:0432\:0430\:0442\:044c \:043d\:043e\:0432\:044b\:0435 \
\:0441\:0442\:0430\:0442\:0438\:0441\:0442\:0438\:0447\:0435\:0441\:043a\:0438\
\:0435 \:0434\:0430\:043d\:043d\:044b\:0435 \:0434\:043b\:044f \:043e\:0446\
\:0435\:043d\:043a\:0438 \:043f\:0430\:0440\:0430\:043c\:0435\:0442\:0440\
\:043e\:0432. \:042d\:0442\:043e \:0440\:0435\:0430\:043b\:0438\:0437\:0443\
\:0435\:0442\:0441\:044f \:043f\:0440\:0438 \:043f\:043e\:043c\:043e\:0449\
\:0438 \:0444\:0443\:043d\:043a\:0446\:0438\:0438 ",
 Cell[BoxData[
  ButtonBox["RandomChoice",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/RandomChoice"]], "InlineFormula"],
 ":"
}], "HowToText",
 CellID->224490222],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FindDistributionParameters", "[", 
  RowBox[{
   RowBox[{"RandomChoice", "[", 
    RowBox[{"gdata", ",", 
     RowBox[{"Length", "[", "gdata", "]"}]}], "]"}], ",", 
   RowBox[{"GammaDistribution", "[", 
    RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}]}], "]"}]], "Input",
 CellLabel->"In[23]:=",
 CellID->175330848],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Alpha]", "\[Rule]", "1.8801526620805697`"}], ",", 
   RowBox[{"\[Beta]", "\[Rule]", "3.7343575394824966`"}]}], "}"}]], "Output",
 ImageSize->{175, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[23]=",
 CellID->615614222]
}, Open  ]],

Cell[TextData[{
 "\:041f\:0440\:0438\:0441\:0432\:043e\:0438\:043c \:044d\:0442\:043e\:043c\
\:0443 \:0432\:044b\:0447\:0438\:0441\:043b\:0435\:043d\:0438\:044e \:0438\
\:043c\:044f ",
 Cell[BoxData["params"], "InlineFormula"],
 ":"
}], "HowToText",
 CellID->1496668379],

Cell[BoxData[
 RowBox[{"params", ":=", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\[Alpha]", ",", "\[Beta]"}], "}"}], "/.", 
   RowBox[{"FindDistributionParameters", "[", 
    RowBox[{
     RowBox[{"RandomChoice", "[", 
      RowBox[{"gdata", ",", 
       RowBox[{"Length", "[", "gdata", "]"}]}], "]"}], ",", 
     RowBox[{"GammaDistribution", "[", 
      RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}]}], "]"}]}]}]], "Input",
 CellLabel->"In[24]:=",
 CellID->36763837],

Cell[TextData[{
 "\:041c\:043e\:0436\:043d\:043e \:043c\:043d\:043e\:0433\:043e\:043a\:0440\
\:0430\:0442\:043d\:043e \:0432\:044b\:0447\:0438\:0441\:043b\:044f\:0442\
\:044c ",
 Cell[BoxData["params"], "InlineFormula"],
 " \:0434\:043b\:044f \:0433\:0435\:043d\:0435\:0440\:0438\:0440\:043e\:0432\
\:0430\:043d\:0438\:044f \:043c\:043d\:043e\:0433\:043e\:0447\:0438\:0441\
\:043b\:0435\:043d\:043d\:044b\:0445 \:043e\:0446\:0435\:043d\:043e\:043a \
\:043f\:0430\:0440\:0430\:043c\:0435\:0442\:0440\:043e\:0432 ",
 StyleBox["\[Alpha]", "InlineMath"],
 " \:0438 ",
 StyleBox["\[Beta]", "InlineMath"],
 ", \:0441\:043e\:0437\:0434\:0430\:0432\:0430\:044f, \
\:0442\:0430\:043a\:0438\:043c \:043e\:0431\:0440\:0430\:0437\:043e\:043c, \
\:0432\:044b\:0431\:043e\:0440\:043e\:0447\:043d\:043e\:0435 \:043f\:0440\
\:043e\:0441\:0442\:0440\:0430\:043d\:0441\:0442\:0432\:043e \:043f\:0430\
\:0440\:0430\:043c\:0435\:0442\:0440\:043e\:0432."
}], "HowToText",
 CellID->338181515],

Cell[TextData[{
 "\:0412\:043e\:0441\:043f\:043e\:043b\:044c\:0437\:0443\:0435\:043c\:0441\
\:044f \:0444\:0443\:043d\:043a\:0446\:0438\:0435\:0439 ",
 Cell[BoxData[
  ButtonBox["Table",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Table"]], "InlineFormula"],
 " \:0441 \:0430\:0440\:0433\:0443\:043c\:0435\:043d\:0442\:043e\:043c ",
 Cell[BoxData["params"], "InlineFormula"],
 ", \:0447\:0442\:043e\:0431\:044b \:0441\:0433\:0435\:043d\:0435\:0440\:0438\
\:0440\:043e\:0432\:0430\:0442\:044c 100 \:043e\:0446\:0435\:043d\:043e\:043a \
\:0434\:043b\:044f ",
 StyleBox["\[Alpha]", "InlineMath"],
 " \:0438 ",
 StyleBox["\[Beta]", "InlineMath"],
 ":"
}], "HowToText",
 CellID->26535765],

Cell[BoxData[
 RowBox[{
  RowBox[{"ests", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"params", ",", 
     RowBox[{"{", "100", "}"}]}], "]"}]}], ";"}]], "Input",
 CellLabel->"In[25]:=",
 CellID->63168641],

Cell["\<\
\:0427\:0442\:043e\:0431\:044b \:043f\:043e\:043b\:0443\:0447\:0438\:0442\
\:044c \:043e\:0446\:0435\:043d\:043a\:0443 \:0437\:043d\:0430\:0447\:0435\
\:043d\:0438\:0439 \:043f\:0430\:0440\:0430\:043c\:0435\:0442\:0440\:043e\
\:0432, \:043f\:043e\:043b\:0443\:0447\:0435\:043d\:043d\:044b\:0445 \:0431\
\:0443\:0442\:0441\:0442\:0440\:0435\:043f\:043f\:0438\:043d\:0433\:043e\:043c\
, \:0432\:043e\:0437\:044c\:043c\:0435\:043c \:0441\:0440\:0435\:0434\:043d\
\:0435\:0435 \:043e\:0442 \:043f\:043e\:043b\:0443\:0447\:0435\:043d\:043d\
\:043e\:0433\:043e \:043d\:0430\:0431\:043e\:0440\:0430 \:043e\:0446\:0435\
\:043d\:043e\:043a:\
\>", "HowToText",
 CellID->252119581],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Mean", "[", "ests", "]"}]], "Input",
 CellLabel->"In[26]:=",
 CellID->47499536],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2.019502617065987`", ",", "3.478461778473882`"}], "}"}]], "Output",
 ImageSize->{120, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[26]=",
 CellID->446016353]
}, Open  ]],

Cell[TextData[{
 "\:0414\:043b\:044f \:043e\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\
\:0438\:044f \:0437\:0430\:0432\:0438\:0441\:0438\:043c\:043e\:0441\:0442\
\:0438 \:043c\:0435\:0436\:0434\:0443 \:043e\:0446\:0435\:043d\:043a\:0430\
\:043c\:0438 ",
 StyleBox["\[Alpha]", "InlineMath"],
 " \:0438 ",
 StyleBox["\[Beta]", "InlineMath"],
 ", \:043c\:043e\:0436\:043d\:043e \:0432\:044b\:0447\:0438\:0441\:043b\:0438\
\:0442\:044c \:043a\:043e\:0440\:0440\:0435\:043b\:044f\:0446\:0438\:043e\
\:043d\:043d\:0443\:044e \:043c\:0430\:0442\:0440\:0438\:0446\:0443: "
}], "HowToText",
 CellID->58760918],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Correlation", "[", "ests", "]"}], "//", "MatrixForm"}]], "Input",
 CellLabel->"In[27]:=",
 CellID->927480525],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0.9999999999999999`", 
      RowBox[{"-", "0.8919927473606171`"}]},
     {
      RowBox[{"-", "0.8919927473606171`"}], "1.0000000000000004`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 ImageSize->{160, 28},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[27]//MatrixForm=",
 CellID->30297779]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  InterpretationBox[
   StyleBox[
    GraphicsBox[{},
     BaselinePosition->Baseline,
     ImageSize->{6, 0}],
    CacheGraphics->False],
   Spacer[6]]]],
 "\:0423\:0447\:0435\:0431\:043d\:044b\:0435 \:043c\:0430\:0442\:0435\:0440\
\:0438\:0430\:043b\:044b"
}], "TutorialsSection",
 WholeCellGroupOpener->True,
 CellID->250839057],

Cell["", "SectionHeaderSpacer"],

Cell[BoxData[
 TemplateBox[{
  Cell["Numerical Operations on Data"],
   "paclet:tutorial/NumericalOperationsOnDataOverview"},
  "RefLink",
  BaseStyle->"Tutorials"]], "Tutorials",
 CellID->1373153569],

Cell[BoxData[
 TemplateBox[{
  Cell["Pseudorandom Numbers"],"paclet:tutorial/PseudorandomNumbers"},
  "RefLink",
  BaseStyle->"Tutorials"]], "Tutorials",
 CellID->2100600837],

Cell[BoxData[
 TemplateBox[{
  Cell["Random Number Generation"],"paclet:tutorial/RandomNumberGeneration"},
  "RefLink",
  BaseStyle->"Tutorials"]], "Tutorials",
 CellID->2074394605],

Cell["", "SectionFooterSpacer"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  InterpretationBox[
   StyleBox[
    GraphicsBox[{},
     BaselinePosition->Baseline,
     ImageSize->{6, 0}],
    CacheGraphics->False],
   Spacer[6]]]],
 "\:0421\:043e\:043f\:0443\:0442\:0441\:0442\:0432\:0443\:044e\:0449\:0438\
\:0435 \:0440\:0430\:0437\:0434\:0435\:043b\:044b \:043a\:0440\:0430\:0442\
\:043a\:043e\:0433\:043e \:043a\:0443\:0440\:0441\:0430"
}], "RelatedLinksSection",
 WholeCellGroupOpener->True,
 CellID->1584193535],

Cell["", "SectionHeaderSpacer"],

Cell[TextData[ButtonBox["\:041a\:0440\:0430\:0442\:043a\:0438\:0439 \:043a\
\:0443\:0440\:0441: \:0421\:0442\:0430\:0442\:0438\:0441\:0442\:0438\:0447\
\:0435\:0441\:043a\:0438\:0439 \:0430\:043d\:0430\:043b\:0438\:0437",
 BaseStyle->"Hyperlink",
 ButtonData->{"DoStatisticalAnalysisRU.nb", None}]], "RelatedTutorials",
 FontFamily->"Verdana",
 FontSize->11,
 CellID->405226890],

Cell["", "SectionFooterSpacer"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  InterpretationBox[
   StyleBox[
    GraphicsBox[{},
     BaselinePosition->Baseline,
     ImageSize->{6, 0}],
    CacheGraphics->False],
   Spacer[6]]]],
 "\:0421\:043c\:043e\:0442\:0440\:0438 \:0442\:0430\:043a\:0436\:0435"
}], "SeeAlsoSection",
 WholeCellGroupOpener->True,
 CellID->1255426704],

Cell[TextData[{
 Cell[BoxData[
  TemplateBox[{Cell["RandomChoice"],"paclet:ref/RandomChoice"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  TemplateBox[{Cell["Table"],"paclet:ref/Table"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  TemplateBox[{Cell["Mean"],"paclet:ref/Mean"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  TemplateBox[{Cell["StandardDeviation"],"paclet:ref/StandardDeviation"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  TemplateBox[{Cell["Histogram"],"paclet:ref/Histogram"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  TemplateBox[{Cell["Quantile"],"paclet:ref/Quantile"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  TemplateBox[{Cell["Skewness"],"paclet:ref/Skewness"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  TemplateBox[{
   Cell["FindDistributionParameters"],"paclet:ref/FindDistributionParameters"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  TemplateBox[{Cell["Correlation"],"paclet:ref/Correlation"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"]
}], "SeeAlso",
 CellID->929782353]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  InterpretationBox[
   StyleBox[
    GraphicsBox[{},
     BaselinePosition->Baseline,
     ImageSize->{6, 0}],
    CacheGraphics->False],
   Spacer[6]]]],
 "\:0423\:0437\:043d\:0430\:0442\:044c \:0431\:043e\:043b\:044c\:0448\:0435"
}], "MoreAboutSection",
 WholeCellGroupOpener->True,
 CellID->38303248],

Cell["", "SectionHeaderSpacer"],

Cell[BoxData[
 TemplateBox[{Cell["Numerical Data"],"paclet:guide/NumericalData"},
  "RefLink",
  BaseStyle->"MoreAbout"]], "MoreAbout",
 CellID->508728864],

Cell[BoxData[
 TemplateBox[{
  Cell["Handling Arrays of Data"],"paclet:guide/HandlingArraysOfData"},
  "RefLink",
  BaseStyle->"MoreAbout"]], "MoreAbout",
 CellID->1073618541],

Cell[BoxData[
 TemplateBox[{Cell["Statistics"],"paclet:guide/Statistics"},
  "RefLink",
  BaseStyle->"MoreAbout"]], "MoreAbout",
 CellID->1665078683],

Cell[BoxData[
 TemplateBox[{
  Cell["Descriptive Statistics"],"paclet:guide/DescriptiveStatistics"},
  "RefLink",
  BaseStyle->"MoreAbout"]], "MoreAbout",
 CellID->2058676946],

Cell[BoxData[
 TemplateBox[{
  Cell["Statistical Model Analysis"],"paclet:guide/StatisticalModelAnalysis"},
  "RefLink",
  BaseStyle->"MoreAbout"]], "MoreAbout",
 CellID->219351970],

Cell[BoxData[
 TemplateBox[{
  Cell["Random Number Generation"],"paclet:guide/RandomNumberGeneration"},
  "RefLink",
  BaseStyle->"MoreAbout"]], "MoreAbout",
 CellID->167110779],

Cell[BoxData[
 TemplateBox[{Cell["Data Visualization"],"paclet:guide/DataVisualization"},
  "RefLink",
  BaseStyle->"MoreAbout"]], "MoreAbout",
 CellID->1566621538],

Cell[BoxData[
 TemplateBox[{Cell["\"How to\" Topics"],"paclet:guide/HowToTopics"},
  "RefLink",
  BaseStyle->"MoreAbout"]], "MoreAbout",
 CellID->1229872562]
}, Open  ]]
}, Open  ]],

Cell[" ", "FooterCell"]
},
FileChangeProtection->None,
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{Automatic, 510},
WindowMargins->{{312, Automatic}, {Automatic, 0}},
WindowFrame->"Normal",
WindowTitle->"Perform a Bootstrap Analysis - Wolfram Mathematica",
DockedCells->FEPrivate`FrontEndResource["FEExpressions", "HelpViewerToolbar"],
TaggingRules->{
 "ModificationHighlight" -> False, "ColorType" -> "TutorialColor", 
  "LinkTrails" -> "", "ExampleCounter" -> 1, "ExamplePageLinks" -> {}, 
  "RootCaptions" -> "", 
  "Metadata" -> {
   "built" -> "{2013, 1, 24, 22, 48, 33.2010335}", 
    "history" -> {"8.0", "", "", ""}, "context" -> "System`", 
    "keywords" -> {
     "bootstrap", "bootstrap estimate", "bootstrapping", "resample", 
      "resampling", "nonparametric estimation", "sample estimate"}, 
    "specialkeywords" -> {}, "tutorialcollectionlinks" -> {}, "index" -> True,
     "label" -> "Mathematica How To", "language" -> "en", "paclet" -> 
    "Mathematica", "status" -> "None", "summary" -> 
    "Suppose that you have a limited amount of data from which to obtain \
estimates of statistics for a population. The sampling distribution for those \
estimates can be approximated by drawing new samples from the original data \
and then computing statistics from each sample. This process is called \
bootstrapping and can be performed in Mathematica with RandomChoice . ", 
    "synonyms" -> {}, "title" -> "Perform a Bootstrap Analysis", 
    "titlemodifier" -> "", "windowtitle" -> "Perform a Bootstrap Analysis", 
    "type" -> "HowTo", "uri" -> "howto/PerformABootstrapAnalysis"}, 
  "SearchTextTranslated" -> ""},
Magnification->1.,
FrontEndVersion->"10.1 for Microsoft Windows (64-bit) (March 23, 2015)",
StyleDefinitions->FrontEnd`FileName[{"Wolfram"}, "Reference.nb", 
  CharacterEncoding -> "WindowsANSI"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[621, 21, 5771, 135, 48, "AnchorBarGrid",
 CellID->1],
Cell[CellGroupData[{
Cell[6417, 160, 321, 8, 60, "HowToTitle",
 CellID->509267359],
Cell[CellGroupData[{
Cell[6763, 172, 2705, 42, 109, "HowToAbstract",
 CellID->840069076],
Cell[9471, 216, 162, 2, 38, "HowToText",
 CellID->1009846402],
Cell[CellGroupData[{
Cell[9658, 222, 410, 9, 47, "Input",
 CellID->827466675],
Cell[10071, 233, 491, 12, 54, "Output",
 CellID->861465440]
}, Open  ]],
Cell[10577, 248, 1592, 32, 78, "HowToText",
 CellID->1389965763],
Cell[CellGroupData[{
Cell[12194, 284, 200, 6, 28, "Input",
 CellID->411630083],
Cell[12397, 292, 490, 12, 54, "Output",
 CellID->72728370]
}, Open  ]],
Cell[12902, 307, 2037, 29, 92, "HowToText",
 CellID->17352728],
Cell[14942, 338, 544, 12, 40, "HowToText",
 CellID->812217608],
Cell[CellGroupData[{
Cell[15511, 354, 109, 3, 28, "Input",
 CellID->1398028897],
Cell[15623, 359, 195, 6, 36, "Output",
 CellID->592279068]
}, Open  ]],
Cell[15833, 368, 310, 4, 38, "HowToText",
 CellID->239873537],
Cell[CellGroupData[{
Cell[16168, 376, 107, 3, 28, "Input",
 CellID->17381088],
Cell[16278, 381, 195, 6, 36, "Output",
 CellID->536358353]
}, Open  ]],
Cell[16488, 390, 1141, 17, 74, "HowToText",
 CellID->83196217],
Cell[17632, 409, 825, 15, 58, "HowToText",
 CellID->758291895],
Cell[18460, 426, 356, 11, 28, "Input",
 CellID->734056247],
Cell[18819, 439, 901, 16, 58, "HowToText",
 CellID->416325809],
Cell[CellGroupData[{
Cell[19745, 459, 110, 3, 28, "Input",
 CellID->254378789],
Cell[19858, 464, 15286, 502, 159, "Output",
 CellID->185267540]
}, Open  ]],
Cell[35159, 969, 1255, 18, 74, "HowToText",
 CellID->342435841],
Cell[36417, 989, 660, 11, 56, "HowToText",
 CellID->378342759],
Cell[CellGroupData[{
Cell[37102, 1004, 118, 3, 28, "Input",
 CellID->335677854],
Cell[37223, 1009, 178, 5, 36, "Output",
 CellID->846291685]
}, Open  ]],
Cell[37416, 1017, 654, 13, 58, "HowToText",
 CellID->585167324],
Cell[CellGroupData[{
Cell[38095, 1034, 187, 6, 28, "Input",
 CellID->106458678],
Cell[38285, 1042, 260, 9, 36, "Output",
 CellID->394067]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[38594, 1057, 67, 2, 15, "HowToDelimiter",
 CellID->1871769037],
Cell[38664, 1061, 830, 13, 56, "HowToText",
 CellID->334259956],
Cell[39497, 1076, 599, 10, 56, "HowToText",
 CellID->1445501569],
Cell[40099, 1088, 371, 12, 47, "Input",
 CellID->89859940],
Cell[CellGroupData[{
Cell[40495, 1104, 110, 3, 28, "Input",
 CellID->170354028],
Cell[40608, 1109, 4360, 141, 160, "Output",
 CellID->443135780]
}, Open  ]],
Cell[44983, 1253, 1570, 25, 75, "HowToText",
 CellID->62371672],
Cell[46556, 1280, 746, 14, 58, "HowToText",
 CellID->730828722],
Cell[CellGroupData[{
Cell[47327, 1298, 232, 6, 28, "Input",
 CellID->57108537],
Cell[47562, 1306, 313, 9, 36, "Output",
 CellID->226209441]
}, Open  ]],
Cell[47890, 1318, 1157, 20, 76, "HowToText",
 CellID->224490222],
Cell[CellGroupData[{
Cell[49072, 1342, 338, 9, 28, "Input",
 CellID->175330848],
Cell[49413, 1353, 314, 9, 36, "Output",
 CellID->615614222]
}, Open  ]],
Cell[49742, 1365, 270, 7, 40, "HowToText",
 CellID->1496668379],
Cell[50015, 1374, 465, 13, 47, "Input",
 CellID->36763837],
Cell[50483, 1389, 970, 18, 58, "HowToText",
 CellID->338181515],
Cell[51456, 1409, 688, 17, 40, "HowToText",
 CellID->26535765],
Cell[52147, 1428, 204, 7, 28, "Input",
 CellID->63168641],
Cell[52354, 1437, 680, 11, 56, "HowToText",
 CellID->252119581],
Cell[CellGroupData[{
Cell[53059, 1452, 103, 3, 28, "Input",
 CellID->47499536],
Cell[53165, 1457, 239, 7, 36, "Output",
 CellID->446016353]
}, Open  ]],
Cell[53419, 1467, 606, 12, 39, "HowToText",
 CellID->58760918],
Cell[CellGroupData[{
Cell[54050, 1483, 144, 4, 28, "Input",
 CellID->927480525],
Cell[54197, 1489, 844, 24, 62, "Output",
 CellID->30297779]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[55090, 1519, 362, 13, 31, "TutorialsSection",
 CellID->250839057],
Cell[55455, 1534, 31, 0, 14, "SectionHeaderSpacer"],
Cell[55489, 1536, 200, 6, 19, "Tutorials",
 CellID->1373153569],
Cell[55692, 1544, 174, 5, 19, "Tutorials",
 CellID->2100600837],
Cell[55869, 1551, 181, 5, 19, "Tutorials",
 CellID->2074394605],
Cell[56053, 1558, 31, 0, 29, "SectionFooterSpacer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[56121, 1563, 472, 14, 31, "RelatedLinksSection",
 CellID->1584193535],
Cell[56596, 1579, 31, 0, 14, "SectionHeaderSpacer"],
Cell[56630, 1581, 378, 7, 18, "RelatedTutorials",
 CellID->405226890],
Cell[57011, 1590, 31, 0, 29, "SectionFooterSpacer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[57079, 1595, 329, 12, 31, "SeeAlsoSection",
 CellID->1255426704],
Cell[57411, 1609, 2528, 71, 75, "SeeAlso",
 CellID->929782353]
}, Open  ]],
Cell[CellGroupData[{
Cell[59976, 1685, 335, 12, 31, "MoreAboutSection",
 CellID->38303248],
Cell[60314, 1699, 31, 0, 14, "SectionHeaderSpacer"],
Cell[60348, 1701, 155, 4, 19, "MoreAbout",
 CellID->508728864],
Cell[60506, 1707, 175, 5, 19, "MoreAbout",
 CellID->1073618541],
Cell[60684, 1714, 149, 4, 19, "MoreAbout",
 CellID->1665078683],
Cell[60836, 1720, 175, 5, 19, "MoreAbout",
 CellID->2058676946],
Cell[61014, 1727, 181, 5, 19, "MoreAbout",
 CellID->219351970],
Cell[61198, 1734, 177, 5, 19, "MoreAbout",
 CellID->167110779],
Cell[61378, 1741, 164, 4, 19, "MoreAbout",
 CellID->1566621538],
Cell[61545, 1747, 157, 4, 19, "MoreAbout",
 CellID->1229872562]
}, Open  ]]
}, Open  ]],
Cell[61729, 1755, 23, 0, 41, "FooterCell"]
}
]
*)

(* End of internal cache information *)
