(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    170657,       4088]
NotebookOptionsPosition[    161579,       3803]
NotebookOutlinePosition[    163978,       3859]
CellTagsIndexPosition[    163897,       3854]
WindowTitle->Perform a Monte Carlo Simulation - Wolfram Mathematica
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[GridBox[{
   {Cell["MATHEMATICA HOW TO", "PacletNameCell"], Cell[TextData[{
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "Tutorials",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"Tutorials", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->False], {"\<\"Numerical Operations on Data\"\>":>
       Documentation`HelpLookup[
       "paclet:tutorial/NumericalOperationsOnDataOverview"], \
"\<\"Pseudorandom Numbers\"\>":>Documentation`HelpLookup[
       "paclet:tutorial/PseudorandomNumbers"], "\<\"Random Number \
Generation\"\>":>Documentation`HelpLookup[
       "paclet:tutorial/RandomNumberGeneration"]},
       Appearance->None,
       MenuAppearance->Automatic,
       MenuStyle->"Tutorials"]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "See Also",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"See Also", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->False], {"\<\"RandomVariate\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/RandomVariate"], "\<\"RandomReal\"\>":>
       Documentation`HelpLookup["paclet:ref/RandomReal"]},
       Appearance->None,
       MenuAppearance->Automatic,
       MenuStyle->"SeeAlso"]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "Related Guides",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"Related Guides", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->False], {"\<\"Numerical Data\"\>":>
       Documentation`HelpLookup[
       "paclet:guide/NumericalData"], "\<\"Handling Arrays of Data\"\>":>
       Documentation`HelpLookup[
       "paclet:guide/HandlingArraysOfData"], "\<\"Statistics\"\>":>
       Documentation`HelpLookup[
       "paclet:guide/Statistics"], "\<\"Descriptive Statistics\"\>":>
       Documentation`HelpLookup[
       "paclet:guide/DescriptiveStatistics"], "\<\"Statistical Model Analysis\
\"\>":>Documentation`HelpLookup[
       "paclet:guide/StatisticalModelAnalysis"], "\<\"Random Number \
Generation\"\>":>Documentation`HelpLookup[
       "paclet:guide/RandomNumberGeneration"], "\<\"Data Visualization\"\>":>
       Documentation`HelpLookup[
       "paclet:guide/DataVisualization"], "\<\"\\\"How to\\\" Topics\"\>":>
       Documentation`HelpLookup["paclet:guide/HowToTopics"]},
       Appearance->None,
       MenuAppearance->Automatic,
       MenuStyle->"MoreAbout"]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "URL",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"URL", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->False], {"\<\"howto/PerformAMonteCarloSimulation\"\>":>
       None, "\<\"Copy Mathematica URL\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell["howto/PerformAMonteCarloSimulation"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; Null], 
       Delimiter, "\<\"Copy web URL\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell[
              BoxData[
               MakeBoxes[
                Hyperlink[
                "http://reference.wolfram.com/mathematica/howto/\
PerformAMonteCarloSimulation.html"], StandardForm]], "Input", 
              TextClipboardType -> "PlainText"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; 
        Null], "\<\"Go to web URL\"\>":>FrontEndExecute[{
         NotebookLocate[{
           URL[
            StringJoin[
            "http://reference.wolfram.com/mathematica/", 
             "howto/PerformAMonteCarloSimulation", ".html"]], None}]}]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}]
    }], "AnchorBar"]}
  }]], "AnchorBarGrid",
 CellID->1],

Cell[CellGroupData[{

Cell[TextData[{
 Cell["\:041a\:0440\:0430\:0442\:043a\:0438\:0439 \:043a\:0443\:0440\:0441 ", 
  "HowToTitlePrefix"],
 " ",
 "\:041c\:043e\:0434\:0435\:043b\:0438\:0440\:043e\:0432\:0430\:043d\:0438\
\:0435 \:043c\:0435\:0442\:043e\:0434\:043e\:043c \:041c\:043e\:043d\:0442\
\:0435-\:041a\:0430\:0440\:043b\:043e"
}], "HowToTitle",
 CellID->509267359],

Cell[CellGroupData[{

Cell[TextData[{
 "\:041c\:0435\:0442\:043e\:0434\:044b \:041c\:043e\:043d\:0442\:0435-\:041a\
\:0430\:0440\:043b\:043e \:0438\:0441\:043f\:043e\:043b\:044c\:0437\:0443\
\:044e\:0442 \:0441\:043b\:0443\:0447\:0430\:0439\:043d\:043e \:0433\:0435\
\:043d\:0435\:0440\:0438\:0440\:0443\:0435\:043c\:044b\:0435 \:0447\:0438\
\:0441\:043b\:0430 \:0438\:043b\:0438 \:0441\:043e\:0431\:044b\:0442\:0438\
\:044f \:0434\:043b\:044f \:043c\:043e\:0434\:0435\:043b\:0438\:0440\:043e\
\:0432\:0430\:043d\:0438\:044f \:0441\:043b\:0443\:0447\:0430\:0439\:043d\
\:044b\:0445 \:043f\:0440\:043e\:0446\:0435\:0441\:0441\:043e\:0432 \:0438 \
\:043e\:0446\:0435\:043d\:043a\:0438 \:0441\:043b\:043e\:0436\:043d\:044b\
\:0445 \:0440\:0435\:0437\:0443\:043b\:044c\:0442\:0430\:0442\:043e\:0432. \
\:041d\:0430\:043f\:0440\:0438\:043c\:0435\:0440, \:043e\:043d\:0438 \:0438\
\:0441\:043f\:043e\:043b\:044c\:0437\:0443\:0435\:0442\:0441\:044f \:0434\
\:043b\:044f \:043c\:043e\:0434\:0435\:043b\:0438\:0440\:043e\:0432\:0430\
\:043d\:0438\:044f \:0444\:0438\:043d\:0430\:043d\:0441\:043e\:0432\:044b\
\:0445 \:0441\:0438\:0441\:0442\:0435\:043c, \:0442\:0435\:043b\:0435\:043a\
\:043e\:043c\:043c\:0443\:043d\:0438\:043a\:0430\:0446\:0438\:043e\:043d\:043d\
\:044b\:0445 \:0441\:0435\:0442\:0435\:0439 \:0438 \:0432\:044b\:0447\:0438\
\:0441\:043b\:0435\:043d\:0438\:044f \:0440\:0435\:0437\:0443\:043b\:044c\
\:0442\:0430\:0442\:043e\:0432 \:043c\:043d\:043e\:0433\:043e\:043c\:0435\
\:0440\:043d\:044b\:0445 \:0438\:043d\:0442\:0435\:0433\:0440\:0430\:043b\
\:043e\:0432 \:0432 \:0444\:0438\:0437\:0438\:043a\:0435. \:041c\:043e\:0434\
\:0435\:043b\:0438\:0440\:043e\:0432\:0430\:043d\:0438\:0435 \:043c\:0435\
\:0442\:043e\:0434\:043e\:043c \:041c\:043e\:043d\:0442\:0435-\:041a\:0430\
\:0440\:043b\:043e \:043c\:043e\:0436\:0435\:0442 \:0431\:044b\:0442\:044c \
\:0432\:044b\:043f\:043e\:043b\:043d\:0435\:043d\:043e \:043f\:0440\:0438 \
\:043f\:043e\:043c\:043e\:0449\:0438 \:0432\:0441\:0442\:0440\:043e\:0435\
\:043d\:043d\:044b\:0445 \:0432 ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " \:0444\:0443\:043d\:043a\:0446\:0438\:0439 \:0433\:0435\:043d\:0435\:0440\
\:0430\:0446\:0438\:0438 \:0441\:043b\:0443\:0447\:0430\:0439\:043d\:044b\
\:0445 \:0447\:0438\:0441\:0435\:043b."
}], "HowToAbstract",
 CellID->1045883471],

Cell["\<\
\:041f\:0440\:043e\:0441\:0442\:0435\:0439\:0448\:0438\:043c \:0441\:043b\
\:0443\:0447\:0430\:0435\:043c \:043c\:043e\:0434\:0435\:043b\:0438\:0440\
\:043e\:0432\:0430\:043d\:0438\:044f \:043c\:0435\:0442\:043e\:0434\:043e\
\:043c \:041c\:043e\:043d\:0442\:0435-\:041a\:0430\:0440\:043b\:043e \:043c\
\:043e\:0436\:0435\:0442 \:0431\:044b\:0442\:044c \:043f\:043e\:0441\:043b\
\:0435\:0434\:043e\:0432\:0430\:0442\:0435\:043b\:044c\:043d\:043e\:0441\:0442\
\:044c \:0441\:043b\:0443\:0447\:0430\:0439\:043d\:044b\:0445 \:0447\:0438\
\:0441\:0435\:043b. \:041a \:043f\:0440\:0438\:043c\:0435\:0440\:0443, \:0441\
\:043f\:0438\:0441\:043e\:043a \:0441\:043b\:0443\:0447\:0430\:0439\:043d\
\:044b\:0445 \:0447\:0438\:0441\:0435\:043b, \:043d\:0435\:0437\:0430\:0432\
\:0438\:0441\:0438\:043c\:043e \:0441\:043e\:0441\:0442\:0430\:0432\:043b\
\:0435\:043d\:043d\:044b\:0439 \:0438\:0437 \:043d\:043e\:0440\:043c\:0430\
\:043b\:044c\:043d\:043e\:0433\:043e \:0440\:0430\:0441\:043f\:0440\:0435\
\:0434\:0435\:043b\:0435\:043d\:0438\:044f \:0441\:043e \:0441\:0440\:0435\
\:0434\:043d\:0438\:043c 0, \:043c\:043e\:0436\:0435\:0442 \:043c\:043e\:0434\
\:0435\:043b\:0438\:0440\:043e\:0432\:0430\:0442\:044c \:043f\:0440\:043e\
\:0446\:0435\:0441\:0441 \:0431\:0435\:043b\:043e\:0433\:043e \:0448\:0443\
\:043c\:0430.\
\>", "HowToText",
 CellID->231582574],

Cell[TextData[{
 "\:0412\:043e\:0441\:043f\:043e\:043b\:044c\:0437\:0443\:0435\:043c\:0441\
\:044f \:0444\:0443\:043d\:043a\:0446\:0438\:0435\:0439 ",
 Cell[BoxData[
  ButtonBox["RandomVariate",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/RandomVariate"]], "InlineFormula"],
 " \:0432\:043c\:0435\:0441\:0442\:0435 \:0441 ",
 Cell[BoxData[
  ButtonBox["NormalDistribution",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/NormalDistribution"]], "InlineFormula"],
 " \:0434\:043b\:044f \:0441\:043e\:0437\:0434\:0430\:043d\:0438\:044f \:043f\
\:043e\:0441\:043b\:0435\:0434\:043e\:0432\:0430\:0442\:0435\:043b\:044c\:043d\
\:043e\:0441\:0442\:0438 \:0438\:0437 20 \:0447\:0438\:0441\:0435\:043b \
\:043f\:043e \:043d\:043e\:0440\:043c\:0430\:043b\:044c\:043d\:043e\:043c\
\:0443 \:0440\:0430\:0441\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\
\:0438\:044e, \:0441\:043e \:0441\:0440\:0435\:0434\:043d\:0438\:043c 0 \
\:0438 \:0441\:0442\:0430\:043d\:0434\:0430\:0440\:0442\:043d\:044b\:043c \
\:043e\:0442\:043a\:043b\:043e\:043d\:0435\:043d\:0438\:0435\:043c 1:"
}], "HowToText",
 CellID->1009846402],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rnorms1", "=", 
  RowBox[{"RandomVariate", "[", 
   RowBox[{
    RowBox[{"NormalDistribution", "[", 
     RowBox[{"0", ",", "1"}], "]"}], ",", "20"}], "]"}]}]], "Input",
 CellLabel->"In[1]:=",
 CellID->827466675],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.3707905081913175`", ",", 
   RowBox[{"-", "0.6940456963802321`"}], ",", 
   RowBox[{"-", "0.25469986690349494`"}], ",", 
   RowBox[{"-", "0.18027660594645398`"}], ",", 
   RowBox[{"-", "1.127575725305548`"}], ",", 
   RowBox[{"-", "1.1969885236654347`"}], ",", "0.12973530581948692`", ",", 
   "0.35454265605386315`", ",", "1.3087519966765437`", ",", 
   "1.0185324242826044`", ",", "1.192813746486134`", ",", 
   RowBox[{"-", "0.018204474409186912`"}], ",", 
   RowBox[{"-", "1.1539647108068114`"}], ",", "1.5294779300552555`", ",", 
   "1.2745097249012842`", ",", 
   RowBox[{"-", "1.0299107122433966`"}], ",", 
   RowBox[{"-", "0.09906479260639661`"}], ",", 
   RowBox[{"-", "0.5947779453036343`"}], ",", 
   RowBox[{"-", "0.4420104195634598`"}], ",", "0.7480223498511788`"}], 
  "}"}]], "Output",
 ImageSize->{488, 50},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[1]=",
 CellID->240359784]
}, Open  ]],

Cell[TextData[{
 "\:041f\:0440\:0438\:043c\:0435\:043d\:0438\:043c \:0444\:0443\:043d\:043a\
\:0446\:0438\:044e ",
 Cell[BoxData[
  ButtonBox["ListPlot",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/ListPlot"]], "InlineFormula"],
 " \:0434\:043b\:044f \:0432\:0438\:0437\:0443\:0430\:043b\:0438\:0437\:0430\
\:0446\:0438\:0438 \:0434\:0430\:043d\:043d\:044b\:0445:"
}], "HowToText",
 CellID->1389965763],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", "rnorms1", "]"}]], "Input",
 CellLabel->"In[2]:=",
 CellID->411630083],

Cell[BoxData[
 GraphicsBox[
  {Hue[0.67, 0.6, 0.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQDQEf7G+GTJPh2H3dHirgMNvuT+B802f7IVwOB+nI
lasZfC9A+QIO8vzJx32Fj0P5Ig7NZv+v93B9gvIlHHQ8dQvuqn2G8mUcvp65
MF9r9gGo+QoOF4qN1l3ecA3KV3JYfY7l/dIPX6B8FYeFkYeXv/D+AOWrObzj
+Hb3sOhnKF/DoercyxmGSyZBzddyUCqJ2ry4DGa/jkPYihk391b8gKrXc7ip
oeefkgIz38Dhsta65c1VH6DqDR1KPufm+MfshPKNHDgPvTuYzfEYyjd24ORW
FHrmeQfKN3EIN9OceOb9c3sAyidhbg==
    "]]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, Automatic},
  PlotRange->Automatic,
  PlotRangeClipping->True]], "Output",
 ImageSize->{184, 100},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[2]=",
 CellID->48514815]
}, Open  ]],

Cell["\<\
\:041f\:043e \:043f\:043e\:043b\:0443\:0447\:0435\:043d\:043d\:044b\:043c \
\:0434\:0430\:043d\:043d\:044b\:043c \:043c\:043e\:0436\:043d\:043e \:043f\
\:043e\:0441\:0442\:0440\:043e\:0438\:0442\:044c \:0433\:0440\:0430\:0444\
\:0438\:043a \:0441\:043b\:0443\:0447\:0430\:0439\:043d\:043e\:0433\:043e \
\:0431\:043b\:0443\:0436\:0434\:0430\:043d\:0438\:044f:\
\>", "HowToText",
 CellID->1322801873],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLinePlot", "[", "rnorms1", "]"}]], "Input",
 CellLabel->"In[3]:=",
 CellID->11302808],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQAWIQDQEf7G+GTJPh2H3dHirgMNvuT+B802f7IVwOB+nI
lasZfC9A+QIO8vzJx32Fj0P5Ig7NZv+v93B9gvIlHHQ8dQvuqn2G8mUcvp65
MF9r9gGo+QoOF4qN1l3ecA3KV3JYfY7l/dIPX6B8FYeFkYeXv/D+AOWrObzj
+Hb3sOhnKF/DoercyxmGSyZBzddyUCqJ2ry4DGa/jkPYihk391b8gKrXc7ip
oeefkgIz38Dhsta65c1VH6DqDR1KPufm+MfshPKNHDgPvTuYzfEYyjd24ORW
FHrmeQfKN3EIN9OceOb9c3sAyidhbg==
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0., 20.}, {-1.1969885236654347`, 1.5294779300552555`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 ImageSize->{184, 101},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[3]=",
 CellID->126322202]
}, Open  ]],

Cell["\<\
\:0427\:0442\:043e\:0431\:044b \:043d\:0430\:0447\:0430\:0442\:044c \:0431\
\:043b\:0443\:0436\:0434\:0430\:043d\:0438\:0435 \:0441 \:043d\:0443\:043b\
\:044f, \:0434\:043e\:0431\:0430\:0432\:0438\:043c \:043d\:043e\:043b\:044c \
\:0432 \:043d\:0430\:0447\:0430\:043b\:043e \:0441\:043f\:0438\:0441\:043a\
\:0430: \
\>", "HowToText",
 CellID->812217608],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rnorms2", "=", 
  RowBox[{"Prepend", "[", 
   RowBox[{"rnorms1", ",", "0"}], "]"}]}]], "Input",
 CellLabel->"In[4]:=",
 CellID->1129699873],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0.3707905081913175`", ",", 
   RowBox[{"-", "0.6940456963802321`"}], ",", 
   RowBox[{"-", "0.25469986690349494`"}], ",", 
   RowBox[{"-", "0.18027660594645398`"}], ",", 
   RowBox[{"-", "1.127575725305548`"}], ",", 
   RowBox[{"-", "1.1969885236654347`"}], ",", "0.12973530581948692`", ",", 
   "0.35454265605386315`", ",", "1.3087519966765437`", ",", 
   "1.0185324242826044`", ",", "1.192813746486134`", ",", 
   RowBox[{"-", "0.018204474409186912`"}], ",", 
   RowBox[{"-", "1.1539647108068114`"}], ",", "1.5294779300552555`", ",", 
   "1.2745097249012842`", ",", 
   RowBox[{"-", "1.0299107122433966`"}], ",", 
   RowBox[{"-", "0.09906479260639661`"}], ",", 
   RowBox[{"-", "0.5947779453036343`"}], ",", 
   RowBox[{"-", "0.4420104195634598`"}], ",", "0.7480223498511788`"}], 
  "}"}]], "Output",
 ImageSize->{488, 50},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[4]=",
 CellID->11902110]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLinePlot", "[", "rnorms2", "]"}]], "Input",
 CellLabel->"In[5]:=",
 CellID->402046648],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQEf7BlQgcPNkGkyHLuvQ8U5HGbb/Qmcb/psP4Qv
4CAduXI1g+8FKF/EQZ4/+biv8HEoX8Kh2ez/9R6uT1C+jIOOp27BXbXPUL6C
w9czF+ZrzT4ANV/J4UKx0brLG65B+SoOq8+xvF/64QuUr+awMPLw8hfeMHdq
OLzj+Hb3sOhnKF/LoercyxmGSyZBzddxUCqJ2ry4DGa/nkPYihk391b8gKo3
cLipoeefkgIz39Dhsta65c1VH6DqjRxKPufm+MfshPKNHTgPvTuYzfEYyjdx
4ORWFHrmeQfKN3UIN9OceOb9c3sAdBBh5A==
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0., 21.}, {-1.1969885236654347`, 1.5294779300552555`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 ImageSize->{184, 102},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[5]=",
 CellID->77340569]
}, Open  ]],

Cell[TextData[{
 "\:0418\:0441\:043f\:043e\:043b\:044c\:0437\:0443\:0435\:043c \:043a\:043e\
\:043c\:0430\:043d\:0434\:0443 ",
 Cell[BoxData[
  ButtonBox["Accumulate",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Accumulate"]], "InlineFormula"],
 " \:0434\:043b\:044f \:043f\:043e\:0441\:043b\:0435\:0434\:043e\:0432\:0430\
\:0442\:0435\:043b\:044c\:043d\:043e\:0433\:043e \:0441\:0443\:043c\:043c\
\:0438\:0440\:043e\:0432\:0430\:043d\:0438\:044f \:0434\:0430\:043d\:043d\
\:044b\:0445, \:043e\:0442\:043e\:0431\:0440\:0430\:0437\:0438\:0432 \:043f\
\:043e\:043b\:0443\:0447\:0435\:043d\:043d\:044b\:0435 \:0440\:0435\:0437\
\:0443\:043b\:044c\:0442\:0430\:0442\:044b \:043f\:0440\:0438 \:043f\:043e\
\:043c\:043e\:0449\:0438 ",
 Cell[BoxData[
  ButtonBox["ListLinePlot",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/ListLinePlot"]], "InlineFormula"],
 ":"
}], "HowToText",
 CellID->1580365767],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLinePlot", "[", 
  RowBox[{"Accumulate", "[", "rnorms2", "]"}], "]"}]], "Input",
 CellLabel->"In[13]:=",
 CellID->1398028897],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQBWIQDQEf7BlQgUOk3d2ZS5vfQcU5HIKe/ljw+ec3KF/A
IU39X1jpV3YHCF/EoWAOh+mnj0xQvoRDTrB2zud3v6HqZRyeuUUYCd39CeUr
OGz4cFrkTT2Mr+TQslFDfN0/Nqh+FYfYvwE+J57B+GoOB5cttG42Y4TyNRwe
1bps/tkA06/lwPLUpULZ7S6Ur+PAdSnvcPmJC1C+nsOa2Kh42ftf90P4Bg78
7zddup7+B8o3dJg1eUIKiy3bAQjfyCHL2sEuYQk/lG/skNwXP6WUhRXKN3HQ
Oh3fdMSQEco3dXjUd8Cr8QnbAQCgB1vy
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0., 21.}, {-3.9552616942741468`, 2.9948527141868224`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 ImageSize->{184, 113},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[13]=",
 CellID->39654963]
}, Open  ]],

Cell["\<\
\:0421\:043b\:0435\:0434\:0443\:044e\:0449\:0435\:0435 \:043e\:043f\:0440\
\:0435\:0434\:0435\:043b\:0435\:043d\:0438\:0435 \:043e\:0431\:044a\:0435\
\:0434\:0438\:043d\:044f\:0435\:0442 \:0432\:043c\:0435\:0441\:0442\:0435 \
\:043f\:0440\:0435\:0434\:044b\:0434\:0443\:0449\:0438\:0435 \:043a\:043e\
\:043c\:0430\:043d\:0434\:044b \:0434\:043b\:044f \:0441\:043e\:0437\:0434\
\:0430\:043d\:0438\:044f \:0441\:043b\:0443\:0447\:0430\:0439\:043d\:043e\
\:0433\:043e \:0431\:043b\:0443\:0436\:0434\:0430\:043d\:0438\:044f. \:042d\
\:0442\:043e \:043e\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\:0438\
\:0435 \:0432 \:0434\:0430\:043b\:044c\:043d\:0435\:0439\:0448\:0435\:043c \
\:043c\:043e\:0436\:0435\:0442 \:0431\:044b\:0442\:044c \:0438\:0441\:043f\
\:043e\:043b\:044c\:0437\:043e\:0432\:0430\:043d\:043e \:0434\:043b\:044f \
\:043c\:043e\:0434\:0435\:043b\:0438\:0440\:043e\:0432\:0430\:043d\:0438\:044f\
 \:043c\:043d\:043e\:0433\:0438\:0445 \:0441\:043b\:0443\:0447\:0430\:0439\
\:043d\:044b\:0445 \:0431\:043b\:0443\:0436\:0434\:0430\:043d\:0438\:0439 \
\:0438 \:0430\:043d\:0430\:043b\:0438\:0437\:0430 \:0438\:0445 \:0441\:0432\
\:043e\:0439\:0441\:0442\:0432.\
\>", "HowToText",
 CellID->773710253],

Cell[TextData[{
 "\:0412\:044b\:043f\:043e\:043b\:043d\:0438\:043c \:043e\:043f\:0440\:0435\
\:0434\:0435\:043b\:0435\:043d\:0438\:0435 \:0444\:0443\:043d\:043a\:0446\
\:0438\:0438 ",
 Cell[BoxData["randomWalk"], "InlineFormula"],
 ", \:043a\:043e\:0442\:043e\:0440\:0430\:044f \:0433\:0435\:043d\:0435\:0440\
\:0438\:0440\:0443\:0435\:0442 \:0441\:043b\:0443\:0447\:0430\:0439\:043d\
\:044b\:0435 \:0431\:043b\:0443\:0436\:0434\:0430\:043d\:0438\:044f \:0434\
\:043b\:0438\:043d\:043e\:0439 ",
 Cell[BoxData[
  StyleBox["n", "MR"]], "InlineFormula",
  FontSlant->"Italic"],
 ":"
}], "HowToText",
 CellID->165287740],

Cell[BoxData[
 RowBox[{
  RowBox[{"randomWalk", "[", "n_", "]"}], ":=", 
  RowBox[{"Accumulate", "[", 
   RowBox[{"Prepend", "[", 
    RowBox[{
     RowBox[{"RandomVariate", "[", 
      RowBox[{
       RowBox[{"NormalDistribution", "[", 
        RowBox[{"0", ",", "1"}], "]"}], ",", "n"}], "]"}], ",", "0"}], "]"}], 
   "]"}]}]], "Input",
 CellLabel->"In[36]:=",
 CellID->117258227],

Cell[TextData[{
 "\:0417\:0434\:0435\:0441\:044c, \:0444\:0443\:043d\:043a\:0446\:0438\:044f ",
 Cell[BoxData[
  ButtonBox["Table",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Table"]], "InlineFormula"],
 " \:0438\:0441\:043f\:043e\:043b\:044c\:0437\:043e\:0432\:0430\:043d\:0430 \
\:0434\:043b\:044f \:0441\:043e\:0437\:0434\:0430\:043d\:0438\:044f \:043f\
\:044f\:0442\:0438 \:0441\:043b\:0443\:0447\:0430\:0439\:043d\:044b\:0445 \
\:0431\:043b\:0443\:0436\:0434\:0430\:043d\:0438\:0439, \:0441 \:043e\:0434\
\:0438\:043d\:0430\:043a\:043e\:0432\:043e\:0439 \:0434\:043b\:0438\:043d\
\:043e\:0439 100. \:0412\:0441\:0435 \:043e\:043d\:0438 \:043e\:0442\:043e\
\:0431\:0440\:0430\:0436\:0435\:043d\:044b \:043f\:0440\:0438 \:043f\:043e\
\:043c\:043e\:0449\:0438 \:043a\:043e\:043c\:0430\:043d\:0434\:044b ",
 Cell[BoxData[
  ButtonBox["ListLinePlot",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/ListLinePlot"]], "InlineFormula"],
 ":"
}], "HowToText",
 CellID->803924961],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListLinePlot", "[", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"randomWalk", "[", "100", "]"}], ",", 
    RowBox[{"{", "5", "}"}]}], "]"}], "]"}]], "Input",
 CellLabel->"In[15]:=",
 CellID->219941940],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJxVkntQlGUUxj8EXASGi7HJZSFuCw423FZ25bY+3OQqLAvsLhIjMipCEUNI
oJCuhM5ozIBGAqJLSWoqBgStCjZuhYJQhoOTOiKEQA2oBcuUCqjZcN4/+ma+
+eb3Pe855znnPS7ZBfJtyziO2/b6/e+79Mys5/7/gOfdeOY7vp7+m8DFc7mq
XG+EJbZC3JG5yvoTPGIbCL+6F5iXbUlsC6FUvPLZuAWxAB5vGMZ2nWS6M0qq
zIasvayIXbH4kUzxQydH7I4zJpeeSTRmxB5oM6jq9BtdSbwa6fVmIaJ5a2Iv
5GpWNTR5s/xvI338cf9EH8vvDd+DjfqkClNiX+TZ9j619zQh9oMJp5PFTq8i
9sd0U/Sx5wLGIhiLS8VykR3xWoR/kFStqbInDoD7/APlpJ7p4tf+Mswd7BlL
8JPN7pH6X/jE66A323P9j0esn0CYz53GrQXWTxCKm6/EdPPY/IIR5BBYP1lo
QxyClGsx1fmGjEPhtvd8L+8G8ysFv2XawKSE+VuP9uibliE/svrA4689rk18
Q/Fq4PJspnn3IPMThnNa/ee+BnReHYbtfgVPZoptSQ/HGF+iW6giVoejdqbX
qnyI9RsB8ax7rWSW6qsjIOpK/DvDkfmLhPmR2q5LtUyPRE7Ozox1LxxIj4LP
/dHSWXfKp45CW6R2zKfgTdI3oL9S05dVTH7VG/BXwq41ai3To7FCUTW4x1RA
ejRyM/65ebedzSMGzhVFXhObmP8YvMie0lSWMn+xkLY6WrT3O5IeixGem++f
BS6kx6Hv3qPYh0fdSI+DsC00v3VeSHo8hj9pSIo+7Up6PE6WFf72a48z6QlY
zKzYzNe+RXoCdE0X7pd+Rue5jZCcD9AvSui8eiPWOk+tvmXL6iciO3Ju/7Eu
d9ITccNJnv7lFvLDJaF1oHtrjIr5S0Ky6OeBlrMsXgajSsM2UabTEkMG8+n6
Mv/b7D5kkNZp9wnLiXUyBJxyau2zpnlyyTguHL/Q/AX5RzLSDtTc9m9g/SYj
ii8Y/n0fsS4Zn46YXX2qZ/3JEeLX2xNiRP4gx4cOXjXLs5lfOXwrOy3CE4l1
cohM31Ev7KB+uRQMdft0n7vK4lPAzSa5FBuz+BTsnbQ7/J4xzU+XAulURXNF
C6ufihOBCVcsXxEjFTEvvfo9Cll8KoJq2jataWb1U1EWHFR0PZrNLw2aA5Xe
h/iUH2n4fnLq4xIZ6eo0HHrfc+ZJIs1HlwbB1n6x4jntE6fA8JTB2AMpzRMK
cMHuYQ872L4rsHvkVMCu7bSfOgUiBqpf7RSz/VWitaPjrPIoMZSwKpAKRgLZ
/SmRFboi+LA35dcp0Xe8Xfayke23Cne3aAU7eOQHKjRF2eXlzrN9V6Hock7d
aA/th06FrHd5d769yPY3HfnLEg9urqN+kY7IwZk78Rdd8S9lP5nb
     "]]}, 
   {Hue[0.9060679774997897, 0.6, 0.6], LineBox[CompressedData["
1:eJxVj3lQlHUYx18OBYNiueQWRJBFLgFZDgW+HHLsAi67sIsRTHJJaZQwJjpq
a1SUCBOUDNdweIBjYAqEjgguFExUjIJEESEEIorgIG2wyVUNz/tH78w773ze
z+/7+z7P1qR3RamqDMOk/vv+911/5vyZ/z9Q6HadKK9Yof+aMC2N9ebgJTEH
M6KcIyLDv4gNwHFxyLcs7iU2BvNT8CXuyGNic7Sd7Cj8qI7tsYKPxSKv7doq
sTXUUmoLKvkviG1w/Mq3Xd7Nj4i3Y+CXngcax3rvrjMXPa3FjT/MTRHvgOXP
NxVNL5XEjghPqedNvL1A7IzTXSYT7jOzxDth3drx0KNwhtgVkrrUIrfJMepz
w3CpoK0gnWV3JHQuqZmZP6fzu6CMHP9D/YiKfJ090K9cKVV+okHMQ2eNRl7y
9AZiT1jo6e5K5r5C7IU3GvXdiz/fTOyNxLm31Bbd9Il9cFO81pK9W494N+an
uIJBGct7oKdYURh/pkvsC6GPpNwg5FViP1S/L+nbePUFzeuPGxJL/lenlomB
stywputfqq+flwFV8rXWG+abKB8AyeAjJ8Mi6pMFwNzZrrHmEod8IL4u/DVp
OJ/1gWj6scTxuJKdLwiOY/6NyQ3G5IOgIYwvCsxk9w2GUL2jX8xjfTCeaJmN
SP5m99+LiqWFgoEI6pPtxYhNikFcvDb5EFRmSzfcsyGWhSB9er49PoX2YUJR
aywI98zWJB+Kgdy+pep4LfJh+DihajwsgfpkYVgOMEv3umdIPhz9PVv4s70m
5MORopWWHRBhRJ6PpOHno6NpxDI+Fi6q3rJSsSQvQFea/pyfwJq8ABWckdKB
Y8RMBL4zcYgx8rYhH4GDmxprxs+zPhJ3Guzc3uTRfbJIDL939E7GU1PyUWAS
gy6rtFiQj8LqdfHhPDsr8vuwOj3cfXaE9fswqOlrau/NeiFiJe3pud1b1xlC
8E5uGzowZEvnhUj59E8PhxGaRy7E5ebOgxPpdJ6JRtOecxm/P2Tz0TjbkbQ5
qmQ75aPRXcsbU1TQffJoSHN9Q7lZ5BkR+sQbpxINuZQX4cyhAhWVWbZfhLsF
aw8sy9i8CM8KXVdfO0PMiNF+xV7/fhDdBzGWp2p3NtTZU16MGYu8qsrzTpQX
YyBn3scn2JHyMZhzcjvqFeZC+RjUmtz3YbSIZTFQz5n8fjSTzcdA50KkqXOm
A+VjUc0vufpMjfoQi5PhtmJOFtsfC+6QbfMXnnaUj4Vi5h3XC2PbKC9BQvEQ
X7OB3V+Cp+cS8lU/3EF5CZRJsxe52tQnl+B1vk59/CTbL4XfgW8+uJ1J+0CK
Fu3b9YtKmlcmxbXgQxktRuTlUsgKzMsUUmfKx+GE55DL48N0HnGYLTw139ZL
XhYHD99A44gn7P5xaBLcKt+iQ/Mx+6GSbuincZrt3w+H0bys37qc5P8AP2na
SA==
     "]]}, 
   {Hue[0.14213595499957954`, 0.6, 0.6], LineBox[CompressedData["
1:eJxVk3tQVGUYh5eEFIjlIshFh3E3IFDY0AVdIOCnLKxcF5ZdFrQEkiWuOjlx
GRBYAwZRRIQKnYEwrQANScWQJtiFaYpLJAYyRGCEO1EgIqUgjGU1vN8fnZkz
Z555vt/3fu97zuG9eUSmeoHD4aj+vf97rl2P/Dn/v3Bg9JNGftlzzRpuQJt7
q+rVg8vEZhBJv77TN3GX2BKVep9+79s8RvvYwH5pdlPHZ6PEW/BIkNHb/OAp
8VbYzT5XdHvqYY35qBrLT1OpFsk7IK/+DE/LXyJ2gklIrn9J6u/EzmjsuWJz
fmGVeBssarVatfscsSu2XswbtP/5Pp1PgJduXEpINB0mdodFyGQyL2eaeAcO
N7ZtPtb1mHgnimzL6r4tZnkhLtfFT1rpWD8eCKsKW4gpXyD2RKF38dkaRwPq
Zxcqs7mCZdFG4t2wSNeOC29aEovwzYSbEUqtib0gOpPVlPtwE7E3Ml2CksXt
9sQ+MLwwaxtgziN+DSuhmfG/TTH2BadaP6snyoHYD+L6+O1CDWN/SD7aeD/p
iiMxsFzaqT+vI68G2oznTKZusPV7MPDjLZeRKj75PYjLUdjy04g5e7Eo7f/8
LQnVV++Fw6JxrMvtLeQDYDgzfbI1j/kAVBgJcvrFW8mLUdnYf7Q/lXkx+INO
93xVTuQDcStsMaCg6xXygajJyjbOHnEmH4QfJixzor/aTj4Ip7hxbs5JruQl
GF89EX7eZBt5CfqSM2tNlWz/fdilrXh3stKF/D4U7L6Y0FRG9TjBSJSYa015
rH4wnpweer/FgNUPwcj8kLzDi1gdgry62qvpI2y+oUg9GD387DCxOhRp78Ul
Xr/LfBh+ubxOLz2P+TAo9w8cj9W8TD4czeNTz0Lt2XzCUS33//tJDJt/BJr8
nlZ7+LP3EwHvQ2HDYiWbrxTC6iazcBCrpWjIdwvs9GA+EtWF7bcDyzavMSIh
zvrinDTTjtZHoju5IIXTZbbG2ki08XyDW/5k32cUIkaD22S99P0iCm+3CbmB
R1m9KITMp5QnyakfbRRq/e4JB9ez88swPb7/wXIP9QcZcppf1C0M0XnUMqjK
vX1dKmwpL0Nmhaiv8ENWPxo7kox13BpWPxp2jV+eOJBP69XRuJAUUiJupn60
0ei1WLlTeJP9j3KYf3BEI3iH/kfIIS0tvHZqA+2nloM72t7qYW1FeTncT4sE
UxnEHAXm5/TdpG40HyhgJBm4uvQTl/IKqB3/Oi5UEWsV8OmukXxnb0T5GMw4
eOo/LlpH+Rgk8DrqM8ZYPga6oCLdoY/NKR8DP1s9n4czVI+jxLnXc38taqF5
QAnONdc/NCl0PrUS19+4FDytYv0r0WAtnk4ytKF8LPg1xQ1nS2leiIW/l6ah
WJ/NLxbrE0vURjtpvTYW1Sud+VZxLB+H1aV0GLjReREH62OhzdJlLv4B/GKm
6Q==
     "]]}, 
   {Hue[0.37820393249936934`, 0.6, 0.6], LineBox[CompressedData["
1:eJxVj3tQVGUYh9ctkgREAoQVkOUOK8Jyv8MPuQhy22XZi6QUwpYiI4WRUZMc
QmZUnJCLBmIogZTGoEMQ5ICuwIAgxWXGBjAgSEANRC7REAbV8J4/OjNnzjzn
+Z7v/T6zQ2mxSi6Hw1H++/733XheBHD+/6BAqvZSad9H/9VR29pzuMPk8d0N
3oYStbky3dJZYj1E96eMtPj1ERvCOqOuIsFkgnpjlHzz0G5gvIGYj9mrL+Ld
j03QenMMGwlbfkpfJbbEBSYnOyiFq9pga/A9L8ZotGgR26LAZ/5C4PHNxALo
VPZyS5XqxPZY+o53YtxqG7EDymTtNx2jNIiF4E8GT4Ubs94JDfq/9hq0ahI7
49Mx1bFzv20ldsHT/u1uWwrZ+a54wjMoUN+tR+wGI49LR4IydYjdsdNmR96d
u7rEHnDgdHa9FBsQe6J9cleu03N9Yi8YeteLbzey670h005d2ircQeyDs7dP
Vk5qGBL7wu6DvpWiJvY+fjg3P6iM7WPv74+4Z70lll7seQLQOrqu1xa9nRg4
3lm0WMCjeQxgeVBdsLmRnReIhCitWzuv8MgHYtyYe/9GhhH5Peh5JcuzLodP
fg9yTU4Ndb1rRj4IhxMWfm7JImaC8Fqzzft+QgvywTCu7xXL2lgfDDVXTUdt
K9aHoCNj8llisSX5EMQJdMzqgq3Jh2IyMm/6RIQt+VD0Pd8qF7jTes5erCbn
KVc0aT9mL7IV6QO6B4zJh6FztDq/50cT8mHglcbf0xpkzx+OsWJRZdJ1K/Lh
MDCdVLwdQPM4+zAj6lD/KoLOw+zDpsfmeimXbchHQJLzoNtbaEc+Agv+Dx2n
Atk+Ems3uzzvnRGQj0Q9/4hIm0/MicJp+4biuUdsH4XPkv2+HJEQc6IxenK5
enWa5jHR4ObHfO8kYPsY1CzL0w2Eu8jHIPXQhGlb2G7yIoRqZoY43HLYYIiw
xb72z5lyYkaERF7b0V+shBusEkFnUfOLyzzyHDHu2F63PZtF+0GMBTf/qcJ8
R+rFGDg4t+46Ql4lxrzlzDvd1WwfC6a1eXBJSusRizJJ1egjf7aPRb/m/STr
JnZ+LNKWqyoqFMQcCRiBIfeKDTEkeH3ow4XKNGJGgmnnoS4nQ7aXYC3IYoqv
z/ZxWG5B6oP3nKiPQ33V+eQ3A5ypj4O0Jvcj/0uu1Mche+30fCHfg3opmsyX
cjPCiCFF1SlPTk05MSNF4OzfRdxiT+qlkM42lsf7elEvQ7RR7/lr9eQhQ+aY
87xPADEjw0WtJ+tltd7Uy3B1+Kj820Uf6uVIyir3eCuSGHKsJNoO/15K+zNy
tH/9+asuT4lVcnycXvnH8htsr0B8e7CP6Q+0PxTwvVYr7v6EPKNA9LKLRekN
YpUCmzqKkyL9fanfj/iCujPSQWLsx1+hBxSDzX6qfwD+mtXC
     "]]}, 
   {Hue[0.6142719099991583, 0.6, 0.6], LineBox[CompressedData["
1:eJxVlH801Wccx79+X7+K0Vg6ijWxSaNICW9crusS94dfbWoxdY4xTjjaVtwM
naNZnGnTjMOJlDXph0W0bqZJuynCRhYRXcRBuMKcbed+vn/sOed7vuf1fX/e
n8/zfJ7n+VpFJ4pi1RmGif33+e+tGtOezP8H/MwMdRWaC/SdA3PvuA5tARtn
hBXzmF2T8a+JTTEVM3L4QJI2VGwOvfVxXhNRDPEGyIXB1bsjByh+E9Z8PVRz
wH6K2Bp5PxTft1C+It6MTU0Xflm5Vktsg9wdEwHyo4XEtmis65UvV7D53kVG
2dnVgmerxPYQGTeZaKdrUn0HKGw9hj5pZvl9vDOpn5qqZUDsiOxqywa/OjVi
J0g0vlxqeTlJ+bbDTe+DAL90BfEO2N/e31ee0EPsDE6e/Hrsd0+JXVDEjOjo
xM0T70Rfo45GvOvz2yp2xVornp3yVDfxLiyUVJ00Mp6l+N0ofm/0Vn7PHLEb
4rUyTyensfPfg4+N0yUFuex83ZHv+LawrHKJ4j1wkG+du4FhdU+Ulap7bdcy
JAZcOY1CJzNjFUuBwqNfHNrKWUe6F1L0bzIrT94k3Qs9Q2Z1ChM90r1hUGlT
WWxP85F6Y0pxvdz/CVvPBynJj4fW1ND5kfrAxsf8jHEte164cJv6llOQw+pc
jCS6TG/GK+qHL5Su3NJMwZyKpb5oZQKDeTYvSPfDA8FfjOPWcdL9wO+5+9PM
nUHKz0O5XWr38o1R0nkYTJzKi46vI90ff6Tsk8h/p/5K/VHfxcsWm/STzsce
zYFHTsNt5OdD8xtzjbQH3aQHwMjnVKdZ+wz5A6B3/iv/KgG7PgEKP3TWmusk
lgoQYJi0+vk4259AFPGP9Ta7/U16IDTSLY+4BbLnNwjDRzI2VuYoSQ+CyaBv
A8Nl799eyN1N1Z0d6L5J9yJjsZAn//ENyh8M53u/9p1pIJYG42K/Jb/0Mu03
E4Ir1uut1s3QfiIEC9XT81l26hQfAoXFcV3lQYqXhaD8M6vTwWVryS+Ets6d
R+dqWL8QE71bOrNK9MkvRISkIif6Eq1XJkQut92k25vWw4hQzU1q923TIr8I
kiuPgi+CXa8IFfm82C3u1A+ZCE0XPj3e+YI9/2KMBzr5VQxxyC+GONr7Zpcv
5ZOKkdDVMRrIpf+PTIxL9e6Px2bZ/kkgE6/4dncUqRgSCJiPrvL/fEn7LYGN
i+lgyeGnKpZJoPmw+Of99ez9DUX9tZ2JkVVLKkYoOtJO3D1/g5Gp/KGYys8S
tbSqqVgWCk2PIO+YEm0VM2EwtB+7dXbfCvnDcEJqmd6/TUn1w7B4OcvhXPQ8
1Q/Dvcy3vneteU31w5HAaUkL2sb6w7FRLS6sX7BI/nBo/KaIak6m+cjCEacR
ZTfrr0v1I1Ae9twis5b1R+D+8qDBgNYE9T8CV/ULh7Prh6h+BBivVlujnIfU
v0iEatc+E7vSfiAS5jrHDinbxjz/AeQZycY=
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0., 101.}, {-29.737676165131212`, 14.195619027253334`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 ImageSize->{184, 104},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[15]=",
 CellID->76831591]
}, Open  ]],

Cell[TextData[{
 "\:0422\:0435\:043f\:0435\:0440\:044c \:0441\:0433\:0435\:043d\:0435\:0440\
\:0438\:0440\:0443\:0435\:043c 1000 \
\:0431\:043b\:0443\:0436\:0434\:0430\:043d\:0438\:0439, \:043a\:0430\:0436\
\:0434\:043e\:0435 \:0434\:043b\:0438\:043d\:043e\:0439 100 \
\:0442\:043e\:0447\:0435\:043a. \:0412\:044b\:0432\:043e\:0434 \:0442\:0430\
\:043a\:043e\:0433\:043e \:0431\:043e\:043b\:044c\:0448\:043e\:0433\:043e \
\:0440\:0435\:0437\:0443\:043b\:044c\:0442\:0430\:0442\:0430 \:043d\:0430 \
\:044d\:043a\:0440\:0430\:043d \:043f\:043e\:0434\:0430\:0432\:043b\:044f\
\:0435\:0442\:0441\:044f \:043f\:0440\:0438 \:043f\:043e\:043c\:043e\:0449\
\:0438 \:0442\:043e\:0447\:043a\:0438 \:0441 \:0437\:0430\:043f\:044f\:0442\
\:043e\:0439 (",
 Cell[BoxData[";"], "InlineFormula"],
 "), \:0442\:0430\:043a \:043a\:0430\:043a \:0432\:0438\:0434\:0435\:0442\
\:044c \:0435\:0433\:043e \:0441\:043e\:0432\:0441\:0435\:043c \:043d\:0435 \
\:043e\:0431\:044f\:0437\:0430\:0442\:0435\:043b\:044c\:043d\:043e:"
}], "HowToText",
 CellID->241676294],

Cell[BoxData[
 RowBox[{
  RowBox[{"rwalks", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"randomWalk", "[", "100", "]"}], ",", 
     RowBox[{"{", "1000", "}"}]}], "]"}]}], ";"}]], "Input",
 CellLabel->"In[16]:=",
 CellID->104955898],

Cell["\<\
\:0422\:0435\:043f\:0435\:0440\:044c \:043c\:043e\:0436\:043d\:043e \:043f\
\:0440\:043e\:0432\:043e\:0434\:0438\:0442\:044c \:0432\:044b\:0447\:0438\
\:0441\:043b\:0435\:043d\:0438\:044f \:043e\:043f\:0438\:0441\:0430\:0442\
\:0435\:043b\:044c\:043d\:043e\:0439 \:0441\:0442\:0430\:0442\:0438\:0441\
\:0442\:0438\:043a\:0438 \:0434\:043b\:044f \:043b\:044e\:0431\:044b\:0445 \
\:0430\:0441\:043f\:0435\:043a\:0442\:043e\:0432 \:0441\:043b\:0443\:0447\
\:0430\:0439\:043d\:044b\:0445 \:0431\:043b\:0443\:0436\:0434\:0430\:043d\
\:0438\:0439. \:041d\:0438\:0436\:0435 \:043f\:0440\:0438\:0432\:0435\:0434\
\:0435\:043d \:0430\:043d\:0430\:043b\:0438\:0437 \:043a\:043e\:043d\:0435\
\:0447\:043d\:043e\:0439 \:043f\:043e\:0437\:0438\:0446\:0438\:0438 \:043a\
\:0430\:0436\:0434\:043e\:0433\:043e \:0431\:043b\:0443\:0436\:0434\:0430\
\:043d\:0438\:044f. \
\>", "HowToText",
 CellID->212592104],

Cell[TextData[{
 "\:0418\:0441\:043f\:043e\:043b\:044c\:0437\:0443\:0435\:043c ",
 Cell[BoxData[
  RowBox[{"[", 
   RowBox[{"[", " ", "]"}], "]"}]], "InlineFormula"],
 " (\:043a\:0440\:0430\:0442\:043a\:0430\:044f \:0444\:043e\:0440\:043c\:0430 \
\:0437\:0430\:043f\:0438\:0441\:0438 \:0444\:0443\:043d\:043a\:0446\:0438\
\:0438 ",
 Cell[BoxData[
  ButtonBox["Part",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Part"]], "InlineFormula"],
 ") \:0434\:043b\:044f \:0438\:0437\:0432\:043b\:0435\:0447\:0435\:043d\:0438\
\:044f \:043a\:043e\:043d\:0435\:0447\:043d\:043e\:0439 \:0442\:043e\:0447\
\:043a\:0438 \:043a\:0430\:0436\:0434\:043e\:0433\:043e \:0441\:043b\:0443\
\:0447\:0430\:0439\:043d\:043e\:0433\:043e \:0431\:043b\:0443\:0436\:0434\
\:0430\:043d\:0438\:044f:"
}], "HowToText",
 CellID->165948033],

Cell[BoxData[
 RowBox[{
  RowBox[{"final", "=", 
   RowBox[{"rwalks", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", 
      RowBox[{"-", "1"}]}], "]"}], "]"}]}], ";"}]], "Input",
 CellLabel->"In[17]:=",
 CellID->550673364],

Cell["\<\
\:0420\:0430\:0441\:0441\:0447\:0438\:0442\:0430\:0435\:043c \:0440\:0430\
\:0437\:043b\:0438\:0447\:043d\:044b\:0435 \:0441\:0442\:0430\:0442\:0438\
\:0441\:0442\:0438\:0447\:0435\:0441\:043a\:0438\:0435 \:043f\:043e\:043a\
\:0430\:0437\:0430\:0442\:0435\:043b\:0438 \:0434\:043b\:044f \:043a\:043e\
\:043d\:0435\:0447\:043d\:044b\:0445 \:0442\:043e\:0447\:0435\:043a 1000 \
\:0441\:043b\:0443\:0447\:0430\:0439\:043d\:044b\:0445 \:0431\:043b\:0443\
\:0436\:0434\:0430\:043d\:0438\:0439:\
\>", "HowToText",
 CellID->118701798],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Mean", "[", "final", "]"}], ",", 
   RowBox[{"StandardDeviation", "[", "final", "]"}], ",", 
   RowBox[{"Max", "[", "final", "]"}], ",", 
   RowBox[{"Min", "[", "final", "]"}]}], "}"}]], "Input",
 CellLabel->"In[18]:=",
 CellID->82679961],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.022553748584125403`"}], ",", "10.34256808309031`", ",", 
   "37.85907225897043`", ",", 
   RowBox[{"-", "34.24493470521082`"}]}], "}"}]], "Output",
 ImageSize->{277, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[18]=",
 CellID->73428001]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\t", "HowToDelimiter",
 Editable->False,
 CellID->219617233],

Cell[TextData[{
 "\:041c\:0435\:0442\:043e\:0434 \:041c\:043e\:043d\:0442\:0435-\:041a\:0430\
\:0440\:043b\:043e \:043c\:043e\:0436\:0435\:0442, \:0442\:0430\:043a\:0436\
\:0435, \:0438\:0441\:043f\:043e\:043b\:044c\:0437\:043e\:0432\:0430\:0442\
\:044c\:0441\:044f \:0434\:043b\:044f \:043d\:0430\:0445\:043e\:0436\:0434\
\:0435\:043d\:0438\:044f \:043f\:0440\:0438\:0431\:043b\:0438\:0436\:0435\
\:043d\:043d\:044b\:0445 \:0437\:043d\:0430\:0447\:0435\:043d\:0438\:0439, \
\:0442\:0430\:043a\:0438\:0445 \:043a\:0430\:043a \:043a\:043e\:043d\:0441\
\:0442\:0430\:043d\:0442\:044b \:0438 \:0447\:0438\:0441\:043b\:0435\:043d\
\:043d\:044b\:0435 \:0438\:043d\:0442\:0435\:0433\:0440\:0430\:043b\:044b. \
\:041d\:0430\:043f\:0440\:0438\:043c\:0435\:0440, \:0434\:0430\:043b\:0435\
\:0435 \:0432\:044b\:043f\:043e\:043b\:043d\:044f\:0435\:0442\:0441\:044f \
\:043f\:0440\:0438\:0431\:043b\:0438\:0437\:0438\:0442\:0435\:043b\:044c\:043d\
\:044b\:0439 \:0440\:0430\:0441\:0447\:0435\:0442 \:0437\:043d\:0430\:0447\
\:0435\:043d\:0438\:044f ",
 Cell[BoxData[
  FormBox["\[Pi]", TraditionalForm]], "InlineMath"],
 " \:043f\:0443\:0442\:0435\:043c \:0433\:0435\:043d\:0435\:0440\:0430\:0446\
\:0438\:0438 \:0441\:043b\:0443\:0447\:0430\:0439\:043d\:044b\:0445 \:0442\
\:043e\:0447\:0435\:043a \:0432\:043d\:0443\:0442\:0440\:0438 \:043a\:0432\
\:0430\:0434\:0440\:0430\:0442\:0430, \:0432 \:043a\:043e\:0442\:043e\:0440\
\:044b\:0439 \:0432\:043f\:0438\:0441\:0430\:043d \:043a\:0440\:0443\:0433 \
\:0441 \:0440\:0430\:0434\:0438\:0443\:0441\:043e\:043c 1, \:0438 \
\:043f\:043e\:0441\:043b\:0435\:0434\:0443\:044e\:0449\:0438\:043c \:043d\
\:0430\:0445\:043e\:0436\:0434\:0435\:043d\:0438\:0435\:043c \:0441\:043e\
\:043e\:0442\:043d\:043e\:0448\:0435\:043d\:0438\:044f \:043c\:0435\:0436\
\:0434\:0443 \:043f\:043b\:043e\:0449\:0430\:0434\:044c\:044e \:043a\:0432\
\:0430\:0434\:0440\:0430\:0442\:0430 \:0438 \:043a\:0440\:0443\:0433\:0430. "
}], "HowToText",
 CellID->19005116],

Cell[TextData[{
 "\:0421\:0433\:0435\:043d\:0435\:0440\:0438\:0440\:0443\:0435\:043c 10,000 \
\:0442\:043e\:0447\:0435\:043a \:0432 \:043a\:0432\:0430\:0434\:0440\:0430\
\:0442\:0435, \:043e\:0433\:0440\:0430\:043d\:0438\:0447\:0435\:043d\:043d\
\:043e\:043c \:0437\:043d\:0430\:0447\:0435\:043d\:0438\:044f\:043c\:0438 ",
 StyleBox["{-1,-1}", "MR"],
 " \:0438 ",
 StyleBox["{1,1}", "MR"],
 ":"
}], "HowToText",
 CellID->729454103],

Cell[BoxData[
 RowBox[{
  RowBox[{"pairs", "=", 
   RowBox[{"RandomReal", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"10000", ",", "2"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellLabel->"In[19]:=",
 CellID->301947459],

Cell["\:041f\:0440\:043e\:0441\:043c\:043e\:0442\:0440\:0438\:043c \:043f\
\:043e\:043b\:0443\:0447\:0435\:043d\:043d\:044b\:0435 \:0442\:043e\:0447\
\:043a\:0438:", "HowToText",
 CellID->759761004],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"lp", "=", 
  RowBox[{"ListPlot", "[", 
   RowBox[{"pairs", ",", 
    RowBox[{"AspectRatio", "\[Rule]", "1"}]}], "]"}]}]], "Input",
 CellLabel->"In[20]:=",
 CellID->191132991],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJztfVuvZMd13iDJQ56IGHEQEdFDQpCBkHAEMRYImc7p3X1uM2dmztxnSFEj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    "], {{0, 176}, {180, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{180, 176},
  PlotRange->{{0, 180}, {0, 176}}]], "Output",
 ImageSize->{184, 176},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"RasterizedOutput",
 CellLabel->"Out[20]=",
 CellID->590802568]
}, Open  ]],

Cell[TextData[{
 "\:0414\:043b\:044f \:043f\:0440\:0438\:0431\:043b\:0438\:0437\:0438\:0442\
\:0435\:043b\:044c\:043d\:043e\:0433\:043e \:0432\:044b\:0447\:0438\:0441\
\:043b\:0435\:043d\:0438\:044f ",
 Cell[BoxData[
  FormBox["\[Pi]", TraditionalForm]], "InlineMath"],
 ", \:0443\:043c\:043d\:043e\:0436\:0438\:043c \:043f\:043b\:043e\:0449\:0430\
\:0434\:044c \:043a\:0432\:0430\:0434\:0440\:0430\:0442\:0430 \:043d\:0430 \
\:043f\:0440\:043e\:0446\:0435\:043d\:0442\:043d\:043e\:0435 \:0441\:043e\
\:043e\:0442\:043d\:043e\:0448\:0435\:043d\:0438\:0435 \:0442\:043e\:0447\
\:0435\:043a, \:043f\:043e\:043f\:0430\:0434\:0430\:044e\:0449\:0438\:0445 \
\:0432 \:043a\:0440\:0443\:0433 \:0440\:0430\:0434\:0438\:0443\:0441\:043e\
\:043c 1 \:0441 \:0446\:0435\:043d\:0442\:0440\:043e\:043c \:0432 \
\:043d\:0430\:0447\:0430\:043b\:0435 \:043a\:043e\:043e\:0440\:0434\:0438\
\:043d\:0430\:0442."
}], "HowToText",
 CellID->240307068],

Cell["\<\
\:0423\:043c\:043d\:043e\:0436\:0438\:043c \:043f\:043b\:043e\:0449\:0430\
\:0434\:044c \:043a\:0432\:0430\:0434\:0440\:0430\:0442\:0430 (\:0432 \:0434\
\:0430\:043d\:043d\:043e\:043c \:0441\:043b\:0443\:0447\:0430\:0435 4) \:043d\
\:0430 \:043e\:0442\:043d\:043e\:0441\:0438\:0442\:0435\:043b\:044c\:043d\
\:0443\:044e \:043c\:0430\:0441\:0441\:0443 \:0442\:043e\:0447\:0435\:043a, \
\:043d\:0430\:0445\:043e\:0434\:044f\:0449\:0438\:0445\:0441\:044f \:0432\
\:043d\:0443\:0442\:0440\:0438 \:043a\:0440\:0443\:0433\:0430:\
\>", "HowToText",
 CellID->149798134],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"4", 
  RowBox[{
   RowBox[{"Count", "[", 
    RowBox[{
     RowBox[{"Map", "[", 
      RowBox[{"Norm", ",", "pairs"}], "]"}], ",", 
     RowBox[{"_", "?", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"#", "\[LessEqual]", "1"}], "&"}], ")"}]}]}], "]"}], "/", 
   "10000."}]}]], "Input",
 CellLabel->"In[21]:=",
 CellID->258614930],

Cell[BoxData["3.1248`"], "Output",
 ImageSize->{46, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[21]=",
 CellID->144544110]
}, Open  ]],

Cell["\<\
\:0418\:0441\:043f\:043e\:043b\:044c\:0437\:043e\:0432\:0430\:043d\:0438\:0435\
 \:0431\:043e\:043b\:044c\:0448\:0435\:0433\:043e \:043a\:043e\:043b\:0438\
\:0447\:0435\:0441\:0442\:0432\:0430 \:0442\:043e\:0447\:0435\:043a \:0438\
\:043b\:0438 \:0441\:0440\:0435\:0434\:043d\:0435\:0433\:043e \:0434\:043b\
\:044f \:043d\:0435\:0441\:043a\:043e\:043b\:044c\:043a\:0438\:0445 \:0430\
\:043f\:043f\:0440\:043e\:043a\:0441\:0438\:043c\:0430\:0446\:0438\:0439, \
\:043a\:0430\:043a \:043f\:0440\:0430\:0432\:0438\:043b\:043e, \:0434\:0430\
\:0435\:0442 \:043b\:0443\:0447\:0448\:0438\:0439 \:0440\:0435\:0437\:0443\
\:043b\:044c\:0442\:0430\:0442 \:0430\:043f\:043f\:0440\:043e\:043a\:0441\
\:0438\:043c\:0430\:0446\:0438\:0438.\
\>", "HowToText",
 CellID->126123407],

Cell[TextData[{
 "\:041e\:043f\:0440\:0435\:0434\:0435\:043b\:0438\:043c \:0444\:0443\:043d\
\:043a\:0446\:0438\:044e ",
 Cell[BoxData["approxPi"], "InlineFormula"],
 " \:0434\:043b\:044f \:043d\:0430\:0445\:043e\:0436\:0434\:0435\:043d\:0438\
\:044f \:043f\:0440\:0438\:0431\:043b\:0438\:0437\:0438\:0442\:0435\:043b\
\:044c\:043d\:043e\:0433\:043e \:0437\:043d\:0430\:0447\:0435\:043d\:0438\
\:044f ",
 Cell[BoxData[
  FormBox["\[Pi]", TraditionalForm]], "InlineMath"],
 " \:0438\:0437 \:043d\:0430\:0431\:043e\:0440\:0430 \:0434\:0430\:043d\:043d\
\:044b\:0445 \:0440\:0430\:0437\:043c\:0435\:0440\:0430 ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]], "InlineMath"],
 ":"
}], "HowToText",
 CellID->535273393],

Cell[BoxData[
 RowBox[{
  RowBox[{"approxPi", "[", "n_", "]"}], ":=", 
  RowBox[{"4.", 
   RowBox[{
    RowBox[{"Count", "[", 
     RowBox[{
      RowBox[{"Map", "[", 
       RowBox[{"Norm", ",", 
        RowBox[{"RandomReal", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"n", ",", "2"}], "}"}]}], "]"}]}], "]"}], ",", 
      RowBox[{"_", "?", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"#", "\[LessEqual]", "1"}], "&"}], ")"}]}]}], "]"}], "/", 
    "n"}]}]}]], "Input",
 CellLabel->"In[22]:=",
 CellID->679590844],

Cell[TextData[{
 "\:0412\:044b\:043f\:043e\:043b\:043d\:0438\:043c \:0430\:043f\:043f\:0440\
\:043e\:043a\:0441\:0438\:043c\:0430\:0446\:0438\:044e ",
 Cell[BoxData[
  FormBox["\[Pi]", TraditionalForm]], "InlineMath"],
 ", \:0438\:0441\:043f\:043e\:043b\:044c\:0437\:0443\:044f \:043c\:0438\:043b\
\:043b\:0438\:043e\:043d \:0442\:043e\:0447\:0435\:043a:"
}], "HowToText",
 CellID->110572458],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"approxPi", "[", 
  RowBox[{"10", "^", "6"}], "]"}]], "Input",
 CellLabel->"In[23]:=",
 CellID->385453611],

Cell[BoxData["3.142052`"], "Output",
 ImageSize->{53, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[23]=",
 CellID->35815205]
}, Open  ]],

Cell[TextData[{
 "\:0420\:0430\:0441\:0441\:0447\:0438\:0442\:0430\:0435\:043c \:043f\:0440\
\:0438\:0431\:043b\:0438\:0437\:0438\:0442\:0435\:043b\:044c\:043d\:043e\:0435\
 \:0437\:043d\:0430\:0447\:0435\:043d\:0438\:0435 ",
 Cell[BoxData[
  FormBox["\[Pi]", TraditionalForm]], "InlineMath"],
 " \:043a\:0430\:043a \:0441\:0440\:0435\:0434\:043d\:0435\:0435 \:043e\:0442 \
50 \:0430\:043f\:043f\:0440\:043e\:043a\:0441\:0438\:043c\:0430\:0446\:0438\
\:0439 \:0438\:0437 \:043d\:0430\:0431\:043e\:0440\:0430 \:0434\:0430\:043d\
\:043d\:044b\:0445 \:0440\:0430\:0437\:043c\:0435\:0440\:0430 10000:"
}], "HowToText",
 CellID->13105520],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Mean", "[", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"approxPi", "[", "10000", "]"}], ",", 
    RowBox[{"{", "50", "}"}]}], "]"}], "]"}]], "Input",
 CellLabel->"In[24]:=",
 CellID->257188490],

Cell[BoxData["3.1436080000000004`"], "Output",
 ImageSize->{53, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[24]=",
 CellID->152766616]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\t", "HowToDelimiter",
 Editable->False,
 CellID->20856566],

Cell["\<\
\:041c\:043e\:0434\:0435\:043b\:0438\:0440\:043e\:0432\:0430\:043d\:0438\:0435\
 \:043c\:0435\:0442\:043e\:0434\:043e\:043c \:041c\:043e\:043d\:0442\:0435-\
\:041a\:0430\:0440\:043b\:043e \:0447\:0430\:0441\:0442\:043e \:0431\:044b\
\:0432\:0430\:0435\:0442 \:043f\:043e\:043b\:0435\:0437\:043d\:043e \:043f\
\:0440\:0438 \:0440\:0430\:0441\:0441\:043c\:043e\:0442\:0440\:0435\:043d\
\:0438\:0438 \:0441\:0438\:0441\:0442\:0435\:043c \:0441\:043e \:0441\:043b\
\:043e\:0436\:043d\:044b\:043c\:0438 \:0441\:0432\:043e\:0439\:0441\:0442\
\:0432\:0430\:043c\:0438. \:0412 \:0411\:0430\:0439\:0435\:0441\:043e\:0432\
\:0441\:043a\:043e\:043c \:0430\:043d\:0430\:043b\:0438\:0437\:0435, \:0437\
\:0430\:0447\:0430\:0441\:0442\:0443\:044e \:043f\:043e\:043d\:0430\:0434\
\:043e\:0431\:0438\:0442\:0441\:044f \:0434\:0432\:0430 \:0440\:0430\:0441\
\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\:0438\:044f \:0441\:0432\
\:0435\:0441\:0442\:0438 \:0432 \:043e\:0434\:043d\:043e, \:0433\:0434\:0435 \
\:043f\:0430\:0440\:0430\:043c\:0435\:0442\:0440\:044b \:043a\:0430\:0436\
\:0434\:043e\:0433\:043e \:0441\:043b\:0435\:0434\:0443\:044e\:0442 \:0434\
\:0440\:0443\:0433 \:0437\:0430 \:0434\:0440\:0443\:0433\:043e\:043c, \:0441\
\:043e\:0437\:0434\:0430\:0432\:0430\:044f \:0434\:0432\:0443\:043c\:0435\
\:0440\:043d\:043e\:0435 \:0440\:0430\:0441\:043f\:0440\:0435\:0434\:0435\
\:043b\:0435\:043d\:0438\:0435. \:0418\:0437-\:0437\:0430 \:0432\:0437\:0430\
\:0438\:043c\:043d\:043e\:0439 \:0437\:0430\:0432\:0438\:0441\:0438\:043c\
\:043e\:0441\:0442\:0438 \:0438\:0441\:0445\:043e\:0434\:043d\:044b\:0445 \
\:0440\:0430\:0441\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\:0438\:0439\
, \:0442\:043e\:0447\:043a\:0438 \:0434\:043e\:043b\:0436\:043d\:044b \:043f\
\:043e\:043e\:0447\:0435\:0440\:0435\:0434\:043d\:043e \:0440\:0430\:0441\
\:0441\:0447\:0438\:0442\:044b\:0432\:0430\:0442\:044c\:0441\:044f \:0438\
\:0437 \:043e\:0431\:0440\:0430\:0437\:043e\:0432\:0430\:043d\:043d\:043e\
\:0433\:043e \:0434\:0432\:0443\:043c\:0435\:0440\:043d\:043e\:0433\:043e \
\:0440\:0430\:0441\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\:0438\:044f\
 \:0438 \:0432\:043a\:043b\:044e\:0447\:0430\:0442\:044c\:0441\:044f \:0432 \
\:0440\:0435\:0437\:0443\:043b\:044c\:0442\:0438\:0440\:0443\:044e\:0449\:0443\
\:044e \:0432\:044b\:0431\:043e\:0440\:043a\:0443. \
\>", "HowToText",
 CellID->458077360],

Cell["\<\
\:042d\:0442\:043e\:0442 \:0441\:043f\:043e\:0441\:043e\:0431 \:0433\:0435\
\:043d\:0435\:0440\:0430\:0446\:0438\:0438 \:0432\:044b\:0431\:043e\:0440\
\:043a\:0438 \:0441\:043e\:0432\:043c\:0435\:0441\:0442\:043d\:043e\:0433\
\:043e \:0440\:0430\:0441\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\
\:0438\:044f \:043d\:0430\:0437\:044b\:0432\:0430\:0435\:0442\:0441\:044f \
\:043c\:0435\:0442\:043e\:0434\:043e\:043c \:0413\:0438\:0431\:0431\:0441\
\:0430. \:041f\:043e \:0437\:0430\:0432\:0435\:0440\:0448\:0435\:043d\:0438\
\:044e \:043f\:043e\:0441\:043b\:0435\:0434\:043e\:0432\:0430\:0442\:0435\
\:043b\:044c\:043d\:043e\:0433\:043e \:0440\:0430\:0441\:0447\:0435\:0442\
\:0430, \:043f\:043e\:043b\:0443\:0447\:0435\:043d\:043d\:044b\:0435 \:0442\
\:043e\:0447\:043a\:0438 \:0431\:0443\:0434\:0443\:0442 \:0432\:043f\:043b\
\:043e\:0442\:043d\:0443\:044e \:0441\:043b\:0435\:0434\:043e\:0432\:0430\
\:0442\:044c \:0441\:043c\:0435\:0448\:0430\:043d\:043d\:043e\:0439 \:0432\
\:044b\:0431\:043e\:0440\:043a\:0435. \:041a\:043e\:043b\:0438\:0447\:0435\
\:0441\:0442\:0432\:043e \:0438\:0442\:0435\:0440\:0430\:0446\:0438\:0439 \
\:043d\:0430\:0437\:044b\:0432\:0430\:0435\:0442\:0441\:044f \:0438\:043d\
\:0442\:0435\:0440\:0432\:0430\:043b\:043e\:043c \:043f\:0440\:0438\:0440\
\:0430\:0431\:043e\:0442\:043a\:0438.\
\>", "HowToText",
 CellID->241669213],

Cell["\<\
\:041d\:0430\:043f\:0440\:0438\:043c\:0435\:0440, \:0438\:043c\:0435\:0435\
\:0442\:0441\:044f \:043d\:043e\:0440\:043c\:0430\:043b\:044c\:043d\:043e\
\:0435 \:0440\:0430\:0441\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\
\:0438\:0435, \:0434\:043b\:044f \:043a\:043e\:0442\:043e\:0440\:043e\:0433\
\:043e \:0434\:0430\:043d\:043e \:0441\:0440\:0435\:0434\:043d\:0435\:0435, \
\:043d\:043e \:043d\:0435\:0438\:0437\:0432\:0435\:0441\:0442\:043d\:043e \
\:0441\:0442\:0430\:043d\:0434\:0430\:0440\:0442\:043d\:043e\:0435 \:043e\
\:0442\:043a\:043b\:043e\:043d\:0435\:043d\:0438\:0435. \:041f\:0440\:0438 \
\:044d\:0442\:043e\:043c \:0438\:0437\:0432\:0435\:0441\:0442\:043d\:043e, \
\:0447\:0442\:043e \:0441\:0442\:0430\:043d\:0434\:0430\:0440\:0442\:043d\
\:043e\:0435 \:043e\:0442\:043a\:043b\:043e\:043d\:0435\:043d\:0438\:0435 \
\:0441\:043b\:0435\:0434\:0443\:0435\:0442 \:0431\:0435\:0442\:0430-\:0440\
\:0430\:0441\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\:0438\:044e, \
\:043a\:043e\:0442\:043e\:0440\:043e\:0435 \:0438\:043c\:0435\:0435\:0442 \
\:043e\:0431\:0449\:0435\:0438\:0437\:0432\:0435\:0441\:0442\:043d\:044b\:0439\
 \:043f\:0430\:0440\:0430\:043c\:0435\:0442\:0440 \:0444\:043e\:0440\:043c\
\:044b, \:0430 \:0434\:0440\:0443\:0433\:043e\:0439 \:043f\:0430\:0440\:0430\
\:043c\:0435\:0442\:0440 \:0444\:043e\:0440\:043c\:044b \:0441\:043e\:043e\
\:0442\:0432\:0435\:0442\:0441\:0442\:0432\:0443\:0435\:0442 \:043d\:043e\
\:0440\:043c\:0430\:043b\:044c\:043d\:043e\:043c\:0443 \:0440\:0430\:0441\
\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\:0438\:044e, \:0434\:043b\
\:044f \:043a\:043e\:0442\:043e\:0440\:043e\:0433\:043e \:0438\:0437\:0432\
\:0435\:0441\:0442\:043d\:043e \:0441\:0440\:0435\:0434\:043d\:0435\:0435.\
\>", "HowToText",
 CellID->82821640],

Cell["\<\
\:041e\:043f\:0440\:0435\:0434\:0435\:043b\:0438\:043c \:0444\:0443\:043d\
\:043a\:0446\:0438\:044e, \:0433\:0435\:043d\:0435\:0440\:0438\:0440\:0443\
\:044e\:0449\:0443\:044e \:0441\:043b\:0443\:0447\:0430\:0439\:043d\:044b\
\:0435 \:0447\:0438\:0441\:043b\:0430 \:043f\:043e \:043d\:043e\:0440\:043c\
\:0430\:043b\:044c\:043d\:043e\:043c\:0443 \:0440\:0430\:0441\:043f\:0440\
\:0435\:0434\:0435\:043b\:0435\:043d\:0438\:044e:\
\>", "HowToText",
 CellID->74027572],

Cell[BoxData[
 RowBox[{
  RowBox[{"dist1", "[", "b_", "]"}], ":=", 
  RowBox[{"RandomVariate", "[", 
   RowBox[{"NormalDistribution", "[", 
    RowBox[{"3", ",", "b"}], "]"}], "]"}]}]], "Input",
 CellLabel->"In[25]:=",
 CellID->164709778],

Cell["\<\
\:041e\:043f\:0440\:0435\:0434\:0435\:043b\:0438\:043c \:0444\:0443\:043d\
\:043a\:0446\:0438\:044e, \:0433\:0435\:043d\:0435\:0440\:0438\:0440\:0443\
\:044e\:0449\:0443\:044e \:0441\:043b\:0443\:0447\:0430\:0439\:043d\:044b\
\:0435 \:0447\:0438\:0441\:043b\:0430 \:043f\:043e \:0431\:0435\:0442\:0430-\
\:0440\:0430\:0441\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\:0438\:044e\
.  \:0412\:0442\:043e\:0440\:044b\:043c \:043f\:0430\:0440\:0430\:043c\:0435\
\:0442\:0440\:043e\:043c \:0444\:043e\:0440\:043c\:044b \:0431\:0435\:0442\
\:0430-\:0440\:0430\:0441\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\
\:0438\:044f \:0431\:0443\:0434\:0435\:0442 \:0430\:0431\:0441\:043e\:043b\
\:044e\:0442\:043d\:043e\:0435 \:0437\:043d\:0430\:0447\:0435\:043d\:0438\
\:0435 \:0441\:043b\:0443\:0447\:0430\:0439\:043d\:043e\:0439 \:043f\:0435\
\:0440\:0435\:043c\:0435\:043d\:043d\:043e\:0439 \:0441 \:043d\:043e\:0440\
\:043c\:0430\:043b\:044c\:043d\:044b\:043c \:0440\:0430\:0441\:043f\:0440\
\:0435\:0434\:0435\:043b\:0435\:043d\:0438\:0435\:043c:\
\>", "HowToText",
 CellID->515821892],

Cell[BoxData[
 RowBox[{
  RowBox[{"dist2", "[", "n_", "]"}], ":=", 
  RowBox[{"RandomVariate", "[", 
   RowBox[{"BetaDistribution", "[", 
    RowBox[{"10", ",", 
     RowBox[{"Abs", "[", "n", "]"}]}], "]"}], "]"}]}]], "Input",
 CellLabel->"In[26]:=",
 CellID->127964417],

Cell["\<\
\:041c\:043e\:0436\:043d\:043e \:043c\:043e\:0434\:0435\:043b\:0438\:0440\
\:043e\:0432\:0430\:0442\:044c \:0442\:043e\:0447\:043a\:0438 \:0438\:0437 \
\:0434\:0432\:0443\:043c\:0435\:0440\:043d\:043e\:0433\:043e \:0440\:0430\
\:0441\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\:0438\:044f, \:0432\
\:0437\:044f\:0432 \:0437\:0430 \:043d\:0430\:0447\:0430\:043b\:044c\:043d\
\:043e\:0435 \:0437\:043d\:0430\:0447\:0435\:043d\:0438\:0435 \:043d\:043e\
\:0440\:043c\:0430\:043b\:044c\:043d\:043e\:0435 \:0441\:0442\:0430\:043d\
\:0434\:0430\:0440\:0442\:043d\:043e\:0435 \:043e\:0442\:043a\:043b\:043e\
\:043d\:0435\:043d\:0438\:0435, \:0430 \:0437\:0430\:0442\:0435\:043c, \:043f\
\:043e\:043e\:0447\:0435\:0440\:0435\:0434\:043d\:043e \:0433\:0435\:043d\
\:0435\:0440\:0438\:0440\:0443\:044f \:0441\:043b\:0443\:0447\:0430\:0439\
\:043d\:044b\:0435 \:0447\:0438\:0441\:043b\:0430 \:043f\:043e \:043d\:043e\
\:0440\:043c\:0430\:043b\:044c\:043d\:043e\:043c\:0443 \:0438 \:0431\:0435\
\:0442\:0430-\:0440\:0430\:0441\:043f\:0440\:0435\:0434\:0435\:043b\:0435\
\:043d\:0438\:044f\:043c. \:041f\:0435\:0440\:0435\:043c\:0435\:043d\:043d\
\:0430\:044f \:0441 \:043d\:043e\:0440\:043c\:0430\:043b\:044c\:043d\:044b\
\:043c \:0440\:0430\:0441\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\
\:0438\:0435\:043c \:0433\:0435\:043d\:0435\:0440\:0438\:0440\:0443\:0435\
\:0442\:0441\:044f \:043f\:0440\:0438 \:043f\:043e\:043c\:043e\:0449\:0438 \
\:043d\:0430\:0447\:0430\:043b\:044c\:043d\:043e\:0433\:043e \:0437\:043d\
\:0430\:0447\:0435\:043d\:0438\:044f \:0434\:043b\:044f \:043d\:043e\:0440\
\:043c\:0430\:043b\:044c\:043d\:043e\:0433\:043e \:0441\:0442\:0430\:043d\
\:0434\:0430\:0440\:0442\:043d\:043e\:0433\:043e \:043e\:0442\:043a\:043b\
\:043e\:043d\:0435\:043d\:0438\:044f. \:0417\:0430\:0442\:0435\:043c \:0433\
\:0435\:043d\:0435\:0440\:0438\:0440\:0443\:0435\:0442\:0441\:044f \:0431\
\:0435\:0442\:0430-\:043f\:0435\:0440\:0435\:043c\:0435\:043d\:043d\:0430\
\:044f, \:0441 \:0438\:0441\:043f\:043e\:043b\:044c\:0437\:043e\:0432\:0430\
\:043d\:0438\:0435\:043c \:043f\:0435\:0440\:0435\:043c\:0435\:043d\:043d\
\:043e\:0439 \:0441 \:043d\:043e\:0440\:043c\:0430\:043b\:044c\:043d\:044b\
\:043c \:0440\:0430\:0441\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\
\:0438\:0435\:043c \:0432 \:043a\:0430\:0447\:0435\:0441\:0442\:0432\:0435 \
\:043d\:0435\:0438\:0437\:0432\:0435\:0441\:0442\:043d\:043e\:0433\:043e \
\:043f\:0430\:0440\:0430\:043c\:0435\:0442\:0440\:0430 \:0444\:043e\:0440\
\:043c\:044b \:0434\:043b\:044f \:0431\:0435\:0442\:0430-\:0440\:0430\:0441\
\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\:0438\:044f. \:041f\:043e\
\:043b\:0443\:0447\:0435\:043d\:043d\:0430\:044f \:0431\:0435\:0442\:0430-\
\:043f\:0435\:0440\:0435\:043c\:0435\:043d\:043d\:0430\:044f \:0437\:0430\
\:0442\:0435\:043c \:0438\:0441\:043f\:043e\:043b\:044c\:0437\:0443\:0435\
\:0442\:0441\:044f \:043a\:0430\:043a \:043d\:0435\:0438\:0437\:0432\:0435\
\:0441\:0442\:043d\:043e\:0435 \:0441\:0442\:0430\:043d\:0434\:0430\:0440\
\:0442\:043d\:043e\:0435 \:043e\:0442\:043a\:043b\:043e\:043d\:0435\:043d\
\:0438\:0435 \:0434\:043b\:044f \:043d\:043e\:0432\:043e\:0433\:043e \:043d\
\:043e\:0440\:043c\:0430\:043b\:044c\:043d\:043e\:0433\:043e \:0440\:0430\
\:0441\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\:0438\:044f \:0438 \
\:0442\:0430\:043a \:0434\:0430\:043b\:0435\:0435. \:042d\:0442\:043e\:0442 \
\:043f\:0440\:043e\:0446\:0435\:0441\:0441 \:0432\:044b\:043f\:043e\:043b\
\:043d\:044f\:0435\:0442\:0441\:044f \:0432 \:0442\:0435\:0447\:0435\:043d\
\:0438\:0435 \:043e\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\:043d\
\:043e\:0433\:043e \:043a\:043e\:043b\:0438\:0447\:0435\:0441\:0442\:0432\
\:0430 \:0446\:0438\:043a\:043b\:043e\:0432, \:0438 \:043f\:043e\:043b\:0443\
\:0447\:0435\:043d\:043d\:044b\:0435 \:0432 \:0440\:0435\:0437\:0443\:043b\
\:044c\:0442\:0430\:0442\:0435 \:043d\:043e\:0440\:043c\:0430\:043b\:044c\
\:043d\:043e \:0440\:0430\:0441\:043f\:0440\:0435\:0434\:0435\:043b\:0435\
\:043d\:043d\:044b\:0435 \:0438 \:0431\:0435\:0442\:0430-\:043f\:0435\:0440\
\:0435\:043c\:0435\:043d\:043d\:044b\:0435 \:044f\:0432\:043b\:044f\:044e\
\:0442\:0441\:044f \:043a\:043e\:043e\:0440\:0434\:0438\:043d\:0430\:0442\
\:0430\:043c\:0438 \:0441\:043c\:043e\:0434\:0435\:043b\:0438\:0440\:043e\
\:0432\:0430\:043d\:043d\:044b\:0445 \:0442\:043e\:0447\:0435\:043a.\
\>", "HowToText",
 CellID->1006787458],

Cell["\<\
\:0421\:0433\:0435\:043d\:0435\:0440\:0438\:0440\:0443\:0435\:043c 500 \:0442\
\:043e\:0447\:0435\:043a, \:043d\:0430\:0447\:0430\:0432 \:0441\:043e \:0437\
\:043d\:0430\:0447\:0435\:043d\:0438\:044f \:0441\:0442\:0430\:043d\:0434\
\:0430\:0440\:0442\:043d\:043e\:0433\:043e \:043e\:0442\:043a\:043b\:043e\
\:043d\:0435\:043d\:0438\:044f 0,5 \:0438 \
\:0432\:044b\:043f\:043e\:043b\:043d\:0438\:0432 1000 \
\:0438\:0442\:0435\:0440\:0430\:0446\:0438\:0439 \:0432 \:043a\:0430\:0447\
\:0435\:0441\:0442\:0432\:0435 \:0438\:043d\:0442\:0435\:0440\:0432\:0430\
\:043b\:0430 \:043f\:0440\:0438\:0440\:0430\:0431\:043e\:0442\:043a\:0438:\
\>", "HowToText",
 CellID->926141267],

Cell[BoxData[
 RowBox[{
  RowBox[{"vals", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"bb", "=", ".5"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Do", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"nn", "=", 
           RowBox[{"dist1", "[", "bb", "]"}]}], ",", 
          RowBox[{"bb", "=", 
           RowBox[{"dist2", "[", "nn", "]"}]}]}], "}"}], ",", 
        RowBox[{"{", "1000", "}"}]}], "]"}], ";", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"dist1", "[", "bb", "]"}], ",", 
        RowBox[{"dist2", "[", "nn", "]"}]}], "}"}]}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", "500", "}"}]}], "]"}]}], ";"}]], "Input",
 CellLabel->"In[27]:=",
 CellID->551406535],

Cell[TextData[{
 "\:041e\:0442\:043e\:0431\:0440\:0430\:0437\:0438\:043c \:0440\:0435\:0437\
\:0443\:043b\:044c\:0442\:0438\:0440\:0443\:044e\:0449\:0438\:0435 \:0442\
\:043e\:0447\:043a\:0438 \:043f\:0440\:0438 \:043f\:043e\:043c\:043e\:0449\
\:0438 \:0444\:0443\:043d\:043a\:0446\:0438\:0438 ",
 Cell[BoxData[
  ButtonBox["ListPlot",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/ListPlot"]], "InlineFormula"],
 ":"
}], "HowToText",
 CellID->413575971],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", "vals", "]"}]], "Input",
 CellLabel->"In[28]:=",
 CellID->10395743],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJztXc2PHEcVXwEHTpy5cuVPiOSdmd34O05ik8hEYGFbyhoESZCxY0Uo4kgU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    "], {{0, 108}, {180, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{180, 108},
  PlotRange->{{0, 180}, {0, 108}}]], "Output",
 ImageSize->{184, 108},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"RasterizedOutput",
 CellLabel->"Out[28]=",
 CellID->436272664]
}, Open  ]],

Cell[TextData[{
 "\:0412\:0438\:0437\:0443\:0430\:043b\:0438\:0437\:0438\:0440\:0443\:0435\
\:043c \:043f\:043b\:043e\:0442\:043d\:043e\:0441\:0442\:044c \:0440\:0430\
\:0441\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\:0438\:044f \:0442\
\:043e\:0447\:0435\:043a, \:043f\:0440\:0438 \:043f\:043e\:043c\:043e\:0449\
\:0438 \:0444\:0443\:043d\:043a\:0446\:0438\:0438 ",
 Cell[BoxData[
  ButtonBox["Histogram3D",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Histogram3D"]], "InlineFormula"],
 ":"
}], "HowToText",
 CellID->205670445],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Histogram3D", "[", 
  RowBox[{"vals", ",", "Automatic", ",", "\"\<ProbabilityDensity\>\""}], 
  "]"}]], "Input",
 CellLabel->"In[29]:=",
 CellID->335757017],

Cell[BoxData[
 Graphics3DBox[
  {RGBColor[0.5, 0.5, 1], EdgeForm[GrayLevel[0.5]], {}, 
   {RGBColor[0.5, 0.5, 1], EdgeForm[GrayLevel[0.5]], {}, {}, {}, {}, {}, {}, 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{0., 0.7, 0}, {0.5, 0.75, 0.07999999999999993}]},
        ImageSizeCache->{{51.41583839969991, 
         64.79744300044158}, {-21.29199480722484, -11.40319233353651}}],
       StatusArea[#, 0.07999999999999993]& ,
       TagBoxNote->"0.07999999999999993"],
      StyleBox["0.07999999999999993`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.07999999999999993, {
        GrayLevel[0]}], "Tooltip"]& ], {}, {}, {}, {}, 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{0., 0.95, 0}, {0.5, 1., 0.07999999999999993}]},
        ImageSizeCache->{{72.56184920801624, 
         84.94439544577207}, {-40.46408459996313, -31.522255828253023`}}],
       StatusArea[#, 0.07999999999999993]& ,
       TagBoxNote->"0.07999999999999993"],
      StyleBox["0.07999999999999993`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.07999999999999993, {
        GrayLevel[0]}], "Tooltip"]& ], {}, {}, {}, {}, {}, 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{0.5, 0.65, 0}, {1., 0.7, 0.08000000000000011}]},
        ImageSizeCache->{{53.736165478124974`, 
         67.36979354264264}, {-14.777975089883626`, -4.553650659516322}}],
       StatusArea[#, 0.08000000000000011]& ,
       TagBoxNote->"0.08000000000000011"],
      StyleBox["0.08000000000000011`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.08000000000000011, {
        GrayLevel[0]}], "Tooltip"]& ], {}, {}, {}, 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{0.5, 0.85, 0}, {1., 0.9, 0.15999999999999986`}]},
        ImageSizeCache->{{71.09430262145159, 
         83.9397909742678}, {-32.412334994400055`, -21.67142838449466}}],
       StatusArea[#, 0.15999999999999986`]& ,
       TagBoxNote->"0.15999999999999986"],
      StyleBox["0.15999999999999986`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.15999999999999986`, {
        GrayLevel[0]}], "Tooltip"]& ], {}, {}, {}, {}, 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{1., 0.5, 0}, {1.5, 0.55, 0.15999999999999986`}]},
        ImageSizeCache->{{46.302786954447924`, 60.83726083909954}, {
         0.024792344737576855`, 12.531561714462555`}}],
       StatusArea[#, 0.15999999999999986`]& ,
       TagBoxNote->"0.15999999999999986"],
      StyleBox["0.15999999999999986`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.15999999999999986`, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{1., 0.55, 0}, {1.5, 0.6, 0.08000000000000011}]},
        ImageSizeCache->{{51.388216333123424`, 
         65.52875062997731}, {-3.3270832976319724`, 7.504032323715194}}],
       StatusArea[#, 0.08000000000000011]& ,
       TagBoxNote->"0.08000000000000011"],
      StyleBox["0.08000000000000011`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.08000000000000011, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{1., 0.6, 0}, {1.5, 0.65, 0.15999999999999986`}]},
        ImageSizeCache->{{56.06409908157222, 
         70.06953504360087}, {-9.340597923756562, 2.6406392436332737`}}],
       StatusArea[#, 0.15999999999999986`]& ,
       TagBoxNote->"0.15999999999999986"],
      StyleBox["0.15999999999999986`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.15999999999999986`, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{1., 0.65, 0}, {1.5, 0.7, 0.16000000000000023`}]},
        ImageSizeCache->{{60.71031206893339, 
         74.46676098407838}, {-13.801903887089594`, -2.066526385992603}}],
       StatusArea[#, 0.16000000000000023`]& ,
       TagBoxNote->"0.16000000000000023"],
      StyleBox["0.16000000000000023`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.16000000000000023`, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{1., 0.7, 0}, {1.5, 0.75, 0.15999999999999986`}]},
        ImageSizeCache->{{65.21008214800175, 
         78.72713048419742}, {-18.12477660632274, -6.62487334265812}}],
       StatusArea[#, 0.15999999999999986`]& ,
       TagBoxNote->"0.15999999999999986"],
      StyleBox["0.15999999999999986`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.15999999999999986`, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{1., 0.75, 0}, {1.5, 0.8, 0.15999999999999986`}]},
        ImageSizeCache->{{69.57022545076984, 
         82.85693478973975}, {-22.315560966414893`, -11.04134923177952}}],
       StatusArea[#, 0.15999999999999986`]& ,
       TagBoxNote->"0.15999999999999986"],
      StyleBox["0.15999999999999986`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.15999999999999986`, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{1., 0.8, 0}, {1.5, 0.85, 0.08000000000000011}]},
        ImageSizeCache->{{73.85201980199297, 
         86.86208535740062}, {-25.02228891565821, -15.322475819909513`}}],
       StatusArea[#, 0.08000000000000011]& ,
       TagBoxNote->"0.08000000000000011"],
      StyleBox["0.08000000000000011`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.08000000000000011, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{1., 0.85, 0}, {1.5, 0.9, 0.2399999999999998}]},
        ImageSizeCache->{{77.85326383973656, 
         90.74814208752223}, {-31.67932621407809, -19.474381168466934`}}],
       StatusArea[#, 0.2399999999999998]& ,
       TagBoxNote->"0.2399999999999998"],
      StyleBox["0.2399999999999998`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.2399999999999998, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{1., 0.9, 0}, {1.5, 0.95, 0.16000000000000023`}]},
        ImageSizeCache->{{81.87499312856275, 
         94.52033907520783}, {-34.1532714642715, -23.502828900960694`}}],
       StatusArea[#, 0.16000000000000023`]& ,
       TagBoxNote->"0.16000000000000023"],
      StyleBox["0.16000000000000023`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.16000000000000023`, {
        GrayLevel[0]}], "Tooltip"]& ], {}, {}, 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{1.5, 0.45, 0}, {2., 0.5, 0.16000000000000003`}]},
        ImageSizeCache->{{48.69763858970542, 63.52832702875767}, {
         7.677943546362769, 20.623644434507952`}}],
       StatusArea[#, 0.16000000000000003`]& ,
       TagBoxNote->"0.16000000000000003"],
      StyleBox["0.16000000000000003`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.16000000000000003`, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{1.5, 0.5, 0}, {2., 0.55, 0.15999999999999986`}]},
        ImageSizeCache->{{53.74820993104538, 68.29586742749218}, {
         2.668856227346339, 15.326305873820019`}}],
       StatusArea[#, 0.15999999999999986`]& ,
       TagBoxNote->"0.15999999999999986"],
      StyleBox["0.15999999999999986`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.15999999999999986`, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{1.5, 0.55, 0}, {2., 0.6, 0.24000000000000035`}]},
        ImageSizeCache->{{58.52574021994826, 
         72.90637098344801}, {-3.5960604992571064`, 10.206376872464418`}}],
       StatusArea[#, 0.24000000000000035`]& ,
       TagBoxNote->"0.24000000000000035"],
      StyleBox["0.24000000000000035`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.24000000000000035`, {
        GrayLevel[0]}], "Tooltip"]& ], {}, 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{1.5, 0.65, 0}, {2., 0.7, 0.4800000000000007}]},
        ImageSizeCache->{{67.61890842106244, 
         81.68631348014117}, {-17.05234427577085, 0.4642537397583766}}],
       StatusArea[#, 0.4800000000000007]& ,
       TagBoxNote->"0.4800000000000007"],
      StyleBox["0.4800000000000007`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.4800000000000007, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{1.5, 0.7, 0}, {2., 0.75, 0.2399999999999998}]},
        ImageSizeCache->{{72.28348032355088, 
         85.8695965284675}, {-17.190634696961922`, -4.173812355558326}}],
       StatusArea[#, 0.2399999999999998]& ,
       TagBoxNote->"0.2399999999999998"],
      StyleBox["0.2399999999999998`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.2399999999999998, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{1.5, 0.75, 0}, {2., 0.8, 0.39999999999999963`}]},
        ImageSizeCache->{{76.4832471117268, 
         89.92360380900394}, {-24.225723551835813`, -8.666299132532572}}],
       StatusArea[#, 0.39999999999999963`]& ,
       TagBoxNote->"0.39999999999999963"],
      StyleBox["0.39999999999999963`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.39999999999999963`, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{1.5, 0.8, 0}, {2., 0.85, 0.24000000000000035`}]},
        ImageSizeCache->{{80.74693402134415, 
         93.85423664067955}, {-25.564360174698436`, -13.019954835761624`}}],
       StatusArea[#, 0.24000000000000035`]& ,
       TagBoxNote->"0.24000000000000035"],
      StyleBox["0.24000000000000035`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.24000000000000035`, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{1.5, 0.85, 0}, {2., 0.9, 0.7199999999999994}]},
        ImageSizeCache->{{84.62876075731467, 
         97.69493243795426}, {-37.8768659459714, -17.24111697503122}}],
       StatusArea[#, 0.7199999999999994]& ,
       TagBoxNote->"0.7199999999999994"],
      StyleBox["0.7199999999999994`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.7199999999999994, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{1.5, 0.9, 0}, {2., 0.95, 0.4800000000000007}]},
        ImageSizeCache->{{88.65740540556135, 
         101.4433189318121}, {-37.5365493311714, -21.335743106378942`}}],
       StatusArea[#, 0.4800000000000007]& ,
       TagBoxNote->"0.4800000000000007"],
      StyleBox["0.4800000000000007`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.4800000000000007, {
        GrayLevel[0]}], "Tooltip"]& ], {}, {}, 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{2., 0.45, 0}, {2.5, 0.5, 0.08000000000000002}]},
        ImageSizeCache->{{56.481013774580134`, 71.2096389379998}, {
         11.898836240526691`, 23.570403612453035`}}],
       StatusArea[#, 0.08000000000000002]& ,
       TagBoxNote->"0.08000000000000002"],
      StyleBox["0.08000000000000002`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.08000000000000002, {
        GrayLevel[0]}], "Tooltip"]& ], {}, 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{2., 0.55, 0}, {2.5, 0.6, 0.32000000000000045`}]},
        ImageSizeCache->{{65.96337877045717, 
         80.41680638222961}, {-2.4308853095803045`, 12.958192259634657`}}],
       StatusArea[#, 0.32000000000000045`]& ,
       TagBoxNote->"0.32000000000000045"],
      StyleBox["0.32000000000000045`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.32000000000000045`, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{2., 0.6, 0}, {2.5, 0.65, 0.7999999999999993}]},
        ImageSizeCache->{{70.21048637831952, 
         84.79463970217029}, {-15.89990566722706, 7.916611152172322}}],
       StatusArea[#, 0.7999999999999993]& ,
       TagBoxNote->"0.7999999999999993"],
      StyleBox["0.7999999999999993`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.7999999999999993, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{2., 0.65, 0}, {2.5, 0.7, 0.8000000000000012}]},
        ImageSizeCache->{{74.81253947299163, 
         89.03165479503299}, {-20.43469205127319, 3.0398493146968093`}}],
       StatusArea[#, 0.8000000000000012]& ,
       TagBoxNote->"0.8000000000000012"],
      StyleBox["0.8000000000000012`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.8000000000000012, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{2., 0.7, 0}, {2.5, 0.75, 1.0399999999999991`}]},
        ImageSizeCache->{{79.13211596217967, 
         93.13453849501362}, {-29.22643890011986, -1.6800456652153883`}}],
       StatusArea[#, 1.0399999999999991`]& ,
       TagBoxNote->"1.0399999999999991"],
      StyleBox["1.0399999999999991`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[1.0399999999999991`, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{2., 0.75, 0}, {2.5, 0.8, 0.8799999999999991}]},
        ImageSizeCache->{{83.54036971013697, 
         97.12810197139054}, {-30.52027207530388, -6.2505227001740735`}}],
       StatusArea[#, 0.8799999999999991]& ,
       TagBoxNote->"0.8799999999999991"],
      StyleBox["0.8799999999999991`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.8799999999999991, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{2., 0.8, 0}, {2.5, 0.85, 0.9600000000000014}]},
        ImageSizeCache->{{87.70426814358594, 
         101.11002378653852`}, {-36.069473685973605`, -10.678566430358856`}}],
       StatusArea[#, 0.9600000000000014]& ,
       TagBoxNote->"0.9600000000000014"],
      StyleBox["0.9600000000000014`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.9600000000000014, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{2., 0.85, 0}, {2.5, 0.9, 0.4799999999999996}]},
        ImageSizeCache->{{91.81145115151631, 
         104.83046522603009`}, {-31.55317256601971, -14.97073283975162}}],
       StatusArea[#, 0.4799999999999996]& ,
       TagBoxNote->"0.4799999999999996"],
      StyleBox["0.4799999999999996`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.4799999999999996, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{2., 0.9, 0}, {2.5, 0.95, 0.5600000000000008}]},
        ImageSizeCache->{{95.66704253969601, 
         108.54268890264899`}, {-36.8500926913469, -19.13318164319392}}],
       StatusArea[#, 0.5600000000000008]& ,
       TagBoxNote->"0.5600000000000008"],
      StyleBox["0.5600000000000008`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.5600000000000008, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{2., 0.95, 0}, {2.5, 1., 0.15999999999999986`}]},
        ImageSizeCache->{{99.36724134247942, 
         111.92221276471709`}, {-33.838473681908056`, -23.17170578075607}}],
       StatusArea[#, 0.15999999999999986`]& ,
       TagBoxNote->"0.15999999999999986"],
      StyleBox["0.15999999999999986`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.15999999999999986`, {
        GrayLevel[0]}], "Tooltip"]& ], {}, 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{2.5, 0.45, 0}, {3., 0.5, 0.08000000000000002}]},
        ImageSizeCache->{{64.27255167411931, 79.03533119037607}, {
         14.740827287196339`, 26.573528976623273`}}],
       StatusArea[#, 0.08000000000000002]& ,
       TagBoxNote->"0.08000000000000002"],
      StyleBox["0.08000000000000002`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.08000000000000002, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{2.5, 0.5, 0}, {3., 0.55, 0.15999999999999986`}]},
        ImageSizeCache->{{69.05748810741159, 83.62649066922305}, {
         8.10305429874657, 21.07338685071673}}],
       StatusArea[#, 0.15999999999999986`]& ,
       TagBoxNote->"0.15999999999999986"],
      StyleBox["0.15999999999999986`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.15999999999999986`, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{2.5, 0.55, 0}, {3., 0.6, 0.4000000000000006}]},
        ImageSizeCache->{{73.58357433625704, 
         88.0636758913122}, {-1.2375930868195582`, 15.760849501533244`}}],
       StatusArea[#, 0.4000000000000006]& ,
       TagBoxNote->"0.4000000000000006"],
      StyleBox["0.4000000000000006`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.4000000000000006, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{2.5, 0.6, 0}, {3., 0.65, 0.9599999999999992}]},
        ImageSizeCache->{{77.83877942941471, 
         92.35450489236695}, {-16.36564766829268, 10.626479343798351`}}],
       StatusArea[#, 0.9599999999999992]& ,
       TagBoxNote->"0.9599999999999992"],
      StyleBox["0.9599999999999992`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.9599999999999992, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{2.5, 0.65, 0}, {3., 0.7, 0.4800000000000007}]},
        ImageSizeCache->{{82.59141464056, 
         96.50610131471589}, {-12.17245534989813, 5.661461371303986}}],
       StatusArea[#, 0.4800000000000007]& ,
       TagBoxNote->"0.4800000000000007"],
      StyleBox["0.4800000000000007`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.4800000000000007, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{2.5, 0.7, 0}, {3., 0.75, 1.279999999999999}]},
        ImageSizeCache->{{86.68147979966967, 
         100.71198216533325`}, {-31.38468373495843, 0.8575526519309591}}],
       StatusArea[#, 1.279999999999999]& ,
       TagBoxNote->"1.279999999999999"],
      StyleBox["1.279999999999999`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[1.279999999999999, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{2.5, 0.75, 0}, {3., 0.8, 1.1999999999999988`}]},
        ImageSizeCache->{{90.98932443854758, 
         104.75605394910977`}, {-34.14093537010602, -3.792963339333042}}],
       StatusArea[#, 1.1999999999999988`]& ,
       TagBoxNote->"1.1999999999999988"],
      StyleBox["1.1999999999999988`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[1.1999999999999988`, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{2.5, 0.8, 0}, {3., 0.85, 1.7600000000000025`}]},
        ImageSizeCache->{{95.10956086235407, 
         108.92527022025494`}, {-48.828089896400016`, -8.297318081567326}}],
       StatusArea[#, 1.7600000000000025`]& ,
       TagBoxNote->"1.7600000000000025"],
      StyleBox["1.7600000000000025`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[1.7600000000000025`, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{2.5, 0.85, 0}, {3., 0.9, 1.5199999999999987`}]},
        ImageSizeCache->{{98.96260715577257, 
         112.66072748002762`}, {-48.19920129106093, -12.662295529601906`}}],
       StatusArea[#, 1.5199999999999987`]& ,
       TagBoxNote->"1.5199999999999987"],
      StyleBox["1.5199999999999987`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[1.5199999999999987`, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{2.5, 0.9, 0}, {3., 0.95, 0.8000000000000012}]},
        ImageSizeCache->{{102.69920690608767`, 
         115.90118487939682`}, {-38.96588474234359, -16.89426620569195}}],
       StatusArea[#, 0.8000000000000012]& ,
       TagBoxNote->"0.8000000000000012"],
      StyleBox["0.8000000000000012`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.8000000000000012, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{2.5, 0.95, 0}, {3., 1., 0.31999999999999973`}]},
        ImageSizeCache->{{106.32456039309669`, 
         119.06971032725305`}, {-34.48275432944169, -20.99921822150226}}],
       StatusArea[#, 0.31999999999999973`]& ,
       TagBoxNote->"0.31999999999999973"],
      StyleBox["0.31999999999999973`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.31999999999999973`, {
        GrayLevel[0]}], "Tooltip"]& ], {}, 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{3., 0.45, 0}, {3.5, 0.5, 0.24000000000000005`}]},
        ImageSizeCache->{{72.07540438361313, 87.00951313336483}, {
         14.736169138968691`, 29.63465341932161}}],
       StatusArea[#, 0.24000000000000005`]& ,
       TagBoxNote->"0.24000000000000005"],
      StyleBox["0.24000000000000005`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.24000000000000005`, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{3., 0.5, 0}, {3.5, 0.55, 0.31999999999999973`}]},
        ImageSizeCache->{{76.8218849401992, 91.50621660116164}, {
         7.996559303414273, 24.028713932158695`}}],
       StatusArea[#, 0.31999999999999973`]& ,
       TagBoxNote->"0.31999999999999973"],
      StyleBox["0.31999999999999973`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.31999999999999973`, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{3., 0.55, 0}, {3.5, 0.6, 0.5600000000000008}]},
        ImageSizeCache->{{81.35341394977357, 
         95.8507312683561}, {-1.4854401001861106`, 18.615770747942747`}}],
       StatusArea[#, 0.5600000000000008]& ,
       TagBoxNote->"0.5600000000000008"],
      StyleBox["0.5600000000000008`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.5600000000000008, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{3., 0.6, 0}, {3.5, 0.65, 0.2399999999999998}]},
        ImageSizeCache->{{85.9891627856698, 
         100.08169834618556`}, {-0.5930688599735134, 13.386026063880081`}}],
       StatusArea[#, 0.2399999999999998]& ,
       TagBoxNote->"0.2399999999999998"],
      StyleBox["0.2399999999999998`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.2399999999999998, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{3., 0.65, 0}, {3.5, 0.7, 1.0400000000000016`}]},
        ImageSizeCache->{{90.19371190185277, 
         104.4054134118014}, {-19.991174937248147`, 8.330334245017596}}],
       StatusArea[#, 1.0400000000000016`]& ,
       TagBoxNote->"1.0400000000000016"],
      StyleBox["1.0400000000000016`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[1.0400000000000016`, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{3., 0.7, 0}, {3.5, 0.75, 1.5199999999999987`}]},
        ImageSizeCache->{{94.50610131471589, 
         108.69321389848287`}, {-33.62029410909307, 3.4401484498928454`}}],
       StatusArea[#, 1.5199999999999987`]& ,
       TagBoxNote->"1.5199999999999987"],
      StyleBox["1.5199999999999987`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[1.5199999999999987`, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{3., 0.75, 0}, {3.5, 0.8, 1.359999999999999}]},
        ImageSizeCache->{{98.52513387325453, 
         112.60605919316704`}, {-34.86187825636047, -1.2925275863552486`}}],
       StatusArea[#, 1.359999999999999]& ,
       TagBoxNote->"1.359999999999999"],
      StyleBox["1.359999999999999`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[1.359999999999999, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{3., 0.8, 0}, {3.5, 0.85, 1.8400000000000025`}]},
        ImageSizeCache->{{102.41785210027587`, 
         116.80672527024825`}, {-48.20848003842279, -5.8751831836137995`}}],
       StatusArea[#, 1.8400000000000025`]& ,
       TagBoxNote->"1.8400000000000025"],
      StyleBox["1.8400000000000025`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[1.8400000000000025`, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{3., 0.85, 0}, {3.5, 0.9, 1.5199999999999987`}]},
        ImageSizeCache->{{106.19011877216614`, 
         120.32368730764314`}, {-46.07680247069679, -10.31484026394179}}],
       StatusArea[#, 1.5199999999999987`]& ,
       TagBoxNote->"1.5199999999999987"],
      StyleBox["1.5199999999999987`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[1.5199999999999987`, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{3., 0.9, 0}, {3.5, 0.95, 1.360000000000002}]},
        ImageSizeCache->{{109.84743937184524`, 
         123.80232932632507`}, {-46.996239705909474`, -14.61808925346756}}],
       StatusArea[#, 1.360000000000002]& ,
       TagBoxNote->"1.360000000000002"],
      StyleBox["1.360000000000002`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[1.360000000000002, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{3., 0.95, 0}, {3.5, 1., 0.2399999999999998}]},
        ImageSizeCache->{{113.39498889834337`, 
         126.17535618220937`}, {-31.03179271188189, -18.79112172510699}}],
       StatusArea[#, 0.2399999999999998]& ,
       TagBoxNote->"0.2399999999999998"],
      StyleBox["0.2399999999999998`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.2399999999999998, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{3.5, 0.4, 0}, {4., 0.45, 0.08000000000000002}]},
        ImageSizeCache->{{75.46628897680294, 90.58030507985914}, {
         26.184674787663482`, 38.67981055586748}}],
       StatusArea[#, 0.08000000000000002]& ,
       TagBoxNote->"0.08000000000000002"],
      StyleBox["0.08000000000000002`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.08000000000000002, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{3.5, 0.45, 0}, {4., 0.5, 0.08000000000000002}]},
        ImageSizeCache->{{80.3084631671428, 95.13645155490782}, {
         20.58708094341332, 32.75547351963116}}],
       StatusArea[#, 0.08000000000000002]& ,
       TagBoxNote->"0.08000000000000002"],
      StyleBox["0.08000000000000002`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.08000000000000002, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{3.5, 0.5, 0}, {4., 0.55, 0.07999999999999993}]},
        ImageSizeCache->{{84.98049722886496, 99.54344514541728}, {
         15.182774723520652`, 27.04065438926282}}],
       StatusArea[#, 0.07999999999999993]& ,
       TagBoxNote->"0.07999999999999993"],
      StyleBox["0.07999999999999993`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.07999999999999993, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{3.5, 0.55, 0}, {4., 0.6, 0.5600000000000008}]},
        ImageSizeCache->{{89.3991982140389, 103.93634983218281`}, {
         1.2375141049968477`, 21.52443168840231}}],
       StatusArea[#, 0.5600000000000008]& ,
       TagBoxNote->"0.5600000000000008"],
      StyleBox["0.5600000000000008`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.5600000000000008, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{3.5, 0.6, 0}, {4., 0.65, 0.39999999999999963`}]},
        ImageSizeCache->{{93.8409434628426, 
         108.05544873722604`}, {-0.8278620198042432, 16.19663004403803}}],
       StatusArea[#, 0.39999999999999963`]& ,
       TagBoxNote->"0.39999999999999963"],
      StyleBox["0.39999999999999963`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.39999999999999963`, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{3.5, 0.65, 0}, {4., 0.7, 1.2000000000000017`}]},
        ImageSizeCache->{{98.05065470377708, 
         112.54725122752906`}, {-20.523959058263756`, 11.047757543581014`}}],
       StatusArea[#, 1.2000000000000017`]& ,
       TagBoxNote->"1.2000000000000017"],
      StyleBox["1.2000000000000017`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[1.2000000000000017`, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{3.5, 0.7, 0}, {4., 0.75, 0.5599999999999995}]},
        ImageSizeCache->{{102.11308703952186`, 
         116.08376563068242`}, {-13.234457013498599`, 6.0689492991170795`}}],
       StatusArea[#, 0.5599999999999995]& ,
       TagBoxNote->"0.5599999999999995"],
      StyleBox["0.5599999999999995`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.5599999999999995, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{3.5, 0.75, 0}, {4., 0.8, 0.7999999999999993}]},
        ImageSizeCache->{{106.04467102625424`, 
         120.0692742532531}, {-22.09712654307718, 1.2519165129264707`}}],
       StatusArea[#, 0.7999999999999993]& ,
       TagBoxNote->"0.7999999999999993"],
      StyleBox["0.7999999999999993`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.7999999999999993, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{3.5, 0.8, 0}, {4., 0.85, 0.4000000000000006}]},
        ImageSizeCache->{{109.85162827938042`, 
         123.38249294015337`}, {-19.27659920218035, -3.4110995713576386`}}],
       StatusArea[#, 0.4000000000000006]& ,
       TagBoxNote->"0.4000000000000006"],
      StyleBox["0.4000000000000006`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.4000000000000006, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{3.5, 0.85, 0}, {4., 0.9, 1.0399999999999991`}]},
        ImageSizeCache->{{113.53979213211653`, 
         127.5925670731463}, {-34.98622809806723, -7.927369370084861}}],
       StatusArea[#, 1.0399999999999991`]& ,
       TagBoxNote->"1.0399999999999991"],
      StyleBox["1.0399999999999991`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[1.0399999999999991`, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{3.5, 0.9, 0}, {4., 0.95, 0.7200000000000011}]},
        ImageSizeCache->{{117.11463746033263`, 
         130.70292328028924`}, {-33.27459145443048, -12.303712784859258`}}],
       StatusArea[#, 0.7200000000000011]& ,
       TagBoxNote->"0.7200000000000011"],
      StyleBox["0.7200000000000011`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.7200000000000011, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{3.5, 0.95, 0}, {4., 1., 0.39999999999999963`}]},
        ImageSizeCache->{{120.58130779989352`, 
         133.6526863063067}, {-31.650606788851576`, -16.546533565653547`}}],
       StatusArea[#, 0.39999999999999963`]& ,
       TagBoxNote->"0.39999999999999963"],
      StyleBox["0.39999999999999963`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.39999999999999963`, {
        GrayLevel[0]}], "Tooltip"]& ], {}, {}, {}, {}, 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{4., 0.6, 0}, {4.5, 0.65, 0.15999999999999986`}]},
        ImageSizeCache->{{101.78186310140653`, 115.98161479244463`}, {
         6.199480199184947, 19.059721510986506`}}],
       StatusArea[#, 0.15999999999999986`]& ,
       TagBoxNote->"0.15999999999999986"],
      StyleBox["0.15999999999999986`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.15999999999999986`, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{4., 0.65, 0}, {4.5, 0.7, 0.32000000000000045`}]},
        ImageSizeCache->{{105.886807940128, 
         120.01151121219472`}, {-1.6234015709938632`, 13.815068224854159`}}],
       StatusArea[#, 0.32000000000000045`]& ,
       TagBoxNote->"0.32000000000000045"],
      StyleBox["0.32000000000000045`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.32000000000000045`, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{4., 0.7, 0}, {4.5, 0.75, 0.2399999999999998}]},
        ImageSizeCache->{{109.85616884473036`, 
         123.71700587267492`}, {-4.97640783722413, 8.745206369191763}}],
       StatusArea[#, 0.2399999999999998]& ,
       TagBoxNote->"0.2399999999999998"],
      StyleBox["0.2399999999999998`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.2399999999999998, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{4., 0.75, 0}, {4.5, 0.8, 0.15999999999999986`}]},
        ImageSizeCache->{{113.69655406923734`, 
         127.28141244478316`}, {-8.202858849359785, 3.8415411118368894`}}],
       StatusArea[#, 0.15999999999999986`]& ,
       TagBoxNote->"0.15999999999999986"],
      StyleBox["0.15999999999999986`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.15999999999999986`, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{4., 0.8, 0}, {4.5, 0.85, 0.6400000000000009}]},
        ImageSizeCache->{{117.41414929156188`, 
         131.38844720044688`}, {-21.203301982923634`, -0.9039679672193159}}],
       StatusArea[#, 0.6400000000000009]& ,
       TagBoxNote->"0.6400000000000009"],
      StyleBox["0.6400000000000009`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.6400000000000009, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{4., 0.85, 0}, {4.5, 0.9, 0.39999999999999963`}]},
        ImageSizeCache->{{121.0147508599467, 
         134.5346187145399}, {-21.24252426660196, -5.498850869522499}}],
       StatusArea[#, 0.39999999999999963`]& ,
       TagBoxNote->"0.39999999999999963"],
      StyleBox["0.39999999999999963`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.39999999999999963`, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{4., 0.9, 0}, {4.5, 0.95, 0.4800000000000007}]},
        ImageSizeCache->{{124.5037959492078, 
         137.97888105055236`}, {-26.83510957990663, -9.950167048108483}}],
       StatusArea[#, 0.4800000000000007]& ,
       TagBoxNote->"0.4800000000000007"],
      StyleBox["0.4800000000000007`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.4800000000000007, {
        GrayLevel[0]}], "Tooltip"]& ], {}, 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{4.5, 0.4, 0}, {5., 0.45, 0.08000000000000002}]},
        ImageSizeCache->{{92.34799643769014, 107.56218464866747`}, {
         32.479118881856635`, 45.347911769992244`}}],
       StatusArea[#, 0.08000000000000002]& ,
       TagBoxNote->"0.08000000000000002"],
      StyleBox["0.08000000000000002`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.08000000000000002, {
        GrayLevel[0]}], "Tooltip"]& ], {}, {}, 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{4.5, 0.55, 0}, {5., 0.6, 0.16000000000000023`}]},
        ImageSizeCache->{{105.71486899322531`, 120.23627733149425`}, {
         14.18362154975118, 27.50915851553495}}],
       StatusArea[#, 0.16000000000000023`]& ,
       TagBoxNote->"0.16000000000000023"],
      StyleBox["0.16000000000000023`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.16000000000000023`, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{4.5, 0.6, 0}, {5., 0.65, 0.07999999999999993}]},
        ImageSizeCache->{{109.8611072904701, 124.07669661112638`}, {
         10.390207879355046`, 21.976784613346013`}}],
       StatusArea[#, 0.07999999999999993]& ,
       TagBoxNote->"0.07999999999999993"],
      StyleBox["0.07999999999999993`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.07999999999999993, {
        GrayLevel[0]}], "Tooltip"]& ], {}, 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{4.5, 0.7, 0}, {5., 0.75, 0.15999999999999986`}]},
        ImageSizeCache->{{117.73903202604401`, 
         131.6135277816353}, {-0.9795823026832267, 11.470216414443811`}}],
       StatusArea[#, 0.15999999999999986`]& ,
       TagBoxNote->"0.15999999999999986"],
      StyleBox["0.15999999999999986`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.15999999999999986`, {
        GrayLevel[0]}], "Tooltip"]& ], {}, 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{4.5, 0.8, 0}, {5., 0.85, 0.24000000000000035`}]},
        ImageSizeCache->{{125.10878893053099`, 
         138.70601437761906`}, {-11.684860884591359`, 1.647349654006021}}],
       StatusArea[#, 0.24000000000000035`]& ,
       TagBoxNote->"0.24000000000000035"],
      StyleBox["0.24000000000000035`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.24000000000000035`, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{4.5, 0.85, 0}, {5., 0.9, 0.07999999999999993}]},
        ImageSizeCache->{{128.61822598845373`, 
         141.78455355359227`}, {-13.328169919240679`, -3.028216990594558}}],
       StatusArea[#, 0.07999999999999993]& ,
       TagBoxNote->"0.07999999999999993"],
      StyleBox["0.07999999999999993`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.07999999999999993, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{4.5, 0.9, 0}, {5., 0.95, 0.16000000000000023`}]},
        ImageSizeCache->{{132.01801098533156`, 
         145.12714169822974`}, {-19.00854583540344, -7.556449186522315}}],
       StatusArea[#, 0.16000000000000023`]& ,
       TagBoxNote->"0.16000000000000023"],
      StyleBox["0.16000000000000023`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.16000000000000023`, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{4.5, 0.95, 0}, {5., 1., 0.07999999999999993}]},
        ImageSizeCache->{{135.31320397461434`, 
         148.10834074061188`}, {-21.806787977516265`, -11.944203020579337`}}],
       StatusArea[#, 0.07999999999999993]& ,
       TagBoxNote->"0.07999999999999993"],
      StyleBox["0.07999999999999993`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.07999999999999993, {
        GrayLevel[0]}], 
      "Tooltip"]& ], {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, {}, \
{}, {}, {}, {}, {}, {}, {}, 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            RGBColor[
            0.6666666666666666, 0.6666666666666666, 0.6666666666666666], 
            AbsoluteThickness[1.5]}], {}, {}], 
         CuboidBox[{5.5, 0.85, 0}, {6., 0.9, 0.07999999999999993}]},
        ImageSizeCache->{{144.22421480561823`, 
         157.51364171016138`}, {-8.509931681797454, 2.0438564299502247`}}],
       StatusArea[#, 0.07999999999999993]& ,
       TagBoxNote->"0.07999999999999993"],
      StyleBox["0.07999999999999993`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.07999999999999993, {
        GrayLevel[0]}], "Tooltip"]& ], {}, {}}, {}, {}},
  Axes->{True, True, True},
  BoxRatios->{1, 1, 0.4},
  Lighting->"Neutral",
  Method->{"RotationControl" -> "Globe"},
  PlotRangePadding->Scaled[0.02],
  Ticks->{Automatic, Automatic, Automatic}]], "Output",
 ImageSize->{184, 140},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[29]=",
 CellID->6325947]
}, Open  ]],

Cell[TextData[{
 "\:0414\:0440\:0443\:0433\:0438\:0435 \:043f\:0440\:0438\:043c\:0435\:0440\
\:044b \:043f\:0440\:0438\:043c\:0435\:043d\:0435\:043d\:0438\:044f \:043c\
\:0435\:0442\:043e\:0434\:0430 \:041c\:043e\:043d\:0442\:0435-\:041a\:0430\
\:0440\:043b\:043e \:0434\:043b\:044f \:0441\:0442\:0430\:0442\:0438\:0441\
\:0442\:0438\:0447\:0435\:0441\:043a\:0438\:0445 \:043e\:0446\:0435\:043d\
\:043e\:043a \:0432\:043a\:043b\:044e\:0447\:0430\:044e\:0442 \:0432 \:0441\
\:0435\:0431\:044f \:043e\:043f\:0442\:0438\:043c\:0438\:0437\:0430\:0446\
\:0438\:044e \:0438 \:043c\:043d\:043e\:0433\:043e\:043c\:0435\:0440\:043d\
\:0443\:044e \:0438\:043d\:0442\:0435\:0433\:0440\:0430\:0446\:0438\:044e. \
\:0424\:0443\:043d\:043a\:0446\:0438\:0438 ",
 Cell[BoxData[
  ButtonBox["NMinimize",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/NMinimize"]], "InlineFormula"],
 " \:0438 ",
 Cell[BoxData[
  ButtonBox["NIntegrate",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/NIntegrate"]], "InlineFormula"],
 " \:0441\:043e\:0434\:0435\:0440\:0436\:0430\:0442 \:043c\:0435\:0442\:043e\
\:0434\:044b \:043e\:043f\:0442\:0438\:043c\:0438\:0437\:0430\:0446\:0438\
\:0438 \:0438 \:0447\:0438\:0441\:043b\:0435\:043d\:043d\:043e\:0439 \:0438\
\:043d\:0442\:0435\:0433\:0440\:0430\:0446\:0438\:0438, \:0438\:0441\:043f\
\:043e\:043b\:044c\:0437\:0443\:044e\:0449\:0438\:0435 \:044d\:0442\:0438 \
\:0442\:0435\:0445\:043d\:0438\:043a\:0438."
}], "HowToText",
 CellID->240435987]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  InterpretationBox[
   StyleBox[
    GraphicsBox[{},
     BaselinePosition->Baseline,
     ImageSize->{6, 0}],
    CacheGraphics->False],
   Spacer[6]]]],
 "\:0423\:0447\:0435\:0431\:043d\:044b\:0435 \:043c\:0430\:0442\:0435\:0440\
\:0438\:0430\:043b\:044b"
}], "TutorialsSection",
 WholeCellGroupOpener->True,
 CellID->250839057],

Cell["", "SectionHeaderSpacer"],

Cell[BoxData[
 TemplateBox[{
  Cell["Numerical Operations on Data"],
   "paclet:tutorial/NumericalOperationsOnDataOverview"},
  "RefLink",
  BaseStyle->"Tutorials"]], "Tutorials",
 CellID->341631938],

Cell[BoxData[
 TemplateBox[{
  Cell["Pseudorandom Numbers"],"paclet:tutorial/PseudorandomNumbers"},
  "RefLink",
  BaseStyle->"Tutorials"]], "Tutorials",
 CellID->413676733],

Cell[BoxData[
 TemplateBox[{
  Cell["Random Number Generation"],"paclet:tutorial/RandomNumberGeneration"},
  "RefLink",
  BaseStyle->"Tutorials"]], "Tutorials",
 CellID->1260286192],

Cell["", "SectionFooterSpacer"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  InterpretationBox[
   StyleBox[
    GraphicsBox[{},
     BaselinePosition->Baseline,
     ImageSize->{6, 0}],
    CacheGraphics->False],
   Spacer[6]]]],
 "\:0421\:043e\:043f\:0443\:0442\:0441\:0442\:0432\:0443\:044e\:0449\:0438\
\:0435 \:0440\:0430\:0437\:0434\:0435\:043b\:044b \:043a\:0440\:0430\:0442\
\:043a\:043e\:0433\:043e \:043a\:0443\:0440\:0441\:0430"
}], "RelatedLinksSection",
 WholeCellGroupOpener->True,
 CellID->1584193535],

Cell["", "SectionHeaderSpacer"],

Cell[TextData[ButtonBox["\:041a\:0440\:0430\:0442\:043a\:0438\:0439 \:043a\
\:0443\:0440\:0441: \:0421\:0442\:0430\:0442\:0438\:0441\:0442\:0438\:0447\
\:0435\:0441\:043a\:0438\:0439 \:0430\:043d\:0430\:043b\:0438\:0437",
 BaseStyle->"Hyperlink",
 ButtonData->{"DoStatisticalAnalysisRU.nb", None}]], "RelatedLinks",
 FontFamily->"Verdana",
 FontSize->11,
 CellID->405226890],

Cell["", "SectionFooterSpacer"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  InterpretationBox[
   StyleBox[
    GraphicsBox[{},
     BaselinePosition->Baseline,
     ImageSize->{6, 0}],
    CacheGraphics->False],
   Spacer[6]]]],
 "\:0421\:043c\:043e\:0442\:0440\:0438 \:0442\:0430\:043a\:0436\:0435"
}], "SeeAlsoSection",
 WholeCellGroupOpener->True,
 CellID->1255426704],

Cell[TextData[{
 Cell[BoxData[
  TemplateBox[{Cell["RandomVariate"],"paclet:ref/RandomVariate"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  TemplateBox[{Cell["RandomReal"],"paclet:ref/RandomReal"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"]
}], "SeeAlso",
 CellID->929782353]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  InterpretationBox[
   StyleBox[
    GraphicsBox[{},
     BaselinePosition->Baseline,
     ImageSize->{6, 0}],
    CacheGraphics->False],
   Spacer[6]]]],
 "\:0423\:0437\:043d\:0430\:0442\:044c \:0431\:043e\:043b\:044c\:0448\:0435"
}], "MoreAboutSection",
 WholeCellGroupOpener->True,
 CellID->38303248],

Cell["", "SectionHeaderSpacer"],

Cell[BoxData[
 TemplateBox[{Cell["Numerical Data"],"paclet:guide/NumericalData"},
  "RefLink",
  BaseStyle->"MoreAbout"]], "MoreAbout",
 CellID->1665078683],

Cell[BoxData[
 TemplateBox[{
  Cell["Handling Arrays of Data"],"paclet:guide/HandlingArraysOfData"},
  "RefLink",
  BaseStyle->"MoreAbout"]], "MoreAbout",
 CellID->998818583],

Cell[BoxData[
 TemplateBox[{Cell["Statistics"],"paclet:guide/Statistics"},
  "RefLink",
  BaseStyle->"MoreAbout"]], "MoreAbout",
 CellID->264255882],

Cell[BoxData[
 TemplateBox[{
  Cell["Descriptive Statistics"],"paclet:guide/DescriptiveStatistics"},
  "RefLink",
  BaseStyle->"MoreAbout"]], "MoreAbout",
 CellID->352426778],

Cell[BoxData[
 TemplateBox[{
  Cell["Statistical Model Analysis"],"paclet:guide/StatisticalModelAnalysis"},
  "RefLink",
  BaseStyle->"MoreAbout"]], "MoreAbout",
 CellID->476959420],

Cell[BoxData[
 TemplateBox[{
  Cell["Random Number Generation"],"paclet:guide/RandomNumberGeneration"},
  "RefLink",
  BaseStyle->"MoreAbout"]], "MoreAbout",
 CellID->1848001336],

Cell[BoxData[
 TemplateBox[{Cell["Data Visualization"],"paclet:guide/DataVisualization"},
  "RefLink",
  BaseStyle->"MoreAbout"]], "MoreAbout",
 CellID->302467591],

Cell[BoxData[
 TemplateBox[{Cell["\"How to\" Topics"],"paclet:guide/HowToTopics"},
  "RefLink",
  BaseStyle->"MoreAbout"]], "MoreAbout",
 CellID->938047159]
}, Open  ]]
}, Open  ]],

Cell[" ", "FooterCell"]
},
FileChangeProtection->None,
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{Automatic, 510},
WindowMargins->{{312, Automatic}, {Automatic, 0}},
WindowFrame->"Normal",
WindowTitle->"Perform a Monte Carlo Simulation - Wolfram Mathematica",
DockedCells->FEPrivate`FrontEndResource["FEExpressions", "HelpViewerToolbar"],
TaggingRules->{
 "ModificationHighlight" -> False, "ColorType" -> "TutorialColor", 
  "LinkTrails" -> "", "ExampleCounter" -> 1, "ExamplePageLinks" -> {}, 
  "RootCaptions" -> "", 
  "Metadata" -> {
   "built" -> "{2013, 1, 24, 22, 48, 34.9482335}", 
    "history" -> {"8.0", "", "", ""}, "context" -> "System`", 
    "keywords" -> {
     "monte carlo", "simulation", "random process", "stochastic simulation", 
      "random walk", "approximating pi", "Gibbs sampler", "Gibbs sampling", 
      "mixture distribution", "Bayesian analysis", "approximation"}, 
    "specialkeywords" -> {}, "tutorialcollectionlinks" -> {}, "index" -> True,
     "label" -> "Mathematica How To", "language" -> "en", "paclet" -> 
    "Mathematica", "status" -> "None", "summary" -> 
    "Monte Carlo methods use randomly generated numbers or events to simulate \
random processes and estimate complicated results. For example, they are used \
to model financial systems, to simulate telecommunication networks, and to \
compute results for high-dimensional integrals in physics. Monte Carlo \
simulations can be constructed directly by using Mathematica 's built-in \
random number generation functions.", "synonyms" -> {}, "title" -> 
    "Perform a Monte Carlo Simulation", "titlemodifier" -> "", "windowtitle" -> 
    "Perform a Monte Carlo Simulation", "type" -> "HowTo", "uri" -> 
    "howto/PerformAMonteCarloSimulation"}, "SearchTextTranslated" -> ""},
Magnification->1.,
FrontEndVersion->"10.1 for Microsoft Windows (64-bit) (March 23, 2015)",
StyleDefinitions->FrontEnd`FileName[{"Wolfram"}, "Reference.nb", 
  CharacterEncoding -> "WindowsANSI"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "RasterizedOutput"->{
  Cell[38755, 913, 27880, 465, 197, "Output",
   CellTags->"RasterizedOutput",
   CellID->590802568],
  Cell[86915, 1807, 5477, 98, 129, "Output",
   CellTags->"RasterizedOutput",
   CellID->436272664]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"RasterizedOutput", 163670, 3844}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[625, 21, 5178, 125, 48, "AnchorBarGrid",
 CellID->1],
Cell[CellGroupData[{
Cell[5828, 150, 352, 8, 91, "HowToTitle",
 CellID->509267359],
Cell[CellGroupData[{
Cell[6205, 162, 2312, 34, 108, "HowToAbstract",
 CellID->1045883471],
Cell[8520, 198, 1359, 20, 74, "HowToText",
 CellID->231582574],
Cell[9882, 220, 1110, 21, 76, "HowToText",
 CellID->1009846402],
Cell[CellGroupData[{
Cell[11017, 245, 236, 7, 28, "Input",
 CellID->827466675],
Cell[11256, 254, 973, 22, 71, "Output",
 CellID->240359784]
}, Open  ]],
Cell[12244, 279, 407, 10, 40, "HowToText",
 CellID->1389965763],
Cell[CellGroupData[{
Cell[12676, 293, 110, 3, 28, "Input",
 CellID->411630083],
Cell[12789, 298, 726, 19, 157, "Output",
 CellID->48514815]
}, Open  ]],
Cell[13530, 320, 408, 7, 38, "HowToText",
 CellID->1322801873],
Cell[CellGroupData[{
Cell[13963, 331, 113, 3, 28, "Input",
 CellID->11302808],
Cell[14079, 336, 837, 22, 159, "Output",
 CellID->126322202]
}, Open  ]],
Cell[14931, 361, 363, 7, 38, "HowToText",
 CellID->812217608],
Cell[CellGroupData[{
Cell[15319, 372, 163, 5, 28, "Input",
 CellID->1129699873],
Cell[15485, 379, 982, 22, 71, "Output",
 CellID->11902110]
}, Open  ]],
Cell[CellGroupData[{
Cell[16504, 406, 114, 3, 28, "Input",
 CellID->402046648],
Cell[16621, 411, 840, 22, 160, "Output",
 CellID->77340569]
}, Open  ]],
Cell[17476, 436, 903, 20, 60, "HowToText",
 CellID->1580365767],
Cell[CellGroupData[{
Cell[18404, 460, 153, 4, 28, "Input",
 CellID->1398028897],
Cell[18560, 466, 837, 22, 171, "Output",
 CellID->39654963]
}, Open  ]],
Cell[19412, 491, 1222, 18, 74, "HowToText",
 CellID->773710253],
Cell[20637, 511, 616, 14, 40, "HowToText",
 CellID->165287740],
Cell[21256, 527, 382, 12, 28, "Input",
 CellID->117258227],
Cell[21641, 541, 982, 20, 60, "HowToText",
 CellID->803924961],
Cell[CellGroupData[{
Cell[22648, 565, 231, 7, 28, "Input",
 CellID->219941940],
Cell[22882, 574, 8163, 147, 162, "Output",
 CellID->76831591]
}, Open  ]],
Cell[31060, 724, 1039, 17, 58, "HowToText",
 CellID->241676294],
Cell[32102, 743, 245, 8, 28, "Input",
 CellID->104955898],
Cell[32350, 753, 901, 14, 56, "HowToText",
 CellID->212592104],
Cell[33254, 769, 812, 18, 58, "HowToText",
 CellID->165948033],
Cell[34069, 789, 224, 8, 28, "Input",
 CellID->550673364],
Cell[34296, 799, 537, 9, 38, "HowToText",
 CellID->118701798],
Cell[CellGroupData[{
Cell[34858, 812, 290, 8, 28, "Input",
 CellID->82679961],
Cell[35151, 822, 337, 10, 36, "Output",
 CellID->73428001]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[35537, 838, 66, 2, 15, "HowToDelimiter",
 CellID->219617233],
Cell[35606, 842, 1974, 29, 93, "HowToText",
 CellID->19005116],
Cell[37583, 873, 431, 10, 39, "HowToText",
 CellID->729454103],
Cell[38017, 885, 311, 11, 28, "Input",
 CellID->301947459],
Cell[38331, 898, 198, 3, 38, "HowToText",
 CellID->759761004],
Cell[CellGroupData[{
Cell[38554, 905, 198, 6, 28, "Input",
 CellID->191132991],
Cell[38755, 913, 27880, 465, 197, "Output",
 CellTags->"RasterizedOutput",
 CellID->590802568]
}, Open  ]],
Cell[66650, 1381, 929, 16, 57, "HowToText",
 CellID->240307068],
Cell[67582, 1399, 571, 9, 56, "HowToText",
 CellID->149798134],
Cell[CellGroupData[{
Cell[68178, 1412, 361, 13, 28, "Input",
 CellID->258614930],
Cell[68542, 1427, 165, 5, 36, "Output",
 CellID->144544110]
}, Open  ]],
Cell[68722, 1435, 774, 12, 56, "HowToText",
 CellID->126123407],
Cell[69499, 1449, 715, 16, 59, "HowToText",
 CellID->535273393],
Cell[70217, 1467, 650, 22, 28, "Input",
 CellID->679590844],
Cell[70870, 1491, 392, 8, 39, "HowToText",
 CellID->110572458],
Cell[CellGroupData[{
Cell[71287, 1503, 129, 4, 28, "Input",
 CellID->385453611],
Cell[71419, 1509, 166, 5, 36, "Output",
 CellID->35815205]
}, Open  ]],
Cell[71600, 1517, 633, 11, 57, "HowToText",
 CellID->13105520],
Cell[CellGroupData[{
Cell[72258, 1532, 224, 7, 28, "Input",
 CellID->257188490],
Cell[72485, 1541, 177, 5, 36, "Output",
 CellID->152766616]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[72711, 1552, 65, 2, 15, "HowToDelimiter",
 CellID->20856566],
Cell[72779, 1556, 2400, 33, 110, "HowToText",
 CellID->458077360],
Cell[75182, 1591, 1371, 20, 74, "HowToText",
 CellID->241669213],
Cell[76556, 1613, 1799, 25, 92, "HowToText",
 CellID->82821640],
Cell[78358, 1640, 475, 8, 38, "HowToText",
 CellID->74027572],
Cell[78836, 1650, 238, 7, 28, "Input",
 CellID->164709778],
Cell[79077, 1659, 1095, 16, 74, "HowToText",
 CellID->515821892],
Cell[80175, 1677, 270, 8, 28, "Input",
 CellID->127964417],
Cell[80448, 1687, 4435, 60, 200, "HowToText",
 CellID->1006787458],
Cell[84886, 1749, 681, 11, 56, "HowToText",
 CellID->926141267],
Cell[85570, 1762, 750, 23, 65, "Input",
 CellID->551406535],
Cell[86323, 1787, 457, 11, 40, "HowToText",
 CellID->413575971],
Cell[CellGroupData[{
Cell[86805, 1802, 107, 3, 28, "Input",
 CellID->10395743],
Cell[86915, 1807, 5477, 98, 129, "Output",
 CellTags->"RasterizedOutput",
 CellID->436272664]
}, Open  ]],
Cell[92407, 1908, 539, 12, 40, "HowToText",
 CellID->205670445],
Cell[CellGroupData[{
Cell[92971, 1924, 180, 5, 28, "Input",
 CellID->335757017],
Cell[93154, 1931, 62269, 1656, 207, "Output",
 CellID->6325947]
}, Open  ]],
Cell[155438, 3590, 1467, 27, 76, "HowToText",
 CellID->240435987]
}, Open  ]],
Cell[CellGroupData[{
Cell[156942, 3622, 362, 13, 31, "TutorialsSection",
 CellID->250839057],
Cell[157307, 3637, 31, 0, 14, "SectionHeaderSpacer"],
Cell[157341, 3639, 199, 6, 19, "Tutorials",
 CellID->341631938],
Cell[157543, 3647, 173, 5, 19, "Tutorials",
 CellID->413676733],
Cell[157719, 3654, 181, 5, 19, "Tutorials",
 CellID->1260286192],
Cell[157903, 3661, 31, 0, 29, "SectionFooterSpacer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[157971, 3666, 472, 14, 31, "RelatedLinksSection",
 CellID->1584193535],
Cell[158446, 3682, 31, 0, 14, "SectionHeaderSpacer"],
Cell[158480, 3684, 374, 7, 18, "RelatedLinks",
 CellID->405226890],
Cell[158857, 3693, 31, 0, 29, "SectionFooterSpacer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[158925, 3698, 329, 12, 31, "SeeAlsoSection",
 CellID->1255426704],
Cell[159257, 3712, 508, 14, 58, "SeeAlso",
 CellID->929782353]
}, Open  ]],
Cell[CellGroupData[{
Cell[159802, 3731, 335, 12, 31, "MoreAboutSection",
 CellID->38303248],
Cell[160140, 3745, 31, 0, 14, "SectionHeaderSpacer"],
Cell[160174, 3747, 156, 4, 19, "MoreAbout",
 CellID->1665078683],
Cell[160333, 3753, 174, 5, 19, "MoreAbout",
 CellID->998818583],
Cell[160510, 3760, 148, 4, 19, "MoreAbout",
 CellID->264255882],
Cell[160661, 3766, 174, 5, 19, "MoreAbout",
 CellID->352426778],
Cell[160838, 3773, 181, 5, 19, "MoreAbout",
 CellID->476959420],
Cell[161022, 3780, 178, 5, 19, "MoreAbout",
 CellID->1848001336],
Cell[161203, 3787, 163, 4, 19, "MoreAbout",
 CellID->302467591],
Cell[161369, 3793, 156, 4, 19, "MoreAbout",
 CellID->938047159]
}, Open  ]]
}, Open  ]],
Cell[161552, 3801, 23, 0, 41, "FooterCell"]
}
]
*)

(* End of internal cache information *)
