(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     76438,       2092]
NotebookOptionsPosition[     68863,       1859]
NotebookOutlinePosition[     70922,       1905]
CellTagsIndexPosition[     70879,       1902]
WindowTitle->Perform Operations on Subgroups of Data - Wolfram Mathematica
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[GridBox[{
   {Cell["MATHEMATICA HOW TO", "PacletNameCell"], Cell[TextData[{
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "Tutorials",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"Tutorials", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->False], {"\<\"Tables and Matrices\"\>":>
       Documentation`HelpLookup[
       "paclet:tutorial/TablesAndMatrices"], "\<\"Grids, Rows, and Columns in \
Mathematica\"\>":>Documentation`HelpLookup[
       "paclet:tutorial/GridsRowsAndColumns"], "\<\"Basic Statistics\"\>":>
       Documentation`HelpLookup[
       "paclet:tutorial/BasicStatistics"], "\<\"Descriptive Statistics\"\>":>
       Documentation`HelpLookup[
       "paclet:tutorial/DescriptiveStatistics"], "\<\"Partitioning Data into \
Clusters\"\>":>Documentation`HelpLookup[
       "paclet:tutorial/PartitioningDataIntoClusters"], "\<\"Lists\"\>":>
       Documentation`HelpLookup[
       "paclet:tutorial/ListsOverview"], "\<\"Manipulating Lists\"\>":>
       Documentation`HelpLookup["paclet:tutorial/ManipulatingListsOverview"]},
       Appearance->None,
       MenuAppearance->Automatic,
       MenuStyle->"Tutorials"]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "See Also",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"See Also", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->False], {"\<\"GatherBy\"\>":>Documentation`HelpLookup[
       "paclet:ref/GatherBy"], "\<\"First\"\>":>Documentation`HelpLookup[
       "paclet:ref/First"], "\<\"Table\"\>":>Documentation`HelpLookup[
       "paclet:ref/Table"], "\<\"N\"\>":>Documentation`HelpLookup[
       "paclet:ref/N"], "\<\"Mean\"\>":>Documentation`HelpLookup[
       "paclet:ref/Mean"], "\<\"Min\"\>":>Documentation`HelpLookup[
       "paclet:ref/Min"], "\<\"Max\"\>":>Documentation`HelpLookup[
       "paclet:ref/Max"], "\<\"Length\"\>":>Documentation`HelpLookup[
       "paclet:ref/Length"], "\<\"Median\"\>":>Documentation`HelpLookup[
       "paclet:ref/Median"], "\<\"Sort\"\>":>Documentation`HelpLookup[
       "paclet:ref/Sort"], "\<\"IntegerPart\"\>":>Documentation`HelpLookup[
       "paclet:ref/IntegerPart"], "\<\"Grid\"\>":>Documentation`HelpLookup[
       "paclet:ref/Grid"]},
       Appearance->None,
       MenuAppearance->Automatic,
       MenuStyle->"SeeAlso"]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "Related Guides",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"Related Guides", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->False], {"\<\"Grids & Tables\"\>":>
       Documentation`HelpLookup[
       "paclet:guide/GridsAndTables"], "\<\"Statistics\"\>":>
       Documentation`HelpLookup[
       "paclet:guide/Statistics"], "\<\"Descriptive Statistics\"\>":>
       Documentation`HelpLookup[
       "paclet:guide/DescriptiveStatistics"], "\<\"Math & Counting Operations \
on Lists\"\>":>Documentation`HelpLookup[
       "paclet:guide/MathematicalAndCountingOperationsOnLists"], \
"\<\"Rearranging & Restructuring Lists\"\>":>Documentation`HelpLookup[
       "paclet:guide/RearrangingAndRestructuringLists"], "\<\"List \
Manipulation\"\>":>Documentation`HelpLookup[
       "paclet:guide/ListManipulation"], "\<\"Elements of Lists\"\>":>
       Documentation`HelpLookup[
       "paclet:guide/ElementsOfLists"], "\<\"\\\"How to\\\" Topics\"\>":>
       Documentation`HelpLookup["paclet:guide/HowToTopics"]},
       Appearance->None,
       MenuAppearance->Automatic,
       MenuStyle->"MoreAbout"]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "URL",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"URL", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->
         False], {"\<\"howto/PerformOperationsOnSubgroupsOfData\"\>":>
       None, "\<\"Copy Mathematica URL\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell["howto/PerformOperationsOnSubgroupsOfData"]}, Visible -> 
            False]]; SelectionMove[
         DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; Null], 
       Delimiter, "\<\"Copy web URL\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell[
              BoxData[
               MakeBoxes[
                Hyperlink[
                "http://reference.wolfram.com/mathematica/howto/\
PerformOperationsOnSubgroupsOfData.html"], StandardForm]], "Input", 
              TextClipboardType -> "PlainText"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; 
        Null], "\<\"Go to web URL\"\>":>FrontEndExecute[{
         NotebookLocate[{
           URL[
            StringJoin[
            "http://reference.wolfram.com/mathematica/", 
             "howto/PerformOperationsOnSubgroupsOfData", ".html"]], None}]}]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}]
    }], "AnchorBar"]}
  }]], "AnchorBarGrid",
 CellID->1],

Cell[CellGroupData[{

Cell[TextData[{
 Cell["\:041a\:0440\:0430\:0442\:043a\:0438\:0439 \:043a\:0443\:0440\:0441 ", 
  "HowToTitlePrefix"],
 " ",
 "\:0412\:044b\:043f\:043e\:043b\:043d\:0435\:043d\:0438\:0435 \:043e\:043f\
\:0435\:0440\:0430\:0446\:0438\:0439 \:0441 \:043f\:043e\:0434\:0433\:0440\
\:0443\:043f\:043f\:0430\:043c\:0438 \:0434\:0430\:043d\:043d\:044b\:0445"
}], "HowToTitle",
 CellID->509267359],

Cell[CellGroupData[{

Cell[TextData[{
 "\:041f\:0440\:0438 \:043e\:0431\:043e\:0431\:0449\:0435\:043d\:0438\:0438 \
\:0434\:0430\:043d\:043d\:044b\:0445 \:043e\:0447\:0435\:043d\:044c \:0443\
\:0434\:043e\:0431\:043d\:044b\:043c \:044f\:0432\:043b\:044f\:0435\:0442\
\:0441\:044f \:0438\:0445 \:0430\:043d\:0430\:043b\:0438\:0437 \:043f\:043e \
\:043f\:043e\:0434\:0433\:0440\:0443\:043f\:043f\:0430\:043c. \:041d\:0430\
\:043f\:0440\:0438\:043c\:0435\:0440, \:0434\:0430\:043d\:043d\:044b\:0435 \
\:043e\:0431 \:0443\:0440\:043e\:0436\:0430\:0439\:043d\:043e\:0441\:0442\
\:0438 \:043a\:0443\:043b\:044c\:0442\:0443\:0440 \:043c\:043e\:0433\:0443\
\:0442 \:0431\:044b\:0442\:044c \:0440\:0430\:0437\:0434\:0435\:043b\:0435\
\:043d\:044b \:043d\:0430 \:0440\:0430\:0437\:043d\:044b\:0435 \:043a\:0430\
\:0442\:0435\:0433\:043e\:0440\:0438\:0438 \:043f\:043e \:0441\:043e\:0440\
\:0442\:0443 \:0441\:0435\:043c\:044f\:043d \:0438 \:0442\:0438\:043f\:0443 \
\:0433\:0440\:0443\:043d\:0442\:0430, \:0430 \:0441\:0440\:0435\:0434\:043d\
\:0435\:0435 \:0432\:0440\:0435\:043c\:044f \:043b\:0435\:0447\:0435\:043d\
\:0438\:044f \:043f\:0430\:0446\:0438\:0435\:043d\:0442\:0430 - \:043f\:043e \
\:0432\:043e\:0437\:0440\:0430\:0441\:0442\:0443 \:043f\:0430\:0446\:0438\
\:0435\:043d\:0442\:0430 \:0438 \:0432\:0438\:0434\:0443 \:043b\:0435\:043a\
\:0430\:0440\:0441\:0442\:0432\:0430. ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " \:0434\:0430\:0435\:0442 \:043f\:043e\:043b\:044c\:0437\:043e\:0432\:0430\
\:0442\:0435\:043b\:044e \:0432\:043e\:0437\:043c\:043e\:0436\:043d\:043e\
\:0441\:0442\:044c \:0440\:0430\:0437\:0434\:0435\:043b\:044f\:0442\:044c \
\:0441\:0442\:043e\:043b\:0431\:0446\:044b \:0434\:0430\:043d\:043d\:044b\
\:0445, \:043e\:0441\:043d\:043e\:0432\:044b\:0432\:0430\:044f\:0441\:044c \
\:043d\:0430 \:0437\:043d\:0430\:0447\:0435\:043d\:0438\:044f\:0445 \:0432 \
\:0434\:0440\:0443\:0433\:0438\:0445 \:0441\:0442\:043e\:043b\:0431\:0446\
\:0430\:0445. \:041f\:043e\:0441\:043b\:0435 \:044d\:0442\:043e\:0433\:043e, \
\:043c\:043e\:0436\:043d\:043e \:0432\:044b\:043f\:043e\:043b\:043d\:044f\
\:0442\:044c \:0441\:0442\:0430\:0442\:0438\:0441\:0442\:0438\:0447\:0435\
\:0441\:043a\:0438\:0439 \:0430\:043d\:0430\:043b\:0438\:0437 \:0441\:0444\
\:043e\:0440\:043c\:0438\:0440\:043e\:0432\:0430\:043d\:043d\:044b\:0445 \
\:0433\:0440\:0443\:043f\:043f."
}], "HowToAbstract",
 CellID->1045883471],

Cell["\<\
\:0421\:043b\:0435\:0434\:0443\:044e\:0449\:0438\:0435 \:0434\:0430\:043d\
\:043d\:044b\:0435 \:043f\:0440\:0435\:0434\:0441\:0442\:0430\:0432\:043b\
\:044f\:044e\:0442 \:0443\:0440\:043e\:0436\:0430\:0439\:043d\:043e\:0441\
\:0442\:044c \:0434\:043b\:044f \:0442\:0440\:0435\:0445 \:0442\:0438\:043f\
\:043e\:0432 \:0433\:0440\:0443\:043d\:0442\:0430 \:0438 \:0434\:0432\:0443\
\:0445 \:0441\:043e\:0440\:0442\:043e\:0432 \:0441\:0435\:043c\:044f\:043d \
\:043a\:0443\:043a\:0443\:0440\:0443\:0437\:044b:\
\>", "HowToText",
 CellID->1009846402],

Cell[BoxData[
 RowBox[{
  RowBox[{"agdata", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"clay", ",", "seedB", ",", "175"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"silty", ",", "seedB", ",", "180"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"clay", ",", "seedB", ",", "165"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"sandy", ",", "seedA", ",", "168"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"clay", ",", "seedA", ",", "184"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"sandy", ",", "seedB", ",", "171"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"sandy", ",", "seedB", ",", "173"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"sandy", ",", "seedA", ",", "189"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"clay", ",", "seedA", ",", "186"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"silty", ",", "seedB", ",", "174"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"clay", ",", "seedA", ",", "192"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"clay", ",", "seedA", ",", "184"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"clay", ",", "seedA", ",", "179"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"sandy", ",", "seedA", ",", "182"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"sandy", ",", "seedB", ",", "177"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"silty", ",", "seedA", ",", "180"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"clay", ",", "seedB", ",", "175"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"silty", ",", "seedB", ",", "181"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"sandy", ",", "seedA", ",", "176"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"silty", ",", "seedB", ",", "190"}], "}"}]}], "}"}]}], 
  ";"}]], "Input",
 CellLabel->"In[29]:=",
 CellID->827466675],

Cell[TextData[{
 "\:0414\:0430\:043d\:043d\:044b\:0435 \:043c\:043e\:0433\:0443\:0442 \:0431\
\:044b\:0442\:044c \:0441\:0433\:0440\:0443\:043f\:043f\:0438\:0440\:043e\
\:0432\:0430\:043d\:044b \:043f\:043e \:0442\:0438\:043f\:0443 \:043f\:043e\
\:0447\:0432\:044b \:043f\:0440\:0438 \:043f\:043e\:043c\:043e\:0449\:0438 \
\:0444\:0443\:043d\:043a\:0446\:0438\:0439 ",
 Cell[BoxData[
  ButtonBox["First",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/First"]], "InlineFormula"],
 " \:0438 ",
 Cell[BoxData[
  ButtonBox["GatherBy",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/GatherBy"]], "InlineFormula"],
 ", \:043a\:043e\:0442\:043e\:0440\:044b\:0435 \:0434\:0435\:043b\:0430\:044e\
\:0442 \:0432\:044b\:0431\:043e\:0440\:043a\:0443 \:0432 \:043f\:043e\:0434\
\:0441\:043f\:0438\:0441\:043a\:0438 \:043f\:043e \:043f\:0435\:0440\:0432\
\:043e\:043c\:0443 \:044d\:043b\:0435\:043c\:0435\:043d\:0442\:0443 \:043a\
\:0430\:0436\:0434\:043e\:0439 \:0442\:043e\:0447\:043a\:0438 \:0434\:0430\
\:043d\:043d\:044b\:0445:"
}], "HowToText",
 CellID->1389965763],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"bySoilType", "=", 
  RowBox[{"GatherBy", "[", 
   RowBox[{"agdata", ",", "First"}], "]"}]}]], "Input",
 CellLabel->"In[30]:=",
 CellID->411630083],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"clay", ",", "seedB", ",", "175"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"clay", ",", "seedB", ",", "165"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"clay", ",", "seedA", ",", "184"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"clay", ",", "seedA", ",", "186"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"clay", ",", "seedA", ",", "192"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"clay", ",", "seedA", ",", "184"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"clay", ",", "seedA", ",", "179"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"clay", ",", "seedB", ",", "175"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"silty", ",", "seedB", ",", "180"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"silty", ",", "seedB", ",", "174"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"silty", ",", "seedA", ",", "180"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"silty", ",", "seedB", ",", "181"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"silty", ",", "seedB", ",", "190"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"sandy", ",", "seedA", ",", "168"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"sandy", ",", "seedB", ",", "171"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"sandy", ",", "seedB", ",", "173"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"sandy", ",", "seedA", ",", "189"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"sandy", ",", "seedA", ",", "182"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"sandy", ",", "seedB", ",", "177"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"sandy", ",", "seedA", ",", "176"}], "}"}]}], "}"}]}], 
  "}"}]], "Output",
 ImageSize->{567, 101},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[30]=",
 CellID->368652006]
}, Open  ]],

Cell[TextData[{
 "\:0421\:0440\:0435\:0434\:043d\:044f\:044f \:0443\:0440\:043e\:0436\:0430\
\:0439\:043d\:043e\:0441\:0442\:044c \:0434\:043b\:044f \:043a\:0430\:0436\
\:0434\:043e\:0433\:043e \:0442\:0438\:043f\:0430 \:043f\:043e\:0447\:0432\
\:044b \:043c\:043e\:0436\:0435\:0442 \:0431\:044b\:0442\:044c \:0432\:044b\
\:0447\:0438\:0441\:043b\:0435\:043d\:0430 \:043f\:0443\:0442\:0435\:043c \
\:0438\:0437\:0432\:043b\:0435\:0447\:0435\:043d\:0438\:044f \:0437\:043d\
\:0430\:0447\:0435\:043d\:0438\:044f \:0443\:0440\:043e\:0436\:0430\:0439\
\:043d\:043e\:0441\:0442\:0438 (\:043f\:043e\:0441\:043b\:0435\:0434\:043d\
\:0435\:0433\:043e \:044d\:043b\:0435\:043c\:0435\:043d\:0442\:0430 \:043a\
\:0430\:0436\:0434\:043e\:0433\:043e \:043f\:043e\:0434\:0441\:043f\:0438\
\:0441\:043a\:0435) \:043e\:0442\:0434\:0435\:043b\:044c\:043d\:043e \:0434\
\:043b\:044f \:043a\:0430\:0436\:0434\:043e\:0433\:043e \:0442\:0438\:043f\
\:0430 \:043f\:043e\:0447\:0432\:044b \:0438 \:0432\:044b\:0447\:0438\:0441\
\:043b\:0435\:043d\:0438\:044f \:0441\:0440\:0435\:0434\:043d\:0435\:0433\
\:043e ",
 Cell[BoxData[
  ButtonBox["Mean",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Mean"]], "InlineFormula"],
 ". \:0414\:043b\:044f \:043f\:043e\:043b\:0443\:0447\:0435\:043d\:0438\:044f \
\:044d\:0442\:043e\:0433\:043e \:0440\:0435\:0437\:0443\:043b\:044c\:0442\
\:0430\:0442\:0430 \:043c\:043e\:0436\:043d\:043e \:0432\:043e\:0441\:043f\
\:043e\:043b\:044c\:0437\:043e\:0432\:0430\:0442\:044c\:0441\:044f \:0444\
\:0443\:043d\:043a\:0446\:0438\:0435\:0439 ",
 Cell[BoxData[
  ButtonBox["Table",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Table"]], "InlineFormula"],
 ", \:0438 \:0442\:0440\:0435\:043c\:044f \
\:0441\:0444\:043e\:0440\:043c\:0438\:0440\:043e\:0432\:0430\:043d\:043d\:044b\
\:043c\:0438 \:0432\:044b\:0448\:0435 \:0433\:0440\:0443\:043f\:043f\:0430\
\:043c\:0438 \:0432 \:043a\:0430\:0447\:0435\:0441\:0442\:0432\:0435 \:0437\
\:043d\:0430\:0447\:0435\:043d\:0438\:044f \:0434\:043b\:044f \:0438\:0442\
\:0435\:0440\:0430\:0442\:0438\:0432\:043d\:043e\:0439 \:043f\:0435\:0440\
\:0435\:043c\:0435\:043d\:043d\:043e\:0439 ",
 Cell[BoxData["x"], "InlineFormula"],
 ". "
}], "HowToText",
 CellID->150789310],

Cell[TextData[{
 "\:041f\:0440\:0438\:043c\:0435\:043d\:0438\:043c \:0444\:0443\:043d\:043a\
\:0446\:0438\:044e ",
 Cell[BoxData[
  ButtonBox["Table",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Table"]], "InlineFormula"],
 " \:0434\:043b\:044f \:0432\:044b\:0432\:043e\:0434\:0430 \:0442\:0438\:043f\
\:0430 \:0433\:0440\:0443\:043d\:0442\:0430 \:0438 \:0441\:0440\:0435\:0434\
\:043d\:0435\:0439 \:0443\:0440\:043e\:0436\:0430\:0439\:043d\:043e\:0441\
\:0442\:0438 \:0434\:043b\:044f \:043a\:0430\:0436\:0434\:043e\:0439 \:0433\
\:0440\:0443\:043f\:043f\:044b:"
}], "HowToText",
 CellID->812217608],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
     RowBox[{"N", "[", 
      RowBox[{"Mean", "[", 
       RowBox[{"x", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", 
          RowBox[{"-", "1"}]}], "]"}], "]"}], "]"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "bySoilType"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[31]:=",
 CellID->1398028897],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"clay", ",", "180.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"silty", ",", "181.`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"sandy", ",", "176.57142857142858`"}], "}"}]}], "}"}]], "Output",
 ImageSize->{318, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[31]=",
 CellID->443943247]
}, Open  ]],

Cell["\<\
\:0414\:043b\:044f \:043f\:043e\:043b\:0443\:0447\:0435\:043d\:0438\:044f \
\:0438\:043d\:0444\:043e\:0440\:043c\:0430\:0446\:0438\:0438 \:043e\:0431 \
\:0443\:0440\:043e\:0436\:0430\:0439\:043d\:043e\:0441\:0442\:0438 \:0432 \
\:0437\:0430\:0432\:0438\:0441\:0438\:043c\:043e\:0441\:0442\:0438 \:043e\
\:0442 \:0441\:043e\:0440\:0442\:0430 \:0441\:0435\:043c\:044f\:043d, \:0441\
\:0433\:0440\:0443\:043f\:043f\:0438\:0440\:0443\:0435\:043c, \:0434\:043b\
\:044f \:043d\:0430\:0447\:0430\:043b\:0430, \:0434\:0430\:043d\:043d\:044b\
\:0435 \:043f\:043e \:0432\:0442\:043e\:0440\:043e\:043c\:0443 \:044d\:043b\
\:0435\:043c\:0435\:043d\:0442\:0443 \:043a\:0430\:0436\:0434\:043e\:0439 \
\:0442\:043e\:0447\:043a\:0438 \:0434\:0430\:043d\:043d\:044b\:0445.\
\>", "HowToText",
 CellID->334259956],

Cell[TextData[{
 "\:0412\:043e\:0441\:043f\:043e\:043b\:044c\:0437\:0443\:0435\:043c\:0441\
\:044f \:0447\:0438\:0441\:0442\:043e\:0439 \:0444\:0443\:043d\:043a\:0446\
\:0438\:0435\:0439 ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"#", "[", 
    RowBox[{"[", "2", "]"}], "]"}], "&"}]], "InlineFormula"],
 " \:0432\:043c\:0435\:0441\:0442\:0435 \:0441 ",
 Cell[BoxData[
  ButtonBox["GatherBy",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/GatherBy"]], "InlineFormula"],
 ", \:0434\:043b\:044f \:0432\:044b\:0431\:043e\:0440\:043a\:0438 \
\:0434\:0430\:043d\:043d\:044b\:0445 \:043f\:043e \:0441\:043e\:0440\:0442\
\:0443 \:0441\:0435\:043c\:044f\:043d:"
}], "HowToText",
 CellID->1445501569],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"bySeedType", "=", 
  RowBox[{"GatherBy", "[", 
   RowBox[{"agdata", ",", 
    RowBox[{
     RowBox[{"#", "[", 
      RowBox[{"[", "2", "]"}], "]"}], "&"}]}], "]"}]}]], "Input",
 CellLabel->"In[32]:=",
 CellID->89859940],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"clay", ",", "seedB", ",", "175"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"silty", ",", "seedB", ",", "180"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"clay", ",", "seedB", ",", "165"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"sandy", ",", "seedB", ",", "171"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"sandy", ",", "seedB", ",", "173"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"silty", ",", "seedB", ",", "174"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"sandy", ",", "seedB", ",", "177"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"clay", ",", "seedB", ",", "175"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"silty", ",", "seedB", ",", "181"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"silty", ",", "seedB", ",", "190"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"sandy", ",", "seedA", ",", "168"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"clay", ",", "seedA", ",", "184"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"sandy", ",", "seedA", ",", "189"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"clay", ",", "seedA", ",", "186"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"clay", ",", "seedA", ",", "192"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"clay", ",", "seedA", ",", "184"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"clay", ",", "seedA", ",", "179"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"sandy", ",", "seedA", ",", "182"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"silty", ",", "seedA", ",", "180"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"sandy", ",", "seedA", ",", "176"}], "}"}]}], "}"}]}], 
  "}"}]], "Output",
 ImageSize->{552, 101},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[32]=",
 CellID->995962651]
}, Open  ]],

Cell[TextData[{
 "\:0412\:044b\:0447\:0438\:0441\:043b\:0435\:043d\:0438\:0435 \:0441\:0440\
\:0435\:0434\:043d\:0435\:0433\:043e \:0432 \:0440\:0430\:0437\:0440\:0435\
\:0437\:0435 \:0441\:043e\:0440\:0442\:043e\:0432 \:0441\:0435\:043c\:044f\
\:043d \:043e\:0447\:0435\:043d\:044c \:043f\:043e\:0445\:043e\:0436\:0435 \
\:043d\:0430 \:043f\:0440\:043e\:0446\:0435\:0434\:0443\:0440\:0443, \:0438\
\:0441\:043f\:043e\:043b\:044c\:0437\:043e\:0432\:0430\:043d\:043d\:0443\:044e\
 \:0434\:043b\:044f \:043f\:043e\:043b\:0443\:0447\:0435\:043d\:0438\:044f \
\:0434\:0430\:043d\:043d\:044b\:0445 \:0432 \:0440\:0430\:0437\:0440\:0435\
\:0437\:0435 \:0442\:0438\:043f\:0430 \:043f\:043e\:0447\:0432\:044b. \:041e\
\:0434\:043d\:0430\:043a\:043e, \:043f\:0440\:0438 \:044d\:0442\:043e\:043c \
\:0431\:044b\:043b \:0438\:0441\:043f\:043e\:043b\:044c\:0437\:043e\:0432\
\:0430\:043d \:0442\:043e\:043b\:044c\:043a\:043e \:0447\:0442\:043e \:0441\
\:0444\:043e\:0440\:043c\:0438\:0440\:043e\:0432\:0430\:043d\:043d\:044b\:0439\
 \:043d\:0430\:0431\:043e\:0440 \:0434\:0430\:043d\:043d\:044b\:0445 ",
 Cell[BoxData["bySeedType"], "InlineFormula"],
 ". \:0418, \:043a\:0440\:043e\:043c\:0435 \:0442\:043e\:0433\:043e, \:0431\
\:044b\:043b \:0432\:0437\:044f\:0442 \:0432\:0442\:043e\:0440\:043e\:0439 \
\:044d\:043b\:0435\:043c\:0435\:043d\:0442 \:0434\:043b\:044f \:043f\:043e\
\:043b\:0443\:0447\:0435\:043d\:0438\:044f \:0441\:043e\:0440\:0442\:0430 \
\:0441\:0435\:043c\:044f\:043d. "
}], "HowToText",
 CellID->62371672],

Cell[TextData[{
 "\:0412\:043e\:0441\:043f\:043e\:043b\:044c\:0437\:0443\:0435\:043c\:0441\
\:044f \:0444\:0443\:043d\:043a\:0446\:0438\:0435\:0439 ",
 Cell[BoxData[
  ButtonBox["Table",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Table"]], "InlineFormula"],
 " \:0434\:043b\:044f \:0432\:044b\:0447\:0438\:0441\:043b\:0435\:043d\:0438\
\:044f \:0441\:0440\:0435\:0434\:043d\:0435\:0439 \:0443\:0440\:043e\:0436\
\:0430\:0439\:043d\:043e\:0441\:0442\:0438 \:0434\:043b\:044f \:043a\:0430\
\:0436\:0434\:043e\:0433\:043e \:0441\:043e\:0440\:0442\:0430 \:0441\:0435\
\:043c\:044f\:043d:"
}], "HowToText",
 CellID->1611208941],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "2"}], "]"}], "]"}], ",", 
     RowBox[{"N", "[", 
      RowBox[{"Mean", "[", 
       RowBox[{"x", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", 
          RowBox[{"-", "1"}]}], "]"}], "]"}], "]"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "bySeedType"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[33]:=",
 CellID->1967366364],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"seedB", ",", "176.1`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"seedA", ",", "182.`"}], "}"}]}], "}"}]], "Output",
 ImageSize->{212, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[33]=",
 CellID->1656730639]
}, Open  ]],

Cell["\<\
\:041c\:043e\:0436\:043d\:043e \:043f\:0440\:043e\:0434\:043e\:043b\:0436\
\:0438\:0442\:044c \:0432\:044b\:0447\:0438\:0441\:043b\:0435\:043d\:0438\
\:0435 \:0438 \:0434\:0440\:0443\:0433\:0438\:0445 \:043f\:043e\:043a\:0430\
\:0437\:0430\:0442\:0435\:043b\:0435\:0439 \:043e\:043f\:0438\:0441\:0430\
\:0442\:0435\:043b\:044c\:043d\:043e\:0439 \:0441\:0442\:0430\:0442\:0438\
\:0441\:0442\:0438\:043a\:0438. \:041d\:0430\:043f\:0440\:0438\:043c\:0435\
\:0440, \:043c\:043e\:0436\:043d\:043e \:0443\:0437\:043d\:0430\:0442\:044c \
\:0434\:0438\:0430\:043f\:0430\:0437\:043e\:043d \:0443\:0440\:043e\:0436\
\:0430\:0439\:043d\:043e\:0441\:0442\:0438 \:0438 \:043c\:0438\:043d\:0438\
\:043c\:0430\:043b\:044c\:043d\:0443\:044e \:0438 \:043c\:0430\:043a\:0441\
\:0438\:043c\:0430\:043b\:044c\:043d\:0443\:044e \:0443\:0440\:043e\:0436\
\:0430\:0439\:043d\:043e\:0441\:0442\:044c \:0432 \:0437\:0430\:0432\:0438\
\:0441\:0438\:043c\:043e\:0441\:0442\:0438 \:043e\:0442 \:0441\:043e\:0440\
\:0442\:0430 \:0441\:0435\:043c\:044f\:043d.\
\>", "HowToText",
 CellID->767258044],

Cell["\<\
\:0422\:0430\:043a \:0432\:044b\:0447\:0438\:0441\:043b\:044f\:0435\:0442\
\:0441\:044f \:043c\:0438\:043d\:0438\:043c\:0430\:043b\:044c\:043d\:0430\
\:044f \:0438 \:043c\:0430\:043a\:0441\:0438\:043c\:0430\:043b\:044c\:043d\
\:0430\:044f \:0443\:0440\:043e\:0436\:0430\:0439\:043d\:043e\:0441\:0442\
\:044c \:0434\:043b\:044f \:043a\:0430\:0436\:0434\:043e\:0433\:043e \:0441\
\:043e\:0440\:0442\:0430 \:0441\:0435\:043c\:044f\:043d:\
\>", "HowToText",
 CellID->384363626],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "2"}], "]"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"N", "[", 
        RowBox[{"Min", "[", 
         RowBox[{"x", "[", 
          RowBox[{"[", 
           RowBox[{"All", ",", 
            RowBox[{"-", "1"}]}], "]"}], "]"}], "]"}], "]"}], ",", 
       RowBox[{"N", "[", 
        RowBox[{"Max", "[", 
         RowBox[{"x", "[", 
          RowBox[{"[", 
           RowBox[{"All", ",", 
            RowBox[{"-", "1"}]}], "]"}], "]"}], "]"}], "]"}]}], "}"}]}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "bySeedType"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[34]:=",
 CellID->296863878],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"seedB", ",", 
     RowBox[{"{", 
      RowBox[{"165.`", ",", "190.`"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"seedA", ",", 
     RowBox[{"{", 
      RowBox[{"168.`", ",", "192.`"}], "}"}]}], "}"}]}], "}"}]], "Output",
 ImageSize->{311, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[34]=",
 CellID->398882671]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\t", "HowToDelimiter",
 Editable->False,
 CellID->163636713],

Cell["\<\
\:0421\:043b\:0435\:0434\:0443\:044e\:0449\:0438\:0439 \:043d\:0430\:0431\
\:043e\:0440 \:0434\:0430\:043d\:043d\:044b\:0445 \:0441\:043e\:0434\:0435\
\:0440\:0436\:0438\:0442 \:0438\:043d\:0444\:043e\:0440\:043c\:0430\:0446\
\:0438\:044e \:043e\:0442 \:0432\:0438\:0434\:0435 \:043b\:0435\:043a\:0430\
\:0440\:0441\:0442\:0432\:0430, \:0432\:043e\:0437\:0440\:0430\:0441\:0442\
\:0435 \:043f\:0430\:0446\:0438\:0435\:043d\:0442\:0430 \:0438 \:0432\:0440\
\:0435\:043c\:0435\:043d\:0438 \:0432\:044b\:0437\:0434\:043e\:0440\:043e\
\:0432\:043b\:0435\:043d\:0438\:044f \:043f\:0430\:0446\:0438\:0435\:043d\
\:0442\:043e\:0432, \:043f\:043e\:043b\:0443\:0447\:0430\:0432\:0448\:0438\
\:0445 \:043b\:0435\:0447\:0435\:043d\:0438\:0435 \:0432 \:043e\:043f\:0440\
\:0435\:0434\:0435\:043b\:0435\:043d\:043d\:044b\:0445 \:0443\:0441\:043b\
\:043e\:0432\:0438\:044f\:0445:\
\>", "HowToText",
 CellID->323423614],

Cell[BoxData[
 RowBox[{
  RowBox[{"meddata", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"drugB", ",", "67", ",", "18"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"drugB", ",", "48", ",", "18"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"drugA", ",", "33", ",", "16"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"drugB", ",", "76", ",", "33"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"drugB", ",", "33", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"placebo", ",", "40", ",", "15"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"drugB", ",", "78", ",", "28"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"drugB", ",", "54", ",", "13"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"placebo", ",", "46", ",", "23"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"drugA", ",", "36", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"drugA", ",", "69", ",", "30"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"drugA", ",", "78", ",", "40"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"placebo", ",", "77", ",", "37"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"drugA", ",", "79", ",", "36"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"drugA", ",", "45", ",", "16"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"drugA", ",", "36", ",", "18"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"drugA", ",", "58", ",", "24"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"placebo", ",", "25", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"drugB", ",", "75", ",", "25"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"drugB", ",", "22", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"placebo", ",", "51", ",", "25"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"placebo", ",", "27", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"placebo", ",", "47", ",", "20"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"placebo", ",", "69", ",", "34"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"drugB", ",", "52", ",", "16"}], "}"}]}], "}"}]}], 
  ";"}]], "Input",
 CellLabel->"In[35]:=",
 CellID->948295756],

Cell["\<\
\:041a\:0430\:043a \:0438 \:0432 \:043f\:0440\:0438\:043c\:0435\:0440\:0435 \
\:0441 \:0443\:0440\:043e\:0436\:0430\:0439\:043d\:043e\:0441\:0442\:044c\
\:044e \:043a\:0443\:043a\:0443\:0440\:0443\:0437\:044b, \:043c\:043e\:0436\
\:043d\:043e \:0441\:0433\:0440\:0443\:043f\:043f\:0438\:0440\:043e\:0432\
\:0430\:0442\:044c \:0434\:0430\:043d\:043d\:044b\:0435 \:043f\:043e \:043e\
\:0434\:043d\:043e\:043c\:0443 \:0438\:0437 \:0441\:0442\:043e\:043b\:0431\
\:0446\:043e\:0432 \:0438 \:0440\:0430\:0441\:0441\:0447\:0438\:0442\:0430\
\:0442\:044c \:0440\:0435\:0437\:0443\:043b\:044c\:0442\:0430\:0442\:044b \
\:0434\:043b\:044f \:0440\:0430\:0437\:043d\:044b\:0445 \:0433\:0440\:0443\
\:043f\:043f. \
\>", "HowToText",
 CellID->54379160],

Cell[TextData[{
 "\:0421\:0433\:0440\:0443\:043f\:043f\:0438\:0440\:0443\:0435\:043c \:0434\
\:0430\:043d\:043d\:044b\:0435 \:043f\:043e \:0432\:0438\:0434\:0443 \:043b\
\:0435\:043a\:0430\:0440\:0441\:0442\:0432\:0430, \:0441\:043e\:0445\:0440\
\:0430\:043d\:0438\:0432 \:043d\:043e\:0432\:044b\:0439 \:0441\:043f\:0438\
\:0441\:043e\:043a \:043f\:043e\:0434 \:0438\:043c\:0435\:043d\:0435\:043c ",
 Cell[BoxData["byDrug"], "InlineFormula"],
 ":"
}], "HowToText",
 CellID->51739288],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"byDrug", "=", 
  RowBox[{"GatherBy", "[", 
   RowBox[{"meddata", ",", "First"}], "]"}]}]], "Input",
 CellLabel->"In[36]:=",
 CellID->380755307],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"drugB", ",", "67", ",", "18"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"drugB", ",", "48", ",", "18"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"drugB", ",", "76", ",", "33"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"drugB", ",", "33", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"drugB", ",", "78", ",", "28"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"drugB", ",", "54", ",", "13"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"drugB", ",", "75", ",", "25"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"drugB", ",", "22", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"drugB", ",", "52", ",", "16"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"drugA", ",", "33", ",", "16"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"drugA", ",", "36", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"drugA", ",", "69", ",", "30"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"drugA", ",", "78", ",", "40"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"drugA", ",", "79", ",", "36"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"drugA", ",", "45", ",", "16"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"drugA", ",", "36", ",", "18"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"drugA", ",", "58", ",", "24"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"placebo", ",", "40", ",", "15"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"placebo", ",", "46", ",", "23"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"placebo", ",", "77", ",", "37"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"placebo", ",", "25", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"placebo", ",", "51", ",", "25"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"placebo", ",", "27", ",", "8"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"placebo", ",", "47", ",", "20"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"placebo", ",", "69", ",", "34"}], "}"}]}], "}"}]}], 
  "}"}]], "Output",
 ImageSize->{557, 101},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[36]=",
 CellID->1724589210]
}, Open  ]],

Cell["\<\
\:0421\:043b\:0435\:0434\:0443\:044e\:0449\:0430\:044f \:0444\:0443\:043d\
\:043a\:0446\:0438\:044f \:0438\:0441\:043f\:043e\:043b\:044c\:0437\:0443\
\:0435\:0442\:0441\:044f \:0434\:043b\:044f \:043f\:043e\:043b\:0443\:0447\
\:0435\:043d\:0438\:044f \:0437\:043d\:0430\:0447\:0435\:043d\:0438\:0439 \
\:0440\:0430\:0437\:043c\:0435\:0440\:0430 \:0432\:044b\:0431\:043e\:0440\
\:043a\:0438, \:0441\:0440\:0435\:0434\:043d\:0435\:0433\:043e, \:043c\:0435\
\:0434\:0438\:0430\:043d\:044b \:0438 \:0434\:0438\:0430\:043f\:0430\:0437\
\:043e\:043d\:0430 \:0434\:043b\:044f \:0432\:044b\:0431\:0440\:0430\:043d\
\:043d\:043e\:0433\:043e \:0441\:043f\:0438\:0441\:043a\:0430:\
\>", "HowToText",
 CellID->60920969],

Cell[BoxData[
 RowBox[{
  RowBox[{"describe", "[", "values_", "]"}], ":=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Length", "[", "values", "]"}], ",", 
    RowBox[{"Mean", "[", "values", "]"}], ",", 
    RowBox[{"Median", "[", "values", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Min", "[", "values", "]"}], ",", 
      RowBox[{"Max", "[", "values", "]"}]}], "}"}]}], "}"}]}]], "Input",
 CellLabel->"In[37]:=",
 CellID->384907061],

Cell[TextData[{
 "\:041f\:0440\:0438\:043c\:0435\:043d\:0438\:043c \:0444\:0443\:043d\:043a\
\:0446\:0438\:044e ",
 Cell[BoxData[
  ButtonBox["Table",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Table"]], "InlineFormula"],
 " \:0432\:043c\:0435\:0441\:0442\:0435 \:0441 ",
 Cell[BoxData["describe"], "InlineFormula"],
 " \:0434\:043b\:044f \:043f\:043e\:043b\:0443\:0447\:0435\:043d\:0438\:044f \
\:0441\:0442\:0430\:0442\:0438\:0441\:0442\:0438\:0447\:0435\:0441\:043a\:0438\
\:0445 \:0440\:0435\:0437\:0443\:043b\:044c\:0442\:0430\:0442\:043e\:0432 \
\:0432 \:0440\:0430\:0437\:0440\:0435\:0437\:0435 \:0432\:0438\:0434\:0430 \
\:043b\:0435\:043a\:0430\:0440\:0441\:0442\:0432\:0430. \:041f\:043e\:0441\
\:043b\:0435\:0434\:043e\:0432\:0430\:0442\:0435\:043b\:044c\:043d\:043e\:0441\
\:0442\:044c \:0440\:0435\:0437\:0443\:043b\:044c\:0442\:0430\:0442\:043e\
\:0432 \:0434\:043b\:044f \:043a\:0430\:0436\:0434\:043e\:0433\:043e \:0432\
\:0438\:0434\:0430 \:043b\:0435\:043a\:0430\:0440\:0441\:0442\:0432\:0430 \
\:0441\:043e\:0432\:043f\:0430\:0434\:0430\:0435\:0442 \:0441 \:043f\:0430\
\:0440\:0430\:043c\:0435\:0442\:0440\:0430\:043c\:0438, \:0443\:043a\:0430\
\:0437\:0430\:043d\:043d\:044b\:043c\:0438 \:0432 \:043e\:043f\:0440\:0435\
\:0434\:0435\:043b\:0435\:043d\:0438\:0438 \:0444\:0443\:043d\:043a\:0446\
\:0438\:0438 ",
 Cell[BoxData["describe"], "InlineFormula"],
 " (\:0440\:0430\:0437\:043c\:0435\:0440 \:0432\:044b\:0431\:043e\:0440\:043a\
\:0438, \:0441\:0440\:0435\:0434\:043d\:0435\:0435, \:043c\:0435\:0434\:0438\
\:0430\:043d\:0430, \:0434\:0438\:0430\:043f\:0430\:0437\:043e\:043d \:0432\
\:044b\:0431\:043e\:0440\:043a\:0438):"
}], "HowToText",
 CellID->196214012],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "[", 
      RowBox[{"[", 
       RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
     RowBox[{"describe", "[", 
      RowBox[{"N", "[", 
       RowBox[{"x", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", 
          RowBox[{"-", "1"}]}], "]"}], "]"}], "]"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "byDrug"}], "}"}]}], " ", "]"}]], "Input",
 CellLabel->"In[38]:=",
 CellID->391246615],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"drugB", ",", 
     RowBox[{"{", 
      RowBox[{"9", ",", "17.444444444444443`", ",", "18.`", ",", 
       RowBox[{"{", 
        RowBox[{"3.`", ",", "33.`"}], "}"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"drugA", ",", 
     RowBox[{"{", 
      RowBox[{"8", ",", "24.`", ",", "21.`", ",", 
       RowBox[{"{", 
        RowBox[{"12.`", ",", "40.`"}], "}"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"placebo", ",", 
     RowBox[{"{", 
      RowBox[{"8", ",", "21.375`", ",", "21.5`", ",", 
       RowBox[{"{", 
        RowBox[{"8.`", ",", "37.`"}], "}"}]}], "}"}]}], "}"}]}], 
  "}"}]], "Output",
 ImageSize->{511, 33},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[38]=",
 CellID->584068911]
}, Open  ]],

Cell["\<\
\:041f\:0440\:0438 \:0433\:0440\:0443\:043f\:043f\:0438\:0440\:043e\:0432\
\:043a\:0435 \:043f\:043e \:0432\:043e\:0437\:0440\:0430\:0441\:0442\:0443, \
\:0441\:043a\:043e\:0440\:0435\:0435 \:0432\:0441\:0435\:0433\:043e \:043f\
\:043e\:043d\:0430\:0434\:043e\:0431\:0438\:0442\:0441\:044f \:0441\:043e\
\:0437\:0434\:0430\:0442\:044c \:0433\:0440\:0443\:043f\:043f\:044b, \:0441\
\:043e\:043e\:0442\:0432\:0435\:0442\:0441\:0442\:0432\:0443\:044e\:0449\:0438\
\:0435 \:0434\:0438\:0430\:043f\:0430\:0437\:043e\:043d\:0430\:043c \:0432\
\:043e\:0437\:0440\:0430\:0441\:0442\:043e\:0432 \:0432\:043c\:0435\:0441\
\:0442\:043e \:043a\:0430\:0436\:0434\:043e\:0433\:043e \:043e\:0442\:0434\
\:0435\:043b\:044c\:043d\:043e\:0433\:043e \:0432\:043e\:0437\:0440\:0430\
\:0441\:0442\:0430. \:0412 \:044d\:0442\:043e\:043c \:043f\:0440\:0438\:043c\
\:0435\:0440\:0435 \:043a\:0430\:0436\:0434\:044b\:0435 10 \:043b\:0435\:0442 \
\:0432\:043e\:0437\:0440\:0430\:0441\:0442\:0430 \:043f\:0430\:0446\:0438\
\:0435\:043d\:0442\:0430 \:0441\:043e\:043e\:0442\:0432\:0435\:0442\:0441\
\:0442\:0432\:0443\:044e\:0442 \:0435\:0433\:043e/\:0435\:0435 \:0432\:043e\
\:0437\:0440\:0430\:0441\:0442\:043d\:043e\:0439 \:0433\:0440\:0443\:043f\
\:043f\:0435.   \
\>", "HowToText",
 CellID->772452016],

Cell[TextData[{
 "\:0414\:043b\:044f \:0441\:043e\:0437\:0434\:0430\:043d\:0438\:044f \:044d\
\:0442\:0438\:0445 \:0433\:0440\:0443\:043f\:043f \:043a\:0430\:0436\:0434\
\:044b\:0439 \:0432\:043e\:0437\:0440\:0430\:0441\:0442 \:0434\:0435\:043b\
\:0438\:0442\:0441\:044f \:043d\:0430 10, \:0437\:0430\:0442\:0435\:043c, \
\:0441 \:043f\:043e\:043c\:043e\:0449\:044c\:044e \:0444\:0443\:043d\:043a\
\:0446\:0438\:0438 ",
 Cell[BoxData[
  ButtonBox["IntegerPart",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/IntegerPart"]], "InlineFormula"],
 " \:0431\:0435\:0440\:0443\:0442\:0441\:044f \:0442\:043e\:043b\:044c\:043a\
\:043e \:0442\:0435 \:0446\:0438\:0444\:0440\:044b, \:043a\:043e\:0442\:043e\
\:0440\:044b\:0435 \:043d\:0430\:0445\:043e\:0434\:044f\:0442\:0441\:044f \
\:0441\:043b\:0435\:0432\:0430 \:043e\:0442 \:0434\:0435\:0441\:044f\:0442\
\:0438\:0447\:043d\:043e\:0439 \:0442\:043e\:0447\:043a\:0438. \:0414\:0430\
\:043b\:0435\:0435, \:0444\:0443\:043d\:043a\:0446\:0438\:044f ",
 Cell[BoxData[
  ButtonBox["GatherBy",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/GatherBy"]], "InlineFormula"],
 " \:0438\:0441\:043f\:043e\:043b\:044c\:0437\:0443\:0435\:0442\:0441\:044f \
\:0434\:043b\:044f \:0432\:044b\:0431\:043e\:0440\:043a\:0438 \:0434\:0430\
\:043d\:043d\:044b\:0445 \:0432 \:0433\:0440\:0443\:043f\:043f\:044b \:0432 \
\:0437\:0430\:0432\:0438\:0441\:0438\:043c\:043e\:0441\:0442\:0438 \:043e\
\:0442 \:043f\:043e\:043b\:0443\:0447\:0435\:043d\:043d\:043e\:0433\:043e \
\:0447\:0438\:0441\:043b\:0430:"
}], "HowToText",
 CellID->102811083],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"byAgeGroup", "=", 
  RowBox[{"GatherBy", "[", 
   RowBox[{"meddata", ",", 
    RowBox[{
     RowBox[{"IntegerPart", "[", 
      RowBox[{
       RowBox[{"#", "[", 
        RowBox[{"[", "2", "]"}], "]"}], "/", "10"}], "]"}], "&"}]}], 
   "]"}]}]], "Input",
 CellLabel->"In[39]:=",
 CellID->340447965],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"drugB", ",", "67", ",", "18"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"drugA", ",", "69", ",", "30"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"placebo", ",", "69", ",", "34"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"drugB", ",", "48", ",", "18"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"placebo", ",", "40", ",", "15"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"placebo", ",", "46", ",", "23"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"drugA", ",", "45", ",", "16"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"placebo", ",", "47", ",", "20"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"drugA", ",", "33", ",", "16"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"drugB", ",", "33", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"drugA", ",", "36", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"drugA", ",", "36", ",", "18"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"drugB", ",", "76", ",", "33"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"drugB", ",", "78", ",", "28"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"drugA", ",", "78", ",", "40"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"placebo", ",", "77", ",", "37"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"drugA", ",", "79", ",", "36"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"drugB", ",", "75", ",", "25"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"drugB", ",", "54", ",", "13"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"drugA", ",", "58", ",", "24"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"placebo", ",", "51", ",", "25"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"drugB", ",", "52", ",", "16"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"placebo", ",", "25", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"drugB", ",", "22", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"placebo", ",", "27", ",", "8"}], "}"}]}], "}"}]}], 
  "}"}]], "Output",
 ImageSize->{504, 118},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[39]=",
 CellID->298436740]
}, Open  ]],

Cell[TextData[{
 "\:0412\:043e\:0441\:043f\:043e\:043b\:044c\:0437\:0443\:0435\:043c\:0441\
\:044f \:0444\:0443\:043d\:043a\:0446\:0438\:0435\:0439 ",
 Cell[BoxData[
  ButtonBox["Table",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Table"]], "InlineFormula"],
 " \:0432\:043c\:0435\:0441\:0442\:0435 \:0441 ",
 Cell[BoxData["describe"], "InlineFormula"],
 " \:0434\:043b\:044f \:0432\:044b\:0447\:0438\:0441\:043b\:0435\:043d\:0438\
\:044f \:0441\:0442\:0430\:0442\:0438\:0441\:0442\:0438\:0447\:0435\:0441\
\:043a\:0438\:0445 \:0434\:0430\:043d\:043d\:044b\:0445 \:0432 \:0440\:0430\
\:0437\:0440\:0435\:0437\:0435 \:0432\:043e\:0437\:0440\:0430\:0441\:0442\
\:043d\:044b\:0445 \:0433\:0440\:0443\:043f\:043f. \:0424\:0443\:043d\:043a\
\:0446\:0438\:044f ",
 Cell[BoxData[
  ButtonBox["Sort",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Sort"]], "InlineFormula"],
 " \:043f\:0440\:0438\:043c\:0435\:043d\:044f\:0435\:0442\:0441\:044f \:0437\
\:0434\:0435\:0441\:044c \:0434\:043b\:044f \:0441\:043e\:0440\:0442\:0438\
\:0440\:043e\:0432\:043a\:0438 \:0434\:0430\:043d\:043d\:044b\:0445 \:043f\
\:043e \:0443\:0432\:0435\:043b\:0438\:0447\:0435\:043d\:0438\:044e \:0432\
\:043e\:0437\:0440\:0430\:0441\:0442\:0430 \:0433\:0440\:0443\:043f\:043f\
\:044b:"
}], "HowToText",
 CellID->11488553],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"10", 
       RowBox[{"IntegerPart", "[", 
        RowBox[{
         RowBox[{"x", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "2"}], "]"}], "]"}], "/", "10"}], "]"}]}], ",", 
      RowBox[{"describe", "[", 
       RowBox[{"N", "[", 
        RowBox[{"x", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", 
           RowBox[{"-", "1"}]}], "]"}], "]"}], "]"}], "]"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "byAgeGroup"}], "}"}]}], "]"}], "//", 
  "Sort"}]], "Input",
 CellLabel->"In[40]:=",
 CellID->189076812],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"20", ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "6.666666666666667`", ",", "8.`", ",", 
       RowBox[{"{", 
        RowBox[{"3.`", ",", "9.`"}], "}"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"30", ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "12.25`", ",", "14.`", ",", 
       RowBox[{"{", 
        RowBox[{"3.`", ",", "18.`"}], "}"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"40", ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "18.4`", ",", "18.`", ",", 
       RowBox[{"{", 
        RowBox[{"15.`", ",", "23.`"}], "}"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"50", ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "19.5`", ",", "20.`", ",", 
       RowBox[{"{", 
        RowBox[{"13.`", ",", "25.`"}], "}"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"60", ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "27.333333333333332`", ",", "30.`", ",", 
       RowBox[{"{", 
        RowBox[{"18.`", ",", "34.`"}], "}"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"70", ",", 
     RowBox[{"{", 
      RowBox[{"6", ",", "33.166666666666664`", ",", "34.5`", ",", 
       RowBox[{"{", 
        RowBox[{"25.`", ",", "40.`"}], "}"}]}], "}"}]}], "}"}]}], 
  "}"}]], "Output",
 ImageSize->{497, 50},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[40]=",
 CellID->1451973435]
}, Open  ]],

Cell[TextData[{
 "\:0414\:0430\:043d\:043d\:044b\:0435, \:0442\:0430\:043a\:0436\:0435, \
\:043c\:043e\:0433\:0443\:0442 \:0433\:0440\:0443\:043f\:043f\:0438\:0440\
\:043e\:0432\:0430\:0442\:044c\:0441\:044f \:043f\:043e \:043d\:0435\:0441\
\:043a\:043e\:043b\:044c\:043a\:0438\:043c \:043f\:0430\:0440\:0430\:043c\
\:0435\:0442\:0440\:0430\:043c. \:041d\:0430\:043f\:0440\:0438\:043c\:0435\
\:0440, \:043c\:0435\:0434\:0438\:0446\:0438\:043d\:0441\:043a\:0438\:0435 \
\:0434\:0430\:043d\:043d\:044b\:0435 \:043c\:043e\:0433\:0443\:0442 \:0431\
\:044b\:0442\:044c \:0441\:0433\:0440\:0443\:043f\:043f\:0438\:0440\:043e\
\:0432\:0430\:043d\:044b \:043f\:043e \:0432\:0438\:0434\:0443 \:043b\:0435\
\:043a\:0430\:0440\:0441\:0442\:0432\:0430 \:0438 \:043f\:043e \:0432\:043e\
\:0437\:0440\:0430\:0441\:0442\:0443, \:043f\:0443\:0442\:0435\:043c \:0443\
\:043a\:0430\:0437\:0430\:043d\:0438\:044f \:043e\:0431\:0435\:0438\:0445 \
\:0444\:0443\:043d\:043a\:0446\:0438\:0439 - ",
 Cell[BoxData[
  ButtonBox["First",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/First"]], "InlineFormula"],
 " \:0438 ",
 Cell[BoxData[
  ButtonBox["IntegerPart",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/IntegerPart"]], "InlineFormula"],
 " \:0432 \:0441\:043f\:0438\:0441\:043a\:0435 \:0430\:0440\:0433\:0443\:043c\
\:0435\:043d\:0442\:043e\:0432 \:0444\:0443\:043d\:043a\:0446\:0438\:0438 ",
 Cell[BoxData[
  ButtonBox["GatherBy",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/GatherBy"]], "InlineFormula"],
 "."
}], "HowToText",
 CellID->770737824],

Cell["\<\
\:0412\:044b\:043f\:043e\:043b\:043d\:0438\:043c \:0433\:0440\:0443\:043f\
\:043f\:0438\:0440\:043e\:0432\:043a\:0443 \:0434\:0430\:043d\:043d\:044b\
\:0445 \:043f\:043e \:0432\:0438\:0434\:0443 \:043b\:0435\:043a\:0430\:0440\
\:0441\:0442\:0432\:0430 \:0438 \:0432\:043e\:0437\:0440\:0430\:0441\:0442\
\:043d\:043e\:0439 \:0433\:0440\:0443\:043f\:043f\:0435:\
\>", "HowToText",
 CellID->825194660],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"byDrugAndAgeGroup", "=", 
  RowBox[{"GatherBy", "[", 
   RowBox[{"meddata", ",", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"First", "[", "#", "]"}], ",", 
       RowBox[{"IntegerPart", "[", 
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "2", "]"}], "]"}], "/", "10"}], "]"}]}], "}"}], 
     "&"}]}], "]"}]}]], "Input",
 CellLabel->"In[41]:=",
 CellID->124481783],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"drugB", ",", "67", ",", "18"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"drugB", ",", "48", ",", "18"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"drugA", ",", "33", ",", "16"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"drugA", ",", "36", ",", "12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"drugA", ",", "36", ",", "18"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"drugB", ",", "76", ",", "33"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"drugB", ",", "78", ",", "28"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"drugB", ",", "75", ",", "25"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"drugB", ",", "33", ",", "3"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"placebo", ",", "40", ",", "15"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"placebo", ",", "46", ",", "23"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"placebo", ",", "47", ",", "20"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"drugB", ",", "54", ",", "13"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"drugB", ",", "52", ",", "16"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"drugA", ",", "69", ",", "30"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"drugA", ",", "78", ",", "40"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"drugA", ",", "79", ",", "36"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"placebo", ",", "77", ",", "37"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"drugA", ",", "45", ",", "16"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"drugA", ",", "58", ",", "24"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"placebo", ",", "25", ",", "9"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"placebo", ",", "27", ",", "8"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"drugB", ",", "22", ",", "3"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"placebo", ",", "51", ",", "25"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"placebo", ",", "69", ",", "34"}], "}"}], "}"}]}], 
  "}"}]], "Output",
 ImageSize->{504, 135},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[41]=",
 CellID->1460841184]
}, Open  ]],

Cell[TextData[{
 "\:0422\:0430\:043a \:0436\:0435, \:043a\:0430\:043a \:0438 \:0440\:0430\
\:043d\:0435\:0435, \:0441\:0442\:0430\:0442\:0438\:0441\:0442\:0438\:0447\
\:0435\:0441\:043a\:0438\:0435 \:043f\:0430\:0440\:0430\:043c\:0435\:0442\
\:0440\:044b \:043c\:043e\:0433\:0443\:0442 \:0431\:044b\:0442\:044c \:0440\
\:0430\:0441\:0441\:0447\:0438\:0442\:0430\:043d\:044b \:0432 \:0440\:0430\
\:0437\:0440\:0435\:0437\:0435 \:0433\:0440\:0443\:043f\:043f \:0434\:0430\
\:043d\:043d\:044b\:0445. \:0417\:0434\:0435\:0441\:044c, \:0434\:0430\:043d\
\:043d\:044b\:0435 \:043e\:0442\:0441\:043e\:0440\:0442\:0438\:0440\:043e\
\:0432\:0430\:043d\:044b \:043f\:043e \:0432\:0438\:0434\:0443 \:043b\:0435\
\:043a\:0430\:0440\:0441\:0442\:0432\:0430 \:0438 \:043e\:0442\:043e\:0431\
\:0440\:0430\:0436\:0435\:043d\:044b \:0432 \:0432\:0438\:0434\:0435 \:0442\
\:0430\:0431\:043b\:0438\:0446\:044b, \:043f\:0440\:0438 \:043f\:043e\:043c\
\:043e\:0449\:0438 \:0444\:0443\:043d\:043a\:0446\:0438\:0438 ",
 Cell[BoxData[
  ButtonBox["Grid",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Grid"]], "InlineFormula"],
 ":"
}], "HowToText",
 CellID->170062781],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
       RowBox[{"10", 
        RowBox[{"IntegerPart", "[", 
         RowBox[{
          RowBox[{"x", "[", 
           RowBox[{"[", 
            RowBox[{"1", ",", "2"}], "]"}], "]"}], "/", "10"}], "]"}]}], ",", 
       RowBox[{"describe", "[", 
        RowBox[{"N", "[", 
         RowBox[{"x", "[", 
          RowBox[{"[", 
           RowBox[{"All", ",", 
            RowBox[{"-", "1"}]}], "]"}], "]"}], "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "byDrugAndAgeGroup"}], "}"}]}], "]"}], "//", "Sort"}],
   "//", "Grid"}]], "Input",
 CellLabel->"In[45]:=",
 CellID->33379938],

Cell[BoxData[
 TagBox[GridBox[{
    {"drugA", "30", 
     RowBox[{"{", 
      RowBox[{"3", ",", "15.333333333333334`", ",", "16.`", ",", 
       RowBox[{"{", 
        RowBox[{"12.`", ",", "18.`"}], "}"}]}], "}"}]},
    {"drugA", "40", 
     RowBox[{"{", 
      RowBox[{"1", ",", "16.`", ",", "16.`", ",", 
       RowBox[{"{", 
        RowBox[{"16.`", ",", "16.`"}], "}"}]}], "}"}]},
    {"drugA", "50", 
     RowBox[{"{", 
      RowBox[{"1", ",", "24.`", ",", "24.`", ",", 
       RowBox[{"{", 
        RowBox[{"24.`", ",", "24.`"}], "}"}]}], "}"}]},
    {"drugA", "60", 
     RowBox[{"{", 
      RowBox[{"1", ",", "30.`", ",", "30.`", ",", 
       RowBox[{"{", 
        RowBox[{"30.`", ",", "30.`"}], "}"}]}], "}"}]},
    {"drugA", "70", 
     RowBox[{"{", 
      RowBox[{"2", ",", "38.`", ",", "38.`", ",", 
       RowBox[{"{", 
        RowBox[{"36.`", ",", "40.`"}], "}"}]}], "}"}]},
    {"drugB", "20", 
     RowBox[{"{", 
      RowBox[{"1", ",", "3.`", ",", "3.`", ",", 
       RowBox[{"{", 
        RowBox[{"3.`", ",", "3.`"}], "}"}]}], "}"}]},
    {"drugB", "30", 
     RowBox[{"{", 
      RowBox[{"1", ",", "3.`", ",", "3.`", ",", 
       RowBox[{"{", 
        RowBox[{"3.`", ",", "3.`"}], "}"}]}], "}"}]},
    {"drugB", "40", 
     RowBox[{"{", 
      RowBox[{"1", ",", "18.`", ",", "18.`", ",", 
       RowBox[{"{", 
        RowBox[{"18.`", ",", "18.`"}], "}"}]}], "}"}]},
    {"drugB", "50", 
     RowBox[{"{", 
      RowBox[{"2", ",", "14.5`", ",", "14.5`", ",", 
       RowBox[{"{", 
        RowBox[{"13.`", ",", "16.`"}], "}"}]}], "}"}]},
    {"drugB", "60", 
     RowBox[{"{", 
      RowBox[{"1", ",", "18.`", ",", "18.`", ",", 
       RowBox[{"{", 
        RowBox[{"18.`", ",", "18.`"}], "}"}]}], "}"}]},
    {"drugB", "70", 
     RowBox[{"{", 
      RowBox[{"3", ",", "28.666666666666668`", ",", "28.`", ",", 
       RowBox[{"{", 
        RowBox[{"25.`", ",", "33.`"}], "}"}]}], "}"}]},
    {"placebo", "20", 
     RowBox[{"{", 
      RowBox[{"2", ",", "8.5`", ",", "8.5`", ",", 
       RowBox[{"{", 
        RowBox[{"8.`", ",", "9.`"}], "}"}]}], "}"}]},
    {"placebo", "40", 
     RowBox[{"{", 
      RowBox[{"3", ",", "19.333333333333332`", ",", "20.`", ",", 
       RowBox[{"{", 
        RowBox[{"15.`", ",", "23.`"}], "}"}]}], "}"}]},
    {"placebo", "50", 
     RowBox[{"{", 
      RowBox[{"1", ",", "25.`", ",", "25.`", ",", 
       RowBox[{"{", 
        RowBox[{"25.`", ",", "25.`"}], "}"}]}], "}"}]},
    {"placebo", "60", 
     RowBox[{"{", 
      RowBox[{"1", ",", "34.`", ",", "34.`", ",", 
       RowBox[{"{", 
        RowBox[{"34.`", ",", "34.`"}], "}"}]}], "}"}]},
    {"placebo", "70", 
     RowBox[{"{", 
      RowBox[{"1", ",", "37.`", ",", "37.`", ",", 
       RowBox[{"{", 
        RowBox[{"37.`", ",", "37.`"}], "}"}]}], "}"}]}
   },
   AutoDelete->False,
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 ImageSize->{274, 237},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[45]=",
 CellID->1633822425]
}, Open  ]],

Cell[TextData[{
 "\:0417\:0430 \:0434\:043e\:043f\:043e\:043b\:043d\:0438\:0442\:0435\:043b\
\:044c\:043d\:043e\:0439 \:0438\:043d\:0444\:043e\:0440\:043c\:0430\:0446\
\:0438\:0435\:0439 \:043f\:043e \:043e\:0442\:043e\:0431\:0440\:0430\:0436\
\:0435\:043d\:0438\:044e \:0438 \:0444\:043e\:0440\:043c\:0430\:0442\:0438\
\:0440\:043e\:0432\:0430\:043d\:0438\:044e \:0442\:0430\:0431\:043b\:0438\
\:0446 \:0434\:0430\:043d\:043d\:044b\:0445, \:043e\:0431\:0440\:0430\:0442\
\:0438\:0442\:0435\:0441\:044c \:043a \:0440\:0430\:0437\:0434\:0435\:043b\
\:0443 \"",
 ButtonBox["\:0420\:0430\:0431\:043e\:0442\:0430 \:0441 \:0442\:0430\:0431\
\:043b\:0438\:0446\:0430\:043c\:0438",
  BaseStyle->"Hyperlink",
  ButtonData->{"WorkWithTablesRU.nb", None}],
 "\"."
}], "HowToText",
 CellID->821408029]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  InterpretationBox[
   StyleBox[
    GraphicsBox[{},
     BaselinePosition->Baseline,
     ImageSize->{6, 0}],
    CacheGraphics->False],
   Spacer[6]]]],
 "\:0423\:0447\:0435\:0431\:043d\:044b\:0435 \:043c\:0430\:0442\:0435\:0440\
\:0438\:0430\:043b\:044b"
}], "TutorialsSection",
 WholeCellGroupOpener->True,
 CellID->250839057],

Cell["", "SectionHeaderSpacer"],

Cell[BoxData[
 TemplateBox[{Cell["Tables and Matrices"],"paclet:tutorial/TablesAndMatrices"},
  "RefLink",
  BaseStyle->"Tutorials"]], "Tutorials",
 CellID->854320837],

Cell[BoxData[
 TemplateBox[{Cell[
    TextData[{"Grids, Rows, and Columns in ", 
      StyleBox["Mathematica", FontSlant -> "Italic"]}]],
   "paclet:tutorial/GridsRowsAndColumns"},
  "RefLink",
  BaseStyle->"Tutorials"]], "Tutorials",
 CellID->494643617],

Cell[BoxData[
 TemplateBox[{Cell["Basic Statistics"],"paclet:tutorial/BasicStatistics"},
  "RefLink",
  BaseStyle->"Tutorials"]], "Tutorials",
 CellID->566073382],

Cell[BoxData[
 TemplateBox[{
  Cell["Descriptive Statistics"],"paclet:tutorial/DescriptiveStatistics"},
  "RefLink",
  BaseStyle->"Tutorials"]], "Tutorials",
 CellID->642775064],

Cell[BoxData[
 TemplateBox[{
  Cell["Partitioning Data into Clusters"],
   "paclet:tutorial/PartitioningDataIntoClusters"},
  "RefLink",
  BaseStyle->"Tutorials"]], "Tutorials",
 CellID->1868435549],

Cell[TextData[ButtonBox["\:0421\:043f\:0438\:0441\:043a\:0438",
 BaseStyle->"Hyperlink",
 ButtonData->{"ListsOverviewRU.nb", None}]], "RelatedTutorials",
 FontFamily->"Verdana",
 FontSize->11,
 CellID->405226890],

Cell[TextData[ButtonBox["\:0420\:0430\:0431\:043e\:0442\:0430 \:0441\:043e \
\:0441\:043f\:0438\:0441\:043a\:0430\:043c\:0438",
 BaseStyle->"Hyperlink",
 ButtonData->{"ManipulatingListsOverviewRU.nb", None}]], "Tutorials",
 FontFamily->"Verdana",
 FontSize->11,
 CellID->107365972],

Cell["", "SectionFooterSpacer"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  InterpretationBox[
   StyleBox[
    GraphicsBox[{},
     BaselinePosition->Baseline,
     ImageSize->{6, 0}],
    CacheGraphics->False],
   Spacer[6]]]],
 "\:0421\:043e\:043f\:0443\:0442\:0441\:0442\:0432\:0443\:044e\:0449\:0438\
\:0435 \:0440\:0430\:0437\:0434\:0435\:043b\:044b \:043a\:0440\:0430\:0442\
\:043a\:043e\:0433\:043e \:043a\:0443\:0440\:0441\:0430"
}], "RelatedLinksSection",
 WholeCellGroupOpener->True,
 CellID->1584193535],

Cell["", "SectionHeaderSpacer"],

Cell[TextData[ButtonBox["\:041a\:0440\:0430\:0442\:043a\:0438\:0439 \:043a\
\:0443\:0440\:0441: \:0421\:0442\:0430\:0442\:0438\:0441\:0442\:0438\:0447\
\:0435\:0441\:043a\:0438\:0439 \:0430\:043d\:0430\:043b\:0438\:0437",
 BaseStyle->"Hyperlink",
 ButtonData->{"DoStatisticalAnalysisRU.nb", None}]], "RelatedLinks",
 FontFamily->"Verdana",
 FontSize->11,
 CellID->10284414],

Cell[TextData[ButtonBox["\:041a\:0440\:0430\:0442\:043a\:0438\:0439 \:043a\
\:0443\:0440\:0441: \:0420\:0430\:0431\:043e\:0442\:0430 \:0441 \:0442\:0430\
\:0431\:043b\:0438\:0446\:0430\:043c\:0438",
 BaseStyle->"Hyperlink",
 ButtonData->{"WorkWithTablesRU.nb", None}]], "RelatedLinks",
 FontFamily->"Verdana",
 FontSize->11,
 CellID->479687921],

Cell[TextData[ButtonBox["\:041a\:0440\:0430\:0442\:043a\:0438\:0439 \:043a\
\:0443\:0440\:0441: \:0420\:0430\:0431\:043e\:0442\:0430 \:0441\:043e \:0441\
\:043f\:0438\:0441\:043a\:0430\:043c\:0438",
 BaseStyle->"Hyperlink",
 ButtonData->{"WorkWithListsRU.nb", None}]], "RelatedTutorials",
 FontFamily->"Verdana",
 FontSize->11,
 CellID->449799395],

Cell["", "SectionFooterSpacer"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  InterpretationBox[
   StyleBox[
    GraphicsBox[{},
     BaselinePosition->Baseline,
     ImageSize->{6, 0}],
    CacheGraphics->False],
   Spacer[6]]]],
 "\:0421\:043c\:043e\:0442\:0440\:0438 \:0442\:0430\:043a\:0436\:0435"
}], "SeeAlsoSection",
 WholeCellGroupOpener->True,
 CellID->1255426704],

Cell[TextData[{
 Cell[BoxData[
  TemplateBox[{Cell["GatherBy"],"paclet:ref/GatherBy"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  TemplateBox[{Cell["First"],"paclet:ref/First"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  TemplateBox[{Cell["Table"],"paclet:ref/Table"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  TemplateBox[{Cell["N"],"paclet:ref/N"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  TemplateBox[{Cell["Mean"],"paclet:ref/Mean"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  TemplateBox[{Cell["Min"],"paclet:ref/Min"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  TemplateBox[{Cell["Max"],"paclet:ref/Max"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  TemplateBox[{Cell["Length"],"paclet:ref/Length"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  TemplateBox[{Cell["Median"],"paclet:ref/Median"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  TemplateBox[{Cell["Sort"],"paclet:ref/Sort"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  TemplateBox[{Cell["IntegerPart"],"paclet:ref/IntegerPart"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  TemplateBox[{Cell["Grid"],"paclet:ref/Grid"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"]
}], "SeeAlso",
 CellID->929782353]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  InterpretationBox[
   StyleBox[
    GraphicsBox[{},
     BaselinePosition->Baseline,
     ImageSize->{6, 0}],
    CacheGraphics->False],
   Spacer[6]]]],
 "\:0423\:0437\:043d\:0430\:0442\:044c \:0431\:043e\:043b\:044c\:0448\:0435"
}], "MoreAboutSection",
 WholeCellGroupOpener->True,
 CellID->38303248],

Cell["", "SectionHeaderSpacer"],

Cell[BoxData[
 TemplateBox[{Cell["Grids & Tables"],"paclet:guide/GridsAndTables"},
  "RefLink",
  BaseStyle->"MoreAbout"]], "MoreAbout",
 CellID->1665078683],

Cell[BoxData[
 TemplateBox[{Cell["Statistics"],"paclet:guide/Statistics"},
  "RefLink",
  BaseStyle->"MoreAbout"]], "MoreAbout",
 CellID->1277756238],

Cell[BoxData[
 TemplateBox[{
  Cell["Descriptive Statistics"],"paclet:guide/DescriptiveStatistics"},
  "RefLink",
  BaseStyle->"MoreAbout"]], "MoreAbout",
 CellID->412622066],

Cell[BoxData[
 TemplateBox[{
  Cell["Math & Counting Operations on Lists"],
   "paclet:guide/MathematicalAndCountingOperationsOnLists"},
  "RefLink",
  BaseStyle->"MoreAbout"]], "MoreAbout",
 CellID->714367099],

Cell[BoxData[
 TemplateBox[{
  Cell["Rearranging & Restructuring Lists"],
   "paclet:guide/RearrangingAndRestructuringLists"},
  "RefLink",
  BaseStyle->"MoreAbout"]], "MoreAbout",
 CellID->1905439333],

Cell[BoxData[
 TemplateBox[{Cell["List Manipulation"],"paclet:guide/ListManipulation"},
  "RefLink",
  BaseStyle->"MoreAbout"]], "MoreAbout",
 CellID->1715039083],

Cell[BoxData[
 TemplateBox[{Cell["Elements of Lists"],"paclet:guide/ElementsOfLists"},
  "RefLink",
  BaseStyle->"MoreAbout"]], "MoreAbout",
 CellID->1136357947],

Cell[BoxData[
 TemplateBox[{Cell["\"How to\" Topics"],"paclet:guide/HowToTopics"},
  "RefLink",
  BaseStyle->"MoreAbout"]], "MoreAbout",
 CellID->1081148686]
}, Open  ]]
}, Open  ]],

Cell[" ", "FooterCell"]
},
FileChangeProtection->None,
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{Automatic, 510},
WindowMargins->{{312, Automatic}, {Automatic, 0}},
WindowFrame->"Normal",
WindowTitle->"Perform Operations on Subgroups of Data - Wolfram Mathematica",
DockedCells->FEPrivate`FrontEndResource["FEExpressions", "HelpViewerToolbar"],
TaggingRules->{
 "ModificationHighlight" -> False, "ColorType" -> "TutorialColor", 
  "LinkTrails" -> "", "ExampleCounter" -> 1, "ExamplePageLinks" -> {}, 
  "RootCaptions" -> "", 
  "Metadata" -> {
   "built" -> "{2013, 1, 24, 22, 48, 37.5846335}", 
    "history" -> {"8.0", "", "", ""}, "context" -> "System`", 
    "keywords" -> {
     "sort by", "split by", "by column", "conditional statistic", 
      "marginal statistic", "descriptive statistic", "groups of data", 
      "columns of data", "subsets of data"}, "specialkeywords" -> {}, 
    "tutorialcollectionlinks" -> {}, "index" -> True, "label" -> 
    "Mathematica How To", "language" -> "en", "paclet" -> "Mathematica", 
    "status" -> "None", "summary" -> 
    "When summarizing data, it is often useful to analyze it by subgroup. For \
example, crop yields could be categorized by seed variety, or average patient \
recovery time by patient age or drug type. Mathematica lets you split columns \
of data based on the values in other columns. You can then compute the \
desired statistics on the resulting groups.", "synonyms" -> {}, "title" -> 
    "Perform Operations on Subgroups of Data", "titlemodifier" -> "", 
    "windowtitle" -> "Perform Operations on Subgroups of Data", "type" -> 
    "HowTo", "uri" -> "howto/PerformOperationsOnSubgroupsOfData"}, 
  "SearchTextTranslated" -> ""},
Magnification->1.,
FrontEndVersion->"10.1 for Microsoft Windows (64-bit) (March 23, 2015)",
StyleDefinitions->FrontEnd`FileName[{"Wolfram"}, "Reference.nb", 
  CharacterEncoding -> "WindowsANSI"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[632, 21, 6358, 143, 70, "AnchorBarGrid",
 CellID->1],
Cell[CellGroupData[{
Cell[7015, 168, 389, 8, 91, "HowToTitle",
 CellID->509267359],
Cell[CellGroupData[{
Cell[7429, 180, 2395, 35, 144, "HowToAbstract",
 CellID->1045883471],
Cell[9827, 217, 555, 9, 56, "HowToText",
 CellID->1009846402],
Cell[10385, 228, 1800, 47, 155, "Input",
 CellID->827466675],
Cell[12188, 277, 1062, 22, 76, "HowToText",
 CellID->1389965763],
Cell[CellGroupData[{
Cell[13275, 303, 170, 5, 28, "Input",
 CellID->411630083],
Cell[13448, 310, 1958, 54, 173, "Output",
 CellID->368652006]
}, Open  ]],
Cell[15421, 367, 2220, 39, 134, "HowToText",
 CellID->150789310],
Cell[17644, 408, 605, 13, 58, "HowToText",
 CellID->812217608],
Cell[CellGroupData[{
Cell[18274, 425, 505, 17, 28, "Input",
 CellID->1398028897],
Cell[18782, 444, 399, 13, 36, "Output",
 CellID->443943247]
}, Open  ]],
Cell[19196, 460, 804, 12, 74, "HowToText",
 CellID->334259956],
Cell[20003, 474, 690, 17, 58, "HowToText",
 CellID->1445501569],
Cell[CellGroupData[{
Cell[20718, 495, 243, 8, 28, "Input",
 CellID->89859940],
Cell[20964, 505, 1919, 52, 156, "Output",
 CellID->995962651]
}, Open  ]],
Cell[22898, 560, 1514, 22, 112, "HowToText",
 CellID->62371672],
Cell[24415, 584, 628, 13, 58, "HowToText",
 CellID->1611208941],
Cell[CellGroupData[{
Cell[25068, 601, 505, 17, 28, "Input",
 CellID->1967366364],
Cell[25576, 620, 321, 11, 36, "Output",
 CellID->1656730639]
}, Open  ]],
Cell[25912, 634, 1078, 16, 92, "HowToText",
 CellID->767258044],
Cell[26993, 652, 483, 8, 56, "HowToText",
 CellID->384363626],
Cell[CellGroupData[{
Cell[27501, 664, 770, 26, 65, "Input",
 CellID->296863878],
Cell[28274, 692, 433, 15, 36, "Output",
 CellID->398882671]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[28756, 713, 66, 2, 15, "HowToDelimiter",
 CellID->163636713],
Cell[28825, 717, 914, 14, 74, "HowToText",
 CellID->323423614],
Cell[29742, 733, 2136, 57, 173, "Input",
 CellID->948295756],
Cell[31881, 792, 748, 12, 74, "HowToText",
 CellID->54379160],
Cell[32632, 806, 483, 9, 58, "HowToText",
 CellID->51739288],
Cell[CellGroupData[{
Cell[33140, 819, 167, 5, 28, "Input",
 CellID->380755307],
Cell[33310, 826, 2294, 64, 173, "Output",
 CellID->1724589210]
}, Open  ]],
Cell[35619, 893, 717, 11, 56, "HowToText",
 CellID->60920969],
Cell[36339, 906, 449, 13, 47, "Input",
 CellID->384907061],
Cell[36791, 921, 1693, 29, 114, "HowToText",
 CellID->196214012],
Cell[CellGroupData[{
Cell[38509, 954, 509, 17, 28, "Input",
 CellID->391246615],
Cell[39021, 973, 822, 26, 71, "Output",
 CellID->584068911]
}, Open  ]],
Cell[39858, 1002, 1288, 19, 92, "HowToText",
 CellID->772452016],
Cell[41149, 1023, 1567, 28, 114, "HowToText",
 CellID->102811083],
Cell[CellGroupData[{
Cell[42741, 1055, 322, 11, 28, "Input",
 CellID->340447965],
Cell[43066, 1068, 2410, 70, 173, "Output",
 CellID->298436740]
}, Open  ]],
Cell[45491, 1141, 1299, 26, 96, "HowToText",
 CellID->11488553],
Cell[CellGroupData[{
Cell[46815, 1171, 657, 22, 47, "Input",
 CellID->189076812],
Cell[47475, 1195, 1446, 44, 122, "Output",
 CellID->1451973435]
}, Open  ]],
Cell[48936, 1242, 1542, 31, 96, "HowToText",
 CellID->770737824],
Cell[50481, 1275, 408, 7, 38, "HowToText",
 CellID->825194660],
Cell[CellGroupData[{
Cell[50914, 1286, 429, 14, 47, "Input",
 CellID->124481783],
Cell[51346, 1302, 2631, 80, 190, "Output",
 CellID->1460841184]
}, Open  ]],
Cell[53992, 1385, 1148, 20, 94, "HowToText",
 CellID->170062781],
Cell[CellGroupData[{
Cell[55165, 1409, 810, 26, 65, "Input",
 CellID->33379938],
Cell[55978, 1437, 3025, 90, 258, "Output",
 CellID->1633822425]
}, Open  ]],
Cell[59018, 1530, 790, 15, 74, "HowToText",
 CellID->821408029]
}, Open  ]],
Cell[CellGroupData[{
Cell[59845, 1550, 362, 13, 30, "TutorialsSection",
 CellID->250839057],
Cell[60210, 1565, 31, 0, 14, "SectionHeaderSpacer"],
Cell[60244, 1567, 167, 4, 19, "Tutorials",
 CellID->854320837],
Cell[60414, 1573, 254, 7, 19, "Tutorials",
 CellID->494643617],
Cell[60671, 1582, 162, 4, 19, "Tutorials",
 CellID->566073382],
Cell[60836, 1588, 177, 5, 19, "Tutorials",
 CellID->642775064],
Cell[61016, 1595, 198, 6, 19, "Tutorials",
 CellID->1868435549],
Cell[61217, 1603, 212, 5, 18, "RelatedTutorials",
 CellID->405226890],
Cell[61432, 1610, 281, 6, 18, "Tutorials",
 CellID->107365972],
Cell[61716, 1618, 31, 0, 29, "SectionFooterSpacer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[61784, 1623, 472, 14, 30, "RelatedLinksSection",
 CellID->1584193535],
Cell[62259, 1639, 31, 0, 14, "SectionHeaderSpacer"],
Cell[62293, 1641, 373, 7, 18, "RelatedLinks",
 CellID->10284414],
Cell[62669, 1650, 344, 7, 18, "RelatedLinks",
 CellID->479687921],
Cell[63016, 1659, 347, 7, 18, "RelatedTutorials",
 CellID->449799395],
Cell[63366, 1668, 31, 0, 29, "SectionFooterSpacer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[63434, 1673, 329, 12, 30, "SeeAlsoSection",
 CellID->1255426704],
Cell[63766, 1687, 3242, 94, 75, "SeeAlso",
 CellID->929782353]
}, Open  ]],
Cell[CellGroupData[{
Cell[67045, 1786, 335, 12, 30, "MoreAboutSection",
 CellID->38303248],
Cell[67383, 1800, 31, 0, 14, "SectionHeaderSpacer"],
Cell[67417, 1802, 157, 4, 19, "MoreAbout",
 CellID->1665078683],
Cell[67577, 1808, 149, 4, 19, "MoreAbout",
 CellID->1277756238],
Cell[67729, 1814, 174, 5, 19, "MoreAbout",
 CellID->412622066],
Cell[67906, 1821, 210, 6, 19, "MoreAbout",
 CellID->714367099],
Cell[68119, 1829, 201, 6, 19, "MoreAbout",
 CellID->1905439333],
Cell[68323, 1837, 162, 4, 19, "MoreAbout",
 CellID->1715039083],
Cell[68488, 1843, 161, 4, 19, "MoreAbout",
 CellID->1136357947],
Cell[68652, 1849, 157, 4, 19, "MoreAbout",
 CellID->1081148686]
}, Open  ]]
}, Open  ]],
Cell[68836, 1857, 23, 0, 41, "FooterCell"]
}
]
*)

(* End of internal cache information *)
