(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     92614,       2338]
NotebookOptionsPosition[     82697,       2040]
NotebookOutlinePosition[     85541,       2097]
CellTagsIndexPosition[     85498,       2094]
WindowTitle->Plot Diagnostics for Fitted Models - Wolfram Mathematica
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[GridBox[{
   {Cell["MATHEMATICA HOW TO", "PacletNameCell"], Cell[TextData[{
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "Tutorials",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"Tutorials", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->False], {"\<\"Statistical Model Analysis\"\>":>
       Documentation`HelpLookup[
       "paclet:tutorial/StatisticalModelAnalysis"], "\<\"Plotting Lists of \
Data\"\>":>Documentation`HelpLookup[
       "paclet:tutorial/PlottingListsOfData"], "\<\"Options for Graphics\"\>":>
       Documentation`HelpLookup[
       "paclet:tutorial/Options"], "\<\"Basic Plotting\"\>":>
       Documentation`HelpLookup["paclet:tutorial/BasicPlotting"]},
       Appearance->None,
       MenuAppearance->Automatic,
       MenuStyle->"Tutorials"]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "See Also",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"See Also", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->False], {"\<\"LinearModelFit\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/LinearModelFit"], "\<\"FittedModel\"\>":>
       Documentation`HelpLookup["paclet:ref/FittedModel"], "\<\"ListPlot\"\>":>
       Documentation`HelpLookup["paclet:ref/ListPlot"], "\<\"Plot\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/Plot"], "\<\"NonlinearModelFit\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/NonlinearModelFit"], "\<\"Exp\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/Exp"], "\<\"GeneralizedLinearModelFit\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/GeneralizedLinearModelFit"], "\<\"ExponentialFamily\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/ExponentialFamily"], "\<\"GraphicsGrid\"\>":>
       Documentation`HelpLookup["paclet:ref/GraphicsGrid"], "\<\"Filling\"\>":>
       Documentation`HelpLookup["paclet:ref/Filling"], "\<\"Frame\"\>":>
       Documentation`HelpLookup["paclet:ref/Frame"]},
       Appearance->None,
       MenuAppearance->Automatic,
       MenuStyle->"SeeAlso"]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "Related Guides",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"Related Guides", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->False], {"\<\"Statistics\"\>":>Documentation`HelpLookup[
       "paclet:guide/Statistics"], "\<\"Statistical Model Analysis\"\>":>
       Documentation`HelpLookup[
       "paclet:guide/StatisticalModelAnalysis"], "\<\"Data Visualization\"\>":>
       Documentation`HelpLookup[
       "paclet:guide/DataVisualization"], "\<\"\\\"How to\\\" Topics\"\>":>
       Documentation`HelpLookup["paclet:guide/HowToTopics"]},
       Appearance->None,
       MenuAppearance->Automatic,
       MenuStyle->"MoreAbout"]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "URL",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"URL", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->False], {"\<\"howto/PlotDiagnosticsForFittedModels\"\>":>
       None, "\<\"Copy Mathematica URL\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell["howto/PlotDiagnosticsForFittedModels"]}, Visible -> 
            False]]; SelectionMove[
         DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; Null], 
       Delimiter, "\<\"Copy web URL\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell[
              BoxData[
               MakeBoxes[
                Hyperlink[
                "http://reference.wolfram.com/mathematica/howto/\
PlotDiagnosticsForFittedModels.html"], StandardForm]], "Input", 
              TextClipboardType -> "PlainText"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; 
        Null], "\<\"Go to web URL\"\>":>FrontEndExecute[{
         NotebookLocate[{
           URL[
            StringJoin[
            "http://reference.wolfram.com/mathematica/", 
             "howto/PlotDiagnosticsForFittedModels", ".html"]], None}]}]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}]
    }], "AnchorBar"]}
  }]], "AnchorBarGrid",
 CellID->1],

Cell[CellGroupData[{

Cell[TextData[{
 Cell["\:041a\:0440\:0430\:0442\:043a\:0438\:0439 \:043a\:0443\:0440\:0441 ", 
  "HowToTitlePrefix"],
 " ",
 "\:0413\:0440\:0430\:0444\:0438\:0447\:0435\:0441\:043a\:0438\:0435 \:0438\
\:043d\:0441\:0442\:0440\:0443\:043c\:0435\:043d\:0442\:044b \:043f\:0440\
\:043e\:0432\:0435\:0440\:043a\:0438 \:043a\:043e\:0440\:0440\:0435\:043a\
\:0442\:043d\:043e\:0441\:0442\:0438 \:043f\:043e\:0434\:0431\:043e\:0440\
\:0430 \:043c\:043e\:0434\:0435\:043b\:0438 \:043f\:043e \:0442\:043e\:0447\
\:043a\:0430\:043c"
}], "HowToTitle",
 CellID->509267359],

Cell[CellGroupData[{

Cell[TextData[{
 "\:0414\:0438\:0430\:0433\:043d\:043e\:0441\:0442\:0438\:043a\:0430 \:044f\
\:0432\:043b\:044f\:0435\:0442\:0441\:044f \:0432\:0430\:0436\:043d\:043e\
\:0439 \:0447\:0430\:0441\:0442\:044c\:044e \:0430\:043d\:0430\:043b\:0438\
\:0437\:0430 \:043c\:043e\:0434\:0435\:043b\:0435\:0439 \:0434\:0430\:043d\
\:043d\:044b\:0445. \:0413\:0440\:0430\:0444\:0438\:043a\:0438 \:043e\:0441\
\:0442\:0430\:0442\:043a\:043e\:0432 \:0438 \:043f\:043e\:043a\:0430\:0437\
\:0430\:0442\:0435\:043b\:0435\:0439 \:0432\:043b\:0438\:044f\:0442\:0435\
\:043b\:044c\:043d\:043e\:0441\:0442\:0438 \:043f\:0440\:0435\:0434\:043e\
\:0441\:0442\:0430\:0432\:043b\:044f\:044e\:0442 \:0446\:0435\:043d\:043d\
\:0443\:044e \:0438\:043d\:0444\:043e\:0440\:043c\:0430\:0446\:0438\:044e \
\:043e \:0442\:043e\:043c, \:044f\:0432\:043b\:044f\:044e\:0442\:0441\:044f \
\:043b\:0438 \:043a\:043e\:0440\:0440\:0435\:043a\:0442\:043d\:044b\:043c\
\:0438 \:043f\:0440\:0435\:0434\:043f\:043e\:043b\:0430\:0433\:0430\:0435\
\:043c\:044b\:0435 \:043e\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\
\:0438\:044f \:043c\:043e\:0434\:0435\:043b\:0438 \:0438 \:043d\:0435\:0442 \
\:043b\:0438 \:043e\:043f\:043e\:0440\:043d\:044b\:0445 \:0442\:043e\:0447\
\:0435\:043a, \:043e\:043a\:0430\:0437\:044b\:0432\:0430\:044e\:0449\:0438\
\:0445 \:0441\:043b\:0438\:0448\:043a\:043e\:043c \:0441\:0438\:043b\:044c\
\:043d\:043e\:0435 \:0432\:043b\:0438\:044f\:043d\:0438\:0435 \:043d\:0430 \
\:043f\:043e\:0434\:0431\:043e\:0440 \:043c\:043e\:0434\:0435\:043b\:0438. \
\:0412 ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", \:043f\:043e\:0434\:043e\:0431\:043d\:043e\:0433\:043e \:0440\:043e\:0434\
\:0430 \:0433\:0440\:0430\:0444\:0438\:043a\:0438 \:0441\:043e\:0437\:0434\
\:0430\:044e\:0442\:0441\:044f \:043f\:0443\:0442\:0435\:043c \:0441\:043e\
\:0432\:043c\:0435\:0449\:0435\:043d\:0438\:044f \:0440\:0435\:0437\:0443\
\:043b\:044c\:0442\:0430\:0442\:043e\:0432 \:0444\:0443\:043d\:043a\:0446\
\:0438\:0439, \:0442\:0430\:043a\:0438\:0445 \:043a\:0430\:043a ",
 Cell[BoxData[
  ButtonBox["LinearModelFit",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/LinearModelFit"]], "InlineFormula"],
 ", \:0441\:043e \:0432\:0441\:0442\:0440\:043e\:0435\:043d\:043d\:044b\:043c\
\:0438 \:0433\:0440\:0430\:0444\:0438\:0447\:0435\:0441\:043a\:0438\:043c\
\:0438 \:0444\:0443\:043d\:043a\:0446\:0438\:044f\:043c\:0438."
}], "HowToAbstract",
 CellID->1045883471],

Cell["\:0414\:043b\:044f \:043d\:0430\:0447\:0430\:043b\:0430, \:0437\:0430\
\:0434\:0430\:0434\:0438\:043c \:043d\:0430\:0431\:043e\:0440 \:0434\:0430\
\:043d\:043d\:044b\:0445 \:0434\:043b\:044f \:043f\:043e\:0441\:043b\:0435\
\:0434\:0443\:044e\:0449\:0435\:0439 \:043e\:0431\:0440\:0430\:0431\:043e\
\:0442\:043a\:0438:", "HowToText",
 CellID->1009846402],

Cell[BoxData[
 RowBox[{
  RowBox[{"data1", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1.36", ",", "15.36"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.69", ",", "16.12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4.91", ",", "104.62"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4.85", ",", "110.06"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4.41", ",", "99.07"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2.15", ",", "23.83"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2.98", ",", "48.86"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.19", ",", "16.29"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4.08", ",", "79.91"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.05", ",", "0.89"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3.69", ",", "70.13"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2.34", ",", "32.07"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2.32", ",", "29.39"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.77", ",", "26.41"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.47", ",", "6.64"}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellLabel->"In[1]:=",
 CellID->827466675],

Cell[TextData[{
 "\:041b\:0438\:043d\:0435\:0439\:043d\:0430\:044f \:043c\:043e\:0434\:0435\
\:043b\:044c \:044f\:0432\:043b\:044f\:0435\:0442\:0441\:044f \:043c\:043e\
\:0434\:0435\:043b\:044c\:044e, \:043a\:043e\:0442\:043e\:0440\:0430\:044f \
\:043b\:0438\:043d\:0435\:0439\:043d\:0430 \:043f\:043e \:043f\:0430\:0440\
\:0430\:043c\:0435\:0442\:0440\:0430\:043c, \:043f\:043e\:0434\:043b\:0435\
\:0436\:0430\:0449\:0438\:043c \:043e\:0446\:0435\:043d\:043a\:0435. \:041c\
\:043e\:0434\:0435\:043b\:044c \:0432 \:0444\:043e\:0440\:043c\:0435 ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Beta]", "0"], "+", 
    RowBox[{
     SubscriptBox["\[Beta]", "1"], "x"}], "+", 
    RowBox[{
     SubscriptBox["\[Beta]", "2"], 
     SuperscriptBox["x", "2"]}]}], TraditionalForm]], "InlineMath"],
 " \:044f\:0432\:043b\:044f\:0435\:0442\:0441\:044f \:043a\:0432\:0430\:0434\
\:0440\:0430\:0442\:0438\:0447\:043d\:043e\:0439 \:0434\:043b\:044f ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]], "InlineMath"],
 ", \:043d\:043e \:044f\:0432\:043b\:044f\:0435\:0442\:0441\:044f \
\:043b\:0438\:043d\:0435\:0439\:043d\:043e\:0439 \:0434\:043b\:044f \:043f\
\:0430\:0440\:0430\:043c\:0435\:0442\:0440\:043e\:0432 ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Beta]", "0"], TraditionalForm]], "InlineMath"],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Beta]", "1"], TraditionalForm]], "InlineMath"],
 " \:0438 ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Beta]", "2"], TraditionalForm]], "InlineMath"],
 "."
}], "HowToText",
 CellID->9075086],

Cell[TextData[{
 "\:0412\:043e\:0441\:043f\:043e\:043b\:044c\:0437\:0443\:0435\:043c\:0441\
\:044f \:0444\:0443\:043d\:043a\:0446\:0438\:0435\:0439 ",
 Cell[BoxData[
  ButtonBox["LinearModelFit",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/LinearModelFit"]], "InlineFormula"],
 " \:0434\:043b\:044f \:043f\:043e\:0434\:0431\:043e\:0440\:0430 \:043c\:043e\
\:0434\:0435\:043b\:0438:"
}], "HowToText",
 CellID->1389965763],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"lm", "=", 
  RowBox[{"LinearModelFit", "[", 
   RowBox[{"data1", ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"x", "^", "2"}]}], "}"}], ",", "x"}], "]"}]}]], "Input",
 CellLabel->"In[2]:=",
 CellID->411630083],

Cell[BoxData[
 RowBox[{"FittedModel", "[", 
  PanelBox[
   TagBox[
    RowBox[{"1.985803689037119`", "\[InvisibleSpace]", "+", 
     RowBox[{"4.871492293143358`", " ", "x"}], "+", 
     RowBox[{"3.5331524843595172`", " ", 
      SuperscriptBox["x", "2"]}]}],
    Short],
   FrameMargins->5], "]"}]], "Output",
 ImageSize->{266, 36},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[2]=",
 CellID->9673184]
}, Open  ]],

Cell[TextData[{
 "\:041c\:043e\:0436\:043d\:043e \:043f\:043e\:043b\:0443\:0447\:0438\:0442\
\:044c \:0447\:0438\:0441\:043b\:0435\:043d\:043d\:043e\:0435 \:0432\:044b\
\:0440\:0430\:0436\:0435\:043d\:0438\:0435 \:043e\:0431\:044a\:0435\:043a\
\:0442\:0430 ",
 Cell[BoxData[
  ButtonBox["FittedModel",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/FittedModel"]], "InlineFormula"],
 " \:0432 \:0437\:043d\:0430\:0447\:0435\:043d\:0438\:044f\:0445 ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]], "InlineMath"],
 ". \:0422\:0430\:043a\:0438\:043c \
\:043e\:0431\:0440\:0430\:0437\:043e\:043c, \:043f\:043e\:0434\:043e\:0431\
\:0440\:0430\:043d\:043d\:0430\:044f \:043a\:0440\:0438\:0432\:0430\:044f \
\:043c\:043e\:0436\:0435\:0442 \:0431\:044b\:0442\:044c \:043e\:0442\:043e\
\:0431\:0440\:0430\:0436\:0435\:043d\:0430 \:0433\:0440\:0430\:0444\:0438\
\:0447\:0435\:0441\:043a\:0438 \:043f\:0440\:0438 \:043f\:043e\:043c\:043e\
\:0449\:0438 \:0444\:0443\:043d\:043a\:0446\:0438\:0438 ",
 Cell[BoxData[
  ButtonBox["Plot",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Plot"]], "InlineFormula"],
 ", \:0430\:0440\:0433\:0443\:043c\:0435\:043d\:0442\:043e\:043c \:043a\:043e\
\:0442\:043e\:0440\:043e\:0439 \:044f\:0432\:043b\:044f\:0435\:0442\:0441\
\:044f \:0444\:0443\:043d\:043a\:0446\:0438\:044f ",
 Cell[BoxData[
  RowBox[{"lm", "[", "x", "]"}]], "InlineFormula"],
 "."
}], "HowToText",
 CellID->333472440],

Cell["\:041f\:043e\:0441\:0442\:0440\:043e\:0438\:043c \:0433\:0440\:0430\
\:0444\:0438\:043a \:043f\:043e\:0434\:043e\:0431\:0440\:0430\:043d\:043d\
\:043e\:0439 \:0444\:0443\:043d\:043a\:0446\:0438\:0438:", "HowToText",
 CellID->674552109],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"p1", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"lm", "[", "x", "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "5"}], "}"}]}], "]"}]}]], "Input",
 CellLabel->"In[3]:=",
 CellID->773665386],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVxX041AcAB/DTXcx5mbvfWkQcyeU1nvWCXn5ftHk3r6m7XzWXt+atPK41
J0VJVurKLW+ZUNJTlDktvZjiKKRk6cVZPY5swpIuDrltf3yej7kgKThqAY1G
8//P/5ekCzSdIkUbDypcz76UqcmWHo5fOGcrmSxpzksbVJPq1sZDHM4u0nHT
+9l8DRpKmnLNFnJ+JM+cncqM4tAQv0GYMGWWQ256lWeyazsNPbOxkndmhST3
CjudLadBq2+AO2Z2idSOtJ4Z69dAWXvpnrdmDaSr363etlk6aq7m9MU7tJO2
J2VGYUxtxJDdhaPJPWQtw8KdFq6PxCFrhbTmBVnrOdXfp80G0/ww95Xza7I6
bN0FImURThh02JR9pyD3xgexn4waQtAX+ju98w0ZMhzQFKM2wR7ZYUESd4R0
dl+2rfoiB7W7dUMMvcfIN1yxOrnLAmWiuBHH8HfkdYe6I70+y5FZOhf0YXSC
rA9uq6u/ywWt5zVup06Sk3nPs8sDbGCVEr0v1EZJzk18FFa52GNQmb9Z585H
suPcp1GhjiN8hr7ff3rPNBn7w5jo3BUnBAyKbU1NZ0iDQUmdFe8rjDQLDt6v
niUdMiqYeXOr4MDqXeqx4xMpKLEI/PPpGjBJZYR8cp7UrI9X/1XmDM8x3pRF
GA3i1LEPwVWueH4vUoNnpwE7F/G4sGE96o+2bOcoNdDSL1EsadiI6IXC111d
CxBcOM6+IwJ2JovqdYvo0FAtNjQ65YaVMbZdfhEMtLyYiau65I5HbDsdoctC
0Nb6VkoVHrhVk1lsR9eEQ1Jbp5z1NUQaNoGd/ZqgF1xvxc5vwJSneiVKtcAb
cZNl3vDEUKW5pDTtM+idp/Y2q70gWWHEaAjTxnSx+ce4eB+Ii6LbIjhMZJrL
Q9QPfMGTbOvSHWaCvlSt623tj+lNF1SljTrY3ebVaXgtAIoh9333snVhvb1i
7QA7EOUbnIwfRujhpwJvxdaBQFRnCVkx9vq46KI/Ja0KQnbYTl+6Uh8joe+S
DiUFY7W87FL2w88xn7LEhOEXggLr4uqHvgZ4r3ksfYdpKA405Rb4Nhig3fvb
MT+tMPgbh11ot2SBlyBzo0+EwS2xjc/KYcEn475L1qPNKDURWHYqWfjllVJ6
VRYOy+aLZwL4bPRE7L9ifG0LxPb3bJ40stFoG7RufdFWRE8yuh/YEDCO8xr4
ooQHQe17Ts5JAvpDuWxuHh/xmSFzPqcIZN9QyET5fAhDpM908wikizMePy7m
46hSeEJ8hsCI/89vRef5qHFRzeaXELg9b+LSW8+H6q66t/IygdXO1U7Fz/kQ
P9HNbWkjIGF2F0SbUiiqSIg98oCAMoG7utWCQkVKl4dXB4Gep7IVVlwK178U
z3R0EdCre7loeCUFOY+I7XlKQFQRqZXgRoGrMPIYUBCwp1SeOZEUHKWppueH
CBzQerxlPJaCa1afKmqYQPBv400hCRT8uCXX/h4hkGzJyDfbSyE5jmM6MUGg
etVJ3q1sCmnrM1S/ThKYpVcuX3acQpbewB8pSgKtzxhex8QUCq5WHJueJiA/
XnSaKqRQfpARc3OGADex+6ashMLloCj3tDkC/4QEuq4spyC1aF26cZ7Amo2L
WYWVFBonrVRqNYF5OyuSfpnCvxahLz0=
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0, 5}, {0., 114.67207316139317`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 ImageSize->{184, 116},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[3]=",
 CellID->68647072]
}, Open  ]],

Cell[TextData[{
 "\:041c\:043e\:0436\:043d\:043e \:043f\:043e\:0441\:0442\:0440\:043e\:0438\
\:0442\:044c \:0433\:0440\:0430\:0444\:0438\:043a \:0434\:0430\:043d\:043d\
\:044b\:0445, \:0438\:0441\:043f\:043e\:043b\:044c\:0437\:043e\:0432\:0430\
\:0432 \:0444\:0443\:043d\:043a\:0446\:0438\:044e ",
 Cell[BoxData[
  ButtonBox["ListPlot",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/ListPlot"]], "InlineFormula"],
 ", \:0438 \:043f\:0440\:0438\:043c\:0435\:043d\:0438\:0432 \
\:0444\:0443\:043d\:043a\:0446\:0438\:044e ",
 Cell[BoxData[
  ButtonBox["Show",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Show"]], "InlineFormula"],
 " \:0434\:043b\:044f \:043e\:0442\:043e\:0431\:0440\:0430\:0436\:0435\:043d\
\:0438\:044f \:0434\:0430\:043d\:043d\:044b\:0445 \:0432\:043c\:0435\:0441\
\:0442\:0435 \:0441 \:043f\:043e\:0434\:043e\:0431\:0440\:0430\:043d\:043d\
\:043e\:0439 \:043a\:0440\:0438\:0432\:043e\:0439:"
}], "HowToText",
 CellID->812217608],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"ListPlot", "[", "data1", "]"}], ",", "p1"}], "]"}]], "Input",
 CellLabel->"In[4]:=",
 CellID->1398028897],

Cell[BoxData[
 GraphicsBox[{
   {Hue[0.67, 0.6, 0.6], 
    PointBox[{{1.36, 15.36}, {1.69, 16.12}, {4.91, 104.62}, {4.85, 110.06}, {
     4.41, 99.07}, {2.15, 23.83}, {2.98, 48.86}, {1.19, 16.29}, {4.08, 
     79.91}, {0.05, 0.89}, {3.69, 70.13}, {2.34, 32.07}, {2.32, 29.39}, {1.77,
      26.41}, {0.47, 6.64}}]}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVxX041AcAB/DTXcx5mbvfWkQcyeU1nvWCXn5ftHk3r6m7XzWXt+atPK41
J0VJVurKLW+ZUNJTlDktvZjiKKRk6cVZPY5swpIuDrltf3yej7kgKThqAY1G
8//P/5ekCzSdIkUbDypcz76UqcmWHo5fOGcrmSxpzksbVJPq1sZDHM4u0nHT
+9l8DRpKmnLNFnJ+JM+cncqM4tAQv0GYMGWWQ256lWeyazsNPbOxkndmhST3
CjudLadBq2+AO2Z2idSOtJ4Z69dAWXvpnrdmDaSr363etlk6aq7m9MU7tJO2
J2VGYUxtxJDdhaPJPWQtw8KdFq6PxCFrhbTmBVnrOdXfp80G0/ww95Xza7I6
bN0FImURThh02JR9pyD3xgexn4waQtAX+ju98w0ZMhzQFKM2wR7ZYUESd4R0
dl+2rfoiB7W7dUMMvcfIN1yxOrnLAmWiuBHH8HfkdYe6I70+y5FZOhf0YXSC
rA9uq6u/ywWt5zVup06Sk3nPs8sDbGCVEr0v1EZJzk18FFa52GNQmb9Z585H
suPcp1GhjiN8hr7ff3rPNBn7w5jo3BUnBAyKbU1NZ0iDQUmdFe8rjDQLDt6v
niUdMiqYeXOr4MDqXeqx4xMpKLEI/PPpGjBJZYR8cp7UrI9X/1XmDM8x3pRF
GA3i1LEPwVWueH4vUoNnpwE7F/G4sGE96o+2bOcoNdDSL1EsadiI6IXC111d
CxBcOM6+IwJ2JovqdYvo0FAtNjQ65YaVMbZdfhEMtLyYiau65I5HbDsdoctC
0Nb6VkoVHrhVk1lsR9eEQ1Jbp5z1NUQaNoGd/ZqgF1xvxc5vwJSneiVKtcAb
cZNl3vDEUKW5pDTtM+idp/Y2q70gWWHEaAjTxnSx+ce4eB+Ii6LbIjhMZJrL
Q9QPfMGTbOvSHWaCvlSt623tj+lNF1SljTrY3ebVaXgtAIoh9333snVhvb1i
7QA7EOUbnIwfRujhpwJvxdaBQFRnCVkx9vq46KI/Ja0KQnbYTl+6Uh8joe+S
DiUFY7W87FL2w88xn7LEhOEXggLr4uqHvgZ4r3ksfYdpKA405Rb4Nhig3fvb
MT+tMPgbh11ot2SBlyBzo0+EwS2xjc/KYcEn475L1qPNKDURWHYqWfjllVJ6
VRYOy+aLZwL4bPRE7L9ifG0LxPb3bJ40stFoG7RufdFWRE8yuh/YEDCO8xr4
ooQHQe17Ts5JAvpDuWxuHh/xmSFzPqcIZN9QyET5fAhDpM908wikizMePy7m
46hSeEJ8hsCI/89vRef5qHFRzeaXELg9b+LSW8+H6q66t/IygdXO1U7Fz/kQ
P9HNbWkjIGF2F0SbUiiqSIg98oCAMoG7utWCQkVKl4dXB4Gep7IVVlwK178U
z3R0EdCre7loeCUFOY+I7XlKQFQRqZXgRoGrMPIYUBCwp1SeOZEUHKWppueH
CBzQerxlPJaCa1afKmqYQPBv400hCRT8uCXX/h4hkGzJyDfbSyE5jmM6MUGg
etVJ3q1sCmnrM1S/ThKYpVcuX3acQpbewB8pSgKtzxhex8QUCq5WHJueJiA/
XnSaKqRQfpARc3OGADex+6ashMLloCj3tDkC/4QEuq4spyC1aF26cZ7Amo2L
WYWVFBonrVRqNYF5OyuSfpnCvxahLz0=
      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  PlotRange->Automatic,
  PlotRangeClipping->True]], "Output",
 ImageSize->{184, 114},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[4]=",
 CellID->881128876]
}, Open  ]],

Cell[TextData[{
 "\:041f\:043e\:043c\:0438\:043c\:043e \:044d\:0442\:043e\:0433\:043e, \:0434\
\:043e\:0441\:0442\:0443\:043f\:0435\:043d \:0435\:0449\:0435 \:0446\:0435\
\:043b\:044b\:0439 \:0440\:044f\:0434 \:0434\:0430\:043d\:043d\:044b\:0445 \
\:0438 \:0440\:0435\:0437\:0443\:043b\:044c\:0442\:0430\:0442\:043e\:0432 \
\:0434\:0438\:0430\:0433\:043d\:043e\:0441\:0442\:0438\:043a\:0438 \:043e\
\:0431\:044a\:0435\:043a\:0442\:0430 ",
 Cell[BoxData[
  ButtonBox["FittedModel",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/FittedModel"]], "InlineFormula"],
 "."
}], "HowToText",
 CellID->178013378],

Cell["\<\
\:0414\:043b\:044f \:043b\:0438\:043d\:0435\:0439\:043d\:043e\:0439 \:043c\
\:043e\:0434\:0435\:043b\:0438, \:043e\:0441\:0442\:0430\:0442\:043a\:0438 \
\:0434\:043e\:043b\:0436\:043d\:044b \:0432\:044b\:0433\:043b\:044f\:0434\
\:0435\:0442\:044c \:043a\:0430\:043a \"\:0431\:0435\:043b\:044b\:0439 \:0448\
\:0443\:043c\" - \:043f\:0440\:043e\:0438\:0437\:0432\:043e\:043b\:044c\:043d\
\:044b\:0435, \:043d\:043e\:0440\:043c\:0430\:043b\:044c\:043d\:043e \:0440\
\:0430\:0441\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\:043d\:044b\:0435\
 \:0437\:043d\:0430\:0447\:0435\:043d\:0438\:044f \:0441\:043e \:0441\:0440\
\:0435\:0434\:043d\:0438\:043c 0 \:0438 \:043f\:043e\:0441\:0442\:043e\:044f\
\:043d\:043d\:043e\:0439 \:0434\:0438\:0441\:043f\:0435\:0440\:0441\:0438\
\:0435\:0439. \:041b\:044e\:0431\:044b\:0435 \:0442\:0440\:0435\:043d\:0434\
\:044b \:0432 \:043e\:0441\:0442\:0430\:0442\:043a\:0430\:0445 \:043c\:043e\
\:0433\:0443\:0442 \:0443\:043a\:0430\:0437\:044b\:0432\:0430\:0442\:044c \
\:043d\:0430 \:043d\:0435\:043e\:0431\:0445\:043e\:0434\:0438\:043c\:043e\
\:0441\:0442\:044c \:0432\:043d\:0435\:0441\:0435\:043d\:0438\:044f \:0438\
\:0437\:043c\:0435\:043d\:0435\:043d\:0438\:0439 \:0432 \:043c\:043e\:0434\
\:0435\:043b\:044c.\
\>", "HowToText",
 CellID->1522158152],

Cell[TextData[{
 "\:0412\:043e\:0441\:043f\:043e\:043b\:044c\:0437\:0443\:0435\:043c\:0441\
\:044f \:0441\:0432\:043e\:0439\:0441\:0442\:0432\:043e\:043c ",
 Cell[BoxData["\<\"FitResiduals\"\>"], "InlineFormula"],
 " \:043e\:0431\:044a\:0435\:043a\:0442\:0430 ",
 Cell[BoxData[
  ButtonBox["FittedModel",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/FittedModel"]], "InlineFormula"],
 " (\:0432 \:0434\:0430\:043d\:043d\:043e\:043c \
\:0441\:043b\:0443\:0447\:0430\:0435 ",
 Cell[BoxData["lm"], "InlineFormula"],
 ") \:0434\:043b\:044f \:043f\:043e\:043b\:0443\:0447\:0435\:043d\:0438\:044f \
\:043e\:0441\:0442\:0430\:0442\:043a\:043e\:0432, \:0438 \:043e\:0442\:043e\
\:0431\:0440\:0430\:0437\:0438\:043c \:0432\:0441\:0435 \:043d\:0430\:0439\
\:0434\:0435\:043d\:043d\:044b\:0435 \:0442\:043e\:0447\:043a\:0438 \:043d\
\:0430 \:0433\:0440\:0430\:0444\:0438\:043a\:0435:"
}], "HowToText",
 CellID->83629139],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{"lm", "[", "\"\<FitResiduals\>\"", "]"}], "]"}]], "Input",
 CellLabel->"In[5]:=",
 CellID->181272062],

Cell[BoxData[
 GraphicsBox[
  {Hue[0.67, 0.6, 0.6], 
   PointBox[{{1., 0.21404795721654857`}, {2., -4.189662475028609}, {
    3., -6.462424256558677}, {4., 1.3388793758708601`}, {5., 
    6.887812467128327}, {6., -4.9615094782472084`}, {7., 
    0.9813419552894231}, {8., 3.5038232490207726`}, {
    9., -0.7657617607042937}, {10., -1.3482111849051854`}, {11., 
    2.0606322069762655`}, {12., -0.6612253983515473}, {
    13., -2.9145057409463746`}, {14., 4.732641533849204}, {15., 
    1.5841215493904857`}}]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, Automatic},
  PlotRange->Automatic,
  PlotRangeClipping->True]], "Output",
 ImageSize->{184, 105},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[5]=",
 CellID->783349045]
}, Open  ]],

Cell["\<\
\:041a\:0430\:043a \:0438 \:0434\:043b\:044f \:043b\:044e\:0431\:044b\:0445 \
\:0434\:0440\:0443\:0433\:0438\:0445 \:0433\:0440\:0430\:0444\:0438\:043a\
\:043e\:0432, \:043f\:043e \:0436\:0435\:043b\:0430\:043d\:0438\:044e \:043c\
\:043e\:0436\:043d\:043e \:0438\:0441\:043f\:043e\:043b\:044c\:0437\:043e\
\:0432\:0430\:0442\:044c \:0434\:043e\:043f\:043e\:043b\:043d\:0438\:0442\
\:0435\:043b\:044c\:043d\:044b\:0435 \:043e\:043f\:0446\:0438\:0438 \:0434\
\:043b\:044f \:0434\:043e\:0431\:0430\:0432\:043b\:0435\:043d\:0438\:044f \
\:0440\:0430\:0437\:043b\:0438\:0447\:043d\:044b\:0445 \:0434\:0435\:0442\
\:0430\:043b\:0435\:0439, \:0442\:0430\:043a\:0438\:0445 \:043a\:0430\:043a \
\:0440\:0430\:043c\:043a\:0438, \:043d\:0430\:0434\:043f\:0438\:0441\:0438, \
\:0437\:0430\:043b\:0438\:0432\:043a\:0430 \:0438 \:0442.\:0434.\
\>", "HowToText",
 CellID->726278705],

Cell[TextData[{
 "\:0418\:0441\:043f\:043e\:043b\:044c\:0437\:0443\:0435\:043c \:043e\:043f\
\:0446\:0438\:044e ",
 Cell[BoxData[
  ButtonBox["Frame",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Frame"]], "InlineFormula"],
 " \:0434\:043b\:044f \:0434\:043e\:0431\:0430\:0432\:043b\:0435\:043d\:0438\
\:044f \:0440\:0430\:043c\:043a\:0438 \:0432\:043e\:043a\:0440\:0443\:0433 \
\:0433\:0440\:0430\:0444\:0438\:043a\:0430 \:043e\:0441\:0442\:0430\:0442\
\:043a\:043e\:0432, \:0438 \:043e\:043f\:0446\:0438\:044e  ",
 Cell[BoxData[
  ButtonBox["Filling",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Filling"]], "InlineFormula"],
 " \:0434\:043b\:044f \:0434\:043e\:0431\:0430\:0432\:043b\:0435\:043d\:0438\
\:044f \:0441\:043e\:0435\:0434\:0438\:043d\:0438\:0442\:0435\:043b\:044c\
\:043d\:044b\:0445 \:043b\:0438\:043d\:0438\:0439 \:043c\:0435\:0436\:0434\
\:0443 \:0442\:043e\:0447\:043a\:0430\:043c\:0438 \:0438 \:043e\:0441\:044c\
\:044e \:043a\:043e\:043e\:0440\:0434\:0438\:043d\:0430\:0442:"
}], "HowToText",
 CellID->212318464],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"lm", "[", "\"\<FitResiduals\>\"", "]"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"Filling", "\[Rule]", "Axis"}]}], "]"}]], "Input",
 CellLabel->"In[6]:=",
 CellID->335877154],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxTTMoPSmViYGDQBWIQDQEf7A8sZcp4k3raHirg8EbK7qHZIYEDEC6HwwH9
7n2tNyWhfAGHA+WnjvPkfIWqF3FIMJDdJtcr7QDhSzhMKDv/YeoNYah6GQcG
1VY79fT3UPUKDicEz1RfYeeBqldyYBC+cU6u8cV+CF/FYYKfyRPXSV+hfDUH
hkSBvTo1DFD1Gg4M3cu0Dmk8hcprOUz4fCrpRQA71D4dhwRvvqmW74Sg6vUc
voRWXOuP+GkP8y8DKnBA5XKg8QXQ+CJofAk0vgwaXwGNr4TGV0Hjq6HxNdD4
Wmh8HTS+Hhp/5MQvAMQMhqo=
   "], {{{}, {}, {}, 
     {Hue[0.67, 0.6, 0.6], Opacity[0.2], LineBox[{17, 2}], LineBox[{18, 3}], 
      LineBox[{21, 6}], LineBox[{24, 9}], LineBox[{25, 10}], 
      LineBox[{27, 12}], LineBox[{28, 13}]}, 
     {Hue[0.67, 0.6, 0.6], Opacity[0.2], LineBox[{16, 1}], LineBox[{19, 4}], 
      LineBox[{20, 5}], LineBox[{22, 7}], LineBox[{23, 8}], LineBox[{26, 11}],
       LineBox[{29, 14}], LineBox[{30, 15}]}}, {{}, 
     {Hue[0.67, 0.6, 0.6], 
      PointBox[{31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 
       45}]}, {}}}],
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  PlotRange->{{0., 15.}, {-6.462424256558677, 6.887812467128327}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 ImageSize->{184, 117},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[6]=",
 CellID->598245848]
}, Open  ]],

Cell["\<\
\:041d\:043e\:0440\:043c\:0438\:0440\:043e\:0432\:0430\:043d\:043d\:044b\:0435\
 \:043e\:0441\:0442\:0430\:0442\:043a\:0438 \:043c\:043e\:0433\:0443\:0442 \
\:0431\:044b\:0442\:044c \:043f\:043e\:043b\:0435\:0437\:043d\:044b\:043c\
\:0438, \:0442\:0430\:043a \:043a\:0430\:043a \:043e\:043d\:0438 \:044d\:0444\
\:0444\:0435\:043a\:0442\:0438\:0432\:043d\:043e \:0443\:043c\:0435\:043d\
\:044c\:0448\:0430\:044e\:0442 \:0430\:0431\:0441\:043e\:043b\:044e\:0442\
\:043d\:044b\:0439 \:0434\:0438\:0430\:043f\:0430\:0437\:043e\:043d \:043e\
\:0441\:0442\:0430\:0442\:043a\:043e\:0432. \:0412 \:0441\:043b\:0443\:0447\
\:0430\:0435 \:043b\:0438\:043d\:0435\:0439\:043d\:043e\:0439 \:0438 \:043d\
\:0435\:043b\:0438\:043d\:0435\:0439\:043d\:043e\:0439 \:0440\:0435\:0433\
\:0440\:0435\:0441\:0441\:0438\:0438, \:043d\:043e\:0440\:043c\:0438\:0440\
\:043e\:0432\:0430\:043d\:043d\:044b\:0435 \:043e\:0441\:0442\:0430\:0442\
\:043a\:0438 \:0434\:043e\:043b\:0436\:043d\:044b \:0432\:044b\:0433\:043b\
\:044f\:0434\:0435\:0442\:044c \:043a\:0430\:043a \"\:0431\:0435\:043b\:044b\
\:0439 \:0448\:0443\:043c\" \:0441 \:0434\:0438\:0441\:043f\:0435\:0440\:0441\
\:0438\:0435\:0439 \:0440\:0430\:0432\:043d\:043e\:0439 1.\
\>", "HowToText",
 CellID->495141871],

Cell["\<\
\:0421\:043e\:0437\:0434\:0430\:0434\:0438\:043c \:0433\:0440\:0430\:0444\
\:0438\:043a \:043d\:043e\:0440\:043c\:0438\:0440\:043e\:0432\:0430\:043d\
\:043d\:044b\:0445 \:043e\:0441\:0442\:0430\:0442\:043a\:043e\:0432 \:0434\
\:043b\:044f \:043f\:043e\:0434\:043e\:0431\:0440\:0430\:043d\:043d\:043e\
\:0439 \:043b\:0438\:043d\:0435\:0439\:043d\:043e\:0439 \:043c\:043e\:0434\
\:0435\:043b\:0438:\
\>", "HowToText",
 CellID->47917411],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"lm", "[", "\"\<StandardizedResiduals\>\"", "]"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"Filling", "\[Rule]", "Axis"}]}], "]"}]], "Input",
 CellLabel->"In[7]:=",
 CellID->435235952],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxTTMoPSmViYGDQBWIQDQEf7PN6XixbWr/WHirgIPWAOe0836f9EC6Hw4aT
BZtdgxgOQPgCDpKlwaLW+beg6kUctuysmmV1/R+UL+EwVccjVmr6V6h+GQcu
/wN39uhehMorONgFca35FvAOyldyUInImhOw+xRUvYpDwULr71t6HkD5ag57
v81+GX3/IVS9hsMhpQT1aKnjUHkthwRl7Rau4pdQvo6DrVC36LucL1D1eg4/
WK9usWy5Zw/zLwMqcEDlcqDxBdD4Imh8CTS+DBpfAY2vhMZXQeOrofE10Pha
aHwdNL4eGn/kxC8AwmyOYA==
   "], {{{}, {}, {}, 
     {Hue[0.67, 0.6, 0.6], Opacity[0.2], LineBox[{17, 2}], LineBox[{18, 3}], 
      LineBox[{21, 6}], LineBox[{24, 9}], LineBox[{25, 10}], 
      LineBox[{27, 12}], LineBox[{28, 13}]}, 
     {Hue[0.67, 0.6, 0.6], Opacity[0.2], LineBox[{16, 1}], LineBox[{19, 4}], 
      LineBox[{20, 5}], LineBox[{22, 7}], LineBox[{23, 8}], LineBox[{26, 11}],
       LineBox[{29, 14}], LineBox[{30, 15}]}}, {{}, 
     {Hue[0.67, 0.6, 0.6], 
      PointBox[{31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 
       45}]}, {}}}],
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  PlotRange->{{0., 15.}, {-2.040172006492149, 1.9275461229659472`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 ImageSize->{184, 123},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[7]=",
 CellID->414999672]
}, Open  ]],

Cell[TextData[{
 "\:0412 \:0442\:043e \:0432\:0440\:0435\:043c\:044f, \:043a\:0430\:043a \
\:043f\:0440\:0435\:0434\:044b\:0434\:0443\:0449\:0438\:0435 \:0433\:0440\
\:0430\:0444\:0438\:043a\:0438 \:043e\:0442\:043e\:0431\:0440\:0430\:0436\
\:0430\:044e\:0442 \:043e\:0441\:0442\:0430\:0442\:043a\:0438 \:0434\:043b\
\:044f \:043a\:0430\:0436\:0434\:043e\:0439 \:0442\:043e\:0447\:043a\:0438 \
\:0434\:0430\:043d\:043d\:044b\:0445, \:043c\:043e\:0436\:0435\:0442 \:043e\
\:043a\:0430\:0437\:0430\:0442\:044c\:0441\:044f \:043f\:043e\:043b\:0435\
\:0437\:043d\:044b\:043c \:043f\:043e\:0441\:0442\:0440\:043e\:0438\:0442\
\:044c \:0433\:0440\:0430\:0444\:0438\:043a \:043e\:0441\:0442\:0430\:0442\
\:043a\:043e\:0432 \:0432 \:0437\:0430\:0432\:0438\:0441\:0438\:043c\:043e\
\:0441\:0442\:0438 \:043e\:0442 \:043f\:0440\:0435\:0434\:0438\:043a\:0442\
\:043e\:0440\:043d\:043e\:0439 \:043f\:0435\:0440\:0435\:043c\:0435\:043d\
\:043d\:043e\:0439. \:0412 \:0441\:043b\:0435\:0434\:0443\:044e\:0449\:0435\
\:043c \:043f\:0440\:0438\:043c\:0435\:0440\:0435, ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]], "InlineMath"],
 " \:044f\:0432\:043b\:044f\:0435\:0442\:0441\:044f \:043f\:0440\:0435\:0434\
\:0438\:043a\:0442\:043e\:0440\:043d\:043e\:0439 \:043f\:0435\:0440\:0435\
\:043c\:0435\:043d\:043d\:043e\:0439."
}], "HowToText",
 CellID->31027390],

Cell[TextData[{
 "\:0413\:0440\:0430\:0444\:0438\:043a \:043e\:0441\:0442\:0430\:0442\:043a\
\:043e\:0432 \:0432 \:0437\:0430\:0432\:0438\:0441\:0438\:043c\:043e\:0441\
\:0442\:0438 \:043e\:0442 \:043f\:0440\:0435\:0434\:0438\:043a\:0442\:043e\
\:0440\:043d\:043e\:0439 \:043f\:0435\:0440\:0435\:043c\:0435\:043d\:043d\
\:043e\:0439 \:0441\:0442\:0440\:043e\:0438\:0442\:0441\:044f \:043f\:0443\
\:0442\:0435\:043c \:0441\:043e\:0437\:0434\:0430\:043d\:0438\:044f \:043f\
\:0430\:0440 \:0438\:0437 \:0437\:043d\:0430\:0447\:0435\:043d\:0438\:0439 \
\:0434\:0430\:043d\:043d\:044b\:0445 \:0438 \:0441\:043e\:043e\:0442\:0432\
\:0435\:0442\:0441\:0442\:0432\:0443\:044e\:0449\:0438\:0445 \:0438\:043c \
\:043e\:0441\:0442\:0430\:0442\:043a\:043e\:0432. \:041f\:0440\:0435\:0434\
\:0438\:043a\:0442\:043e\:0440\:043d\:044b\:0435 \:0437\:043d\:0430\:0447\
\:0435\:043d\:0438\:044f \:044f\:0432\:043b\:044f\:044e\:0442\:0441\:044f \
\:043f\:0435\:0440\:0432\:044b\:043c\:0438 \:044d\:043b\:0435\:043c\:0435\
\:043d\:0442\:0430\:043c\:0438 \:043a\:0430\:0436\:0434\:043e\:0439 \:0442\
\:043e\:0447\:043a\:0438 \:0434\:0430\:043d\:043d\:044b\:0445 \:0432 ",
 Cell[BoxData["data"], "InlineFormula"],
 ":"
}], "HowToText",
 CellID->451940841],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"xvals", "=", 
  RowBox[{"data1", "[", 
   RowBox[{"[", 
    RowBox[{"All", ",", "1"}], "]"}], "]"}]}]], "Input",
 CellLabel->"In[8]:=",
 CellID->312101611],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1.36`", ",", "1.69`", ",", "4.91`", ",", "4.85`", ",", "4.41`", ",", 
   "2.15`", ",", "2.98`", ",", "1.19`", ",", "4.08`", ",", "0.05`", ",", 
   "3.69`", ",", "2.34`", ",", "2.32`", ",", "1.77`", ",", "0.47`"}], 
  "}"}]], "Output",
 ImageSize->{359, 33},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[8]=",
 CellID->16579683]
}, Open  ]],

Cell[TextData[{
 "\:0421\:043e\:0441\:0442\:0430\:0432\:0438\:043c \:043f\:0430\:0440\:044b \
\:0438\:0437 \:0437\:043d\:0430\:0447\:0435\:043d\:0438\:0439 ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]], "InlineMath"],
 " \:0438 \:043e\:0441\:0442\:0430\:0442\:043a\:043e\:0432 \:043f\:0440\:0438 \
\:043f\:043e\:043c\:043e\:0449\:0438 \:0444\:0443\:043d\:043a\:0446\:0438\
\:0438 ",
 Cell[BoxData[
  ButtonBox["Transpose",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Transpose"]], "InlineFormula"],
 ", \:0430 \:0437\:0430\:0442\:0435\:043c \
\:043e\:0442\:043e\:0431\:0440\:0430\:0437\:0438\:043c \:044d\:0442\:0438 \
\:043f\:0430\:0440\:044b \:043d\:0430 \:0433\:0440\:0430\:0444\:0438\:043a\
\:0435, \:0438\:0441\:043f\:043e\:043b\:044c\:0437\:0443\:044f \:0444\:0443\
\:043d\:043a\:0446\:0438\:044e ",
 Cell[BoxData[
  ButtonBox["ListPlot",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/ListPlot"]], "InlineFormula"],
 ":"
}], "HowToText",
 CellID->319914358],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{"Transpose", "[", 
   RowBox[{"{", 
    RowBox[{"xvals", ",", 
     RowBox[{"lm", "[", "\"\<FitResiduals\>\"", "]"}]}], "}"}], "]"}], 
  "]"}]], "Input",
 CellLabel->"In[9]:=",
 CellID->378538415],

Cell[BoxData[
 GraphicsBox[
  {Hue[0.67, 0.6, 0.6], 
   PointBox[{{1.36, 0.21404795721654857`}, {1.69, -4.189662475028609}, {
    4.91, -6.462424256558677}, {4.85, 1.3388793758708601`}, {4.41, 
    6.887812467128327}, {2.15, -4.9615094782472084`}, {2.98, 
    0.9813419552894231}, {1.19, 3.5038232490207726`}, {
    4.08, -0.7657617607042937}, {0.05, -1.3482111849051854`}, {3.69, 
    2.0606322069762655`}, {2.34, -0.6612253983515473}, {
    2.32, -2.9145057409463746`}, {1.77, 4.732641533849204}, {0.47, 
    1.5841215493904857`}}]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  PlotRange->Automatic,
  PlotRangeClipping->True]], "Output",
 ImageSize->{184, 103},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[9]=",
 CellID->254131239]
}, Open  ]],

Cell["\:0414\:043e\:0431\:0430\:0432\:0438\:043c \:043a \:0433\:0440\:0430\
\:0444\:0438\:043a\:0443 \:0440\:0430\:043c\:043a\:0443, \:0441\:043e\:0435\
\:0434\:0438\:043d\:0438\:0442\:0435\:043b\:044c\:043d\:044b\:0435 \:043b\
\:0438\:043d\:0438\:0438 \:0438 \:043d\:0430\:0434\:043f\:0438\:0441\:0438:", \
"HowToText",
 CellID->25666235],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"data1", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "1"}], "]"}], "]"}], ",", 
      RowBox[{"lm", "[", "\"\<FitResiduals\>\"", "]"}]}], "}"}], "]"}], ",", 
   RowBox[{"Frame", "\[Rule]", "True"}], ",", 
   RowBox[{"Filling", "\[Rule]", "0"}], ",", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<x\>\"", ",", "\"\<residual\>\""}], "}"}]}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<Residual vs. Predictor\>\""}]}], 
  "]"}]], "Input",
 CellLabel->"In[10]:=",
 CellID->69547533],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxTTMoPSmViYGDQBWIQffirRkz/oa/2B5YyZbxJPW3PdX1xgS3Xb/s3UnYP
zQ4JHFgC5F1fLOxwQL97X+tNyQNpYADkl586zpPz1R4iL+iQYCC7Ta5X2sEY
DBgdJpSd/zD1hvABsHHX2R0YVFvt1NPfQ83/bH9C8Ez1FXYeh6Adcq2vAwUc
GIRvnJNrfLF/1kwQWGk/wc/kieukr/uBkkAVvA4MiQJ7dWoYHMDKdzA5MHQv
0zqk8XQ/0O1ADzA5TPh8KulFAPsBiHl/7BO8+aZavhNyEFnn/rBK5J79l9CK
a/0RP+1h/mWAAph/YXyYf2F8mH9R5QXhfJh/YXy4f1HM/ww3H+5fKID5F8aH
+xcK4P6FAph/Uc37A9cP8y+MP9LiFwAKGA40
   "], {{{}, {}, {}, 
     {Hue[0.67, 0.6, 0.6], Opacity[0.2], LineBox[{17, 2}], LineBox[{18, 3}], 
      LineBox[{21, 6}], LineBox[{24, 9}], LineBox[{25, 10}], 
      LineBox[{27, 12}], LineBox[{28, 13}]}, 
     {Hue[0.67, 0.6, 0.6], Opacity[0.2], LineBox[{16, 1}], LineBox[{19, 4}], 
      LineBox[{20, 5}], LineBox[{22, 7}], LineBox[{23, 8}], LineBox[{26, 11}],
       LineBox[{29, 14}], LineBox[{30, 15}]}}, {{}, 
     {Hue[0.67, 0.6, 0.6], 
      PointBox[{31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 
       45}]}, {}}}],
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  Frame->True,
  FrameLabel->{
    FormBox["\"x\"", TraditionalForm], 
    FormBox["\"residual\"", TraditionalForm]},
  PlotLabel->FormBox["\"Residual vs. Predictor\"", TraditionalForm],
  PlotRange->{{0., 4.91}, {-6.462424256558677, 6.887812467128327}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 ImageSize->{184, 138},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[10]=",
 CellID->595307435]
}, Open  ]],

Cell["\<\
\:0410\:043d\:0430\:043b\:043e\:0433\:0438\:0447\:043d\:044b\:043c \:043e\
\:0431\:0440\:0430\:0437\:043e\:043c, \:0432\:0435\:043b\:0438\:0447\:0438\
\:043d\:0430 \:0432\:043b\:0438\:044f\:043d\:0438\:044f \:0438\:043b\:0438 \
\:0431\:0430\:043b\:0430\:043d\:0441\:0438\:0440\:043e\:0432\:043a\:0430 \
\:043e\:043f\:043e\:0440\:043d\:044b\:0445 \:0442\:043e\:0447\:0435\:043a \
\:043d\:0430\:0431\:043e\:0440\:0430 \:0434\:0430\:043d\:043d\:044b\:0445 \
\:043c\:043e\:0436\:0435\:0442 \:0431\:044b\:0442\:044c \:043e\:0442\:043e\
\:0431\:0440\:0430\:0436\:0435\:043d\:0430 \:0433\:0440\:0430\:0444\:0438\
\:0447\:0435\:0441\:043a\:0438, \:0434\:043b\:044f \:043e\:043f\:0440\:0435\
\:0434\:0435\:043b\:0435\:043d\:0438\:044f \:043d\:0430\:043b\:0438\:0447\
\:0438\:044f \:043e\:043f\:043e\:0440\:043d\:044b\:0445 \:0442\:043e\:0447\
\:0435\:043a, \:043e\:043a\:0430\:0437\:044b\:0432\:0430\:044e\:0449\:0438\
\:0445 \:0441\:043b\:0438\:0448\:043a\:043e\:043c \:0441\:0438\:043b\:044c\
\:043d\:043e\:0435 \:0432\:043b\:0438\:044f\:043d\:0438\:0435 \:043d\:0430 \
\:043f\:043e\:0434\:0431\:043e\:0440 \:043c\:043e\:0434\:0435\:043b\:0438.\
\>", "HowToText",
 CellID->168171910],

Cell["\<\
\:041c\:043e\:0436\:043d\:043e, \:043d\:0430\:043f\:0440\:0438\:043c\:0435\
\:0440, \:043f\:043e\:0441\:0442\:0440\:043e\:0438\:0442\:044c \:0433\:0440\
\:0430\:0444\:0438\:043a \:0440\:0430\:0441\:0441\:0442\:043e\:044f\:043d\
\:0438\:0439 \:041a\:0443\:043a\:0430 \:0434\:043b\:044f \:043a\:0430\:0436\
\:0434\:043e\:0439 \:0442\:043e\:0447\:043a\:0438 \:0434\:0430\:043d\:043d\
\:044b\:0445. \:0420\:0430\:0441\:0441\:0442\:043e\:044f\:043d\:0438\:0435 \
\:041a\:0443\:043a\:0430 \:0434\:043b\:044f \:0442\:043e\:0447\:043a\:0438 \
\:0443\:043a\:0430\:0437\:044b\:0432\:0430\:0435\:0442 \:043d\:0430 \:0432\
\:0435\:043b\:0438\:0447\:0438\:043d\:0443 \:0432\:043b\:0438\:044f\:043d\
\:0438\:044f \:044d\:0442\:043e\:0439 \:0442\:043e\:0447\:043a\:0438 \:043d\
\:0430 \:043f\:043e\:0434\:0431\:043e\:0440 \:043a\:0440\:0438\:0432\:043e\
\:0439 \:043f\:043e \:0442\:043e\:0447\:043a\:0430\:043c \:0432 \:0446\:0435\
\:043b\:043e\:043c:\
\>", "HowToText",
 CellID->234353591],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"lm", "[", "\"\<CookDistances\>\"", "]"}], ",", 
   RowBox[{"Filling", "\[Rule]", "0"}]}], "]"}]], "Input",
 CellLabel->"In[11]:=",
 CellID->388400420],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxTTMoPSmViYGDQBWIQDQEf7PXCFuTqr1Syhwo4XJp+9IRg7Bp7mDwDChBw
0Jl7Y3mk1ByouIjDHe13388XXITyJRwSjCadfLZqO5Qv41B1SE9V0b0Ayldw
ePZWbtZE96VQvpLD7zKRZcueJUH5Kg4TladPTqrfC+WrORQy9J3oOdQH5Ws4
2P3oqPo5MwbK13LYl/tc+ZHLQihfx8Foo04Ex8RNUL6eQ+LEppkH38635/t4
rPTJZCaHaxY+K16aXbIProzwm2/OC+fD/I/uX1S+CBpfAo0vg8ZXQOMrofFV
0PhqaHwNNL4WGl8Hja+HxicUvxwOq3SfT1XufAHlD934BQDHe5YE
   "], {{{}, {}, {}, {}, 
     {Hue[0.67, 0.6, 0.6], Opacity[0.2], LineBox[{3, 1}], LineBox[{18, 2}], 
      LineBox[{19, 4}], LineBox[{20, 5}], LineBox[{21, 6}], LineBox[{22, 7}], 
      LineBox[{23, 8}], LineBox[{24, 9}], LineBox[{25, 10}], 
      LineBox[{26, 11}], LineBox[{27, 12}], LineBox[{28, 13}], 
      LineBox[{29, 14}], LineBox[{30, 15}]}}, {{}, 
     {Hue[0.67, 0.6, 0.6], 
      PointBox[{31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 
       45}]}, {}}}],
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0., 15.}, {0., 0.2846016067059173}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 ImageSize->{184, 114},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[11]=",
 CellID->103921319]
}, Open  ]],

Cell[TextData[{
 "\:0414\:0440\:0443\:0433\:0438\:0435 \:0441\:0440\:0435\:0434\:0441\:0442\
\:0432\:0430 \:043f\:043e\:0442\:043e\:0447\:0435\:0447\:043d\:043e\:0439 \
\:0434\:0438\:0430\:0433\:043d\:043e\:0441\:0442\:0438\:043a\:0438 \:0432\
\:043a\:043b\:044e\:0447\:0430\:044e\:0442 \:0432 \:0441\:0435\:0431\:044f \
\:0441\:0432\:043e\:0439\:0441\:0442\:0432\:0430 ",
 Cell[BoxData["\<\"FitDifferences\"\>"], "InlineFormula"],
 " \:0438 ",
 Cell[BoxData["\<\"BetaDifferences\"\>"], "InlineFormula"],
 ", \:0447\:0430\:0441\:0442\:043e \:0438\:043c\:0435\:043d\:0443\:0435\:043c\
\:044b\:0435 \:043a\:0430\:043a DFFITS \:0438 DFBETAS \
\:0441\:043e\:043e\:0442\:0432\:0435\:0442\:0441\:0442\:0432\:0435\:043d\:043d\
\:043e. \:042d\:0442\:0438 \:0437\:043d\:0430\:0447\:0435\:043d\:0438\:044f \
\:043c\:043e\:0433\:0443\:0442 \:0431\:044b\:0442\:044c \:0432\:0438\:0437\
\:0443\:0430\:043b\:0438\:0437\:0438\:0440\:043e\:0432\:0430\:043d\:044b \
\:0434\:043b\:044f \:043e\:0446\:0435\:043d\:043a\:0438 \:0438\:043d\:044b\
\:0445 \:0432\:0438\:0434\:043e\:0432 \:0432\:043b\:0438\:044f\:043d\:0438\
\:044f."
}], "HowToText",
 CellID->75382226],

Cell[TextData[{
 "\:0413\:0440\:0430\:0444\:0438\:043a \:0441\:0432\:043e\:0439\:0441\:0442\
\:0432\:0430 ",
 Cell[BoxData["\<\"FitDifferences\"\>"], "InlineFormula"],
 " \:043f\:043e\:043a\:0430\:0437\:044b\:0432\:0430\:0435\:0442 \:0432\:0435\
\:043b\:0438\:0447\:0438\:043d\:0443 \:0432\:043b\:0438\:044f\:043d\:0438\
\:044f \:043a\:0430\:0436\:0434\:043e\:0439 \:0442\:043e\:0447\:043a\:0438 \
\:043d\:0430 \:043f\:0440\:043e\:0433\:043d\:043e\:0437\:0438\:0440\:0443\
\:0435\:043c\:044b\:0435 \:0437\:043d\:0430\:0447\:0435\:043d\:0438\:044f:"
}], "HowToText",
 CellID->665973240],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"lm", "[", "\"\<FitDifferences\>\"", "]"}], ",", 
   RowBox[{"Filling", "\[Rule]", "0"}]}], "]"}]], "Input",
 CellLabel->"In[12]:=",
 CellID->180736321],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxTTMoPSmViYGDQBWIQDQEf7IPvL5DZ7TzFHirgUF57f+ub7Fv7IVwOhyW7
hM9W7v8D5Qs4hNgdDI/fehGqXsThmPz+2IbVH6B8CYd7AdeybrU8hKqXcejm
Y7145fouqLyCw+oXzNF9ddegfCWHic7+L0/mboGqV3HgOLLXYZH5IyhfzWHV
tSchl6JPQdVrOLzXk9ny5dBGqLyWw5a1RmJH2a5A+ToOdcX+/h/23YOq13OI
MZ2ftff1JXuYfxlQgQMqlwONL4DGF0HjS6DxZdD4Cmh8JTS+ChpfDY2vgcbX
QuProPH10PgjJ34BrgicTg==
   "], {{{}, {}, {}, 
     {Hue[0.67, 0.6, 0.6], Opacity[0.2], LineBox[{17, 2}], LineBox[{18, 3}], 
      LineBox[{21, 6}], LineBox[{24, 9}], LineBox[{25, 10}], 
      LineBox[{27, 12}], LineBox[{28, 13}]}, 
     {Hue[0.67, 0.6, 0.6], Opacity[0.2], LineBox[{16, 1}], LineBox[{19, 4}], 
      LineBox[{20, 5}], LineBox[{22, 7}], LineBox[{23, 8}], LineBox[{26, 11}],
       LineBox[{29, 14}], LineBox[{30, 15}]}}, {{}, 
     {Hue[0.67, 0.6, 0.6], 
      PointBox[{31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 
       45}]}, {}}}],
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0., 15.}, {-1.796747017938892, 1.0418704664207197`}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 ImageSize->{184, 102},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[12]=",
 CellID->38741979]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\t", "HowToDelimiter",
 Editable->False,
 CellID->1876377496],

Cell[TextData[{
 "\:0410\:043d\:0430\:043b\:043e\:0433\:0438\:0447\:043d\:044b\:043c \:043e\
\:0431\:0440\:0430\:0437\:043e\:043c, \:0434\:0438\:0430\:0433\:043d\:043e\
\:0441\:0442\:0438\:0447\:0435\:0441\:043a\:0438\:0435 \:0433\:0440\:0430\
\:0444\:0438\:043a\:0438 \:043c\:043e\:0433\:0443\:0442 \:0431\:044b\:0442\
\:044c \:043f\:043e\:043b\:0443\:0447\:0435\:043d\:044b \:0434\:043b\:044f \
\:043d\:0435\:043b\:0438\:043d\:0435\:0439\:043d\:043e\:0439 \:0438 \:043e\
\:0431\:043e\:0431\:0449\:0435\:043d\:043d\:043e\:0439 \:043b\:0438\:043d\
\:0435\:0439\:043d\:043e\:0439 \:043c\:043e\:0434\:0435\:043b\:0435\:0439, \
\:043f\:043e\:0434\:043e\:0431\:0440\:0430\:043d\:043d\:044b\:0445 \:043f\
\:0440\:0438 \:043f\:043e\:043c\:043e\:0449\:0438 \:0444\:0443\:043d\:043a\
\:0446\:0438\:0439 ",
 Cell[BoxData[
  ButtonBox["NonlinearModelFit",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/NonlinearModelFit"]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  ButtonBox["GeneralizedLinearModelFit",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/GeneralizedLinearModelFit"]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  ButtonBox["LogitModelFit",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/LogitModelFit"]], "InlineFormula"],
 " \:0438 ",
 Cell[BoxData[
  ButtonBox["ProbitModelFit",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/ProbitModelFit"]], "InlineFormula"],
 "."
}], "HowToText",
 CellID->52592172],

Cell["\<\
\:0422\:0435 \:0436\:0435 \:0441\:0430\:043c\:044b\:0435 \:0437\:043d\:0430\
\:0447\:0435\:043d\:0438\:044f, \:043a\:043e\:0442\:043e\:0440\:044b\:0435 \
\:0438\:0441\:043f\:043e\:043b\:044c\:0437\:043e\:0432\:0430\:043b\:0438\:0441\
\:044c \:0434\:043b\:044f \:043b\:0438\:043d\:0435\:0439\:043d\:043e\:0439 \
\:043c\:043e\:0434\:0435\:043b\:0438, \:0442\:0435\:043f\:0435\:0440\:044c \
\:0431\:0443\:0434\:0443\:0442 \:0438\:0441\:043f\:043e\:043b\:044c\:0437\
\:043e\:0432\:0430\:043d\:044b \:0434\:043b\:044f \:043d\:0435\:043b\:0438\
\:043d\:0435\:0439\:043d\:043e\:0433\:043e \:0438 \:043e\:0431\:043e\:0431\
\:0449\:0435\:043d\:043d\:043e\:0433\:043e \:043b\:0438\:043d\:0435\:0439\
\:043d\:043e\:0433\:043e \:043f\:043e\:0434\:0431\:043e\:0440\:0430 \:043f\
\:043e \:0442\:043e\:0447\:043a\:0430\:043c:\
\>", "HowToText",
 CellID->147206014],

Cell[BoxData[
 RowBox[{
  RowBox[{"data2", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1.36", ",", "15.36"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.69", ",", "16.12"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4.91", ",", "104.62"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4.85", ",", "110.06"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4.41", ",", "99.07"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2.15", ",", "23.83"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2.98", ",", "48.86"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.19", ",", "16.29"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4.08", ",", "79.91"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.05", ",", "0.89"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3.69", ",", "70.13"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2.34", ",", "32.07"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"2.32", ",", "29.39"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.77", ",", "26.41"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.47", ",", "6.64"}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellLabel->"In[13]:=",
 CellID->90504538],

Cell[TextData[{
 "\:041a \:043f\:0440\:0438\:043c\:0435\:0440\:0443, \:0438\:0441\:043f\:043e\
\:043b\:044c\:0437\:0443\:0435\:043c \:0444\:0443\:043d\:043a\:0446\:0438\
\:044e ",
 Cell[BoxData[
  ButtonBox["Exp",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Exp"]], "InlineFormula"],
 " \:0432\:043c\:0435\:0441\:0442\:0435 \:0441 ",
 Cell[BoxData[
  ButtonBox["NonlinearModelFit",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/NonlinearModelFit"]], "InlineFormula"],
 " \:0434\:043b\:044f \:043f\:043e\:0434\:0431\:043e\:0440\:0430 \:044d\:043a\
\:0441\:043f\:043e\:043d\:0435\:043d\:0446\:0438\:0430\:043b\:044c\:043d\:043e\
\:0439 \:043c\:043e\:0434\:0435\:043b\:0438 \:043f\:043e \:0434\:0430\:043d\
\:043d\:044b\:043c:"
}], "HowToText",
 CellID->77307161],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"nlm", "=", 
  RowBox[{"NonlinearModelFit", "[", 
   RowBox[{"data2", ",", 
    RowBox[{"a", " ", 
     RowBox[{"Exp", "[", 
      RowBox[{"b", "+", 
       RowBox[{"c", " ", 
        RowBox[{"x", "^", 
         RowBox[{"(", 
          RowBox[{"1", "/", "2"}], ")"}]}]}]}], "]"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c"}], "}"}], ",", "x"}], "]"}]}]], "Input",
 CellLabel->"In[14]:=",
 CellID->183634098],

Cell[BoxData[
 RowBox[{"FittedModel", "[", 
  PanelBox[
   TagBox[
    RowBox[{"0.6440440315724166`", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"1.1543287447279682`", "\[InvisibleSpace]", "+", 
       RowBox[{"\[LeftSkeleton]", "1", "\[RightSkeleton]"}]}]]}],
    Short],
   FrameMargins->5], "]"}]], "Output",
 ImageSize->{227, 36},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[14]=",
 CellID->432475383]
}, Open  ]],

Cell[TextData[{
 "\:0412\:043e\:0441\:043f\:043e\:043b\:044c\:0437\:0443\:0435\:043c\:0441\
\:044f \:0432\:043d\:043e\:0432\:044c \:0444\:0443\:043d\:043a\:0446\:0438\
\:044f\:043c\:0438 ",
 Cell[BoxData[
  ButtonBox["ListPlot",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/ListPlot"]], "InlineFormula"],
 " \:0438 ",
 Cell[BoxData[
  ButtonBox["Plot",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Plot"]], "InlineFormula"],
 " \:0434\:043b\:044f \:0432\:0438\:0437\:0443\:0430\:043b\:0438\:0437\:0430\
\:0446\:0438\:0438 \:0432\:044b\:043f\:043e\:043b\:043d\:0435\:043d\:043d\
\:043e\:0433\:043e \:043f\:043e\:0434\:0431\:043e\:0440\:0430 \:043c\:043e\
\:0434\:0435\:043b\:0438:"
}], "HowToText",
 CellID->300163535],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{
   RowBox[{"ListPlot", "[", "data2", "]"}], ",", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"nlm", "[", "x", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", "5"}], "}"}]}], "]"}]}], "]"}]], "Input",
 CellLabel->"In[15]:=",
 CellID->522443779],

Cell[BoxData[
 GraphicsBox[{
   {Hue[0.67, 0.6, 0.6], 
    PointBox[{{1.36, 15.36}, {1.69, 16.12}, {4.91, 104.62}, {4.85, 110.06}, {
     4.41, 99.07}, {2.15, 23.83}, {2.98, 48.86}, {1.19, 16.29}, {4.08, 
     79.91}, {0.05, 0.89}, {3.69, 70.13}, {2.34, 32.07}, {2.32, 29.39}, {1.77,
      26.41}, {0.47, 6.64}}]}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwV0Gs81PkCx/ExMy6Nyxr/TbUthpUpqbDVqozfl9EmIdeEGdYk4xy55NXs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      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  PlotRange->Automatic,
  PlotRangeClipping->True]], "Output",
 ImageSize->{184, 120},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[15]=",
 CellID->25789244]
}, Open  ]],

Cell[TextData[{
 "\:041a\:0430\:043a \:0438 \:0432 \:0441\:043b\:0443\:0447\:0430\:0435 \
\:0441 \:043b\:0438\:043d\:0435\:0439\:043d\:043e\:0439 \:043c\:043e\:0434\
\:0435\:043b\:044c\:044e, \:0438\:0441\:043f\:043e\:043b\:044c\:0437\:0443\
\:044f \:0444\:0443\:043d\:043a\:0446\:0438\:044e ",
 Cell[BoxData[
  ButtonBox["ListPlot",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/ListPlot"]], "InlineFormula"],
 ", \:043c\:043e\:0436\:043d\:043e \:0441\:0442\:0440\:043e\:0438\:0442\:044c \
\:0433\:0440\:0430\:0444\:0438\:043a\:0438 \:043f\:043e\:0442\:043e\:0447\
\:0435\:0447\:043d\:043e\:0439 \:0434\:0438\:0430\:0433\:043d\:043e\:0441\
\:0442\:0438\:043a\:0438; \:043d\:0430\:043f\:0440\:0438\:043c\:0435\:0440, \
\:0433\:0440\:0430\:0444\:0438\:043a \:043e\:0441\:0442\:0430\:0442\:043a\
\:043e\:0432:"
}], "HowToText",
 CellID->70907008],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"nlm", "[", "\"\<FitResiduals\>\"", "]"}], ",", 
   RowBox[{"Filling", "\[Rule]", "0"}]}], "]"}]], "Input",
 CellLabel->"In[16]:=",
 CellID->998849277],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxTTMoPSmViYGDQBWIQDQEf7BUWTP3seOf7fqiAQ0EDd+PFZNEDEC6HQ0GN
o2v4dXkoX8CBISny4C/d0/YQvojDh3AzfTc5eQcIX8Khxe3ZtE0bRaDqZRwW
pGsZtdYwQ+UVHApE33XujPsJ1a/kwOB343fw17dQvorD+hwp3dR4Rqh+NQeG
F2FmplkCUP0aDg1bRJ+8L7wLda+Ww4S2cM6rvGxQ9ToOFV4/WoQv80LV6zk4
XGMLjOK8vR/mXwZU4IDK5UDjC6DxRdD4Emh8GTS+AhpfCY2vgsZXQ+NroPG1
0Pg6aHw9NP7IiV8A6i6CBg==
   "], {{{}, {}, {}, 
     {Hue[0.67, 0.6, 0.6], Opacity[0.2], LineBox[{16, 1}], LineBox[{17, 2}], 
      LineBox[{18, 3}], LineBox[{21, 6}], LineBox[{25, 10}], 
      LineBox[{27, 12}], LineBox[{28, 13}], LineBox[{30, 15}]}, 
     {Hue[0.67, 0.6, 0.6], Opacity[0.2], LineBox[{19, 4}], LineBox[{20, 5}], 
      LineBox[{22, 7}], LineBox[{23, 8}], LineBox[{24, 9}], LineBox[{26, 11}],
       LineBox[{29, 14}]}}, {{}, 
     {Hue[0.67, 0.6, 0.6], 
      PointBox[{31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 
       45}]}, {}}}],
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesOrigin->{0, 0},
  PlotRange->{{0., 15.}, {-7.9602938481540235`, 7.779564607326378}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 ImageSize->{184, 105},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[16]=",
 CellID->739409677]
}, Open  ]],

Cell[TextData[{
 "\:0412 \:0441\:043b\:0435\:0434\:0443\:044e\:0449\:0435\:043c \:043f\:0440\
\:0438\:043c\:0435\:0440\:0435 \:0432\:044b\:043f\:043e\:043b\:043d\:044f\
\:0435\:0442\:0441\:044f \:043f\:043e\:0434\:0431\:043e\:0440 \:043c\:043e\
\:0434\:0435\:043b\:0438 \:0432\:0438\:0434\:0430 ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Beta]", "0"], "+", 
    RowBox[{
     SubscriptBox["\[Beta]", "1"], "x"}], "+", 
    RowBox[{
     SubscriptBox["\[Beta]", "2"], 
     SuperscriptBox["x", "2"]}]}], TraditionalForm]], "InlineMath"],
 ", \:043d\:043e \:043f\:0440\:0435\:0434\:043f\:043e\:043b\:0430\:0433\:0430\
\:0435\:0442\:0441\:044f, \:0447\:0442\:043e \:043e\:0442\:043a\:043b\:0438\
\:043a\:0438 (\:0437\:043d\:0430\:0447\:0435\:043d\:0438\:044f ",
 Cell[BoxData[
  FormBox["y", TraditionalForm]], "InlineMath"],
 " \:0432 \:043d\:0430\:0431\:043e\:0440\:0435 \:0434\:0430\:043d\:043d\:044b\
\:0445) \:0441\:043b\:0435\:0434\:0443\:044e\:0442 \:043e\:0431\:0440\:0430\
\:0442\:043d\:043e\:043c\:0443 \:0440\:0430\:0441\:043f\:0440\:0435\:0434\
\:0435\:043b\:0435\:043d\:0438\:044e \:0413\:0430\:0443\:0441\:0441\:0430. \
\:042d\:0442\:043e \:043e\:043f\:0440\:0435\:0434\:0435\:043b\:044f\:0435\
\:0442\:0441\:044f \:0443\:0441\:0442\:0430\:043d\:043e\:0432\:043a\:043e\
\:0439 \:0441\:0432\:043e\:0439\:0441\:0442\:0432\:0430",
 Cell[BoxData[
  RowBox[{" ", "\<\"InverseGaussian\"\>"}]], "InlineFormula"],
 " \:0432 \:043e\:043f\:0446\:0438\:0438 ",
 Cell[BoxData[
  ButtonBox["ExponentialFamily",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/ExponentialFamily"]], "InlineFormula"],
 " \:0434\:043b\:044f \:0444\:0443\:043d\:043a\:0446\:0438\:0438 ",
 Cell[BoxData[
  ButtonBox["GeneralizedLinearModelFit",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/GeneralizedLinearModelFit"]], "InlineFormula"],
 ":"
}], "HowToText",
 CellID->247228587],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"glm", "=", 
  RowBox[{"GeneralizedLinearModelFit", "[", 
   RowBox[{"data2", ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", 
      RowBox[{"x", "^", "2"}]}], "}"}], ",", "x", ",", 
    RowBox[{"ExponentialFamily", "\[Rule]", "\"\<InverseGaussian\>\""}], ",", 
    RowBox[{"LinkFunction", "\[Rule]", "Identity"}]}], "]"}]}]], "Input",
 CellLabel->"In[17]:=",
 CellID->463204662],

Cell[BoxData[
 RowBox[{"FittedModel", "[", 
  PanelBox[
   TagBox[
    RowBox[{"0.32211160464399863`", "\[InvisibleSpace]", "+", 
     RowBox[{"11.318670041913224`", " ", "x"}], "+", 
     RowBox[{"1.4065533347926598`", " ", 
      SuperscriptBox["x", "2"]}]}],
    Short],
   FrameMargins->5], "]"}]], "Output",
 ImageSize->{278, 36},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[17]=",
 CellID->20879690]
}, Open  ]],

Cell["\<\
\:0412 \:043e\:0442\:043b\:0438\:0447\:0438\:0435 \:043e\:0442 \:043c\:043e\
\:0434\:0435\:043b\:0435\:0439 \:043b\:0438\:043d\:0435\:0439\:043d\:043e\
\:0439 \:0438 \:043d\:0435\:043b\:0438\:043d\:0435\:0439\:043d\:043e\:0439 \
\:0440\:0435\:0433\:0440\:0435\:0441\:0441\:0438\:0438, \:043e\:0436\:0438\
\:0434\:0430\:0435\:0442\:0441\:044f, \:0447\:0442\:043e \:0434\:0438\:0441\
\:043f\:0435\:0440\:0441\:0438\:044f \:043f\:043e\:0433\:0440\:0435\:0448\
\:043d\:043e\:0441\:0442\:0438 \:043d\:0435 \:0431\:0443\:0434\:0435\:0442 \
\:043a\:043e\:043d\:0441\:0442\:0430\:043d\:0442\:043e\:0439. \:0414\:043b\
\:044f \:043e\:0431\:0440\:0430\:0442\:043d\:043e\:0439 \:0413\:0430\:0443\
\:0441\:0441\:043e\:0432\:043e\:0439 \:043c\:043e\:0434\:0435\:043b\:0438, \
\:043e\:0436\:0438\:0434\:0430\:0435\:0442\:0441\:044f, \:0447\:0442\:043e \
\:043f\:043e\:0433\:0440\:0435\:0448\:043d\:043e\:0441\:0442\:0438 \:0443\
\:0432\:0435\:043b\:0438\:0447\:0438\:0432\:0430\:044e\:0442\:0441\:044f \
\:0441 \:0443\:0432\:0435\:043b\:0438\:0447\:0435\:043d\:0438\:0435\:043c \
\:0432\:0435\:043b\:0438\:0447\:0438\:043d \:043e\:0442\:043a\:043b\:0438\
\:043a\:0430. \
\>", "HowToText",
 CellID->301400387],

Cell["\<\
\:0414\:043b\:044f \:044d\:0442\:0438\:0445 \:043c\:043e\:0434\:0435\:043b\
\:0435\:0439 \:043c\:043e\:0433\:0443\:0442 \:0431\:044b\:0442\:044c \:0438\
\:0441\:043f\:043e\:043b\:044c\:0437\:043e\:0432\:0430\:043d\:044b \:0440\
\:0430\:0437\:043b\:0438\:0447\:043d\:044b\:0435 \:0432\:0438\:0434\:044b \
\:043f\:0440\:0435\:043e\:0431\:0440\:0430\:0437\:043e\:0432\:0430\:043d\:043d\
\:044b\:0445 \:043e\:0441\:0442\:0430\:0442\:043a\:043e\:0432, \:0438 \:0432\
\:043e\:0437\:043c\:043e\:0436\:043d\:043e, \:0431\:0443\:0434\:0435\:0442 \
\:043b\:044e\:0431\:043e\:043f\:044b\:0442\:043d\:043e \:0440\:0430\:0441\
\:0441\:043c\:043e\:0442\:0440\:0435\:0442\:044c \:043d\:0435\:0441\:043a\
\:043e\:043b\:044c\:043a\:043e \:0438\:0437 \:043d\:0438\:0445 \:0441\:0440\
\:0430\:0437\:0443. \:0414\:043b\:044f \:043d\:0430\:0447\:0430\:043b\:0430, \
\:0443\:043a\:0430\:0436\:0435\:043c \:043e\:0441\:0442\:0430\:0442\:043a\
\:0438, \:043a\:043e\:0442\:043e\:0440\:044b\:0435 \:0445\:043e\:0442\:0435\
\:043b\:043e\:0441\:044c \:0431\:044b \:0443\:0432\:0438\:0434\:0435\:0442\
\:044c \:0432\:043c\:0435\:0441\:0442\:0435:\
\>", "HowToText",
 CellID->41489410],

Cell[BoxData[
 RowBox[{
  RowBox[{"glmresids", "=", 
   RowBox[{"glm", "[", 
    RowBox[{"{", 
     RowBox[{
     "\"\<FitResiduals\>\"", ",", "\"\<AnscombeResiduals\>\"", ",", 
      "\"\<PearsonResiduals\>\"", ",", 
      "\"\<StandardizedPearsonResiduals\>\""}], "}"}], "]"}]}], 
  ";"}]], "Input",
 CellLabel->"In[18]:=",
 CellID->74959020],

Cell[TextData[{
 "\:0422\:0430\:043a \:0436\:0435, \:043a\:0430\:043a \:0432 \:043b\:0438\
\:043d\:0435\:0439\:043d\:043e\:0439 \:0438 \:043d\:0435\:043b\:0438\:043d\
\:0435\:0439\:043d\:043e\:0439 \:0440\:0435\:0433\:0440\:0435\:0441\:0441\
\:0438\:0438, \:043e\:0441\:0442\:0430\:0442\:043a\:0438 ",
 Cell[BoxData["\<\"FitResiduals\"\>"], "InlineFormula"],
 " \:044f\:0432\:043b\:044f\:044e\:0442\:0441\:044f \:0440\:0430\:0437\:043d\
\:0438\:0446\:0435\:0439 \:043c\:0435\:0436\:0434\:0443 \:043e\:0442\:043a\
\:043b\:0438\:043a\:043e\:043c \:0438 \:0440\:0430\:0441\:0447\:0435\:0442\
\:043d\:044b\:043c\:0438 \:0432\:0435\:043b\:0438\:0447\:0438\:043d\:0430\
\:043c\:0438.  ",
 Cell[BoxData["\<\"AnscombeResiduals\"\>"], "InlineFormula"],
 " \:043f\:0440\:0435\:043e\:0431\:0440\:0430\:0437\:0443\:0435\:0442 \:043e\
\:0441\:0442\:0430\:0442\:043a\:0438 \:043f\:043e\:0434\:0431\:043e\:0440\
\:0430 \:0442\:0430\:043a, \:0447\:0442\:043e\:0431\:044b \:043e\:043d\:0438 \
\:0441\:0442\:0430\:043b\:0438 \:0431\:043b\:0438\:0436\:0435 \:043a \:043d\
\:043e\:0440\:043c\:0430\:043b\:044c\:043d\:043e\:043c\:0443 \:0448\:0443\
\:043c\:0443 \:0434\:043b\:044f \:043f\:0440\:0435\:0434\:043f\:043e\:043b\
\:0430\:0433\:0430\:0435\:043c\:043e\:0433\:043e \:0440\:0430\:0441\:043f\
\:0440\:0435\:0434\:0435\:043b\:0435\:043d\:0438\:044f. ",
 Cell[BoxData["\<\"PearsonResiduals\"\>"], "InlineFormula"],
 " \:0432\:044b\:043f\:043e\:043b\:043d\:044f\:0435\:0442 \:043f\:0435\:0440\
\:0435\:0440\:0430\:0441\:0447\:0435\:0442 \:043e\:0441\:0442\:0430\:0442\
\:043a\:043e\:0432 \:043d\:0430 \:043e\:0441\:043d\:043e\:0432\:0435 \:043e\
\:0446\:0435\:043d\:043a\:0438 \:0434\:0438\:0441\:043f\:0435\:0440\:0441\
\:0438\:0438 \:0432 \:043a\:0430\:0436\:0434\:043e\:0439 \:0442\:043e\:0447\
\:043a\:0435, \:0430 ",
 Cell[BoxData["\<\"StandardizedPearsonResiduals\"\>"], "InlineFormula"],
 " \:0432\:044b\:043f\:043e\:043b\:043d\:044f\:0435\:0442 \:043f\:0435\:0440\
\:0435\:0440\:0430\:0441\:0447\:0435\:0442 \:043e\:0441\:0442\:0430\:0442\
\:043a\:043e\:0432 \:043d\:0430 \:043e\:0441\:043d\:043e\:0432\:0435 \:043e\
\:0431\:0449\:0435\:0439 \:0434\:0438\:0441\:043f\:0435\:0440\:0441\:0438\
\:0438."
}], "HowToText",
 CellID->615872234],

Cell["\<\
\:0414\:0430\:043b\:0435\:0435, \:043e\:043f\:0440\:0435\:0434\:0435\:043b\
\:0438\:043c \:043d\:0430\:0434\:043f\:0438\:0441\:0438 \:0434\:043b\:044f \
\:043a\:0430\:0436\:0434\:043e\:0433\:043e \:0433\:0440\:0430\:0444\:0438\
\:043a\:0430 \:043e\:0441\:0442\:0430\:0442\:043a\:043e\:0432, \:043a\:043e\
\:0442\:043e\:0440\:044b\:0439 \:043f\:0440\:0435\:0434\:043f\:043e\:043b\
\:0430\:0433\:0430\:0435\:0442\:0441\:044f \:0441\:043e\:0437\:0434\:0430\
\:0442\:044c:\
\>", "HowToText",
 CellID->6289605],

Cell[BoxData[
 RowBox[{
  RowBox[{"labels", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<fit\>\"", ",", "\"\<Anscombe\>\"", ",", "\"\<Pearson\>\"", ",", 
     "\"\<standardized Pearson\>\""}], "}"}]}], ";"}]], "Input",
 CellLabel->"In[19]:=",
 CellID->175026300],

Cell[TextData[{
 "\:0421\:043e\:0437\:0434\:0430\:0434\:0438\:043c \:0433\:0440\:0430\:0444\
\:0438\:043a\:0438 \:0434\:043b\:044f \:0440\:0430\:0437\:043d\:044b\:0445 \
\:0432\:0438\:0434\:043e\:0432 \:043e\:0441\:0442\:0430\:0442\:043a\:043e\
\:0432 \:0438 \:0434\:043e\:0431\:0430\:0432\:0438\:043c \:043d\:0430\:0434\
\:043f\:0438\:0441\:044c \:043a \:043a\:0430\:0436\:0434\:043e\:043c\:0443. \
\:0412\:044b\:0432\:043e\:0434 \:0440\:0435\:0437\:0443\:043b\:044c\:0442\
\:0430\:0442\:0430 \:0437\:0434\:0435\:0441\:044c \:043f\:043e\:0434\:0430\
\:0432\:043b\:044f\:0435\:0442\:0441\:044f \:0438\:0441\:043f\:043e\:043b\
\:044c\:0437\:043e\:0432\:0430\:043d\:0438\:0435\:043c \:0442\:043e\:0447\
\:043a\:0438 \:0441 \:0437\:0430\:043f\:044f\:0442\:043e\:0439 (",
 Cell[BoxData[";"], "InlineFormula"],
 "). \:0413\:0440\:0430\:0444\:0438\:043a\:0438 \
\:0431\:0443\:0434\:0443\:0442 \:0432\:044b\:0432\:0435\:0434\:0435\:043d\
\:044b \:0432 \:0442\:0430\:0431\:043b\:0438\:0447\:043d\:043e\:0439 \:0444\
\:043e\:0440\:043c\:0435 \:0432 \:0441\:043b\:0435\:0434\:0443\:044e\:0449\
\:0435\:043c \:0448\:0430\:0433\:0435:"
}], "HowToText",
 CellID->291382582],

Cell[BoxData[
 RowBox[{
  RowBox[{"plots", "=", 
   RowBox[{"MapThread", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"ListPlot", "[", 
       RowBox[{"#1", ",", 
        RowBox[{"Frame", "\[Rule]", "True"}], ",", 
        RowBox[{"PlotLabel", "\[Rule]", "#2"}]}], "]"}], "&"}], ",", 
     RowBox[{"{", 
      RowBox[{"glmresids", ",", "labels"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellLabel->"In[20]:=",
 CellID->482770823],

Cell[TextData[{
 "\:0418\:0441\:043f\:043e\:043b\:044c\:0437\:0443\:0435\:043c \:0444\:0443\
\:043d\:043a\:0446\:0438\:044e ",
 Cell[BoxData[
  ButtonBox["Partition",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Partition"]], "InlineFormula"],
 " \:0434\:043b\:044f \:0441\:043e\:0437\:0434\:0430\:043d\:0438\:044f \:043c\
\:0430\:0441\:0441\:0438\:0432\:0430 2\[Times]2, \:0430 \:0437\:0430\:0442\
\:0435\:043c \:0432\:044b\:0432\:0435\:0434\:0435\:043c \:043d\:0430 \:044d\
\:043a\:0440\:0430\:043d \:0433\:0440\:0430\:0444\:0438\:043a\:0438 \:0432 \
\:0432\:0438\:0434\:0435 \:0442\:0430\:0431\:043b\:0438\:0446\:044b, \:0438\
\:0441\:043f\:043e\:043b\:044c\:0437\:0443\:044f \:0444\:0443\:043d\:043a\
\:0446\:0438\:044e ",
 Cell[BoxData[
  ButtonBox["GraphicsGrid",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/GraphicsGrid"]], "InlineFormula"],
 ":"
}], "HowToText",
 CellID->96139712],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GraphicsGrid", "[", 
  RowBox[{
   RowBox[{"Partition", "[", 
    RowBox[{"plots", ",", "2"}], "]"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", "400"}], ",", 
   RowBox[{"PlotLabel", "\[Rule]", "\"\<Types of Residuals\>\""}]}], 
  "]"}]], "Input",
 CellLabel->"In[21]:=",
 CellID->16063042],

Cell[BoxData[
 GraphicsBox[{{}, {{InsetBox[
      GraphicsBox[
       {Hue[0.67, 0.6, 0.6], 
        PointBox[{{1., -2.9570639096784888`}, {2., -7.347920954978658}, {3., 
         14.813890039047152`}, {4., 21.756687874416542`}, {5., 
         21.47776360013755}, {6., -7.3290449848365}, {7., 
         2.317495436161863}, {8., 0.5068508680793791}, {9., 
         9.993665192057506}, {10., -0.0015614900766415252`}, {11., 
         8.890225078825864}, {12., -2.4395229427116263`}, {
         13., -4.762058771070684}, {14., 1.6472514785976706`}, {15., 
         0.6874058440010868}}]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, Automatic},
       Frame->True,
       PlotLabel->FormBox["\"fit\"", TraditionalForm],
       PlotRange->Automatic,
       PlotRangeClipping->True], {192., -118.66252583997979`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[
       {Hue[0.67, 0.6, 0.6], 
        PointBox[{{1., -0.04113849835889658}, {2., -0.07752786919866378}, {3.,
          0.016111431024155968`}, {4., 0.023438163780376133`}, {5., 
         0.027740847766849864`}, {6., -0.04803975267715527}, {7., 
         0.0071227824199969645`}, {8., 0.007956240697182152}, {9., 
         0.015978007807097832`}, {10., -0.0018564910860266704`}, {11., 
         0.01732187093985986}, {12., -0.012480132951156504`}, {
         13., -0.025696269573029628`}, {14., 0.012942012249938408`}, {15., 
         0.04479265540859279}}]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, Automatic},
       Frame->True,
       PlotLabel->FormBox["\"Anscombe\"", TraditionalForm],
       PlotRange->Automatic,
       PlotRangeClipping->True], {576., -118.66252583997979`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}]}, {InsetBox[
      GraphicsBox[
       {Hue[0.67, 0.6, 0.6], 
        PointBox[{{1., -0.03772045474268753}, {2., -0.06463273748555103}, {3.,
          0.017406453300509682`}, {4., 0.02621967419654241}, {5., 
         0.031424013571856035`}, {6., -0.04213773426833167}, {7., 
         0.007298678983119339}, {8., 0.008083318746200826}, {9., 
         0.017094516254060593`}, {10., -0.001854864872145723}, {11., 
         0.018550788655130723`}, {12., -0.012033624992476075`}, {
         13., -0.02385994384546546}, {14., 0.013367852202268144`}, {15., 
         0.04733188596510166}}]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, Automatic},
       Frame->True,
       PlotLabel->FormBox["\"Pearson\"", TraditionalForm],
       PlotRange->Automatic,
       PlotRangeClipping->True], {192., -355.98757751993935`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}], InsetBox[
      GraphicsBox[
       {Hue[0.67, 0.6, 0.6], 
        PointBox[{{1., -1.2053336026326316`}, {2., -2.031677455430962}, {3., 
         0.5628667142909097}, {4., 0.8474207330564455}, {5., 
         1.0112820253065635`}, {6., -1.318507247184119}, {7., 
         0.23039125188481746`}, {8., 0.26287274187740245`}, {9., 
         0.5480404530758444}, {10., -2.5700998534618233`}, {11., 
         0.5916900737868187}, {12., -0.3769017152414097}, {
         13., -0.747199588744712}, {14., 0.419427997697323}, {15., 
         2.3880122525019885`}}]},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, Automatic},
       Frame->True,
       PlotLabel->FormBox["\"standardized Pearson\"", TraditionalForm],
       PlotRange->Automatic,
       PlotRangeClipping->True], {576., -355.98757751993935`}, 
      ImageScaled[{0.5, 0.5}], {360., 222.4922359499621}]}}, {}},
  ContentSelectable->True,
  ImageSize->400,
  PlotLabel->FormBox["\"Types of Residuals\"", TraditionalForm],
  PlotRangePadding->{6, 5}]], "Output",
 ImageSize->{404, 263},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[21]=",
 CellID->331253686]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  InterpretationBox[
   StyleBox[
    GraphicsBox[{},
     BaselinePosition->Baseline,
     ImageSize->{6, 0}],
    CacheGraphics->False],
   Spacer[6]]]],
 "\:0423\:0447\:0435\:0431\:043d\:044b\:0435 \:043c\:0430\:0442\:0435\:0440\
\:0438\:0430\:043b\:044b"
}], "TutorialsSection",
 WholeCellGroupOpener->True,
 CellID->250839057],

Cell["", "SectionHeaderSpacer"],

Cell[BoxData[
 TemplateBox[{
  Cell["Statistical Model Analysis"],
   "paclet:tutorial/StatisticalModelAnalysis"},
  "RefLink",
  BaseStyle->"Tutorials"]], "Tutorials",
 CellID->341631938],

Cell[BoxData[
 TemplateBox[{
  Cell["Plotting Lists of Data"],"paclet:tutorial/PlottingListsOfData"},
  "RefLink",
  BaseStyle->"Tutorials"]], "Tutorials",
 CellID->138898779],

Cell[BoxData[
 TemplateBox[{Cell["Options for Graphics"],"paclet:tutorial/Options"},
  "RefLink",
  BaseStyle->"Tutorials"]], "Tutorials",
 CellID->21439481],

Cell[BoxData[
 TemplateBox[{Cell["Basic Plotting"],"paclet:tutorial/BasicPlotting"},
  "RefLink",
  BaseStyle->"Tutorials"]], "Tutorials",
 CellID->966876880],

Cell["", "SectionFooterSpacer"]
}, Open  ]],

Cell[CellGroupData[{

Cell["  \:0421\:043e\:043f\:0443\:0442\:0441\:0442\:0432\:0443\:044e\:0449\
\:0438\:0435 \:0434\:0435\:043c\:043e\:043d\:0441\:0442\:0440\:0430\:0446\
\:0438\:043e\:043d\:043d\:044b\:0435 \:043c\:043e\:0434\:0435\:043b\:0438", \
"RelatedDemonstrationsSection",
 CellID->1268215905],

Cell[TextData[Cell[BoxData[
 TemplateBox[{Cell[
    TextData["Fitting Primes to a Linear Model"]],
   "http://demonstrations.wolfram.com/FittingPrimesToALinearModel/"},
  "WebLink",
  BaseStyle->{"RelatedDemonstrations"}]]]], "RelatedDemonstrations",
 CellID->1129518860],

Cell[TextData[Cell[BoxData[
 TemplateBox[{Cell[
    TextData["Comparing Some Residuals for Generalized Linear Models"]],
   "http://demonstrations.wolfram.com/\
ComparingSomeResidualsForGeneralizedLinearModels/"},
  "WebLink",
  BaseStyle->{"RelatedDemonstrations"}]]]], "RelatedDemonstrations",
 CellID->12274091],

Cell[TextData[Cell[BoxData[
 TemplateBox[{Cell[
    TextData["Comparing Binomial Generalized Linear Models"]],
   "http://demonstrations.wolfram.com/\
ComparingBinomialGeneralizedLinearModels/"},
  "WebLink",
  BaseStyle->{"RelatedDemonstrations"}]]]], "RelatedDemonstrations",
 CellID->274339963],

Cell[TextData[Cell[BoxData[
 TemplateBox[{Cell[
    TextData["Logit and Probit Models for O-Ring Failure Data"]],
   "http://demonstrations.wolfram.com/LogitAndProbitModelsForORingFailureData/\
"},
  "WebLink",
  BaseStyle->{"RelatedDemonstrations"}]]]], "RelatedDemonstrations",
 CellID->530850663],

Cell[TextData[Cell[BoxData[
 TemplateBox[{Cell[
    TextData["Maximum Likelihood Estimators for Binary Outcomes"]],
   "http://demonstrations.wolfram.com/\
MaximumLikelihoodEstimatorsForBinaryOutcomes/"},
  "WebLink",
  BaseStyle->{"RelatedDemonstrations"}]]]], "RelatedDemonstrations",
 CellID->288157728],

Cell[TextData[Cell[BoxData[
 TemplateBox[{Cell[
    TextData["Mean and Single Prediction Bands for a Nonlinear Model"]],
   "http://demonstrations.wolfram.com/\
MeanAndSinglePredictionBandsForANonlinearModel/"},
  "WebLink",
  BaseStyle->{"RelatedDemonstrations"}]]]], "RelatedDemonstrations",
 CellID->371495079]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  InterpretationBox[
   StyleBox[
    GraphicsBox[{},
     BaselinePosition->Baseline,
     ImageSize->{6, 0}],
    CacheGraphics->False],
   Spacer[6]]]],
 "\:0421\:043e\:043f\:0443\:0442\:0441\:0442\:0432\:0443\:044e\:0449\:0438\
\:0435 \:0440\:0430\:0437\:0434\:0435\:043b\:044b \:043a\:0440\:0430\:0442\
\:043a\:043e\:0433\:043e \:043a\:0443\:0440\:0441\:0430"
}], "RelatedLinksSection",
 WholeCellGroupOpener->True,
 CellID->1584193535],

Cell["", "SectionHeaderSpacer"],

Cell[TextData[ButtonBox["\:041a\:0440\:0430\:0442\:043a\:0438\:0439 \:043a\
\:0443\:0440\:0441: \:0421\:0442\:0430\:0442\:0438\:0441\:0442\:0438\:0447\
\:0435\:0441\:043a\:0438\:0439 \:0430\:043d\:0430\:043b\:0438\:0437",
 BaseStyle->"Hyperlink",
 ButtonData->{"DoStatisticalAnalysisRU.nb", None}]], "RelatedLinks",
 FontFamily->"Verdana",
 FontSize->11,
 CellID->405226890],

Cell["", "SectionFooterSpacer"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  InterpretationBox[
   StyleBox[
    GraphicsBox[{},
     BaselinePosition->Baseline,
     ImageSize->{6, 0}],
    CacheGraphics->False],
   Spacer[6]]]],
 "\:0421\:043c\:043e\:0442\:0440\:0438 \:0442\:0430\:043a\:0436\:0435"
}], "SeeAlsoSection",
 WholeCellGroupOpener->True,
 CellID->1255426704],

Cell[TextData[{
 Cell[BoxData[
  TemplateBox[{Cell["LinearModelFit"],"paclet:ref/LinearModelFit"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  TemplateBox[{Cell["FittedModel"],"paclet:ref/FittedModel"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  TemplateBox[{Cell["ListPlot"],"paclet:ref/ListPlot"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  TemplateBox[{Cell["Plot"],"paclet:ref/Plot"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  TemplateBox[{Cell["NonlinearModelFit"],"paclet:ref/NonlinearModelFit"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  TemplateBox[{Cell["Exp"],"paclet:ref/Exp"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  TemplateBox[{
   Cell["GeneralizedLinearModelFit"],"paclet:ref/GeneralizedLinearModelFit"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  TemplateBox[{Cell["ExponentialFamily"],"paclet:ref/ExponentialFamily"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  TemplateBox[{Cell["GraphicsGrid"],"paclet:ref/GraphicsGrid"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  TemplateBox[{Cell["Filling"],"paclet:ref/Filling"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  TemplateBox[{Cell["Frame"],"paclet:ref/Frame"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"]
}], "SeeAlso",
 CellID->929782353]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  InterpretationBox[
   StyleBox[
    GraphicsBox[{},
     BaselinePosition->Baseline,
     ImageSize->{6, 0}],
    CacheGraphics->False],
   Spacer[6]]]],
 "\:0423\:0437\:043d\:0430\:0442\:044c \:0431\:043e\:043b\:044c\:0448\:0435"
}], "MoreAboutSection",
 WholeCellGroupOpener->True,
 CellID->38303248],

Cell["", "SectionHeaderSpacer"],

Cell[BoxData[
 TemplateBox[{Cell["Statistics"],"paclet:guide/Statistics"},
  "RefLink",
  BaseStyle->"MoreAbout"]], "MoreAbout",
 CellID->164248854],

Cell[BoxData[
 TemplateBox[{
  Cell["Statistical Model Analysis"],"paclet:guide/StatisticalModelAnalysis"},
  "RefLink",
  BaseStyle->"MoreAbout"]], "MoreAbout",
 CellID->54545674],

Cell[BoxData[
 TemplateBox[{Cell["Data Visualization"],"paclet:guide/DataVisualization"},
  "RefLink",
  BaseStyle->"MoreAbout"]], "MoreAbout",
 CellID->1665078683],

Cell[BoxData[
 TemplateBox[{Cell["\"How to\" Topics"],"paclet:guide/HowToTopics"},
  "RefLink",
  BaseStyle->"MoreAbout"]], "MoreAbout",
 CellID->1040501511]
}, Open  ]]
}, Open  ]],

Cell[" ", "FooterCell"]
},
FileChangeProtection->None,
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{Automatic, 510},
WindowMargins->{{312, Automatic}, {Automatic, 0}},
WindowFrame->"Normal",
WindowTitle->"Plot Diagnostics for Fitted Models - Wolfram Mathematica",
DockedCells->FEPrivate`FrontEndResource["FEExpressions", "HelpViewerToolbar"],
TaggingRules->{
 "ModificationHighlight" -> False, "ColorType" -> "TutorialColor", 
  "LinkTrails" -> "", "ExampleCounter" -> 1, "ExamplePageLinks" -> {}, 
  "RootCaptions" -> "", 
  "Metadata" -> {
   "built" -> "{2013, 1, 24, 22, 48, 55.2126335}", 
    "history" -> {"8", "", "", ""}, "context" -> "System`", 
    "keywords" -> {
     "generate diagnostic plots for fitted models", "residual plot", 
      "linear models", "linear regression", "nonlinear regression", 
      "nonlinear model", "generalized linear model", "probit model", 
      "probit regression", "logit model", "logit regression", "glm", "lm", 
      "model diagnostics", "leverage plot", "influence diagnostics", 
      "residuals", "Cook's distance", "Cook's d", "model diagnostics", 
      "influence measures", "covratio", "dfbetas", "dffits", "fit residuals", 
      "raw residuals", "hat diagonal", "predicted response", "fitted values", 
      "response vector", "standardized residuals", "studentized residuals", 
      "variance inflation factors", "anscombe's residuals", 
      "likelihood residuals", "Pearson's residuals", 
      "standardized deviance residuals", "standardized Pearson's residuals", 
      "working residuals", "deviance residuals"}, "specialkeywords" -> {}, 
    "tutorialcollectionlinks" -> {}, "index" -> True, "label" -> 
    "Mathematica How To", "language" -> "en", "paclet" -> "Mathematica", 
    "status" -> "None", "summary" -> 
    "Diagnostics are an important part of analyzing models of data. Plots of \
residuals and leverage or influence measures provide valuable insight into \
whether assumptions of the model are reasonable and whether there are data \
points that exert too much influence on the fitting. You can create these \
types of graphics in Mathematica by using results from functions such as \
LinearModelFit together with built-in plotting functions.", "synonyms" -> {}, 
    "title" -> "Plot Diagnostics for Fitted Models", "titlemodifier" -> "", 
    "windowtitle" -> "Plot Diagnostics for Fitted Models", "type" -> "HowTo", 
    "uri" -> "howto/PlotDiagnosticsForFittedModels"}, "SearchTextTranslated" -> 
  ""},
Magnification->1.,
FrontEndVersion->"10.1 for Microsoft Windows (64-bit) (March 23, 2015)",
StyleDefinitions->FrontEnd`FileName[{"Wolfram"}, "Reference.nb", 
  CharacterEncoding -> "WindowsANSI"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[627, 21, 5621, 132, 48, "AnchorBarGrid",
 CellID->1],
Cell[CellGroupData[{
Cell[6273, 157, 560, 11, 91, "HowToTitle",
 CellID->509267359],
Cell[CellGroupData[{
Cell[6858, 172, 2434, 38, 109, "HowToAbstract",
 CellID->1045883471],
Cell[9295, 212, 359, 5, 38, "HowToText",
 CellID->1009846402],
Cell[9657, 219, 1193, 36, 65, "Input",
 CellID->827466675],
Cell[10853, 257, 1557, 37, 57, "HowToText",
 CellID->9075086],
Cell[12413, 296, 425, 10, 40, "HowToText",
 CellID->1389965763],
Cell[CellGroupData[{
Cell[12863, 310, 250, 8, 28, "Input",
 CellID->411630083],
Cell[13116, 320, 438, 14, 57, "Output",
 CellID->9673184]
}, Open  ]],
Cell[13569, 337, 1418, 30, 80, "HowToText",
 CellID->333472440],
Cell[14990, 369, 241, 3, 38, "HowToText",
 CellID->674552109],
Cell[CellGroupData[{
Cell[15256, 376, 240, 8, 28, "Input",
 CellID->773665386],
Cell[15499, 386, 2157, 44, 173, "Output",
 CellID->68647072]
}, Open  ]],
Cell[17671, 433, 954, 20, 58, "HowToText",
 CellID->812217608],
Cell[CellGroupData[{
Cell[18650, 457, 165, 5, 28, "Input",
 CellID->1398028897],
Cell[18818, 464, 2341, 45, 171, "Output",
 CellID->881128876]
}, Open  ]],
Cell[21174, 512, 605, 13, 40, "HowToText",
 CellID->178013378],
Cell[21782, 527, 1299, 19, 74, "HowToText",
 CellID->1522158152],
Cell[23084, 548, 913, 18, 58, "HowToText",
 CellID->83629139],
Cell[CellGroupData[{
Cell[24022, 570, 152, 4, 28, "Input",
 CellID->181272062],
Cell[24177, 576, 811, 20, 163, "Output",
 CellID->783349045]
}, Open  ]],
Cell[25003, 599, 877, 13, 56, "HowToText",
 CellID->726278705],
Cell[25883, 614, 1043, 21, 58, "HowToText",
 CellID->212318464],
Cell[CellGroupData[{
Cell[26951, 639, 262, 7, 28, "Input",
 CellID->335877154],
Cell[27216, 648, 1344, 31, 176, "Output",
 CellID->598245848]
}, Open  ]],
Cell[28575, 682, 1257, 18, 74, "HowToText",
 CellID->495141871],
Cell[29835, 702, 444, 8, 38, "HowToText",
 CellID->47917411],
Cell[CellGroupData[{
Cell[30304, 714, 271, 7, 28, "Input",
 CellID->435235952],
Cell[30578, 723, 1346, 31, 182, "Output",
 CellID->414999672]
}, Open  ]],
Cell[31939, 757, 1346, 21, 75, "HowToText",
 CellID->31027390],
Cell[33288, 780, 1233, 19, 76, "HowToText",
 CellID->451940841],
Cell[CellGroupData[{
Cell[34546, 803, 179, 6, 28, "Input",
 CellID->312101611],
Cell[34728, 811, 407, 11, 36, "Output",
 CellID->16579683]
}, Open  ]],
Cell[35150, 825, 976, 23, 60, "HowToText",
 CellID->319914358],
Cell[CellGroupData[{
Cell[36151, 852, 247, 8, 28, "Input",
 CellID->378538415],
Cell[36401, 862, 805, 19, 162, "Output",
 CellID->254131239]
}, Open  ]],
Cell[37221, 884, 339, 5, 38, "HowToText",
 CellID->25666235],
Cell[CellGroupData[{
Cell[37585, 893, 648, 18, 47, "Input",
 CellID->69547533],
Cell[38236, 913, 1591, 36, 197, "Output",
 CellID->595307435]
}, Open  ]],
Cell[39842, 952, 1186, 17, 74, "HowToText",
 CellID->168171910],
Cell[41031, 971, 985, 15, 56, "HowToText",
 CellID->234353591],
Cell[CellGroupData[{
Cell[42041, 990, 214, 6, 28, "Input",
 CellID->388400420],
Cell[42258, 998, 1285, 29, 171, "Output",
 CellID->103921319]
}, Open  ]],
Cell[43558, 1030, 1145, 19, 78, "HowToText",
 CellID->75382226],
Cell[44706, 1051, 585, 10, 58, "HowToText",
 CellID->665973240],
Cell[CellGroupData[{
Cell[45316, 1065, 215, 6, 28, "Input",
 CellID->180736321],
Cell[45534, 1073, 1331, 30, 159, "Output",
 CellID->38741979]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[46914, 1109, 67, 2, 15, "HowToDelimiter",
 CellID->1876377496],
Cell[46984, 1113, 1415, 33, 78, "HowToText",
 CellID->52592172],
Cell[48402, 1148, 859, 13, 56, "HowToText",
 CellID->147206014],
Cell[49264, 1163, 1193, 36, 65, "Input",
 CellID->90504538],
Cell[50460, 1201, 768, 18, 58, "HowToText",
 CellID->77307161],
Cell[CellGroupData[{
Cell[51253, 1223, 451, 14, 28, "Input",
 CellID->183634098],
Cell[51707, 1239, 460, 14, 57, "Output",
 CellID->432475383]
}, Open  ]],
Cell[52182, 1256, 725, 18, 40, "HowToText",
 CellID->300163535],
Cell[CellGroupData[{
Cell[52932, 1278, 317, 10, 28, "Input",
 CellID->522443779],
Cell[53252, 1290, 2788, 52, 177, "Output",
 CellID->25789244]
}, Open  ]],
Cell[56055, 1345, 847, 16, 58, "HowToText",
 CellID->70907008],
Cell[CellGroupData[{
Cell[56927, 1365, 214, 6, 28, "Input",
 CellID->998849277],
Cell[57144, 1373, 1332, 30, 163, "Output",
 CellID->739409677]
}, Open  ]],
Cell[58491, 1406, 1878, 40, 98, "HowToText",
 CellID->247228587],
Cell[CellGroupData[{
Cell[60394, 1450, 401, 10, 47, "Input",
 CellID->463204662],
Cell[60798, 1462, 443, 14, 57, "Output",
 CellID->20879690]
}, Open  ]],
Cell[61256, 1479, 1204, 18, 74, "HowToText",
 CellID->301400387],
Cell[62463, 1499, 1165, 17, 74, "HowToText",
 CellID->41489410],
Cell[63631, 1518, 344, 11, 47, "Input",
 CellID->74959020],
Cell[63978, 1531, 2228, 34, 118, "HowToText",
 CellID->615872234],
Cell[66209, 1567, 515, 9, 38, "HowToText",
 CellID->6289605],
Cell[66727, 1578, 262, 8, 28, "Input",
 CellID->175026300],
Cell[66992, 1588, 1160, 18, 76, "HowToText",
 CellID->291382582],
Cell[68155, 1608, 428, 13, 28, "Input",
 CellID->482770823],
Cell[68586, 1623, 898, 20, 60, "HowToText",
 CellID->96139712],
Cell[CellGroupData[{
Cell[69509, 1647, 313, 9, 28, "Input",
 CellID->16063042],
Cell[69825, 1658, 4017, 82, 284, "Output",
 CellID->331253686]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[73891, 1746, 362, 13, 31, "TutorialsSection",
 CellID->250839057],
Cell[74256, 1761, 31, 0, 14, "SectionHeaderSpacer"],
Cell[74290, 1763, 188, 6, 19, "Tutorials",
 CellID->341631938],
Cell[74481, 1771, 175, 5, 19, "Tutorials",
 CellID->138898779],
Cell[74659, 1778, 157, 4, 19, "Tutorials",
 CellID->21439481],
Cell[74819, 1784, 158, 4, 19, "Tutorials",
 CellID->966876880],
Cell[74980, 1790, 31, 0, 29, "SectionFooterSpacer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[75048, 1795, 281, 4, 30, "RelatedDemonstrationsSection",
 CellID->1268215905],
Cell[75332, 1801, 271, 6, 18, "RelatedDemonstrations",
 CellID->1129518860],
Cell[75606, 1809, 314, 7, 18, "RelatedDemonstrations",
 CellID->12274091],
Cell[75923, 1818, 297, 7, 18, "RelatedDemonstrations",
 CellID->274339963],
Cell[76223, 1827, 299, 7, 18, "RelatedDemonstrations",
 CellID->530850663],
Cell[76525, 1836, 306, 7, 18, "RelatedDemonstrations",
 CellID->288157728],
Cell[76834, 1845, 313, 7, 18, "RelatedDemonstrations",
 CellID->371495079]
}, Open  ]],
Cell[CellGroupData[{
Cell[77184, 1857, 472, 14, 31, "RelatedLinksSection",
 CellID->1584193535],
Cell[77659, 1873, 31, 0, 14, "SectionHeaderSpacer"],
Cell[77693, 1875, 374, 7, 18, "RelatedLinks",
 CellID->405226890],
Cell[78070, 1884, 31, 0, 29, "SectionFooterSpacer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[78138, 1889, 329, 12, 31, "SeeAlsoSection",
 CellID->1255426704],
Cell[78470, 1903, 3106, 87, 75, "SeeAlso",
 CellID->929782353]
}, Open  ]],
Cell[CellGroupData[{
Cell[81613, 1995, 335, 12, 31, "MoreAboutSection",
 CellID->38303248],
Cell[81951, 2009, 31, 0, 14, "SectionHeaderSpacer"],
Cell[81985, 2011, 148, 4, 19, "MoreAbout",
 CellID->164248854],
Cell[82136, 2017, 180, 5, 19, "MoreAbout",
 CellID->54545674],
Cell[82319, 2024, 164, 4, 19, "MoreAbout",
 CellID->1665078683],
Cell[82486, 2030, 157, 4, 19, "MoreAbout",
 CellID->1040501511]
}, Open  ]]
}, Open  ]],
Cell[82670, 2038, 23, 0, 41, "FooterCell"]
}
]
*)

(* End of internal cache information *)
