(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     22404,        703]
NotebookOptionsPosition[     18326,        582]
NotebookOutlinePosition[     20186,        626]
CellTagsIndexPosition[     20143,        623]
WindowTitle->Solve a Differential-Algebraic Equation - Wolfram Mathematica
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[GridBox[{
   {Cell["MATHEMATICA HOW TO", "PacletNameCell"], Cell[TextData[{
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "Tutorials",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"Tutorials", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->False], {"\<\"Differentiation\"\>":>
       Documentation`HelpLookup[
       "paclet:tutorial/Differentiation"], "\<\"Differential Equations\"\>":>
       Documentation`HelpLookup[
       "paclet:tutorial/DifferentialEquations"], "\<\"Introduction to \
Differential Equation Solving with DSolve\"\>":>Documentation`HelpLookup[
       "paclet:tutorial/DSolveIntroduction"], "\<\"Differential Equation \
Solving with DSolve\"\>":>Documentation`HelpLookup[
       "paclet:tutorial/DSolveOverview"]},
       Appearance->None,
       MenuAppearance->Automatic,
       MenuStyle->"Tutorials"]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "See Also",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"See Also", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->False], {"\<\"DSolve\"\>":>Documentation`HelpLookup[
       "paclet:ref/DSolve"]},
       Appearance->None,
       MenuAppearance->Automatic,
       MenuStyle->"SeeAlso"]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "Related Guides",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"Related Guides", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->False], {"\<\"Differential Equations\"\>":>
       Documentation`HelpLookup[
       "paclet:guide/DifferentialEquations"], "\<\"\\\"How to\\\" Topics\"\>":>
       Documentation`HelpLookup["paclet:guide/HowToTopics"]},
       Appearance->None,
       MenuAppearance->Automatic,
       MenuStyle->"MoreAbout"]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "URL",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"URL", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->
         False], {"\<\"howto/SolveADifferentialAlgebraicEquation\"\>":>
       None, "\<\"Copy Mathematica URL\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell["howto/SolveADifferentialAlgebraicEquation"]}, Visible -> 
            False]]; SelectionMove[
         DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; Null], 
       Delimiter, "\<\"Copy web URL\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell[
              BoxData[
               MakeBoxes[
                Hyperlink[
                "http://reference.wolfram.com/mathematica/howto/\
SolveADifferentialAlgebraicEquation.html"], StandardForm]], "Input", 
              TextClipboardType -> "PlainText"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; 
        Null], "\<\"Go to web URL\"\>":>FrontEndExecute[{
         NotebookLocate[{
           URL[
            StringJoin[
            "http://reference.wolfram.com/mathematica/", 
             "howto/SolveADifferentialAlgebraicEquation", ".html"]], None}]}]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}]
    }], "AnchorBar"]}
  }]], "AnchorBarGrid",
 CellID->1],

Cell[CellGroupData[{

Cell[TextData[{
 Cell["\:041a\:0440\:0430\:0442\:043a\:0438\:0439 \:043a\:0443\:0440\:0441 ", 
  "HowToTitlePrefix"],
 " ",
 "\:0420\:0435\:0448\:0435\:043d\:0438\:0435 \:0434\:0438\:0444\:0444\:0435\
\:0440\:0435\:043d\:0446\:0438\:0430\:043b\:044c\:043d\:043e - \:0430\:043b\
\:0433\:0435\:0431\:0440\:0430\:0438\:0447\:0435\:0441\:043a\:0438\:0445 \
\:0443\:0440\:0430\:0432\:043d\:0435\:043d\:0438\:0439"
}], "HowToTitle",
 CellID->509267359],

Cell[CellGroupData[{

Cell[TextData[{
 "\:0424\:0443\:043d\:043a\:0446\:0438\:0438 ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " \:0434\:043b\:044f \:0440\:0435\:0448\:0435\:043d\:0438\:044f \:0434\:0438\
\:0444\:0444\:0435\:0440\:0435\:043d\:0446\:0438\:0430\:043b\:044c\:043d\:044b\
\:0445 \:0443\:0440\:0430\:0432\:043d\:0435\:043d\:0438\:0439 \:043c\:043e\
\:0433\:0443\:0442 \:043f\:0440\:0438\:043c\:0435\:043d\:044f\:0442\:044c\
\:0441\:044f \:043a\:043e \:043c\:043d\:043e\:0433\:0438\:043c \:0440\:0430\
\:0437\:043b\:0438\:0447\:043d\:044b\:043c \:043a\:043b\:0430\:0441\:0441\
\:0430\:043c \:0434\:0438\:0444\:0444\:0435\:0440\:0435\:043d\:0446\:0438\
\:0430\:043b\:044c\:043d\:044b\:0445 \:0443\:0440\:0430\:0432\:043d\:0435\
\:043d\:0438\:0439, \:0430\:0432\:0442\:043e\:043c\:0430\:0442\:0438\:0447\
\:0435\:0441\:043a\:0438 \:0432\:044b\:0431\:0438\:0440\:0430\:044f \:0441\
\:043e\:043e\:0442\:0432\:0435\:0442\:0441\:0442\:0432\:0443\:044e\:0449\:0438\
\:0435 \:0430\:043b\:0433\:043e\:0440\:0438\:0442\:043c\:044b, \:0431\:0435\
\:0437 \:043d\:0435\:043e\:0431\:0445\:043e\:0434\:0438\:043c\:043e\:0441\
\:0442\:0438 \:0438\:0445 \:043f\:0440\:0435\:0434\:0432\:0430\:0440\:0438\
\:0442\:0435\:043b\:044c\:043d\:043e\:0439 \:043e\:0431\:0440\:0430\:0431\
\:043e\:0442\:043a\:0438 \:043f\:043e\:043b\:044c\:0437\:043e\:0432\:0430\
\:0442\:0435\:043b\:0435\:043c. \:041e\:0434\:043d\:0438\:043c \:0438\:0437 \
\:0442\:0430\:043a\:0438\:0445 \:043a\:043b\:0430\:0441\:0441\:043e\:0432 \
\:044f\:0432\:043b\:044f\:044e\:0442\:0441\:044f \:0434\:0438\:0444\:0444\
\:0435\:0440\:0435\:043d\:0446\:0438\:0430\:043b\:044c\:043d\:043e-\:0430\
\:043b\:0433\:0435\:0431\:0440\:0430\:0438\:0447\:0435\:0441\:043a\:0438\:0435\
 \:0443\:0440\:0430\:0432\:043d\:0435\:043d\:0438\:044f (\:0414\:0410\:0423). "
}], "HowToAbstract",
 CellID->156687729],

Cell[TextData[{
 "\:0421\:043e\:0437\:0434\:0430\:0434\:0438\:043c \:0414\:0410\:0423, \:0437\
\:0430\:0434\:0430\:043d\:043d\:043e\:0435 ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["x", "\[Prime]",
       MultilineFunction->None], "(", "t", ")"}], "-", 
     RowBox[{"y", "(", "t", ")"}]}], "\[LongEqual]", "0"}], TraditionalForm]],
   "InlineMath"],
 " ",
 "\:0441 \:0430\:043b\:0433\:0435\:0431\:0440\:0430\:0438\:0447\:0435\:0441\
\:043a\:0438\:043c \:043e\:0433\:0440\:0430\:043d\:0438\:0447\:0435\:043d\
\:0438\:0435\:043c",
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"x", "(", "t", ")"}], "+", 
     RowBox[{"2", 
      RowBox[{"y", "(", "t", ")"}]}]}], "\[LongEqual]", "0"}], 
   TraditionalForm]], "InlineMath"],
 ":"
}], "HowToText",
 CellID->1834468513],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dae", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"x", "'"}], "[", "t", "]"}], "-", 
      RowBox[{"y", "[", "t", "]"}]}], "\[Equal]", "0"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"x", "[", "t", "]"}], "+", 
      RowBox[{"2", 
       RowBox[{"y", "[", "t", "]"}]}]}], "\[Equal]", "0"}]}], 
   "}"}]}]], "Input",
 CellLabel->"In[5]:=",
 CellID->489578012],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      RowBox[{"y", "[", "t", "]"}]}], "+", 
     RowBox[{
      SuperscriptBox["x", "\[Prime]",
       MultilineFunction->None], "[", "t", "]"}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "t", "]"}], "+", 
     RowBox[{"2", " ", 
      RowBox[{"y", "[", "t", "]"}]}]}], "\[Equal]", "0"}]}], "}"}]], "Output",
 ImageSize->{239, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[5]=",
 CellID->864055128]
}, Open  ]],

Cell[TextData[{
 "\:041f\:0440\:0438\:043c\:0435\:043d\:0438\:043c ",
 Cell[BoxData[
  ButtonBox["DSolve",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/DSolve"]], "InlineFormula"],
 ", \:0447\:0442\:043e\:0431\:044b \:0440\:0435\:0448\:0438\:0442\:044c \
\:0443\:0440\:0430\:0432\:043d\:0435\:043d\:0438\:0435 \:0434\:043b\:044f ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", "(", "t", ")"}], TraditionalForm]], "InlineMath"],
 " \:0438 ",
 Cell[BoxData[
  FormBox[
   RowBox[{"y", "(", "t", ")"}], TraditionalForm]], "InlineMath"],
 " \:043f\:043e \:043e\:0442\:043d\:043e\:0448\:0435\:043d\:0438\:044e \:043a \
",
 Cell[BoxData[
  FormBox["t", TraditionalForm]], "InlineMath"],
 ":"
}], "HowToText",
 CellID->812217608],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{"dae", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "[", "t", "]"}], ",", 
     RowBox[{"y", "[", "t", "]"}]}], "}"}], ",", "t"}], "]"}]], "Input",
 CellLabel->"In[6]:=",
 CellID->1398028897],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      FractionBox["4", "9"], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "t"}], "/", "2"}]], " ", 
      RowBox[{"C", "[", "1", "]"}]}]}], ",", 
    RowBox[{
     RowBox[{"y", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["2", "9"]}], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "t"}], "/", "2"}]], " ", 
      RowBox[{"C", "[", "1", "]"}]}]}]}], "}"}], "}"}]], "Output",
 ImageSize->{288, 32},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[6]=",
 CellID->890115282]
}, Open  ]],

Cell[TextData[{
 "\:041c\:043e\:0436\:0435\:043c, \:0442\:0430\:043a\:0436\:0435, \
\:0434\:043e\:0431\:0430\:0432\:0438\:0442\:044c \:043d\:0430\:0447\:0430\
\:043b\:044c\:043d\:044b\:0435 \:0443\:0441\:043b\:043e\:0432\:0438\:044f ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"x", "(", "\[Pi]", ")"}], "\[LongEqual]", "1"}], 
   TraditionalForm]], "InlineMath"],
 StyleBox[" \:0438 ",
  Deletable->True],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["x", "\[Prime]",
      MultilineFunction->None], "(", "\[Pi]", ")"}], "\[LongEqual]", "0"}], 
   TraditionalForm]], "InlineMath"],
 ", \:0432\:043a\:043b\:044e\:0447\:0438\:0432 \:0438\:0445 \:0432 \:043f\
\:0435\:0440\:0432\:044b\:0439 \:0430\:0440\:0433\:0443\:043c\:0435\:043d\
\:0442 \:0444\:0443\:043d\:043a\:0446\:0438\:0438 ",
 Cell[BoxData[
  ButtonBox["DSolve",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/DSolve"]], "InlineFormula"],
 ":"
}], "HowToText",
 CellID->1067006979],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dae2", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"x", "''"}], "[", "t", "]"}], "\[Equal]", 
     RowBox[{"y", "[", "t", "]"}]}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"x", "[", "t", "]"}], "+", 
      RowBox[{"y", "[", "t", "]"}]}], "\[Equal]", "0"}], ",", 
    RowBox[{
     RowBox[{"x", "[", "Pi", "]"}], "\[Equal]", "1"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"x", "'"}], "[", "Pi", "]"}], "\[Equal]", "0"}]}], 
   "}"}]}]], "Input",
 CellLabel->"In[3]:=",
 CellID->1697843603],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox["x", "\[Prime]\[Prime]",
      MultilineFunction->None], "[", "t", "]"}], "\[Equal]", 
    RowBox[{"y", "[", "t", "]"}]}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "t", "]"}], "+", 
     RowBox[{"y", "[", "t", "]"}]}], "\[Equal]", "0"}], ",", 
   RowBox[{
    RowBox[{"x", "[", "\[Pi]", "]"}], "\[Equal]", "1"}], ",", 
   RowBox[{
    RowBox[{
     SuperscriptBox["x", "\[Prime]",
      MultilineFunction->None], "[", "\[Pi]", "]"}], "\[Equal]", "0"}]}], 
  "}"}]], "Output",
 ImageSize->{336, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[3]=",
 CellID->328852717]
}, Open  ]],

Cell[TextData[{
 "\:0422\:0435\:043f\:0435\:0440\:044c \:0438\:0441\:043f\:043e\:043b\:044c\
\:0437\:0443\:0435\:043c ",
 Cell[BoxData[
  ButtonBox["DSolve",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/DSolve"]], "InlineFormula"],
 " \:0432\:043d\:043e\:0432\:044c, \:0447\:0442\:043e\:0431\:044b \
\:043f\:043e\:043b\:0443\:0447\:0438\:0442\:044c \:0440\:0435\:0448\:0435\
\:043d\:0438\:0435:"
}], "HowToText",
 CellID->1389965763],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{"dae2", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"x", "[", "t", "]"}], ",", 
     RowBox[{"y", "[", "t", "]"}]}], "}"}], ",", "t"}], "]"}]], "Input",
 CellLabel->"In[4]:=",
 CellID->411630083],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"x", "[", "t", "]"}], "\[Rule]", 
     RowBox[{"-", 
      RowBox[{"Cos", "[", "t", "]"}]}]}], ",", 
    RowBox[{
     RowBox[{"y", "[", "t", "]"}], "\[Rule]", 
     RowBox[{"Cos", "[", "t", "]"}]}]}], "}"}], "}"}]], "Output",
 ImageSize->{225, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[4]=",
 CellID->1552190888]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  InterpretationBox[
   StyleBox[
    GraphicsBox[{},
     BaselinePosition->Baseline,
     ImageSize->{6, 0}],
    CacheGraphics->False],
   Spacer[6]]]],
 "\:0423\:0447\:0435\:0431\:043d\:044b\:0435 \:043c\:0430\:0442\:0435\:0440\
\:0438\:0430\:043b\:044b"
}], "TutorialsSection",
 WholeCellGroupOpener->True,
 CellID->250839057],

Cell["", "SectionHeaderSpacer"],

Cell[BoxData[
 TemplateBox[{Cell["Differentiation"],"paclet:tutorial/Differentiation"},
  "RefLink",
  BaseStyle->"Tutorials"]], "Tutorials",
 CellID->233430250],

Cell[BoxData[
 TemplateBox[{
  Cell["Differential Equations"],"paclet:tutorial/DifferentialEquations"},
  "RefLink",
  BaseStyle->"Tutorials"]], "Tutorials",
 CellID->341631938],

Cell[BoxData[
 TemplateBox[{
  Cell["Introduction to Differential Equation Solving with DSolve"],
   "paclet:tutorial/DSolveIntroduction"},
  "RefLink",
  BaseStyle->"Tutorials"]], "Tutorials",
 CellID->1768818800],

Cell[BoxData[
 TemplateBox[{
  Cell["Differential Equation Solving with DSolve"],
   "paclet:tutorial/DSolveOverview"},
  "RefLink",
  BaseStyle->"Tutorials"]], "Tutorials",
 CellID->921446179],

Cell["", "SectionFooterSpacer"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  InterpretationBox[
   StyleBox[
    GraphicsBox[{},
     BaselinePosition->Baseline,
     ImageSize->{6, 0}],
    CacheGraphics->False],
   Spacer[6]]]],
 "\:0421\:043e\:043f\:0443\:0442\:0441\:0442\:0432\:0443\:044e\:0449\:0438\
\:0435 \:0440\:0430\:0437\:0434\:0435\:043b\:044b \:043a\:0440\:0430\:0442\
\:043a\:043e\:0433\:043e \:043a\:0443\:0440\:0441\:0430"
}], "RelatedLinksSection",
 WholeCellGroupOpener->True,
 CellID->1584193535],

Cell["", "SectionHeaderSpacer"],

Cell[TextData[ButtonBox["\:041a\:0440\:0430\:0442\:043a\:0438\:0439 \:043a\
\:0443\:0440\:0441: \:0420\:0430\:0431\:043e\:0442\:0430 \:0441 \:0434\:0438\
\:0444\:0444\:0435\:0440\:0435\:043d\:0446\:0438\:0430\:043b\:044c\:043d\:044b\
\:043c\:0438 \:0443\:0440\:0430\:0432\:043d\:0435\:043d\:0438\:044f\:043c\
\:0438",
 BaseStyle->"Hyperlink",
 ButtonData->{"WorkWithDifferentialEquationsRU.nb", None}]], "RelatedLinks",
 FontFamily->"Verdana",
 FontSize->11,
 CellID->405226890],

Cell["", "SectionFooterSpacer"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  InterpretationBox[
   StyleBox[
    GraphicsBox[{},
     BaselinePosition->Baseline,
     ImageSize->{6, 0}],
    CacheGraphics->False],
   Spacer[6]]]],
 "\:0421\:043c\:043e\:0442\:0440\:0438 \:0442\:0430\:043a\:0436\:0435"
}], "SeeAlsoSection",
 WholeCellGroupOpener->True,
 CellID->1255426704],

Cell[TextData[Cell[BoxData[
 TemplateBox[{Cell["DSolve"],"paclet:ref/DSolve"},
  "RefLink",
  BaseStyle->{
   "InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"]], "SeeAlso",
 CellID->929782353]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  InterpretationBox[
   StyleBox[
    GraphicsBox[{},
     BaselinePosition->Baseline,
     ImageSize->{6, 0}],
    CacheGraphics->False],
   Spacer[6]]]],
 "\:0423\:0437\:043d\:0430\:0442\:044c \:0431\:043e\:043b\:044c\:0448\:0435"
}], "MoreAboutSection",
 WholeCellGroupOpener->True,
 CellID->38303248],

Cell["", "SectionHeaderSpacer"],

Cell[BoxData[
 TemplateBox[{
  Cell["Differential Equations"],"paclet:guide/DifferentialEquations"},
  "RefLink",
  BaseStyle->"MoreAbout"]], "MoreAbout",
 CellID->1665078683],

Cell[BoxData[
 TemplateBox[{Cell["\"How to\" Topics"],"paclet:guide/HowToTopics"},
  "RefLink",
  BaseStyle->"MoreAbout"]], "MoreAbout",
 CellID->208153429]
}, Open  ]]
}, Open  ]],

Cell[" ", "FooterCell"]
},
FileChangeProtection->None,
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{Automatic, 510},
WindowMargins->{{312, Automatic}, {Automatic, 0}},
WindowFrame->"Normal",
WindowTitle->"Solve a Differential-Algebraic Equation - Wolfram Mathematica",
DockedCells->FEPrivate`FrontEndResource["FEExpressions", "HelpViewerToolbar"],
TaggingRules->{
 "ModificationHighlight" -> False, "ColorType" -> "TutorialColor", 
  "LinkTrails" -> "", "ExampleCounter" -> 1, "ExamplePageLinks" -> {}, 
  "RootCaptions" -> "", 
  "Metadata" -> {
   "built" -> "{2013, 1, 24, 22, 49, 16.0698335}", 
    "history" -> {"7", "", "", ""}, "context" -> "System`", 
    "keywords" -> {
     "solve a DAE", "DAE", "DiffAlgEq", "algebraic constraints", 
      "solving DAE"}, "specialkeywords" -> {}, 
    "tutorialcollectionlinks" -> {}, "index" -> True, "label" -> 
    "Mathematica How To", "language" -> "en", "paclet" -> "Mathematica", 
    "status" -> "None", "summary" -> 
    "Mathematica 's differential equation solving functions can be applied to \
many classes of differential equations, automatically selecting the \
appropriate algorithms without needing preprocessing by the user. One such \
class of equations is DAEs.", "synonyms" -> {}, "title" -> 
    "Solve a Differential-Algebraic Equation", "titlemodifier" -> "", 
    "windowtitle" -> "Solve a Differential-Algebraic Equation", "type" -> 
    "HowTo", "uri" -> "howto/SolveADifferentialAlgebraicEquation"}, 
  "SearchTextTranslated" -> ""},
Magnification->1.,
FrontEndVersion->"10.1 for Microsoft Windows (64-bit) (March 23, 2015)",
StyleDefinitions->FrontEnd`FileName[{"Wolfram"}, "Reference.nb", 
  CharacterEncoding -> "WindowsANSI"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[632, 21, 4623, 115, 48, "AnchorBarGrid",
 CellID->1],
Cell[CellGroupData[{
Cell[5280, 140, 446, 9, 122, "HowToTitle",
 CellID->509267359],
Cell[CellGroupData[{
Cell[5751, 153, 1839, 27, 108, "HowToAbstract",
 CellID->156687729],
Cell[7593, 182, 836, 27, 58, "HowToText",
 CellID->1834468513],
Cell[CellGroupData[{
Cell[8454, 213, 435, 16, 28, "Input",
 CellID->489578012],
Cell[8892, 231, 556, 19, 36, "Output",
 CellID->864055128]
}, Open  ]],
Cell[9463, 253, 723, 21, 40, "HowToText",
 CellID->812217608],
Cell[CellGroupData[{
Cell[10211, 278, 249, 8, 28, "Input",
 CellID->1398028897],
Cell[10463, 288, 749, 25, 53, "Output",
 CellID->890115282]
}, Open  ]],
Cell[11227, 316, 977, 27, 59, "HowToText",
 CellID->1067006979],
Cell[CellGroupData[{
Cell[12229, 347, 556, 19, 28, "Input",
 CellID->1697843603],
Cell[12788, 368, 704, 23, 36, "Output",
 CellID->328852717]
}, Open  ]],
Cell[13507, 394, 437, 11, 40, "HowToText",
 CellID->1389965763],
Cell[CellGroupData[{
Cell[13969, 409, 249, 8, 28, "Input",
 CellID->411630083],
Cell[14221, 419, 441, 15, 36, "Output",
 CellID->1552190888]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[14711, 440, 362, 13, 30, "TutorialsSection",
 CellID->250839057],
Cell[15076, 455, 31, 0, 14, "SectionHeaderSpacer"],
Cell[15110, 457, 161, 4, 19, "Tutorials",
 CellID->233430250],
Cell[15274, 463, 177, 5, 19, "Tutorials",
 CellID->341631938],
Cell[15454, 470, 214, 6, 19, "Tutorials",
 CellID->1768818800],
Cell[15671, 478, 193, 6, 19, "Tutorials",
 CellID->921446179],
Cell[15867, 486, 31, 0, 29, "SectionFooterSpacer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15935, 491, 472, 14, 30, "RelatedLinksSection",
 CellID->1584193535],
Cell[16410, 507, 31, 0, 14, "SectionHeaderSpacer"],
Cell[16444, 509, 478, 9, 18, "RelatedLinks",
 CellID->405226890],
Cell[16925, 520, 31, 0, 29, "SectionFooterSpacer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[16993, 525, 329, 12, 30, "SeeAlsoSection",
 CellID->1255426704],
Cell[17325, 539, 204, 5, 58, "SeeAlso",
 CellID->929782353]
}, Open  ]],
Cell[CellGroupData[{
Cell[17566, 549, 335, 12, 30, "MoreAboutSection",
 CellID->38303248],
Cell[17904, 563, 31, 0, 14, "SectionHeaderSpacer"],
Cell[17938, 565, 175, 5, 19, "MoreAbout",
 CellID->1665078683],
Cell[18116, 572, 156, 4, 19, "MoreAbout",
 CellID->208153429]
}, Open  ]]
}, Open  ]],
Cell[18299, 580, 23, 0, 41, "FooterCell"]
}
]
*)

(* End of internal cache information *)
