(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     62993,       1526]
NotebookOptionsPosition[     57575,       1360]
NotebookOutlinePosition[     59922,       1420]
CellTagsIndexPosition[     59842,       1415]
WindowTitle->Solve Delay Differential Equations - Wolfram Mathematica
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[GridBox[{
   {Cell["MATHEMATICA HOW TO", "PacletNameCell"], Cell[TextData[{
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "Tutorials",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"Tutorials", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->
         False], {"\<\"Introduction to Numerical Differential Equations\"\>":>
       Documentation`HelpLookup[
       "paclet:tutorial/IntroductionToNumericalDifferentialEquations"], \
"\<\"Numerical Solution of Differential Equations\"\>":>
       Documentation`HelpLookup[
       "paclet:tutorial/NumericalSolutionOfDifferentialEquations"], \
"\<\"Delay Differential Equations\"\>":>Documentation`HelpLookup[
       "paclet:tutorial/NDSolveDelayDifferentialEquations"]},
       Appearance->None,
       MenuAppearance->Automatic,
       MenuStyle->"Tutorials"]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "See Also",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"See Also", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->False], {"\<\"NDSolve\"\>":>Documentation`HelpLookup[
       "paclet:ref/NDSolve"], "\<\"Plot\"\>":>Documentation`HelpLookup[
       "paclet:ref/Plot"], "\<\"Evaluate\"\>":>Documentation`HelpLookup[
       "paclet:ref/Evaluate"], "\<\"PlotLegend\"\>":>Documentation`HelpLookup[
       "paclet:PlotLegends/ref/PlotLegend"]},
       Appearance->None,
       MenuAppearance->Automatic,
       MenuStyle->"SeeAlso"]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "Related Guides",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"Related Guides", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->False], {"\<\"Differential Equations\"\>":>
       Documentation`HelpLookup[
       "paclet:guide/DifferentialEquations"], "\<\"\\\"How to\\\" Topics\"\>":>
       Documentation`HelpLookup["paclet:guide/HowToTopics"]},
       Appearance->None,
       MenuAppearance->Automatic,
       MenuStyle->"MoreAbout"]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "URL",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"URL", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->
         False], {"\<\"howto/SolveDelayDifferentialEquations\"\>":>
       None, "\<\"Copy Mathematica URL\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell["howto/SolveDelayDifferentialEquations"]}, Visible -> 
            False]]; SelectionMove[
         DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; Null], 
       Delimiter, "\<\"Copy web URL\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell[
              BoxData[
               MakeBoxes[
                Hyperlink[
                "http://reference.wolfram.com/mathematica/howto/\
SolveDelayDifferentialEquations.html"], StandardForm]], "Input", 
              TextClipboardType -> "PlainText"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; 
        Null], "\<\"Go to web URL\"\>":>FrontEndExecute[{
         NotebookLocate[{
           URL[
            StringJoin[
            "http://reference.wolfram.com/mathematica/", 
             "howto/SolveDelayDifferentialEquations", ".html"]], None}]}]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}]
    }], "AnchorBar"]}
  }]], "AnchorBarGrid",
 CellID->1],

Cell[CellGroupData[{

Cell[TextData[{
 Cell["\:041a\:0440\:0430\:0442\:043a\:0438\:0439 \:043a\:0443\:0440\:0441 ", 
  "HowToTitlePrefix"],
 " ",
 "\:0420\:0435\:0448\:0435\:043d\:0438\:0435 \:0434\:0438\:0444\:0444\:0435\
\:0440\:0435\:043d\:0446\:0438\:0430\:043b\:044c\:043d\:044b\:0445 \:0443\
\:0440\:0430\:0432\:043d\:0435\:043d\:0438\:0439 \:0441 \:0437\:0430\:043f\
\:0430\:0437\:0434\:044b\:0432\:0430\:044e\:0449\:0438\:043c \:0430\:0440\
\:0433\:0443\:043c\:0435\:043d\:0442\:043e\:043c"
}], "HowToTitle",
 CellID->509267359],

Cell[CellGroupData[{

Cell[TextData[{
 "\:0412\:044b \:043c\:043e\:0436\:0435\:0442\:0435 \:0438\:0441\:043f\:043e\
\:043b\:044c\:0437\:043e\:0432\:0430\:0442\:044c \:0441\:0442\:0430\:043d\
\:0434\:0430\:0440\:0442\:043d\:0443\:044e \:0444\:0443\:043d\:043a\:0446\
\:0438\:044e \:0434\:043b\:044f \:0440\:0435\:0448\:0435\:043d\:0438\:044f \
\:0434\:0438\:0444\:0444\:0435\:0440\:0435\:043d\:0446\:0438\:0430\:043b\:044c\
\:043d\:044b\:0445 \:0443\:0440\:0430\:0432\:043d\:0435\:043d\:0438\:0439 ",
 Cell[BoxData[
  ButtonBox["NDSolve",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/NDSolve"]], "InlineFormula"],
 ", \:0434\:043b\:044f \:0447\:0438\:0441\:043b\:0435\:043d\:043d\:043e\:0433\
\:043e \:0440\:0435\:0448\:0435\:043d\:0438\:044f \:0434\:0438\:0444\:0444\
\:0435\:0440\:0435\:043d\:0446\:0438\:0430\:043b\:044c\:043d\:044b\:0445 \
\:0443\:0440\:0430\:0432\:043d\:0435\:043d\:0438\:0439 \:0441 \:0437\:0430\
\:043f\:0430\:0437\:0434\:044b\:0432\:0430\:044e\:0449\:0438\:043c \:0430\
\:0440\:0433\:0443\:043c\:0435\:043d\:0442\:043e\:043c (\:0414\:0423\:0417\
\:0410) \:0441 \:0444\:0438\:043a\:0441\:0438\:0440\:043e\:0432\:0430\:043d\
\:043d\:044b\:043c\:0438 \:0437\:0430\:043f\:0430\:0437\:0434\:044b\:0432\
\:0430\:043d\:0438\:044f\:043c\:0438. \:041f\:0440\:0438 \:044d\:0442\:043e\
\:043c, ",
 Cell[BoxData[
  ButtonBox["NDSolve",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/NDSolve"]], "InlineFormula"],
 " \:0432\:043e\:0437\:0432\:0440\:0430\:0449\:0430\:0435\:0442 \:0440\:0435\
\:0437\:0443\:043b\:044c\:0442\:0430\:0442 \:0432 \:0432\:0438\:0434\:0435 \
\:0438\:043d\:0442\:0435\:0440\:043f\:043e\:043b\:0438\:0440\:0443\:044e\:0449\
\:0435\:0439 \:0444\:0443\:043d\:043a\:0446\:0438\:0438, \:043a\:043e\:0442\
\:043e\:0440\:0430\:044f \:0437\:0430\:0442\:0435\:043c \:043c\:043e\:0436\
\:0435\:0442 \:0431\:044b\:0442\:044c \:043b\:0435\:0433\:043a\:043e \:0438\
\:0441\:043f\:043e\:043b\:044c\:0437\:043e\:0432\:0430\:043d\:0430 \:0441 \
\:0434\:0440\:0443\:0433\:0438\:043c\:0438 \:0444\:0443\:043d\:043a\:0446\
\:0438\:044f\:043c\:0438."
}], "HowToAbstract",
 CellID->1045883471],

Cell[TextData[{
 "\:0412\:043e\:0437\:044c\:043c\:0435\:043c \:0434\:0438\:0444\:0444\:0435\
\:0440\:0435\:043d\:0446\:0438\:0430\:043b\:044c\:043d\:043e\:0435 \:0443\
\:0440\:0430\:0432\:043d\:0435\:043d\:0438\:0435 \:043f\:0435\:0440\:0432\
\:043e\:0433\:043e \:043f\:043e\:0440\:044f\:0434\:043a\:0430 \:0441 \:0437\
\:0430\:043f\:0430\:0437\:0434\:044b\:0432\:0430\:044e\:0449\:0438\:043c \
\:0430\:0440\:0433\:0443\:043c\:0435\:043d\:0442\:043e\:043c, \:0441 \:0437\
\:0430\:0434\:0435\:0440\:0436\:043a\:043e\:0439 1 \:0438 \:0444\:0443\:043d\
\:043a\:0446\:0438\:0435\:0439 \:043f\:0440\:0435\:0434\:0438\:0441\:0442\
\:043e\:0440\:0438\:0438 ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["t", "2"], TraditionalForm]], "InlineMath"],
 ". \:0412\:043e\:0441\:043f\:043e\:043b\:044c\:0437\:0443\:0435\:043c\:0441\
\:044f \:0444\:0443\:043d\:043a\:0446\:0438\:0435\:0439 ",
 Cell[BoxData[
  ButtonBox["NDSolve",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/NDSolve"]], "InlineFormula"],
 " \:0434\:043b\:044f \:0440\:0435\:0448\:0435\:043d\:0438\:044f \:0443\:0440\
\:0430\:0432\:043d\:0435\:043d\:0438\:044f \:0438 \:0441\:043e\:0445\:0440\
\:0430\:043d\:0438\:043c \:0440\:0435\:0448\:0435\:043d\:0438\:0435 \:043f\
\:043e\:0434 \:0438\:043c\:0435\:043d\:0435\:043c ",
 Cell[BoxData["sol1"], "InlineFormula"],
 ". \:041f\:0435\:0440\:0432\:044b\:043c \:0430\:0440\:0433\:0443\:043c\:0435\
\:043d\:0442\:043e\:043c \:0444\:0443\:043d\:043a\:0446\:0438\:0438 ",
 Cell[BoxData[
  ButtonBox["NDSolve",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/NDSolve"]], "InlineFormula"],
 " \:044f\:0432\:043b\:044f\:0435\:0442\:0441\:044f \:0414\:0423\:0417\:0410, \
\:0432\:0442\:043e\:0440\:044b\:043c \:0430\:0440\:0433\:0443\:043c\:0435\
\:043d\:0442\:043e\:043c \:044f\:0432\:043b\:044f\:0435\:0442\:0441\:044f \
\:043f\:0435\:0440\:0435\:043c\:0435\:043d\:043d\:0430\:044f, \:0434\:043b\
\:044f \:043a\:043e\:0442\:043e\:0440\:043e\:0439 \:043d\:0430\:0445\:043e\
\:0434\:0438\:0442\:0441\:044f \:0440\:0435\:0448\:0435\:043d\:0438\:0435, \
\:0430 \:0442\:0440\:0435\:0442\:044c\:0438\:043c \:0430\:0440\:0433\:0443\
\:043c\:0435\:043d\:0442\:043e\:043c \:044f\:0432\:043b\:044f\:0435\:0442\
\:0441\:044f \:0434\:0438\:0430\:043f\:0430\:0437\:043e\:043d \:0437\:043d\
\:0430\:0447\:0435\:043d\:0438\:0439 \:043f\:0435\:0440\:0435\:043c\:0435\
\:043d\:043d\:043e\:0439:"
}], "HowToText",
 CellID->1009846402],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sol1", "=", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"x", "'"}], "[", "t", "]"}], "\[Equal]", 
       RowBox[{
        RowBox[{"x", "[", 
         RowBox[{"t", "-", "1"}], "]"}], 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"x", "[", "t", "]"}]}], ")"}]}]}], ",", 
      RowBox[{
       RowBox[{"x", "[", 
        RowBox[{"t", "/;", 
         RowBox[{"t", "\[LessEqual]", "0"}]}], "]"}], "\[Equal]", 
       RowBox[{"t", "^", "2"}]}]}], "}"}], ",", "x", ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", 
      RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "]"}]}]], "Input",
 CellLabel->"In[1]:=",
 CellID->411630083],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"x", "\[Rule]", 
    TagBox[
     RowBox[{"InterpolatingFunction", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "2.`"}], ",", "2.`"}], "}"}], "}"}], 
       ",", "\<\"<>\"\>"}], "]"}],
     False,
     Editable->False]}], "}"}], "}"}]], "Output",
 ImageSize->{317, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[1]=",
 CellID->638851236]
}, Open  ]],

Cell[TextData[{
 "\:041f\:0440\:0438 \:043f\:043e\:043c\:043e\:0449\:0438 \:0444\:0443\:043d\
\:043a\:0446\:0438\:0438 ",
 Cell[BoxData[
  ButtonBox["Plot",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Plot"]], "InlineFormula"],
 ", \:043f\:043e\:0441\:0442\:0440\:043e\:0438\:043c \:0433\:0440\:0430\:0444\
\:0438\:043a\:0438 \:0440\:0435\:0448\:0435\:043d\:0438\:044f ",
 Cell[BoxData[
  RowBox[{"x", "[", "t", "]"}]], "InlineFormula"],
 " \:0438 \:0435\:0433\:043e \:043f\:0435\:0440\:0432\:043e\:0439 \
\:043f\:0440\:043e\:0438\:0437\:0432\:043e\:0434\:043d\:043e\:0439 ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"x", "'"}], "[", "t", "]"}]], "InlineFormula"],
 ". \:0414\:043b\:044f \:0442\:043e\:0433\:043e, \:0447\:0442\:043e\:0431\
\:044b \:043e\:0442\:043e\:0431\:0440\:0430\:0437\:0438\:0442\:044c \:0433\
\:0440\:0430\:0444\:0438\:043a\:0438 \:0440\:0430\:0437\:043d\:044b\:043c \
\:0446\:0432\:0435\:0442\:043e\:043c, \:0432\:043e\:0441\:043f\:043e\:043b\
\:044c\:0437\:0443\:0435\:043c\:0441\:044f \:0444\:0443\:043d\:043a\:0446\
\:0438\:0435\:0439 ",
 Cell[BoxData[
  ButtonBox["Evaluate",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Evaluate"]], "InlineFormula"],
 ", \"\:043e\:0431\:0435\:0440\:043d\:0443\:0432\" \:0435\:0435 \:0432\:043e\
\:043a\:0440\:0443\:0433 \:0441\:043f\:0438\:0441\:043a\:0430 \:0438\:0437 \
\:0444\:0443\:043d\:043a\:0446\:0438\:0438 \:0438 \:0435\:0435 \:043f\:0440\
\:043e\:0438\:0437\:0432\:043e\:0434\:043d\:043e\:0439. \:041f\:043e\:043d\
\:0430\:0434\:043e\:0431\:0438\:0442\:0441\:044f, \:0442\:0430\:043a\:0436\
\:0435, \:0437\:0430\:0433\:0440\:0443\:0437\:0438\:0442\:044c \:043c\:043e\
\:0434\:0443\:043b\:044c \:043b\:0435\:0433\:0435\:043d\:0434 (Plot Legends \
Package), \:0435\:0441\:043b\:0438 \:043d\:0435\:043e\:0431\:0445\:043e\:0434\
\:0438\:043c\:043e \:0434\:043e\:0431\:0430\:0432\:0438\:0442\:044c \:043f\
\:043e\:044f\:0441\:043d\:0435\:043d\:0438\:044f \:043a \:0433\:0440\:0430\
\:0444\:0438\:043a\:0443:"
}], "HowToText",
 CellID->812217608],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<PlotLegends`\>\"", "]"}]], "Input",
 CellLabel->"In[2]:=",
 CellID->191378384],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "[", "t", "]"}], ",", 
       RowBox[{
        RowBox[{"x", "'"}], "[", "t", "]"}]}], "}"}], "/.", 
     RowBox[{"First", "[", "sol1", "]"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{"-", "1"}], ",", "5"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", " ", 
   RowBox[{"PlotLegend", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Style", "[", 
       RowBox[{
        RowBox[{"x", "[", "t", "]"}], ",", "14"}], "]"}], ",", 
      RowBox[{"Style", "[", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"x", "'"}], "[", "t", "]"}], ",", "14"}], "]"}]}], "}"}]}]}],
   "]"}]], "Input",
 CellLabel->"In[3]:=",
 CellID->1398028897],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJzt3etrXNd6x3H18qL/Rv8NgSltOC/MoZic4poi/CIKHZReZE6OzSFKMTYG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    "], {{0, 244}, {360, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{360, 244},
  PlotRange->{{0, 360}, {0, 244}}]], "Output",
 ImageSize->{364, 244},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"RasterizedOutput",
 CellLabel->"Out[3]=",
 CellID->67328657]
}, Open  ]],

Cell[TextData[{
 "\:0412\:043e\:0441\:043f\:043e\:043b\:044c\:0437\:0443\:0435\:043c\:0441\
\:044f ",
 Cell[BoxData[
  ButtonBox["Manipulate",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Manipulate"]], "InlineFormula"],
 " \:0434\:043b\:044f \:0438\:0437\:043c\:0435\:043d\:0435\:043d\:0438\:044f \
\:043d\:0430\:0447\:0430\:043b\:044c\:043d\:043e\:0439 \:0444\:0443\:043d\
\:043a\:0446\:0438\:0438:"
}], "HowToText",
 CellID->50667105],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"sol", " ", "=", " ", 
       RowBox[{"NDSolve", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"x", "'"}], "[", "t", "]"}], "\[Equal]", 
            RowBox[{
             RowBox[{"x", "[", 
              RowBox[{"t", "-", "1"}], "]"}], 
             RowBox[{"(", 
              RowBox[{"1", "-", 
               RowBox[{"x", "[", "t", "]"}]}], ")"}]}]}], ",", 
           RowBox[{
            RowBox[{"x", "[", 
             RowBox[{"t", "/;", 
              RowBox[{"t", "\[LessEqual]", "0"}]}], "]"}], "\[Equal]", 
            "\[Phi]"}]}], "}"}], ",", "x", ",", 
         RowBox[{"{", 
          RowBox[{"t", ",", 
           RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "]"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"Plot", "[", 
      RowBox[{
       RowBox[{"Evaluate", "[", 
        RowBox[{
         RowBox[{"x", "[", "t", "]"}], " ", "/.", " ", 
         RowBox[{"First", "[", "sol", "]"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", 
         RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "]"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Phi]", ",", 
     RowBox[{"{", 
      RowBox[{"0.1", ",", 
       RowBox[{"t", "^", "2"}], ",", 
       RowBox[{"Exp", "[", "t", "]"}], ",", 
       RowBox[{"Cos", "[", "t", "]"}], ",", " ", 
       RowBox[{"Sin", "[", "t", "]"}]}], "}"}]}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[4]:=",
 CellID->101537297],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`\[Phi]$$ = 0.1, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{
      Hold[$CellContext`\[Phi]$$], {0.1, $CellContext`t^2, E^$CellContext`t, 
       Cos[$CellContext`t], 
       Sin[$CellContext`t]}}}, Typeset`size$$ = {180., {59., 64.}}, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`\[Phi]$818$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`\[Phi]$$ = 0.1}, 
      "ControllerVariables" :> {
        Hold[$CellContext`\[Phi]$$, $CellContext`\[Phi]$818$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`sol = 
         NDSolve[{
           Derivative[
             1][$CellContext`x][$CellContext`t] == \
$CellContext`x[$CellContext`t - 1] (
              1 - $CellContext`x[$CellContext`t]), $CellContext`x[
              
              Condition[$CellContext`t, $CellContext`t <= 
               0]] == $CellContext`\[Phi]$$}, $CellContext`x, \
{$CellContext`t, -2, 2}]}, 
        Plot[
         Evaluate[
          ReplaceAll[
           $CellContext`x[$CellContext`t], 
           First[$CellContext`sol]]], {$CellContext`t, -2, 2}]], 
      "Specifications" :> {{$CellContext`\[Phi]$$, {
         0.1, $CellContext`t^2, E^$CellContext`t, 
          Cos[$CellContext`t], 
          Sin[$CellContext`t]}}}, "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{229., {104., 109.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 ImageSize->{233, 215},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[4]=",
 CellID->1150982298]
}, Open  ]],

Cell[TextData[{
 "\:0420\:0435\:0448\:0438\:043c \:0414\:0423\:0417\:0410 \:043f\:0435\:0440\
\:0432\:043e\:0433\:043e \:043f\:043e\:0440\:044f\:0434\:043a\:0430 \:0441 \
\:0434\:0432\:0443\:043c\:044f \:0444\:0438\:043a\:0441\:0438\:0440\:043e\
\:0432\:0430\:043d\:043d\:044b\:043c\:0438 \:0437\:0430\:043f\:0430\:0437\
\:0434\:044b\:0432\:0430\:043d\:0438\:044f\:043c\:0438, ",
 Cell[BoxData[
  FormBox["\[Pi]", TraditionalForm]], "InlineMath"],
 " \:0438 1, \:0438 \:0444\:0443\:043d\:043a\:0446\:0438\:0435\:0439 \:043f\
\:0440\:0435\:0434\:0438\:0441\:0442\:043e\:0440\:0438\:0438 ",
 Cell[BoxData[
  FormBox[
   RowBox[{"cos", "(", "t", ")"}], TraditionalForm]], "InlineMath"],
 ":"
}], "HowToText",
 CellID->1445501569],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sol2", "=", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"x", "'"}], "[", "t", "]"}], "\[Equal]", 
       RowBox[{
        RowBox[{"x", "[", "t", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"x", "[", 
           RowBox[{"t", "-", "\[Pi]"}], "]"}], "-", 
          RowBox[{
           RowBox[{"x", "'"}], "[", 
           RowBox[{"t", "-", "1"}], "]"}]}], ")"}]}]}], ",", 
      RowBox[{
       RowBox[{"x", "[", 
        RowBox[{"t", "/;", 
         RowBox[{"t", "\[LessEqual]", "0"}]}], "]"}], "\[Equal]", 
       RowBox[{"Cos", "[", "t", "]"}]}]}], "}"}], ",", "x", ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "8"}], "}"}]}], "]"}]}]], "Input",
 CellLabel->"In[5]:=",
 CellID->1967366364],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"x", "\[Rule]", 
    TagBox[
     RowBox[{"InterpolatingFunction", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"0.`", ",", "7.999999999999773`"}], "}"}], "}"}], 
       ",", "\<\"<>\"\>"}], "]"}],
     False,
     Editable->False]}], "}"}], "}"}]], "Output",
 ImageSize->{309, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[5]=",
 CellID->26790310]
}, Open  ]],

Cell[TextData[{
 "\:041f\:0440\:0438 \:043f\:043e\:043c\:043e\:0449\:0438 \:0444\:0443\:043d\
\:043a\:0446\:0438\:0438 ",
 Cell[BoxData[
  ButtonBox["Plot",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Plot"]], "InlineFormula"],
 " \:043f\:043e\:0441\:0442\:0440\:043e\:0438\:043c \:0433\:0440\:0430\:0444\
\:0438\:043a\:0438 \:0440\:0435\:0448\:0435\:043d\:0438\:044f ",
 Cell[BoxData[
  RowBox[{"x", "[", "t", "]"}]], "InlineFormula"],
 " \:0438 \:0435\:0433\:043e \:043f\:0435\:0440\:0432\:043e\:0439 \
\:043f\:0440\:043e\:0438\:0437\:0432\:043e\:0434\:043d\:043e\:0439 ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"x", "'"}], "[", "t", "]"}]], "InlineFormula"],
 ". \:0414\:043b\:044f \:0442\:043e\:0433\:043e, \:0447\:0442\:043e\:0431\
\:044b \:043e\:0442\:043e\:0431\:0440\:0430\:0437\:0438\:0442\:044c \:0438\
\:0445 \:0433\:0440\:0430\:0444\:0438\:043a\:0438 \:0440\:0430\:0437\:043d\
\:044b\:043c \:0446\:0432\:0435\:0442\:043e\:043c, \:0432\:043e\:0441\:043f\
\:043e\:043b\:044c\:0437\:0443\:0435\:043c\:0441\:044f \:0444\:0443\:043d\
\:043a\:0446\:0438\:0435\:0439 ",
 Cell[BoxData[
  ButtonBox["Evaluate",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Evaluate"]], "InlineFormula"],
 ", \"\:043e\:0431\:0435\:0440\:043d\:0443\:0432\" \:0435\:0435 \:0432\:043e\
\:043a\:0440\:0443\:0433 \:0441\:043f\:0438\:0441\:043a\:0430 \:0438\:0437 \
\:0444\:0443\:043d\:043a\:0446\:0438\:0438 \:0438 \:0435\:0435 \:043f\:0440\
\:043e\:0438\:0437\:0432\:043e\:0434\:043d\:043e\:0439:"
}], "HowToText",
 CellID->1991021187],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "[", "t", "]"}], ",", 
       RowBox[{
        RowBox[{"x", "'"}], "[", "t", "]"}]}], "}"}], "/.", 
     RowBox[{"First", "[", "sol2", "]"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "8"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", " ", 
   RowBox[{"PlotLegend", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Style", "[", 
       RowBox[{
        RowBox[{"x", "[", "t", "]"}], ",", "14"}], "]"}], ",", 
      RowBox[{"Style", "[", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"x", "'"}], "[", "t", "]"}], ",", "14"}], "]"}]}], "}"}]}]}],
   "]"}]], "Input",
 CellLabel->"In[6]:=",
 CellID->1002902355],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJztne9rHEl+h5UfL/Jv5MW9DATyJoiYY8/khbML5jb49oJZDsu3E21CbHyx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    "], {{0, 244}, {360, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{360, 244},
  PlotRange->{{0, 360}, {0, 244}}]], "Output",
 ImageSize->{364, 244},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"RasterizedOutput",
 CellLabel->"Out[6]=",
 CellID->354824955]
}, Open  ]],

Cell[TextData[{
 "\:0420\:0435\:0448\:0438\:043c \:0414\:0423\:0417\:0410 \:0432\:0442\:043e\
\:0440\:043e\:0433\:043e \:043f\:043e\:0440\:044f\:0434\:043a\:0430 \:0441 \
\:0444\:0438\:043a\:0441\:0438\:0440\:043e\:0432\:0430\:043d\:043d\:044b\:043c\
 \:0437\:0430\:043f\:0430\:0437\:0434\:044b\:0432\:0430\:043d\:0438\:0435\
\:043c 1 \:0438 \:0444\:0443\:043d\:043a\:0446\:0438\:0435\:0439 \:043f\:0440\
\:0435\:0434\:0438\:0441\:0442\:043e\:0440\:0438\:0438 ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["t", "2"], TraditionalForm]], "InlineMath"],
 ":"
}], "HowToText",
 CellID->171653936],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sol3", " ", "=", " ", 
  RowBox[{"NDSolve", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"x", "''"}], "[", "t", "]"}], "+", 
        RowBox[{"x", "[", 
         RowBox[{"t", "-", "1"}], "]"}]}], "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"x", "[", 
        RowBox[{"t", "/;", 
         RowBox[{"t", "\[LessEqual]", "0"}]}], "]"}], "\[Equal]", 
       RowBox[{"t", "^", "2"}]}]}], "}"}], ",", " ", "x", ",", " ", 
    RowBox[{"{", 
     RowBox[{"t", ",", " ", 
      RowBox[{"-", "1"}], ",", " ", "5"}], "}"}]}], "]"}]}]], "Input",
 CellLabel->"In[7]:=",
 CellID->1325696659],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"x", "\[Rule]", 
    TagBox[
     RowBox[{"InterpolatingFunction", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "1.`"}], ",", "5.`"}], "}"}], "}"}], 
       ",", "\<\"<>\"\>"}], "]"}],
     False,
     Editable->False]}], "}"}], "}"}]], "Output",
 ImageSize->{317, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[7]=",
 CellID->259995304]
}, Open  ]],

Cell[TextData[{
 "\:041f\:0440\:0438 \:043f\:043e\:043c\:043e\:0449\:0438 \:0444\:0443\:043d\
\:043a\:0446\:0438\:0438 ",
 Cell[BoxData[
  ButtonBox["Plot",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Plot"]], "InlineFormula"],
 " \:043f\:043e\:0441\:0442\:0440\:043e\:0438\:043c \:0433\:0440\:0430\:0444\
\:0438\:043a\:0438 \:0440\:0435\:0448\:0435\:043d\:0438\:044f ",
 Cell[BoxData[
  RowBox[{"x", "[", "t", "]"}]], "InlineFormula"],
 " \:0438 \:0435\:0433\:043e \:043f\:0435\:0440\:0432\:044b\:0445 \
\:0434\:0432\:0443\:0445 \:043f\:0440\:043e\:0438\:0437\:0432\:043e\:0434\
\:043d\:044b\:0445 ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"x", "'"}], "[", "t", "]"}]], "InlineFormula"],
 " \:0438 ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"x", "''"}], "[", "t", "]"}]], "InlineFormula"],
 ". \:0414\:043b\:044f \:0442\:043e\:0433\:043e, \:0447\:0442\:043e\:0431\
\:044b \:043e\:0442\:043e\:0431\:0440\:0430\:0437\:0438\:0442\:044c \:0433\
\:0440\:0430\:0444\:0438\:043a\:0438 \:0440\:0430\:0437\:043d\:044b\:043c \
\:0446\:0432\:0435\:0442\:043e\:043c, \:0432\:043e\:0441\:043f\:043e\:043b\
\:044c\:0437\:0443\:0435\:043c\:0441\:044f \:0444\:0443\:043d\:043a\:0446\
\:0438\:0435\:0439 ",
 Cell[BoxData[
  ButtonBox["Evaluate",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Evaluate"]], "InlineFormula"],
 ", \"\:043e\:0431\:0435\:0440\:043d\:0443\:0432\" \:0435\:0435 \:0432\:043e\
\:043a\:0440\:0443\:0433 \:0441\:043f\:0438\:0441\:043a\:0430 \:0438\:0437 \
\:0444\:0443\:043d\:043a\:0446\:0438\:0438 \:0438 \:0435\:0435 \:043f\:0440\
\:043e\:0438\:0437\:0432\:043e\:0434\:043d\:044b\:0445:"
}], "HowToText",
 CellID->587648809],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"x", "[", "t", "]"}], ",", 
       RowBox[{
        RowBox[{"x", "'"}], "[", "t", "]"}], ",", 
       RowBox[{
        RowBox[{"x", "''"}], "[", "t", "]"}]}], "}"}], "/.", 
     RowBox[{"First", "[", "sol3", "]"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", 
     RowBox[{"-", "1"}], ",", "5"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}], ",", " ", 
   RowBox[{"PlotLegend", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Style", "[", 
       RowBox[{
        RowBox[{"x", "[", "t", "]"}], ",", "14"}], "]"}], ",", 
      RowBox[{"Style", "[", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"x", "'"}], "[", "t", "]"}], ",", "14"}], "]"}], ",", 
      RowBox[{"Style", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"x", "''"}], "[", "t", "]"}], ",", "14"}], "]"}]}], "}"}]}], 
   ",", 
   RowBox[{"LegendPosition", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"0.8", ",", 
      RowBox[{"-", "0.8"}]}], "}"}]}]}], "]"}]], "Input",
 CellLabel->"In[8]:=",
 CellID->336240310],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJztnf1rHNd6x9WXH/pntD8VCv0HDOHeNm2pa7CbFHMLwi2RWyG3INNUplyZ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    "], {{0, 204}, {360, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{360, 204},
  PlotRange->{{0, 360}, {0, 204}}]], "Output",
 ImageSize->{364, 204},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"RasterizedOutput",
 CellLabel->"Out[8]=",
 CellID->625808843]
}, Open  ]],

Cell[TextData[{
 "\:0414\:043b\:044f \:0431\:043e\:043b\:0435\:0435 \:043f\:043e\:0434\:0440\
\:043e\:0431\:043d\:043e\:0433\:043e \:043e\:043f\:0438\:0441\:0430\:043d\
\:0438\:044f \:0442\:0435\:0440\:043c\:0438\:043d\:043e\:0432, \:0441\:0432\
\:044f\:0437\:0430\:043d\:043d\:044b\:0445 \:0441 \:0434\:0438\:0444\:0444\
\:0435\:0440\:0435\:043d\:0446\:0438\:0430\:043b\:044c\:043d\:044b\:043c\:0438\
 \:0443\:0440\:0430\:0432\:043d\:0435\:043d\:0438\:044f\:043c\:0438 \:0441 \
\:0437\:0430\:043f\:0430\:0437\:0434\:044b\:0432\:0430\:044e\:0449\:0438\:043c\
 \:0430\:0440\:0433\:0443\:043c\:0435\:043d\:0442\:043e\:043c, \:043e\:0431\
\:0440\:0430\:0442\:0438\:0442\:0435\:0441\:044c \:043a \:0440\:0430\:0437\
\:0434\:0435\:043b\:0443 ",
 ButtonBox["\"Delay Differential Equations\"",
  BaseStyle->"Link",
  ButtonData->"paclet:tutorial/NDSolveDelayDifferentialEquations"],
 "."
}], "HowToText",
 CellID->1025240252]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  InterpretationBox[
   StyleBox[
    GraphicsBox[{},
     BaselinePosition->Baseline,
     ImageSize->{6, 0}],
    CacheGraphics->False],
   Spacer[6]]]],
 "\:0423\:0447\:0435\:0431\:043d\:044b\:0435 \:043c\:0430\:0442\:0435\:0440\
\:0438\:0430\:043b\:044b"
}], "TutorialsSection",
 WholeCellGroupOpener->True,
 CellID->250839057],

Cell["", "SectionHeaderSpacer"],

Cell[BoxData[
 TemplateBox[{
  Cell["Introduction to Numerical Differential Equations"],
   "paclet:tutorial/IntroductionToNumericalDifferentialEquations"},
  "RefLink",
  BaseStyle->"Tutorials"]], "Tutorials",
 CellID->341631938],

Cell[BoxData[
 TemplateBox[{
  Cell["Numerical Solution of Differential Equations"],
   "paclet:tutorial/NumericalSolutionOfDifferentialEquations"},
  "RefLink",
  BaseStyle->"Tutorials"]], "Tutorials",
 CellID->1421575208],

Cell[BoxData[
 TemplateBox[{
  Cell["Delay Differential Equations"],
   "paclet:tutorial/NDSolveDelayDifferentialEquations"},
  "RefLink",
  BaseStyle->"Tutorials"]], "Tutorials",
 CellID->1351129331],

Cell["", "SectionFooterSpacer"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  InterpretationBox[
   StyleBox[
    GraphicsBox[{},
     BaselinePosition->Baseline,
     ImageSize->{6, 0}],
    CacheGraphics->False],
   Spacer[6]]]],
 "\:0421\:043e\:043f\:0443\:0442\:0441\:0442\:0432\:0443\:044e\:0449\:0438\
\:0435 \:0440\:0430\:0437\:0434\:0435\:043b\:044b \:043a\:0440\:0430\:0442\
\:043a\:043e\:0433\:043e \:043a\:0443\:0440\:0441\:0430"
}], "RelatedLinksSection",
 WholeCellGroupOpener->True,
 CellID->1584193535],

Cell["", "SectionHeaderSpacer"],

Cell[TextData[ButtonBox["\:041a\:0440\:0430\:0442\:043a\:0438\:0439 \:043a\
\:0443\:0440\:0441: \:0420\:0430\:0431\:043e\:0442\:0430 \:0441 \:0434\:0438\
\:0444\:0444\:0435\:0440\:0435\:043d\:0446\:0438\:0430\:043b\:044c\:043d\:044b\
\:043c\:0438 \:0443\:0440\:0430\:0432\:043d\:0435\:043d\:0438\:044f\:043c\
\:0438",
 BaseStyle->"Hyperlink",
 ButtonData->{"WorkWithDifferentialEquationsRU.nb", None}]], "RelatedLinks",
 FontFamily->"Verdana",
 FontSize->11,
 CellID->303051400],

Cell["", "SectionFooterSpacer"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  InterpretationBox[
   StyleBox[
    GraphicsBox[{},
     BaselinePosition->Baseline,
     ImageSize->{6, 0}],
    CacheGraphics->False],
   Spacer[6]]]],
 "\:0421\:043c\:043e\:0442\:0440\:0438 \:0442\:0430\:043a\:0436\:0435"
}], "SeeAlsoSection",
 WholeCellGroupOpener->True,
 CellID->1255426704],

Cell[TextData[{
 Cell[BoxData[
  TemplateBox[{Cell["NDSolve"],"paclet:ref/NDSolve"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  TemplateBox[{Cell["Plot"],"paclet:ref/Plot"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  TemplateBox[{Cell["Evaluate"],"paclet:ref/Evaluate"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  TemplateBox[{Cell["PlotLegend"],"paclet:PlotLegends/ref/PlotLegend"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"]
}], "SeeAlso",
 CellID->929782353]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  InterpretationBox[
   StyleBox[
    GraphicsBox[{},
     BaselinePosition->Baseline,
     ImageSize->{6, 0}],
    CacheGraphics->False],
   Spacer[6]]]],
 "\:0423\:0437\:043d\:0430\:0442\:044c \:0431\:043e\:043b\:044c\:0448\:0435"
}], "MoreAboutSection",
 WholeCellGroupOpener->True,
 CellID->38303248],

Cell["", "SectionHeaderSpacer"],

Cell[BoxData[
 TemplateBox[{
  Cell["Differential Equations"],"paclet:guide/DifferentialEquations"},
  "RefLink",
  BaseStyle->"MoreAbout"]], "MoreAbout",
 CellID->1665078683],

Cell[BoxData[
 TemplateBox[{Cell["\"How to\" Topics"],"paclet:guide/HowToTopics"},
  "RefLink",
  BaseStyle->"MoreAbout"]], "MoreAbout",
 CellID->1956829372]
}, Open  ]]
}, Open  ]],

Cell[" ", "FooterCell"]
},
FileChangeProtection->None,
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{Automatic, 510},
WindowMargins->{{312, Automatic}, {Automatic, 0}},
WindowFrame->"Normal",
WindowTitle->"Solve Delay Differential Equations - Wolfram Mathematica",
DockedCells->FEPrivate`FrontEndResource["FEExpressions", "HelpViewerToolbar"],
TaggingRules->{
 "ModificationHighlight" -> False, "ColorType" -> "TutorialColor", 
  "LinkTrails" -> "", "ExampleCounter" -> 1, "ExamplePageLinks" -> {}, 
  "RootCaptions" -> "", 
  "Metadata" -> {
   "built" -> "{2013, 1, 24, 22, 49, 20.9838335}", 
    "history" -> {"7", "", "", ""}, "context" -> "System`", 
    "keywords" -> {
     "solve DDE's", "plotting the results of DDE's", 
      "use NDSolve with delay differential equations", 
      "use NDsolve with DDE's", 
      "use Manipulate with delay differential equations", 
      "use Manipulate with DDE's"}, "specialkeywords" -> {}, 
    "tutorialcollectionlinks" -> {}, "index" -> True, "label" -> 
    "Mathematica How To", "language" -> "en", "paclet" -> "Mathematica", 
    "status" -> "None", "summary" -> 
    "You can use the standard differential equation solving function, NDSolve \
, to numerically solve delay differential equations with constant delays. It \
returns an interpolation function that can then be easily used with other \
functions.", "synonyms" -> {}, "title" -> 
    "Solve Delay Differential Equations", "titlemodifier" -> "", 
    "windowtitle" -> "Solve Delay Differential Equations", "type" -> "HowTo", 
    "uri" -> "howto/SolveDelayDifferentialEquations"}, "SearchTextTranslated" -> 
  ""},
Magnification->1.,
FrontEndVersion->"10.1 for Microsoft Windows (64-bit) (March 23, 2015)",
StyleDefinitions->FrontEnd`FileName[{"Wolfram"}, "Reference.nb", 
  CharacterEncoding -> "WindowsANSI"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "RasterizedOutput"->{
  Cell[14801, 363, 7150, 125, 265, "Output",
   CellTags->"RasterizedOutput",
   CellID->67328657],
  Cell[30857, 742, 8009, 139, 265, "Output",
   CellTags->"RasterizedOutput",
   CellID->354824955],
  Cell[43519, 1023, 8705, 151, 225, "Output",
   CellTags->"RasterizedOutput",
   CellID->625808843]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"RasterizedOutput", 59515, 1402}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[627, 21, 4826, 118, 48, "AnchorBarGrid",
 CellID->1],
Cell[CellGroupData[{
Cell[5478, 143, 514, 10, 91, "HowToTitle",
 CellID->509267359],
Cell[CellGroupData[{
Cell[6017, 157, 2093, 35, 92, "HowToAbstract",
 CellID->1045883471],
Cell[8113, 194, 2414, 42, 114, "HowToText",
 CellID->1009846402],
Cell[CellGroupData[{
Cell[10552, 240, 736, 24, 28, "Input",
 CellID->411630083],
Cell[11291, 266, 493, 18, 36, "Output",
 CellID->638851236]
}, Open  ]],
Cell[11799, 287, 2018, 38, 96, "HowToText",
 CellID->812217608],
Cell[13820, 327, 120, 3, 28, "Input",
 CellID->191378384],
Cell[CellGroupData[{
Cell[13965, 334, 833, 27, 47, "Input",
 CellID->1398028897],
Cell[14801, 363, 7150, 125, 265, "Output",
 CellTags->"RasterizedOutput",
 CellID->67328657]
}, Open  ]],
Cell[21966, 491, 441, 11, 40, "HowToText",
 CellID->50667105],
Cell[CellGroupData[{
Cell[22432, 506, 1622, 47, 65, "Input",
 CellID->101537297],
Cell[24057, 555, 2344, 54, 236, "Output",
 CellID->1150982298]
}, Open  ]],
Cell[26416, 612, 726, 15, 58, "HowToText",
 CellID->1445501569],
Cell[CellGroupData[{
Cell[27167, 631, 828, 26, 28, "Input",
 CellID->1967366364],
Cell[27998, 659, 481, 17, 36, "Output",
 CellID->26790310]
}, Open  ]],
Cell[28494, 679, 1523, 31, 78, "HowToText",
 CellID->1991021187],
Cell[CellGroupData[{
Cell[30042, 714, 812, 26, 47, "Input",
 CellID->1002902355],
Cell[30857, 742, 8009, 139, 265, "Output",
 CellTags->"RasterizedOutput",
 CellID->354824955]
}, Open  ]],
Cell[38881, 884, 593, 12, 39, "HowToText",
 CellID->171653936],
Cell[CellGroupData[{
Cell[39499, 900, 680, 21, 28, "Input",
 CellID->1325696659],
Cell[40182, 923, 493, 18, 36, "Output",
 CellID->259995304]
}, Open  ]],
Cell[40690, 944, 1635, 36, 78, "HowToText",
 CellID->587648809],
Cell[CellGroupData[{
Cell[42350, 984, 1166, 37, 65, "Input",
 CellID->336240310],
Cell[43519, 1023, 8705, 151, 225, "Output",
 CellTags->"RasterizedOutput",
 CellID->625808843]
}, Open  ]],
Cell[52239, 1177, 918, 16, 56, "HowToText",
 CellID->1025240252]
}, Open  ]],
Cell[CellGroupData[{
Cell[53194, 1198, 362, 13, 31, "TutorialsSection",
 CellID->250839057],
Cell[53559, 1213, 31, 0, 14, "SectionHeaderSpacer"],
Cell[53593, 1215, 230, 6, 19, "Tutorials",
 CellID->341631938],
Cell[53826, 1223, 223, 6, 19, "Tutorials",
 CellID->1421575208],
Cell[54052, 1231, 200, 6, 19, "Tutorials",
 CellID->1351129331],
Cell[54255, 1239, 31, 0, 29, "SectionFooterSpacer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[54323, 1244, 472, 14, 31, "RelatedLinksSection",
 CellID->1584193535],
Cell[54798, 1260, 31, 0, 14, "SectionHeaderSpacer"],
Cell[54832, 1262, 478, 9, 18, "RelatedLinks",
 CellID->303051400],
Cell[55313, 1273, 31, 0, 29, "SectionFooterSpacer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[55381, 1278, 329, 12, 31, "SeeAlsoSection",
 CellID->1255426704],
Cell[55713, 1292, 1064, 30, 58, "SeeAlso",
 CellID->929782353]
}, Open  ]],
Cell[CellGroupData[{
Cell[56814, 1327, 335, 12, 31, "MoreAboutSection",
 CellID->38303248],
Cell[57152, 1341, 31, 0, 14, "SectionHeaderSpacer"],
Cell[57186, 1343, 175, 5, 19, "MoreAbout",
 CellID->1665078683],
Cell[57364, 1350, 157, 4, 19, "MoreAbout",
 CellID->1956829372]
}, Open  ]]
}, Open  ]],
Cell[57548, 1358, 23, 0, 41, "FooterCell"]
}
]
*)

(* End of internal cache information *)
