(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    233789,       5378]
NotebookOptionsPosition[    222844,       5058]
NotebookOutlinePosition[    226407,       5132]
CellTagsIndexPosition[    226326,       5127]
WindowTitle->Work with Statistical Distributions - Wolfram Mathematica
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[GridBox[{
   {Cell["MATHEMATICA HOW TO", "PacletNameCell"], Cell[TextData[{
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "Tutorials",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"Tutorials", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->False], {"\<\"Continuous Distributions\"\>":>
       Documentation`HelpLookup[
       "paclet:tutorial/ContinuousDistributions"], "\<\"Discrete \
Distributions\"\>":>Documentation`HelpLookup[
       "paclet:tutorial/DiscreteDistributions"], "\<\"Random Number \
Generation\"\>":>Documentation`HelpLookup[
       "paclet:tutorial/RandomNumberGenerationOverview"], "\<\"Multivariate \
Statistics Package\"\>":>Documentation`HelpLookup[
       "paclet:MultivariateStatistics/tutorial/MultivariateStatistics"]},
       Appearance->None,
       MenuAppearance->Automatic,
       MenuStyle->"Tutorials"]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "See Also",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"See Also", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->False], {"\<\"NormalDistribution\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/NormalDistribution"], "\<\"PDF\"\>":>
       Documentation`HelpLookup["paclet:ref/PDF"], "\<\"Mean\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/Mean"], "\<\"BinomialDistribution\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/BinomialDistribution"], "\<\"RandomVariate\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/RandomVariate"], "\<\"CauchyDistribution\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/CauchyDistribution"], "\<\"PoissonDistribution\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/PoissonDistribution"], "\<\"ChiSquareDistribution\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/ChiSquareDistribution"], "\<\"GeometricDistribution\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/GeometricDistribution"], "\<\"GammaDistribution\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/GammaDistribution"], "\<\"Histogram\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/Histogram"], "\<\"CharacteristicFunction\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/CharacteristicFunction"], \
"\<\"FindDistributionParameters\"\>":>Documentation`HelpLookup[
       "paclet:ref/FindDistributionParameters"], "\<\"EstimatedDistribution\"\
\>":>Documentation`HelpLookup[
       "paclet:ref/EstimatedDistribution"], "\<\"LogLikelihood\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/LogLikelihood"], "\<\"ContourPlot\"\>":>
       Documentation`HelpLookup["paclet:ref/ContourPlot"]},
       Appearance->None,
       MenuAppearance->Automatic,
       MenuStyle->"SeeAlso"]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "Related Guides",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"Related Guides", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->False], {"\<\"Probability & Statistics\"\>":>
       Documentation`HelpLookup[
       "paclet:guide/ProbabilityAndStatistics"], "\<\"Parametric Statistical \
Distributions\"\>":>Documentation`HelpLookup[
       "paclet:guide/ParametricStatisticalDistributions"], "\<\"Derived \
Distributions\"\>":>Documentation`HelpLookup[
       "paclet:guide/DerivedDistributions"], "\<\"Normal-Related \
Distributions\"\>":>Documentation`HelpLookup[
       "paclet:guide/NormalRelatedDistributions"], "\<\"Discrete Univariate \
Distributions\"\>":>Documentation`HelpLookup[
       "paclet:guide/DiscreteUnivariateDistributions"], "\<\"Extreme Value \
Distributions\"\>":>Documentation`HelpLookup[
       "paclet:guide/ExtremeValueDistributions"], "\<\"Exponential-Related \
Distributions\"\>":>Documentation`HelpLookup[
       "paclet:guide/ExponentialRelatedDistributions"], "\<\"Heavy Tail \
Distributions\"\>":>Documentation`HelpLookup[
       "paclet:guide/HeavyTailDistributions"], "\<\"Urn Model Distributions\"\
\>":>Documentation`HelpLookup[
       "paclet:guide/UrnModelDistributions"], "\<\"Statistics\"\>":>
       Documentation`HelpLookup[
       "paclet:guide/Statistics"], "\<\"Descriptive Statistics\"\>":>
       Documentation`HelpLookup[
       "paclet:guide/DescriptiveStatistics"], "\<\"Multivariate Statistics \
Package\"\>":>Documentation`HelpLookup[
       "paclet:MultivariateStatistics/guide/MultivariateStatisticsPackage"], \
"\<\"\\\"How to\\\" Topics\"\>":>Documentation`HelpLookup[
       "paclet:guide/HowToTopics"]},
       Appearance->None,
       MenuAppearance->Automatic,
       MenuStyle->"MoreAbout"]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "URL",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"URL", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->
         False], {"\<\"howto/WorkWithStatisticalDistributions\"\>":>
       None, "\<\"Copy Mathematica URL\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell["howto/WorkWithStatisticalDistributions"]}, Visible -> 
            False]]; SelectionMove[
         DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; Null], 
       Delimiter, "\<\"Copy web URL\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell[
              BoxData[
               MakeBoxes[
                Hyperlink[
                "http://reference.wolfram.com/mathematica/howto/\
WorkWithStatisticalDistributions.html"], StandardForm]], "Input", 
              TextClipboardType -> "PlainText"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; 
        Null], "\<\"Go to web URL\"\>":>FrontEndExecute[{
         NotebookLocate[{
           URL[
            StringJoin[
            "http://reference.wolfram.com/mathematica/", 
             "howto/WorkWithStatisticalDistributions", ".html"]], None}]}]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}]
    }], "AnchorBar"]}
  }]], "AnchorBarGrid",
 CellID->1],

Cell[CellGroupData[{

Cell[TextData[{
 Cell["\:041a\:0440\:0430\:0442\:043a\:0438\:0439 \:043a\:0443\:0440\:0441 ", 
  "HowToTitlePrefix"],
 " ",
 "\:0420\:0430\:0431\:043e\:0442\:0430 \:0441\:043e \:0441\:0442\:0430\:0442\
\:0438\:0441\:0442\:0438\:0447\:0435\:0441\:043a\:0438\:043c\:0438 \:0440\
\:0430\:0441\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\:0438\:044f\:043c\
\:0438"
}], "HowToTitle",
 CellID->509267359],

Cell[CellGroupData[{

Cell[TextData[{
 "\:0421\:0442\:0430\:0442\:0438\:0441\:0442\:0438\:0447\:0435\:0441\:043a\
\:0438\:0435 \:0440\:0430\:0441\:043f\:0440\:0435\:0434\:0435\:043b\:0435\
\:043d\:0438\:044f \:043d\:0430\:0445\:043e\:0434\:044f\:0442 \:043f\:0440\
\:0438\:043c\:0435\:043d\:0435\:043d\:0438\:0435 \:0432 \:0440\:0430\:0437\
\:043b\:0438\:0447\:043d\:044b\:0445 \:043e\:0431\:043b\:0430\:0441\:0442\
\:044f\:0445 \:0437\:043d\:0430\:043d\:0438\:0439, \:0432\:043a\:043b\:044e\
\:0447\:0430\:044f \:0431\:0438\:043e\:043b\:043e\:0433\:0438\:044e, \:0441\
\:043e\:0446\:0438\:0430\:043b\:044c\:043d\:044b\:0435 \:0438 \:0435\:0441\
\:0442\:0435\:0441\:0442\:0432\:0435\:043d\:043d\:044b\:0435 \:043d\:0430\
\:0443\:043a\:0438. ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " \:043f\:0440\:0435\:0434\:0441\:0442\:0430\:0432\:043b\:044f\:0435\:0442 \
\:0441\:0442\:0430\:0442\:0438\:0441\:0442\:0438\:0447\:0435\:0441\:043a\:0438\
\:0435 \:0440\:0430\:0441\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\
\:0438\:044f \:0432 \:0432\:0438\:0434\:0435 \:0441\:0438\:043c\:0432\:043e\
\:043b\:044c\:043d\:044b\:0445 \:043e\:0431\:044a\:0435\:043a\:0442\:043e\
\:0432. \:041f\:043e\:043b\:044c\:0437\:043e\:0432\:0430\:0442\:0435\:043b\
\:044e \:0434\:043e\:0441\:0442\:0443\:043f\:043d\:044b \:0441\:0432\:043e\
\:0439\:0441\:0442\:0432\:0430, \:0440\:0435\:0437\:0443\:043b\:044c\:0442\
\:0430\:0442\:044b \:0438 \:0441\:043b\:0443\:0447\:0430\:0439\:043d\:044b\
\:0435 \:0447\:0438\:0441\:043b\:0430 \:0434\:043b\:044f \:0441\:043e\:0442\
\:0435\:043d \:0432\:0441\:0442\:0440\:043e\:0435\:043d\:043d\:044b\:0445 \
\:0438\:043b\:0438 \:043f\:043e\:043b\:044c\:0437\:043e\:0432\:0430\:0442\
\:0435\:043b\:044c\:0441\:043a\:0438\:0445 \:0440\:0430\:0441\:043f\:0440\
\:0435\:0434\:0435\:043b\:0435\:043d\:0438\:0439, \:043f\:0443\:0442\:0435\
\:043c \:043f\:0440\:0438\:043c\:0435\:043d\:0435\:043d\:0438\:044f \:0432\
\:0441\:0442\:0440\:043e\:0435\:043d\:043d\:044b\:0445 \:0432 ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " \:0444\:0443\:043d\:043a\:0446\:0438\:0439 \:043a \:043e\:0431\:044a\:0435\
\:043a\:0442\:0430\:043c."
}], "HowToAbstract",
 CellID->1045883471],

Cell[TextData[{
 "\:0421\:0442\:0430\:0442\:0438\:0441\:0442\:0438\:0447\:0435\:0441\:043a\
\:0438\:0435 \:0440\:0430\:0441\:043f\:0440\:0435\:0434\:0435\:043b\:0435\
\:043d\:0438\:044f \:044f\:0432\:043b\:044f\:044e\:0442\:0441\:044f \:043e\
\:0431\:044a\:0435\:043a\:0442\:0430\:043c\:0438 ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ":"
}], "HowToText",
 CellID->1009846402],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"NormalDistribution", "[", 
  RowBox[{"\[Mu]", ",", "\[Sigma]"}], "]"}]], "Input",
 CellLabel->"In[1]:=",
 CellID->827466675],

Cell[BoxData[
 RowBox[{"NormalDistribution", "[", 
  RowBox[{"\[Mu]", ",", "\[Sigma]"}], "]"}]], "Output",
 ImageSize->{170, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[1]=",
 CellID->355055]
}, Open  ]],

Cell[TextData[{
 "\:041c\:043e\:0436\:043d\:043e \:0432\:043e\:0441\:043f\:043e\:043b\:044c\
\:0437\:043e\:0432\:0430\:0442\:044c\:0441\:044f \:0444\:0443\:043d\:043a\
\:0446\:0438\:0435\:0439 ",
 Cell[BoxData[
  ButtonBox["PDF",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/PDF"]], "InlineFormula"],
 ", \:0447\:0442\:043e\:0431\:044b \:043f\:043e\:043b\:0443\:0447\:0438\:0442\
\:044c \:043f\:043b\:043e\:0442\:043d\:043e\:0441\:0442\:044c \:0432\:0435\
\:0440\:043e\:044f\:0442\:043d\:043e\:0441\:0442\:0438 \:0434\:043b\:044f \
\:0440\:0430\:0441\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\:0438\:044f\
:"
}], "HowToText",
 CellID->1389965763],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PDF", "[", 
  RowBox[{
   RowBox[{"NormalDistribution", "[", 
    RowBox[{"\[Mu]", ",", "\[Sigma]"}], "]"}], ",", "x"}], "]"}]], "Input",
 CellLabel->"In[2]:=",
 CellID->411630083],

Cell[BoxData[
 FractionBox[
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{"-", 
    FractionBox[
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"x", "-", "\[Mu]"}], ")"}], "2"], 
     RowBox[{"2", " ", 
      SuperscriptBox["\[Sigma]", "2"]}]]}]], 
  RowBox[{
   SqrtBox[
    RowBox[{"2", " ", "\[Pi]"}]], " ", "\[Sigma]"}]]], "Output",
 ImageSize->{56, 55},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[2]=",
 CellID->66488460]
}, Open  ]],

Cell[TextData[{
 "\:0427\:0438\:0441\:043b\:0435\:043d\:043d\:044b\:0439 \:0440\:0435\:0437\
\:0443\:043b\:044c\:0442\:0430\:0442 \:043c\:043e\:0436\:0435\:0442 \:0431\
\:044b\:0442\:044c \:043f\:043e\:043b\:0443\:0447\:0435\:043d \:043f\:043e\
\:0441\:043b\:0435 \:0432\:0432\:043e\:0434\:0430 \:0437\:043d\:0430\:0447\
\:0435\:043d\:0438\:0439 \:0434\:043b\:044f ",
 Cell[BoxData[
  FormBox["\[Mu]", TraditionalForm]], "InlineMath"],
 ", ",
 Cell[BoxData[
  FormBox["\[Sigma]", TraditionalForm]], "InlineMath"],
 " \:0438 ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]], "InlineMath"],
 "."
}], "HowToText",
 CellID->233545351],

Cell[TextData[{
 "\:041d\:0430\:043f\:0440\:0438\:043c\:0435\:0440, \:0440\:0430\:0441\:0441\
\:0447\:0438\:0442\:0430\:0435\:043c \:043f\:043b\:043e\:0442\:043d\:043e\
\:0441\:0442\:044c \:0434\:043b\:044f \:0447\:0438\:0441\:043b\:0435\:043d\
\:043d\:044b\:0445 \:0437\:043d\:0430\:0447\:0435\:043d\:0438\:0439 ",
 Cell[BoxData[
  FormBox["\[Mu]", TraditionalForm]], "InlineMath"],
 ", ",
 Cell[BoxData[
  FormBox["\[Sigma]", TraditionalForm]], "InlineMath"],
 " \:0438 ",
 Cell[BoxData[
  FormBox["x", TraditionalForm]], "InlineMath"],
 ":"
}], "HowToText",
 CellID->812217608],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PDF", "[", 
  RowBox[{
   RowBox[{"NormalDistribution", "[", 
    RowBox[{"2", ",", "3"}], "]"}], ",", "1.5"}], "]"}]], "Input",
 CellLabel->"In[3]:=",
 CellID->1398028897],

Cell[BoxData["0.13114657203397995`"], "Output",
 ImageSize->{60, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[3]=",
 CellID->44861024]
}, Open  ]],

Cell["\<\
\:0415\:0441\:0442\:0435\:0441\:0442\:0432\:0435\:043d\:043d\:043e, \:0441\
\:0438\:043c\:0432\:043e\:043b\:044c\:043d\:044b\:0435 \:0440\:0435\:0437\
\:0443\:043b\:044c\:0442\:0430\:0442\:044b \:043c\:043e\:0433\:0443\:0442 \
\:0438\:0441\:043f\:043e\:043b\:044c\:0437\:043e\:0432\:0430\:0442\:044c\:0441\
\:044f \:0432 \:0434\:0440\:0443\:0433\:0438\:0445 \:0444\:0443\:043d\:043a\
\:0446\:0438\:044f\:0445 \:0438 \:0432\:044b\:0440\:0430\:0436\:0435\:043d\
\:0438\:044f\:0445.\
\>", "HowToText",
 CellID->778662110],

Cell[TextData[{
 "\:0417\:0434\:0435\:0441\:044c \:0444\:0443\:043d\:043a\:0446\:0438\:044f \
\:043f\:043b\:043e\:0442\:043d\:043e\:0441\:0442\:0438 \:043f\:043e\:043a\
\:0430\:0437\:0430\:043d\:0430 \:043d\:0430 \:0433\:0440\:0430\:0444\:0438\
\:043a\:0435 \:043f\:0440\:0438 \:0437\:0430\:0434\:0430\:043d\:043d\:044b\
\:0445 \:0437\:043d\:0430\:0447\:0435\:043d\:0438\:044f\:0445 ",
 Cell[BoxData[
  FormBox["\[Mu]", TraditionalForm]], "InlineMath"],
 " \:0438 ",
 Cell[BoxData[
  FormBox["\[Sigma]", TraditionalForm]], "InlineMath"],
 ":"
}], "HowToText",
 CellID->672294008],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"PDF", "[", 
    RowBox[{
     RowBox[{"NormalDistribution", "[", 
      RowBox[{"2", ",", "3"}], "]"}], ",", "x"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"-", "5"}], ",", "10"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[4]:=",
 CellID->67990700],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJztnc9rFkcYx1/aHvoH9B9oL15a6KU9WHpooZbaQ6lFPITQGmswByu12qLp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    "], {{0, 124}, {180, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{180, 124},
  PlotRange->{{0, 180}, {0, 124}}]], "Output",
 ImageSize->{184, 124},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"RasterizedOutput",
 CellLabel->"Out[4]=",
 CellID->9203570]
}, Open  ]],

Cell[TextData[{
 "\:041f\:0440\:0438 \:043f\:043e\:043c\:043e\:0449\:0438 \:0432\:0441\:0442\
\:0440\:043e\:0435\:043d\:043d\:044b\:0445 \:0432 ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " \:0444\:0443\:043d\:043a\:0446\:0438\:0439, \:043c\:043e\:0436\:043d\:043e \
\:043d\:0430\:043f\:0440\:044f\:043c\:0443\:044e \:043e\:0446\:0435\:043d\
\:0438\:0432\:0430\:0442\:044c \:0442\:0430\:043a\:0438\:0435 \:0441\:0432\
\:043e\:0439\:0441\:0442\:0432\:0430 \:043a\:0430\:043a \:0441\:0440\:0435\
\:0434\:043d\:0435\:0435 \:0437\:043d\:0430\:0447\:0435\:043d\:0438\:0435, \
\:0434\:0438\:0441\:043f\:0435\:0440\:0441\:0438\:044f, \:0438\:043d\:0442\
\:0435\:0433\:0440\:0430\:043b\:044c\:043d\:0430\:044f \:0444\:0443\:043d\
\:043a\:0446\:0438\:044f \:0440\:0430\:0441\:043f\:0440\:0435\:0434\:0435\
\:043b\:0435\:043d\:0438\:044f, \:0445\:0430\:0440\:0430\:043a\:0442\:0435\
\:0440\:0438\:0441\:0442\:0438\:0447\:0435\:0441\:043a\:0430\:044f \:0444\
\:0443\:043d\:043a\:0446\:0438\:044f."
}], "HowToText",
 CellID->629632699],

Cell["\<\
\:0412\:043e\:0442 \:0441\:0440\:0435\:0434\:043d\:0435\:0435 \:0437\:043d\
\:0430\:0447\:0435\:043d\:0438\:0435 \:0434\:043b\:044f 100 \
\:043f\:043e\:043f\:044b\:0442\:043e\:043a \:043f\:0440\:0438 \:0431\:0438\
\:043d\:043e\:043c\:0438\:0430\:043b\:044c\:043d\:043e\:043c \:0440\:0430\
\:0441\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\:0438\:0438 \:0441 \
\:0432\:0435\:0440\:043e\:044f\:0442\:043d\:043e\:0441\:0442\:044c\:044e \
\:0432\:044b\:0438\:0433\:0440\:0430\:0448\:0430 .3:\
\>", "HowToText",
 CellID->146791716],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Mean", "[", 
  RowBox[{"BinomialDistribution", "[", 
   RowBox[{"100", ",", ".3"}], "]"}], "]"}]], "Input",
 CellLabel->"In[5]:=",
 CellID->57340868],

Cell[BoxData["30.`"], "Output",
 ImageSize->{25, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[5]=",
 CellID->306379219]
}, Open  ]],

Cell["\<\
\:041a\:0430\:043a \:0438 \:0444\:0443\:043d\:043a\:0446\:0438\:044f \:0440\
\:0430\:0441\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\:0438\:044f \
\:0432\:0435\:0440\:043e\:044f\:0442\:043d\:043e\:0441\:0442\:0438 (PDF), \
\:0445\:0430\:0440\:0430\:043a\:0442\:0435\:0440\:0438\:0441\:0442\:0438\:0447\
\:0435\:0441\:043a\:0430\:044f \:0444\:0443\:043d\:043a\:0446\:0438\:044f \
\:043e\:0434\:043d\:043e\:0437\:043d\:0430\:0447\:043d\:043e \:043e\:043f\
\:0440\:0435\:0434\:0435\:043b\:044f\:0435\:0442 \:0440\:0430\:0441\:043f\
\:0440\:0435\:0434\:0435\:043b\:0435\:043d\:0438\:0435.\
\>", "HowToText",
 CellID->99175431],

Cell["\<\
\:041f\:043e\:043b\:0443\:0447\:0438\:043c \:043e\:0431\:0449\:0443\:044e \
\:0444\:043e\:0440\:043c\:0443\:043b\:0443 \:0445\:0430\:0440\:0430\:043a\
\:0442\:0435\:0440\:0438\:0441\:0442\:0438\:0447\:0435\:0441\:043a\:043e\:0439\
 \:0444\:0443\:043d\:043a\:0446\:0438\:0438 \:0434\:043b\:044f \:0440\:0430\
\:0441\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\:0438\:044f \:041a\
\:043e\:0448\:0438:\
\>", "HowToText",
 CellID->298294267],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CharacteristicFunction", "[", 
  RowBox[{
   RowBox[{"CauchyDistribution", "[", 
    RowBox[{"\[Mu]", ",", "\[Sigma]"}], "]"}], ",", "t"}], "]"}]], "Input",
 CellLabel->"In[6]:=",
 CellID->687318132],

Cell[BoxData[
 SuperscriptBox["\[ExponentialE]", 
  RowBox[{
   RowBox[{"\[ImaginaryI]", " ", "t", " ", "\[Mu]"}], "-", 
   RowBox[{"t", " ", "\[Sigma]", " ", 
    RowBox[{"Sign", "[", "t", "]"}]}]}]]], "Output",
 ImageSize->{86, 17},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[6]=",
 CellID->799734107]
}, Open  ]],

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " \:0434\:0430\:0435\:0442 \:0432\:043e\:0437\:043c\:043e\:0436\:043d\:043e\
\:0441\:0442\:044c \:0432\:044b\:0447\:0438\:0441\:043b\:044f\:0442\:044c \
\:043e\:0436\:0438\:0434\:0430\:0435\:043c\:044b\:0435 \:0437\:043d\:0430\
\:0447\:0435\:043d\:0438\:044f \:0431\:043e\:043b\:0435\:0435 \:043e\:0431\
\:0449\:0435\:0433\:043e \:0432\:0438\:0434\:0430, \:0434\:0430\:044e\:0449\
\:0438\:0435 \:0432\:0435\:043b\:0438\:0447\:0438\:043d\:0443, \:043e\:0436\
\:0438\:0434\:0430\:0435\:043c\:0443\:044e \:0434\:043b\:044f \:0437\:0430\
\:0434\:0430\:043d\:043d\:043e\:0439 \:0444\:0443\:043d\:043a\:0446\:0438\
\:0438, \:043f\:0440\:0438\:043c\:0435\:043d\:0435\:043d\:043d\:043e\:0439 \
\:043a \:0441\:043b\:0443\:0447\:0430\:0439\:043d\:043e\:0439 \:0432\:0435\
\:043b\:0438\:0447\:0438\:043d\:0435 \:0438\:0437 \:0437\:0430\:0434\:0430\
\:043d\:043d\:043e\:0433\:043e \:0440\:0430\:0441\:043f\:0440\:0435\:0434\
\:0435\:043b\:0435\:043d\:0438\:044f. \:0422\:0430\:043a,  ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]], "InlineMath"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Null]", 
    RowBox[{"-", "\:044b\:0439"}]], TraditionalForm]]],
 " \:0430\:0431\:0441\:043e\:043b\:044e\:0442\:043d\:044b\:0439 \:043c\:043e\
\:043c\:0435\:043d\:0442 \:044f\:0432\:043b\:044f\:0435\:0442\:0441\:044f \
\:043e\:0436\:0438\:0434\:0430\:0435\:043c\:044b\:043c \:0437\:043d\:0430\
\:0447\:0435\:043d\:0438\:0435\:043c \:043f\:0435\:0440\:0435\:043c\:0435\
\:043d\:043d\:043e\:0439 ",
 Cell[BoxData[
  FormBox["X", TraditionalForm]], "InlineMath"],
 " \:0432\:043e\:0437\:0432\:0435\:0434\:0435\:043d\:043d\:043e\:0439 \:0432 ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]], "InlineMath"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["\[Null]", 
     RowBox[{"-", "\:0443\:044e"}]], " "}], TraditionalForm]]],
 "\:0441\:0442\:0435\:043f\:0435\:043d\:044c."
}], "HowToText",
 CellID->402844773],

Cell[TextData[{
 "\:041a \:043f\:0440\:0438\:043c\:0435\:0440\:0443, \:043d\:0430\:0439\:0434\
\:0435\:043c ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]], "InlineMath"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Null]", 
    RowBox[{"-", "\:044b\:0439"}]], TraditionalForm]]],
 " \:0430\:0431\:0441\:043e\:043b\:044e\:0442\:043d\:044b\:0439 \:043c\:043e\
\:043c\:0435\:043d\:0442 \:0434\:043b\:044f \:0441\:043b\:0443\:0447\:0430\
\:0439\:043d\:043e\:0439 \:043f\:0435\:0440\:0435\:043c\:0435\:043d\:043d\
\:043e\:0439 ",
 Cell[BoxData[
  FormBox["X", TraditionalForm]], "InlineMath"],
 " \:0432 \:041f\:0443\:0430\:0441\:0441\:043e\:043d\:043e\:0432\:043e\:043c \
\:0440\:0430\:0441\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\:0438\:0438\
:"
}], "HowToText",
 CellID->630216976],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Moment", "[", 
  RowBox[{
   RowBox[{"PoissonDistribution", "[", "\[Mu]", "]"}], ",", "n"}], 
  "]"}]], "Input",
 CellLabel->"In[7]:=",
 CellID->708638453],

Cell[BoxData[
 TagBox[GridBox[{
    {"\[Piecewise]", GridBox[{
       {
        RowBox[{"BellB", "[", 
         RowBox[{"n", ",", "\[Mu]"}], "]"}], 
        RowBox[{"n", "\[GreaterEqual]", "0"}]},
       {"0", 
        TagBox["True",
         "PiecewiseDefault",
         AutoDelete->True]}
      },
      AllowedDimensions->{2, Automatic},
      Editable->True,
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.84]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}},
      Selectable->True]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxItemSize->{
    "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.35]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  "Piecewise",
  DeleteWithContents->True,
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 ImageSize->{128, 27},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[7]=",
 CellID->2783892]
}, Open  ]],

Cell[TextData[{
 "\:0418\:0441\:043f\:043e\:043b\:044c\:0437\:043e\:0432\:0430\:043d\:0438\
\:0435 \:0444\:0443\:043d\:043a\:0446\:0438\:0438 ",
 Cell[BoxData[
  ButtonBox["RandomVariate",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/RandomVariate"]], "InlineFormula"],
 " \:0434\:0430\:0435\:0442 \:0432\:043e\:0437\:043c\:043e\:0436\:043d\:043e\
\:0441\:0442\:044c \:0433\:0435\:043d\:0435\:0440\:0438\:0440\:043e\:0432\
\:0430\:0442\:044c \:0441\:043b\:0443\:0447\:0430\:0439\:043d\:044b\:0435 \
\:0447\:0438\:0441\:043b\:0430 \:0438\:0437 \:0440\:0430\:0441\:043f\:0440\
\:0435\:0434\:0435\:043b\:0435\:043d\:0438\:0439."
}], "HowToText",
 CellID->39677951],

Cell[TextData[{
 "\:041d\:0430\:043f\:0440\:0438\:043c\:0435\:0440, \:0432\:043e\:0442 10 \
\:0447\:0438\:0441\:0435\:043b, \:0441\:0433\:0435\:043d\:0435\:0440\:0438\
\:0440\:043e\:0432\:0430\:043d\:043d\:044b\:0445 \:0438\:0437 \:0440\:0430\
\:0441\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\:0438\:044f ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Chi]", "2"], TraditionalForm]], "InlineMath"],
 " \:0441 15 \:0441\:0442\:0435\:043f\:0435\:043d\:044f\:043c\:0438 \:0441\
\:0432\:043e\:0431\:043e\:0434\:044b:"
}], "HowToText",
 CellID->418309923],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RandomVariate", "[", 
  RowBox[{
   RowBox[{"ChiSquareDistribution", "[", "15", "]"}], ",", "10"}], 
  "]"}]], "Input",
 CellLabel->"In[8]:=",
 CellID->157779646],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "13.63016092112991`", ",", "10.585104039547861`", ",", 
   "12.419666394841983`", ",", "8.527325253378919`", ",", 
   "16.797458758248126`", ",", "11.251590353770432`", ",", 
   "11.25499611933553`", ",", "7.761017640903739`", ",", 
   "19.251780680426286`", ",", "6.514117165026947`"}], "}"}]], "Output",
 ImageSize->{361, 33},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[8]=",
 CellID->259790926]
}, Open  ]],

Cell[TextData[{
 "\:0413\:0435\:043e\:043c\:0435\:0442\:0440\:0438\:0447\:0435\:0441\:043a\
\:043e\:0435 \:0440\:0430\:0441\:043f\:0440\:0435\:0434\:0435\:043b\:0435\
\:043d\:0438\:0435 \:043e\:043f\:0438\:0441\:044b\:0432\:0430\:0435\:0442 \
\:043a\:043e\:043b\:0438\:0447\:0435\:0441\:0442\:0432\:043e \:043f\:043e\
\:043f\:044b\:0442\:043e\:043a \:0434\:043e \:043d\:0435\:0443\:0434\:0430\
\:0447\:0438, \:0433\:0434\:0435 \:0441\:0443\:0449\:0435\:0441\:0442\:0432\
\:0443\:0435\:0442 \:0432\:0435\:0440\:043e\:044f\:0442\:043d\:043e\:0441\
\:0442\:044c \:0443\:0441\:043f\:0435\:0445\:0430 ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]], "InlineMath"],
 " \:0434\:043b\:044f \:043a\:0430\:0436\:0434\:043e\:0439 \:043f\:043e\:043f\
\:044b\:0442\:043a\:0438. "
}], "HowToText",
 CellID->104295875],

Cell[TextData[{
 "\:0421\:0433\:0435\:043d\:0435\:0440\:0438\:0440\:0443\:0435\:043c 20 \
\:0447\:0438\:0441\:0435\:043b \:0438\:0437 \:0433\:0435\:043e\:043c\:0435\
\:0442\:0440\:0438\:0447\:0435\:0441\:043a\:043e\:0433\:043e \:0440\:0430\
\:0441\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\:0438\:044f \:0441 \
\:043f\:0430\:0440\:0430\:043c\:0435\:0442\:0440\:043e\:043c \:0432\:0435\
\:0440\:043e\:044f\:0442\:043d\:043e\:0441\:0442\:0438 \:0443\:0441\:043f\
\:0435\:0445\:0430 ",
 Cell[BoxData[
  FormBox[
   RowBox[{"p", "=", 
    FractionBox["1", "3"]}], TraditionalForm]], "InlineMath"],
 ":"
}], "HowToText",
 CellID->28617757],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RandomVariate", "[", 
  RowBox[{
   RowBox[{"GeometricDistribution", "[", 
    RowBox[{"1", "/", "3"}], "]"}], ",", "20"}], "]"}]], "Input",
 CellLabel->"In[9]:=",
 CellID->258027569],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "7", ",", "1", ",", "1", ",", "1", ",", "4", ",", "2", ",", "0", ",", "5", 
   ",", "1", ",", "0", ",", "3", ",", "3", ",", "0", ",", "4", ",", "0", ",", 
   "7", ",", "0", ",", "6", ",", "0", ",", "1"}], "}"}]], "Output",
 ImageSize->{367, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[9]=",
 CellID->56376169]
}, Open  ]],

Cell["\<\
\:041c\:043e\:0436\:043d\:043e \:0442\:0430\:043a\:0436\:0435 \:0432\:0438\
\:0437\:0443\:0430\:043b\:0438\:0437\:0438\:0440\:043e\:0432\:0430\:0442\:044c\
 \:043f\:0440\:0438\:043c\:0435\:0440 \:043d\:0430 \:0444\:043e\:043d\:0435 \
\:0442\:0435\:043e\:0440\:0435\:0442\:0438\:0447\:0435\:0441\:043a\:043e\:0433\
\:043e \:0440\:0430\:0441\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\
\:0438\:044f, \:0441\:043e\:0432\:043c\:0435\:0449\:0430\:044f \:0433\:0440\
\:0430\:0444\:0438\:043a\:0438 \:0434\:0430\:043d\:043d\:044b\:0445 \:0438 \
\:0444\:0443\:043d\:043a\:0446\:0438\:0439.\
\>", "HowToText",
 CellID->266275792],

Cell[TextData[{
 "\:0421\:0433\:0435\:043d\:0435\:0440\:0438\:0440\:0443\:0435\:043c ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", "4"], TraditionalForm]], "InlineMath"],
 " \:0447\:0438\:0441\:0435\:043b \:0438\:0437 \
\:0433\:0430\:043c\:043c\:0430-\:0440\:0430\:0441\:043f\:0440\:0435\:0434\
\:0435\:043b\:0435\:043d\:0438\:044f, \:0438 \:0441\:043e\:0445\:0440\:0430\
\:043d\:0438\:043c \:0438\:0445 \:043f\:043e\:0434 \:0438\:043c\:0435\:043d\
\:0435\:043c ",
 Cell[BoxData[
  StyleBox["data", "TI"]], "InlineFormula"],
 ":"
}], "HowToText",
 CellID->754271],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"RandomVariate", "[", 
    RowBox[{
     RowBox[{"GammaDistribution", "[", 
      RowBox[{"4", ",", "12.5"}], "]"}], ",", 
     RowBox[{"10", "^", "4"}]}], "]"}]}], ";"}]], "Input",
 CellLabel->"In[10]:=",
 CellID->280764772],

Cell[TextData[{
 "\:0414\:0430\:043b\:0435\:0435, \:043f\:0440\:0438\:043c\:0435\:043d\:0438\
\:043c \:0444\:0443\:043d\:043a\:0446\:0438\:044e ",
 Cell[BoxData[
  ButtonBox["Histogram",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Histogram"]], "InlineFormula"],
 " \:0434\:043b\:044f \:043f\:043e\:0441\:0442\:0440\:043e\:0435\:043d\:0438\
\:044f \:0433\:0438\:0441\:0442\:043e\:0433\:0440\:0430\:043c\:043c\:044b \
\:044d\:0442\:0438\:0445 \:0437\:043d\:0430\:0447\:0435\:043d\:0438\:0439 \
\:043f\:043e \:0448\:043a\:0430\:043b\:0435 \:043f\:043b\:043e\:0442\:043d\
\:043e\:0441\:0442\:0438 \:0432\:0435\:0440\:043e\:044f\:0442\:043d\:043e\
\:0441\:0442\:0438:"
}], "HowToText",
 CellID->556967493],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"hist", "=", 
  RowBox[{"Histogram", "[", 
   RowBox[{"data", ",", "Automatic", ",", "\"\<ProbabilityDensity\>\""}], 
   "]"}]}]], "Input",
 CellLabel->"In[11]:=",
 CellID->482111473],

Cell[BoxData[
 GraphicsBox[
  {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
   EdgeForm[Opacity[0.7]], {}, 
   {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
    EdgeForm[Opacity[0.7]], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{0, 0}, {5, 0.00006}]},
        ImageSizeCache->{{25.499999999999996`, 29.904081632653057`}, {
         35.83222561310421, 37.09739687985891}}],
       StatusArea[#, 0.00006]& ,
       TagBoxNote->"0.00006"],
      StyleBox["0.00006`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.00006, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{5, 0}, {10, 0.00192}]},
        ImageSizeCache->{{28.904081632653057`, 33.30816326530612}, {
         27.611916343708316`, 37.09739687985891}}],
       StatusArea[#, 0.00192]& ,
       TagBoxNote->"0.00192"],
      StyleBox["0.00192`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.00192, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{10, 0}, {15, 0.00494}]},
        ImageSizeCache->{{32.30816326530612, 36.71224489795918}, {
         14.264962583721438`, 37.09739687985891}}],
       StatusArea[#, 0.00494]& ,
       TagBoxNote->"0.00494"],
      StyleBox["0.00494`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.00494, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{15, 0}, {20, 0.0092}]},
        ImageSizeCache->{{35.71224489795918, 
         40.11632653061224}, {-4.5621973558627005`, 37.09739687985891}}],
       StatusArea[#, 0.0092]& ,
       TagBoxNote->"0.0092"],
      StyleBox["0.0092`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.0092, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{20, 0}, {25, 0.0131}]},
        ImageSizeCache->{{39.11632653061224, 
         43.5204081632653}, {-21.798329694918607`, 37.09739687985891}}],
       StatusArea[#, 0.0131]& ,
       TagBoxNote->"0.0131"],
      StyleBox["0.0131`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.0131, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{25, 0}, {30, 0.01524}]},
        ImageSizeCache->{{42.5204081632653, 
         46.92448979591836}, {-31.25610487583645, 37.09739687985891}}],
       StatusArea[#, 0.01524]& ,
       TagBoxNote->"0.01524"],
      StyleBox["0.01524`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.01524, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{30, 0}, {35, 0.01728}]},
        ImageSizeCache->{{45.92448979591836, 
         50.32857142857142}, {-40.271927945496465`, 37.09739687985891}}],
       StatusArea[#, 0.01728]& ,
       TagBoxNote->"0.01728"],
      StyleBox["0.01728`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.01728, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{35, 0}, {40, 0.0192}]},
        ImageSizeCache->{{49.32857142857142, 
         53.73265306122448}, {-48.757408481647055`, 37.09739687985891}}],
       StatusArea[#, 0.0192]& ,
       TagBoxNote->"0.0192"],
      StyleBox["0.0192`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.0192, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{40, 0}, {45, 0.01754}]},
        ImageSizeCache->{{52.73265306122448, 
         57.13673469387754}, {-41.42100343476685, 37.09739687985891}}],
       StatusArea[#, 0.01754]& ,
       TagBoxNote->"0.01754"],
      StyleBox["0.01754`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.01754, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{45, 0}, {50, 0.0156}]},
        ImageSizeCache->{{56.13673469387754, 
         60.5408163265306}, {-32.847132476364685`, 37.09739687985891}}],
       StatusArea[#, 0.0156]& ,
       TagBoxNote->"0.0156"],
      StyleBox["0.0156`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.0156, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{50, 0}, {55, 0.01454}]},
        ImageSizeCache->{{59.5408163265306, 
         63.94489795918366}, {-28.162440097031556`, 37.09739687985891}}],
       StatusArea[#, 0.01454]& ,
       TagBoxNote->"0.01454"],
      StyleBox["0.01454`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.01454, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{55, 0}, {60, 0.01244}]},
        ImageSizeCache->{{62.94489795918366, 
         67.34897959183672}, {-18.881445760616835`, 37.09739687985891}}],
       StatusArea[#, 0.01244]& ,
       TagBoxNote->"0.01244"],
      StyleBox["0.01244`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.01244, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{60, 0}, {65, 0.01182}]},
        ImageSizeCache->{{66.34897959183672, 
         70.75306122448978}, {-16.141342670818204`, 37.09739687985891}}],
       StatusArea[#, 0.01182]& ,
       TagBoxNote->"0.01182"],
      StyleBox["0.01182`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.01182, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{65, 0}, {70, 0.00948}]},
        ImageSizeCache->{{69.75306122448978, 
         74.15714285714284}, {-5.799663267384666, 37.09739687985891}}],
       StatusArea[#, 0.00948]& ,
       TagBoxNote->"0.00948"],
      StyleBox["0.00948`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.00948, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{70, 0}, {75, 0.0078}]},
        ImageSizeCache->{{73.15714285714284, 77.5612244897959}, {
         1.625132201747114, 37.09739687985891}}],
       StatusArea[#, 0.0078]& ,
       TagBoxNote->"0.0078"],
      StyleBox["0.0078`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.0078, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{75, 0}, {80, 0.00622}]},
        ImageSizeCache->{{76.5612244897959, 80.96530612244898}, {
         8.607975559621039, 37.09739687985891}}],
       StatusArea[#, 0.00622]& ,
       TagBoxNote->"0.00622"],
      StyleBox["0.00622`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.00622, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{80, 0}, {85, 0.00524}]},
        ImageSizeCache->{{79.96530612244898, 84.36938775510204}, {
         12.939106249947908`, 37.09739687985891}}],
       StatusArea[#, 0.00524]& ,
       TagBoxNote->"0.00524"],
      StyleBox["0.00524`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.00524, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{85, 0}, {90, 0.00382}]},
        ImageSizeCache->{{83.36938775510204, 87.7734693877551}, {
         19.214826229809287`, 37.09739687985891}}],
       StatusArea[#, 0.00382]& ,
       TagBoxNote->"0.00382"],
      StyleBox["0.00382`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.00382, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{90, 0}, {95, 0.0035}]},
        ImageSizeCache->{{86.7734693877551, 91.17755102040816}, {
         20.629072985834384`, 37.09739687985891}}],
       StatusArea[#, 0.0035]& ,
       TagBoxNote->"0.0035"],
      StyleBox["0.0035`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.0035, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{95, 0}, {100, 0.00268}]},
        ImageSizeCache->{{90.17755102040816, 94.58163265306122}, {
         24.253080298148703`, 37.09739687985891}}],
       StatusArea[#, 0.00268]& ,
       TagBoxNote->"0.00268"],
      StyleBox["0.00268`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.00268, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{100, 0}, {105, 0.002}]},
        ImageSizeCache->{{93.58163265306122, 97.98571428571428}, {
         27.25835465470204, 37.09739687985891}}],
       StatusArea[#, 0.002]& ,
       TagBoxNote->"0.002"],
      StyleBox["0.002`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.002, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{105, 0}, {110, 0.0014}]},
        ImageSizeCache->{{96.98571428571428, 101.38979591836734`}, {
         29.910067322249102`, 37.09739687985891}}],
       StatusArea[#, 0.0014]& ,
       TagBoxNote->"0.0014"],
      StyleBox["0.0014`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.0014, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{110, 0}, {115, 0.00132}]},
        ImageSizeCache->{{100.38979591836734`, 104.7938775510204}, {
         30.263629011255375`, 37.09739687985891}}],
       StatusArea[#, 0.00132]& ,
       TagBoxNote->"0.00132"],
      StyleBox["0.00132`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.00132, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{115, 0}, {120, 0.00086}]},
        ImageSizeCache->{{103.7938775510204, 108.19795918367346`}, {
         32.29660872304146, 37.09739687985891}}],
       StatusArea[#, 0.00086]& ,
       TagBoxNote->"0.00086"],
      StyleBox["0.00086`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.00086, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{120, 0}, {125, 0.00076}]},
        ImageSizeCache->{{107.19795918367346`, 111.60204081632652`}, {
         32.7385608342993, 37.09739687985891}}],
       StatusArea[#, 0.00076]& ,
       TagBoxNote->"0.00076"],
      StyleBox["0.00076`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.00076, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{125, 0}, {130, 0.0005}]},
        ImageSizeCache->{{110.60204081632652`, 115.00612244897958`}, {
         33.887636323569694`, 37.09739687985891}}],
       StatusArea[#, 0.0005]& ,
       TagBoxNote->"0.0005"],
      StyleBox["0.0005`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.0005, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{130, 0}, {135, 0.00036}]},
        ImageSizeCache->{{114.00612244897958`, 118.41020408163264`}, {
         34.50636927933068, 37.09739687985891}}],
       StatusArea[#, 0.00036]& ,
       TagBoxNote->"0.00036"],
      StyleBox["0.00036`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.00036, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{135, 0}, {140, 0.00026}]},
        ImageSizeCache->{{117.41020408163264`, 121.8142857142857}, {
         34.94832139058852, 37.09739687985891}}],
       StatusArea[#, 0.00026]& ,
       TagBoxNote->"0.00026"],
      StyleBox["0.00026`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.00026, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{140, 0}, {145, 0.00024}]},
        ImageSizeCache->{{120.8142857142857, 125.21836734693876`}, {
         35.03671181284009, 37.09739687985891}}],
       StatusArea[#, 0.00024]& ,
       TagBoxNote->"0.00024"],
      StyleBox["0.00024`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.00024, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{145, 0}, {150, 0.0002}]},
        ImageSizeCache->{{124.21836734693876`, 128.6224489795918}, {
         35.213492657343224`, 37.09739687985891}}],
       StatusArea[#, 0.0002]& ,
       TagBoxNote->"0.0002"],
      StyleBox["0.0002`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.0002, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{150, 0}, {155, 0.0001}]},
        ImageSizeCache->{{127.62244897959181`, 132.02653061224487`}, {
         35.65544476860107, 37.09739687985891}}],
       StatusArea[#, 0.0001]& ,
       TagBoxNote->"0.0001"],
      StyleBox["0.0001`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.0001, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{155, 0}, {160, 0.00012}]},
        ImageSizeCache->{{131.02653061224487`, 135.43061224489796`}, {
         35.5670543463495, 37.09739687985891}}],
       StatusArea[#, 0.00012]& ,
       TagBoxNote->"0.00012"],
      StyleBox["0.00012`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.00012, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{160, 0}, {165, 0.00012}]},
        ImageSizeCache->{{134.43061224489796`, 138.83469387755102`}, {
         35.5670543463495, 37.09739687985891}}],
       StatusArea[#, 0.00012]& ,
       TagBoxNote->"0.00012"],
      StyleBox["0.00012`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.00012, {
        GrayLevel[0]}], "Tooltip"]& ], {}, 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{170, 0}, {175, 0.00004}]},
        ImageSizeCache->{{141.23877551020408`, 145.64285714285714`}, {
         35.92061603535578, 37.09739687985891}}],
       StatusArea[#, 0.00004]& ,
       TagBoxNote->"0.00004"],
      StyleBox["0.00004`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.00004, {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{175, 0}, {180, 0.00004}]},
        ImageSizeCache->{{144.64285714285714`, 149.0469387755102}, {
         35.92061603535578, 37.09739687985891}}],
       StatusArea[#, 0.00004]& ,
       TagBoxNote->"0.00004"],
      StyleBox["0.00004`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.00004, {
        GrayLevel[0]}], "Tooltip"]& ], {}, 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{185, 0}, {190, 0.00004}]},
        ImageSizeCache->{{151.45102040816326`, 155.85510204081632`}, {
         35.92061603535578, 37.09739687985891}}],
       StatusArea[#, 0.00004]& ,
       TagBoxNote->"0.00004"],
      StyleBox["0.00004`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.00004, {
        GrayLevel[0]}], "Tooltip"]& ], {}, {}, {}, {}, {}, 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{215, 0}, {220, 0.00002}]},
        ImageSizeCache->{{171.87551020408162`, 176.27959183673468`}, {
         36.00900645760734, 37.09739687985891}}],
       StatusArea[#, 0.00002]& ,
       TagBoxNote->"0.00002"],
      StyleBox["0.00002`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[0.00002, {
        GrayLevel[0]}], "Tooltip"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesOrigin->{0, 0},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  PlotRange->{{0, 220}, {All, All}},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.1]}},
  Ticks->{Automatic, Automatic}]], "Output",
 ImageSize->{184, 111},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[11]=",
 CellID->28860006]
}, Open  ]],

Cell[TextData[{
 "\:0414\:043b\:044f \:0432\:0438\:0437\:0443\:0430\:043b\:0438\:0437\:0430\
\:0446\:0438\:0438 \:0444\:0443\:043d\:043a\:0446\:0438\:0438 \:0442\:0435\
\:043e\:0440\:0435\:0442\:0438\:0447\:0435\:0441\:043a\:043e\:0439 \:043f\
\:043b\:043e\:0442\:043d\:043e\:0441\:0442\:0438, \:0432\:043e\:0441\:043f\
\:043e\:043b\:044c\:0437\:0443\:0435\:043c\:0441\:044f \:0444\:0443\:043d\
\:043a\:0446\:0438\:0435\:0439 ",
 Cell[BoxData[
  ButtonBox["Plot",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Plot"]], "InlineFormula"],
 ":"
}], "HowToText",
 CellID->694195944],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pl", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"PDF", "[", 
     RowBox[{
      RowBox[{"GammaDistribution", "[", 
       RowBox[{"4", ",", "12.5"}], "]"}], ",", "x"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "0", ",", "200"}], "}"}]}], "]"}]}]], "Input",
 CellLabel->"In[12]:=",
 CellID->69172925],

Cell[BoxData[
 GraphicsBox[
  TagBox[RasterBox[CompressedData["
1:eJztnU2LFEccxockh3yNfA0hhEQ8iAfREHIQD65k2IXggjEEk8vuRS8KQ3Jx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    "], {{0, 108}, {180, 0}}, {0, 255},
    ColorFunction->RGBColor],
   BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
   Selectable->False],
  BaseStyle->"ImageGraphics",
  ImageSize->Automatic,
  ImageSizeRaw->{180, 108},
  PlotRange->{{0, 180}, {0, 108}}]], "Output",
 ImageSize->{184, 108},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"RasterizedOutput",
 CellLabel->"Out[12]=",
 CellID->258406253]
}, Open  ]],

Cell[TextData[{
 "\:0418 \:043d\:0430\:043a\:043e\:043d\:0435\:0446, \:043f\:0440\:0438\:043c\
\:0435\:043d\:0438\:043c \:043a\:043e\:043c\:0430\:043d\:0434\:0443 ",
 Cell[BoxData[
  ButtonBox["Show",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/Show"]], "InlineFormula"],
 " \:0434\:043b\:044f \:043e\:0442\:043e\:0431\:0440\:0430\:0436\:0435\:043d\
\:0438\:044f \:0434\:0432\:0443\:0445 \:0433\:0440\:0430\:0444\:0438\:043a\
\:043e\:0432 \:0432\:043c\:0435\:0441\:0442\:0435:"
}], "HowToText",
 CellID->240448043],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", 
  RowBox[{"hist", ",", "pl"}], "]"}]], "Input",
 CellLabel->"In[13]:=",
 CellID->111337083],

Cell[BoxData[
 GraphicsBox[{
   {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
    EdgeForm[Opacity[0.7]], {}, 
    {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
     EdgeForm[Opacity[0.7]], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0, 0}, {5, 0.00006}]},
         ImageSizeCache->{{25.499999999999996`, 29.904081632653057`}, {
          35.83222561310421, 37.09739687985891}}],
        StatusArea[#, 0.00006]& ,
        TagBoxNote->"0.00006"],
       StyleBox["0.00006`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.00006, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{5, 0}, {10, 0.00192}]},
         ImageSizeCache->{{28.904081632653057`, 33.30816326530612}, {
          27.611916343708316`, 37.09739687985891}}],
        StatusArea[#, 0.00192]& ,
        TagBoxNote->"0.00192"],
       StyleBox["0.00192`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.00192, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{10, 0}, {15, 0.00494}]},
         ImageSizeCache->{{32.30816326530612, 36.71224489795918}, {
          14.264962583721438`, 37.09739687985891}}],
        StatusArea[#, 0.00494]& ,
        TagBoxNote->"0.00494"],
       StyleBox["0.00494`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.00494, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{15, 0}, {20, 0.0092}]},
         ImageSizeCache->{{35.71224489795918, 
          40.11632653061224}, {-4.5621973558627005`, 37.09739687985891}}],
        StatusArea[#, 0.0092]& ,
        TagBoxNote->"0.0092"],
       StyleBox["0.0092`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.0092, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{20, 0}, {25, 0.0131}]},
         ImageSizeCache->{{39.11632653061224, 
          43.5204081632653}, {-21.798329694918607`, 37.09739687985891}}],
        StatusArea[#, 0.0131]& ,
        TagBoxNote->"0.0131"],
       StyleBox["0.0131`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.0131, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{25, 0}, {30, 0.01524}]},
         ImageSizeCache->{{42.5204081632653, 
          46.92448979591836}, {-31.25610487583645, 37.09739687985891}}],
        StatusArea[#, 0.01524]& ,
        TagBoxNote->"0.01524"],
       StyleBox["0.01524`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.01524, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{30, 0}, {35, 0.01728}]},
         ImageSizeCache->{{45.92448979591836, 
          50.32857142857142}, {-40.271927945496465`, 37.09739687985891}}],
        StatusArea[#, 0.01728]& ,
        TagBoxNote->"0.01728"],
       StyleBox["0.01728`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.01728, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{35, 0}, {40, 0.0192}]},
         ImageSizeCache->{{49.32857142857142, 
          53.73265306122448}, {-48.757408481647055`, 37.09739687985891}}],
        StatusArea[#, 0.0192]& ,
        TagBoxNote->"0.0192"],
       StyleBox["0.0192`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.0192, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{40, 0}, {45, 0.01754}]},
         ImageSizeCache->{{52.73265306122448, 
          57.13673469387754}, {-41.42100343476685, 37.09739687985891}}],
        StatusArea[#, 0.01754]& ,
        TagBoxNote->"0.01754"],
       StyleBox["0.01754`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.01754, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{45, 0}, {50, 0.0156}]},
         ImageSizeCache->{{56.13673469387754, 
          60.5408163265306}, {-32.847132476364685`, 37.09739687985891}}],
        StatusArea[#, 0.0156]& ,
        TagBoxNote->"0.0156"],
       StyleBox["0.0156`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.0156, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{50, 0}, {55, 0.01454}]},
         ImageSizeCache->{{59.5408163265306, 
          63.94489795918366}, {-28.162440097031556`, 37.09739687985891}}],
        StatusArea[#, 0.01454]& ,
        TagBoxNote->"0.01454"],
       StyleBox["0.01454`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.01454, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{55, 0}, {60, 0.01244}]},
         ImageSizeCache->{{62.94489795918366, 
          67.34897959183672}, {-18.881445760616835`, 37.09739687985891}}],
        StatusArea[#, 0.01244]& ,
        TagBoxNote->"0.01244"],
       StyleBox["0.01244`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.01244, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{60, 0}, {65, 0.01182}]},
         ImageSizeCache->{{66.34897959183672, 
          70.75306122448978}, {-16.141342670818204`, 37.09739687985891}}],
        StatusArea[#, 0.01182]& ,
        TagBoxNote->"0.01182"],
       StyleBox["0.01182`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.01182, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{65, 0}, {70, 0.00948}]},
         ImageSizeCache->{{69.75306122448978, 
          74.15714285714284}, {-5.799663267384666, 37.09739687985891}}],
        StatusArea[#, 0.00948]& ,
        TagBoxNote->"0.00948"],
       StyleBox["0.00948`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.00948, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{70, 0}, {75, 0.0078}]},
         ImageSizeCache->{{73.15714285714284, 77.5612244897959}, {
          1.625132201747114, 37.09739687985891}}],
        StatusArea[#, 0.0078]& ,
        TagBoxNote->"0.0078"],
       StyleBox["0.0078`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.0078, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{75, 0}, {80, 0.00622}]},
         ImageSizeCache->{{76.5612244897959, 80.96530612244898}, {
          8.607975559621039, 37.09739687985891}}],
        StatusArea[#, 0.00622]& ,
        TagBoxNote->"0.00622"],
       StyleBox["0.00622`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.00622, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{80, 0}, {85, 0.00524}]},
         ImageSizeCache->{{79.96530612244898, 84.36938775510204}, {
          12.939106249947908`, 37.09739687985891}}],
        StatusArea[#, 0.00524]& ,
        TagBoxNote->"0.00524"],
       StyleBox["0.00524`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.00524, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{85, 0}, {90, 0.00382}]},
         ImageSizeCache->{{83.36938775510204, 87.7734693877551}, {
          19.214826229809287`, 37.09739687985891}}],
        StatusArea[#, 0.00382]& ,
        TagBoxNote->"0.00382"],
       StyleBox["0.00382`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.00382, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{90, 0}, {95, 0.0035}]},
         ImageSizeCache->{{86.7734693877551, 91.17755102040816}, {
          20.629072985834384`, 37.09739687985891}}],
        StatusArea[#, 0.0035]& ,
        TagBoxNote->"0.0035"],
       StyleBox["0.0035`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.0035, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{95, 0}, {100, 0.00268}]},
         ImageSizeCache->{{90.17755102040816, 94.58163265306122}, {
          24.253080298148703`, 37.09739687985891}}],
        StatusArea[#, 0.00268]& ,
        TagBoxNote->"0.00268"],
       StyleBox["0.00268`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.00268, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{100, 0}, {105, 0.002}]},
         ImageSizeCache->{{93.58163265306122, 97.98571428571428}, {
          27.25835465470204, 37.09739687985891}}],
        StatusArea[#, 0.002]& ,
        TagBoxNote->"0.002"],
       StyleBox["0.002`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.002, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{105, 0}, {110, 0.0014}]},
         ImageSizeCache->{{96.98571428571428, 101.38979591836734`}, {
          29.910067322249102`, 37.09739687985891}}],
        StatusArea[#, 0.0014]& ,
        TagBoxNote->"0.0014"],
       StyleBox["0.0014`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.0014, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{110, 0}, {115, 0.00132}]},
         ImageSizeCache->{{100.38979591836734`, 104.7938775510204}, {
          30.263629011255375`, 37.09739687985891}}],
        StatusArea[#, 0.00132]& ,
        TagBoxNote->"0.00132"],
       StyleBox["0.00132`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.00132, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{115, 0}, {120, 0.00086}]},
         ImageSizeCache->{{103.7938775510204, 108.19795918367346`}, {
          32.29660872304146, 37.09739687985891}}],
        StatusArea[#, 0.00086]& ,
        TagBoxNote->"0.00086"],
       StyleBox["0.00086`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.00086, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{120, 0}, {125, 0.00076}]},
         ImageSizeCache->{{107.19795918367346`, 111.60204081632652`}, {
          32.7385608342993, 37.09739687985891}}],
        StatusArea[#, 0.00076]& ,
        TagBoxNote->"0.00076"],
       StyleBox["0.00076`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.00076, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{125, 0}, {130, 0.0005}]},
         ImageSizeCache->{{110.60204081632652`, 115.00612244897958`}, {
          33.887636323569694`, 37.09739687985891}}],
        StatusArea[#, 0.0005]& ,
        TagBoxNote->"0.0005"],
       StyleBox["0.0005`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.0005, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{130, 0}, {135, 0.00036}]},
         ImageSizeCache->{{114.00612244897958`, 118.41020408163264`}, {
          34.50636927933068, 37.09739687985891}}],
        StatusArea[#, 0.00036]& ,
        TagBoxNote->"0.00036"],
       StyleBox["0.00036`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.00036, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{135, 0}, {140, 0.00026}]},
         ImageSizeCache->{{117.41020408163264`, 121.8142857142857}, {
          34.94832139058852, 37.09739687985891}}],
        StatusArea[#, 0.00026]& ,
        TagBoxNote->"0.00026"],
       StyleBox["0.00026`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.00026, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{140, 0}, {145, 0.00024}]},
         ImageSizeCache->{{120.8142857142857, 125.21836734693876`}, {
          35.03671181284009, 37.09739687985891}}],
        StatusArea[#, 0.00024]& ,
        TagBoxNote->"0.00024"],
       StyleBox["0.00024`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.00024, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{145, 0}, {150, 0.0002}]},
         ImageSizeCache->{{124.21836734693876`, 128.6224489795918}, {
          35.213492657343224`, 37.09739687985891}}],
        StatusArea[#, 0.0002]& ,
        TagBoxNote->"0.0002"],
       StyleBox["0.0002`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.0002, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{150, 0}, {155, 0.0001}]},
         ImageSizeCache->{{127.62244897959181`, 132.02653061224487`}, {
          35.65544476860107, 37.09739687985891}}],
        StatusArea[#, 0.0001]& ,
        TagBoxNote->"0.0001"],
       StyleBox["0.0001`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.0001, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{155, 0}, {160, 0.00012}]},
         ImageSizeCache->{{131.02653061224487`, 135.43061224489796`}, {
          35.5670543463495, 37.09739687985891}}],
        StatusArea[#, 0.00012]& ,
        TagBoxNote->"0.00012"],
       StyleBox["0.00012`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.00012, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{160, 0}, {165, 0.00012}]},
         ImageSizeCache->{{134.43061224489796`, 138.83469387755102`}, {
          35.5670543463495, 37.09739687985891}}],
        StatusArea[#, 0.00012]& ,
        TagBoxNote->"0.00012"],
       StyleBox["0.00012`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.00012, {
         GrayLevel[0]}], "Tooltip"]& ], {}, 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{170, 0}, {175, 0.00004}]},
         ImageSizeCache->{{141.23877551020408`, 145.64285714285714`}, {
          35.92061603535578, 37.09739687985891}}],
        StatusArea[#, 0.00004]& ,
        TagBoxNote->"0.00004"],
       StyleBox["0.00004`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.00004, {
         GrayLevel[0]}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{175, 0}, {180, 0.00004}]},
         ImageSizeCache->{{144.64285714285714`, 149.0469387755102}, {
          35.92061603535578, 37.09739687985891}}],
        StatusArea[#, 0.00004]& ,
        TagBoxNote->"0.00004"],
       StyleBox["0.00004`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.00004, {
         GrayLevel[0]}], "Tooltip"]& ], {}, 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{185, 0}, {190, 0.00004}]},
         ImageSizeCache->{{151.45102040816326`, 155.85510204081632`}, {
          35.92061603535578, 37.09739687985891}}],
        StatusArea[#, 0.00004]& ,
        TagBoxNote->"0.00004"],
       StyleBox["0.00004`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.00004, {
         GrayLevel[0]}], "Tooltip"]& ], {}, {}, {}, {}, {}, 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{215, 0}, {220, 0.00002}]},
         ImageSizeCache->{{171.87551020408162`, 176.27959183673468`}, {
          36.00900645760734, 37.09739687985891}}],
        StatusArea[#, 0.00002]& ,
        TagBoxNote->"0.00002"],
       StyleBox["0.00002`", {
         GrayLevel[0]}, StripOnInput -> False]],
      Annotation[#, 
       Style[0.00002, {
         GrayLevel[0]}], "Tooltip"]& ]}, {}, {}}, {{}, {}, 
    {Hue[0.67, 0.6, 0.6], LineBox[CompressedData["
1:eJwVlnc8lY8XxxEaKDsJyRYRIUnPOa4ZUfbe173XCqFQIg0j6976RpEoRCmS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      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesOrigin->{0, 0},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  PlotRange->{{0, 220}, {All, All}},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.1]}},
  Ticks->{Automatic, Automatic}]], "Output",
 ImageSize->{184, 111},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[13]=",
 CellID->177235876]
}, Open  ]],

Cell[TextData[{
 "\:0427\:0430\:0441\:0442\:043e \:0442\:0440\:0435\:0431\:0443\:0435\:0442\
\:0441\:044f \:043e\:0446\:0435\:043d\:0438\:0442\:044c \:0437\:043d\:0430\
\:0447\:0435\:043d\:0438\:044f \:043f\:0430\:0440\:0430\:043c\:0435\:0442\
\:0440\:0430, \:0438\:0441\:0445\:043e\:0434\:044f \:0438\:0437 \:043f\:0440\
\:0435\:0434\:043f\:043e\:043b\:043e\:0436\:0435\:043d\:0438\:044f, \:0447\
\:0442\:043e \:043c\:0430\:0441\:0441\:0438\:0432 \:0434\:0430\:043d\:043d\
\:044b\:0445 \:043f\:043e\:0434\:0447\:0438\:043d\:044f\:0435\:0442\:0441\
\:044f \:043e\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\:043d\:043e\
\:043c\:0443 \:0440\:0430\:0441\:043f\:0440\:0435\:0434\:0435\:043b\:0435\
\:043d\:0438\:044e. \:041a \:043f\:0440\:0438\:043c\:0435\:0440\:0443, \:043d\
\:0430\:0439\:0434\:0435\:043c \:043f\:0440\:043e\:0433\:043d\:043e\:0437 \
\:043c\:0430\:043a\:0441\:0438\:043c\:0430\:043b\:044c\:043d\:043e\:0433\:043e\
 \:043f\:0440\:0430\:0432\:0434\:043e\:043f\:043e\:0434\:043e\:0431\:0438\
\:044f \:043f\:0430\:0440\:0430\:043c\:0435\:0442\:0440\:043e\:0432, \:0438\
\:0441\:043f\:043e\:043b\:044c\:0437\:0443\:044f \:0444\:0443\:043d\:043a\
\:0446\:0438\:044e ",
 Cell[BoxData[
  ButtonBox["FindDistributionParameters",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/FindDistributionParameters"]], "InlineFormula"],
 ":"
}], "HowToText",
 CellID->728646805],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"alphabeta", "=", 
  RowBox[{"FindDistributionParameters", "[", 
   RowBox[{"data", ",", 
    RowBox[{"GammaDistribution", "[", 
     RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}]}], "]"}]}]], "Input",
 CellLabel->"In[14]:=",
 CellID->57229847],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\[Alpha]", "\[Rule]", "3.9863760348524226`"}], ",", 
   RowBox[{"\[Beta]", "\[Rule]", "12.503958090576328`"}]}], "}"}]], "Output",
 ImageSize->{168, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[14]=",
 CellID->199766588]
}, Open  ]],

Cell[TextData[{
 "\:041f\:0440\:0438 \:043f\:043e\:043c\:043e\:0449\:0438 \:0444\:0443\:043d\
\:043a\:0446\:0438\:0438 ",
 Cell[BoxData[
  ButtonBox["EstimatedDistribution",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/EstimatedDistribution"]], "InlineFormula"],
 ", \:0440\:0435\:0437\:0443\:043b\:044c\:0442\:0430\:0442\:044b \:043c\:043e\
\:0433\:0443\:0442 \:0431\:044b\:0442\:044c \:0441\:0433\:0440\:0443\:043f\
\:043f\:0438\:0440\:043e\:0432\:0430\:043d\:044b \:0432 \:043e\:0431\:044a\
\:0435\:043a\:0442, \:043f\:0440\:0435\:0434\:0441\:0442\:0430\:0432\:043b\
\:044f\:044e\:0449\:0438\:0439 \:0441\:043e\:0431\:043e\:0439 \:0440\:0430\
\:0441\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\:0438\:0435:"
}], "HowToText",
 CellID->382640798],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"gdist", "=", 
  RowBox[{"EstimatedDistribution", "[", 
   RowBox[{"data", ",", 
    RowBox[{"GammaDistribution", "[", 
     RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}]}], "]"}]}]], "Input",
 CellLabel->"In[15]:=",
 CellID->337779839],

Cell[BoxData[
 RowBox[{"GammaDistribution", "[", 
  RowBox[{"3.9863760348524226`", ",", "12.503958090576328`"}], 
  "]"}]], "Output",
 ImageSize->{239, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[15]=",
 CellID->646541239]
}, Open  ]],

Cell[TextData[{
 "\:041c\:043e\:0436\:043d\:043e \:0432\:044b\:0447\:0438\:0441\:043b\:0438\
\:0442\:044c \:0442\:0430\:043a\:0436\:0435 \:0438 \:043b\:043e\:0433\:0430\
\:0440\:0438\:0444\:043c\:0438\:0447\:0435\:0441\:043a\:043e\:0435 \:043f\
\:0440\:0430\:0432\:0434\:043e\:043f\:043e\:0434\:043e\:0431\:0438\:0435, \
\:043f\:0440\:0438\:043c\:0435\:043d\:0438\:0432 \:0444\:0443\:043d\:043a\
\:0446\:0438\:044e ",
 Cell[BoxData[
  ButtonBox["LogLikelihood",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/LogLikelihood"]], "InlineFormula"],
 " \:043a \:043e\:0446\:0435\:043d\:0438\:0432\:0430\:0435\:043c\:043e\:043c\
\:0443 \:0440\:0430\:0441\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\
\:0438\:044e:"
}], "HowToText",
 CellID->303559119],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LogLikelihood", "[", 
  RowBox[{"gdist", ",", "gdata"}], "]"}]], "Input",
 CellLabel->"In[16]:=",
 CellID->260996726],

Cell[BoxData[
 RowBox[{"LogLikelihood", "[", 
  RowBox[{
   RowBox[{"GammaDistribution", "[", 
    RowBox[{"3.9863760348524226`", ",", "12.503958090576328`"}], "]"}], ",", 
   "gdata"}], "]"}]], "Output",
 ImageSize->{390, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[16]=",
 CellID->51635081]
}, Open  ]],

Cell[TextData[{
 "\:0417\:043d\:0430\:0447\:0435\:043d\:0438\:0435 \:043b\:043e\:0433\:0430\
\:0440\:0438\:0444\:043c\:0438\:0447\:0435\:0441\:043a\:043e\:0433\:043e \
\:043f\:0440\:0430\:0432\:0434\:043e\:043f\:043e\:0434\:043e\:0431\:0438\:044f\
 \:0433\:043b\:0430\:0432\:043d\:044b\:043c \:043e\:0431\:0440\:0430\:0437\
\:043e\:043c \:0443\:043c\:0435\:0441\:0442\:043d\:043e \:043f\:0440\:0438 \
\:0441\:0440\:0430\:0432\:043d\:0435\:043d\:0438\:0438 \:0441\:043e \:0437\
\:043d\:0430\:0447\:0435\:043d\:0438\:044f\:043c\:0438 \:043b\:043e\:0433\
\:0430\:0440\:0438\:0444\:043c\:0438\:0447\:0435\:0441\:043a\:043e\:0433\:043e\
 \:043f\:0440\:0430\:0432\:0434\:043e\:043f\:043e\:0434\:043e\:0431\:0438\
\:044f \:0434\:0440\:0443\:0433\:0438\:0445 \:043f\:0430\:0440\:0430\:043c\
\:0435\:0442\:0440\:043e\:0432. \:0421\:043e\:0437\:0434\:0430\:043d\:0438\
\:0435 \:043a\:043e\:043d\:0442\:0443\:0440\:043d\:043e\:0433\:043e \:0433\
\:0440\:0430\:0444\:0438\:043a\:0430 \:0441 \:043f\:043e\:043c\:043e\:0449\
\:044c\:044e \:0444\:0443\:043d\:043a\:0446\:0438\:0438 ",
 Cell[BoxData[
  ButtonBox["ContourPlot",
   BaseStyle->"Link",
   ButtonData->"paclet:ref/ContourPlot"]], "InlineFormula"],
 " \:0432 \:043e\:043a\:0440\:0435\:0441\:0442\:043d\:043e\:0441\:0442\:0438 \
\:043d\:0430\:0439\:0434\:0435\:043d\:043d\:044b\:0445 \:0437\:043d\:0430\
\:0447\:0435\:043d\:0438\:0439 \:043e\:0431\:0435\:0441\:043f\:0435\:0447\
\:0438\:0432\:0430\:0435\:0442 \:043a\:0430\:0447\:0435\:0441\:0442\:0432\
\:0435\:043d\:043d\:043e\:0435 \:0441\:0440\:0430\:0432\:043d\:0435\:043d\
\:0438\:0435. \:0422\:043e\:0447\:043a\:0438 \:043d\:0430 \:043e\:043f\:0440\
\:0435\:0434\:0435\:043b\:0435\:043d\:043d\:043e\:0439 \:043b\:0438\:043d\
\:0438\:0438 \:0438\:043c\:0435\:044e\:0442 \:043e\:0434\:0438\:043d\:0430\
\:043a\:043e\:0432\:043e\:0435 \:043f\:0440\:0430\:0432\:0434\:043e\:043f\
\:043e\:0434\:043e\:0431\:0438\:0435.  "
}], "HowToText",
 CellID->415396916],

Cell["\:0417\:0434\:0435\:0441\:044c, \:0431\:0435\:043b\:0430\:044f \:0442\
\:043e\:0447\:043a\:0430 \:043d\:0430\:0445\:043e\:0434\:0438\:0442\:0441\
\:044f \:0432 \:0442\:043e\:0447\:043a\:0435 \:043e\:043f\:0442\:0438\:043c\
\:0443\:043c\:0430:", "HowToText",
 CellID->418167453],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ContourPlot", "[", 
  RowBox[{
   RowBox[{"LogLikelihood", "[", 
    RowBox[{
     RowBox[{"GammaDistribution", "[", 
      RowBox[{"\[Alpha]", ",", "\[Beta]"}], "]"}], ",", "data"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Alpha]", ",", "3", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Beta]", ",", "10", ",", "15"}], "}"}], ",", 
   RowBox[{"Epilog", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"White", ",", 
      RowBox[{"Point", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\[Alpha]", ",", "\[Beta]"}], "}"}], "/.", "alphabeta"}], 
       "]"}]}], "}"}]}]}], "]"}]], "Input",
 CellLabel->"In[17]:=",
 CellID->305665985],

Cell[BoxData[
 GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxsXQVYVM/XRkXcXWrDxnY7MMHWg43dAXZ3dxc2djeKit36wy4UW1GxuwNb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   "], {{{}, 
     {RGBColor[0.29994195923223127`, 0.06875128067165637, 0.5385850251658303],
       EdgeForm[None], 
      GraphicsGroupBox[{
        PolygonBox[{{1183, 794, 605}, {2693, 1183, 2694}, {794, 555, 1}, {
         2338, 1176, 2687}, {1368, 1181, 794}, {1302, 1176, 555}, {1183, 1368,
          794}, {605, 794, 1}, {794, 1181, 555}, {2692, 1181, 2691}, {1181, 
         1302, 555}, {1303, 1183, 605}, {2650, 1303, 2806}}], 
        PolygonBox[{{2687, 1176, 1302, 2647}, {2364, 1368, 1183, 2693}, {2691,
          1181, 1368, 2364}, {2694, 1183, 1303, 2650}, {2806, 1303, 605, 
         2375}, {2647, 1302, 1181, 2692}}]}]}, 
     {RGBColor[0.384191161059809, 0.2152378898889448, 0.6570074702139979], 
      EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFTzsOwlAMS6FDm4kBdtgKSx87O1LZGIrKyAHgCAz8BgZuwFH4SiDOwD0Q
I7FiiSFynuPnxJ3ZYjyviUjbqm7VjUUiI5qRSLC+b3WInO9xlhsWVvgHHFET
2OfU4Q0feBypyWL3Al+qv++Ge6uG+V3U90DTomdO/Ubdd5CKPKjHv7f6/GR4
Yw9up37jKxE5q/tUhsPU7/lY/0xcA+2Eu5fqu3EbdqzJY458gVkqen7V7814
81Q985b6ghmuzFtyHuJ/HuDK+B+Z8iHN
         "]], 
        PolygonBox[{{2755, 1064, 276, 2754}, {2687, 1066, 277, 2338}, {2806, 
         1182, 1073, 2650}, {2691, 513, 1066, 2692}, {2750, 276, 1071, 
         2751}, {2694, 1073, 513, 2693}, {2752, 16, 1064, 2753}, {2808, 1071, 
         2, 2247}}]}]}, 
     {RGBColor[0.4684403628873867, 0.3617244991062332, 0.7754299152621654], 
      EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJwtUrtKQ1EQXM29ITknVmKjgggWmg8QrZJGK20URMHKzkYbHyTfIIGIoFhZ
6V/4lijcWIh+gEUMptTGQsEZZotl987Znd2dveMb20tb/WY2C8vBqkWzMoCv
YPaZmJ3DqnhYK5k182ar8D1gF44Pp2ZniCcRZ3ivwVo5YaN4K3vcTJVzC94u
vu/g50rKny8J+01Um+TFy3z2/4BN5eSHUsVH3pf8T+Aaw+wN+MNUNcxZxPcg
4pdoths1ww582+ck/zKw9X7tXIvirUd9E38H70PQvgdBdXXfcdPrmDOSqBex
TqIdyP8Grj9wvkbVk2elKO0Yc+7M+1F7zt5zbfei9tmP4sy873TU3O0o3Yhx
3xnw54F34U+g6TPyj+Gvguov4b9dE2pDPdo+J3cl52mfdmAOZ+KulVQ9Gq7z
fVAu/wfm863id5mIiqsDMsaPBd2t63fhnTs+d6ugW/8E3Yl9FxDfBN37Omjv
jv9j1D/zmf8BGJRbAg==
         "]], PolygonBox[CompressedData["
1:eJwtkb0uxFEUxMf6E3v/24kGiUg09gG0KiqFEBvbegAKn7svoFCtKESl4i18
syRWIxpqNpREQkLiNzmKSWbuPXfOuXOGF5ZmFguShkAGKknq65JeEKfwjVwq
d0p33dJuSZoENXgLLHM3j27AZ3kzhr4HA7z9RT/AV0ADvs/ZdFG66ZEG//Um
/l+gH53hUYWvU7+NHqXnN/oJ/FDbBmfwixSzHqIv4VOgN4ue7m1Pe9uzSa9K
MWrfQDPFDL7f4b5G/RZnB+hXcAWfK4b2DGvctznrhu91SI8pPOzlGtceoZ+z
mNGzXtNznPo6//mEn6eY3Zk623dQLsTMHyk87e0Mq6XIwFnY8zhFxs7aGa7C
63nM7p14N87IWbnnSB493ds7msCvlcdu3PMWfpJit57ff/8DRUdKHQ==
         "]]}]}, 
     {RGBColor[0.5526895647149644, 0.5082111083235217, 0.893852360310333], 
      EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFVD1PVFEQHVge7ruzzcPCggJQOhQ7yqXSxi3URNSYaLSxg0IUP/kBImqk
0YTG+IUmlDa08rHxK0ZjogYiHRQQjQYTFwrOyZmE4mbmzT3vzMyZe2/XhaHj
g81mdhGrhLUnN3sD+6ts1tZiVmCNN5m9d7ONzOwDbB/WEsCnKmbHgH8MzChi
c1gziOfJ7CTiU4jfQuwHvjfhr8D2w1aDdw1rGquGfwZ3CV+FP1vS/jLqmC+J
8zP8NeSvZfr+XdIe4/uQo4r4Xtf+kUxx4mrhk5s5CvjtmXzm6nTl64BdcOWo
u7jZI3tfjBroE7sY/kzUQP+2i+81+r4E/z54DkOf761m56OvBvrfD/sT+/+g
7xnEHwEz2SKtyUNtqNHdJu0TP4YBXQ5OcrcFhho1MvmMdUQvBfJ8hb+JvS+w
N7B6EH+ea4bMx97uIP4K3+OwT6LWpxVhmZt5OVt+82w8xN4E8FeB73bp+D+p
LtZJbc+59D/omvlSaEQsNZhoVt3VmO8W/j+A+FQu7p7ol5r1B37ZVQ81e5YL
w57mXbPoTuqT/dbgX3NxHAX2ZS5+5iHn7lbxkoP52Ne6K/6prD7YD/8vYLey
uAdJ2o4m1T8bc2dP5GWdV1z2BHK+yMXFmS8kxQdynbuhOIesi/qyBupIjUbi
bk3GeSAHzy7xYy6fd2sO+FXWkdQn6x125WYu5qQu1KfLNTP2ex32AeK94KvD
3nTVwHvMs0QNefZ4LqZjBtSgke2cu0ZgTlc0Y97vQxXVuFHW3WScc/+W9J7w
XalH3nuwH8NnLcyzHu/A3yTd/8C+S4q/TeIlf72st4mcZ13/rkad1JX6tscZ
L6LmbUDQqkc=
         "]], PolygonBox[CompressedData["
1:eJwlkr0vQ2EUxg9abe9bgxgZNGz1NYmpLCxqMQgRhD9AFx8h+AOoatIBiUV8
S4wWq5b6SkQYJEQ3BhIhFjX4nZzhJL/nnHPf+9znvpGxRO94qYhEKR/14kQa
ykQGEQW4GBQZhR/LRbbCIgF67cyr0B9wP71ndJGdAbiZXrdfJE61wB0hkQ1m
P+hr1RUiiYBINboePe2MM5iYgvtCxvqOpCeyQjXhK45Ow8fMY/A+Zy6xv4uO
ojfRc+gQOyfoJ+oMveBs1og+YHfe2bP6jXvoO/Qv7/+jejwr5UrqGx5i54j9
Q3TSmQf18kHvCl52NlO/ms0wdSqWwQicZefNZ2ekPPsm3dVeDs6z8+43zzn4
xllWmmkrfE+lSsiX3gMc94zVs3rXjDVrPeMc/vLMu2au2ddQBfzE6NU586Be
3qkLeD1s/1oz3GF3gp0l8k+zPwmvMmckGfQaHHGWbZaqhV89+/ef6Db40rNs
9B2a3ayzZ/XMGfg2aHdH75TerQXPzlKP6rUrbO+uRHfC+aCx3hm9O9thu4t6
BxY57x89GmOt
         "]]}]}, 
     {RGBColor[0.6175794399564652, 0.6139405040359164, 0.9107242711959184], 
      EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJw1VE1IlFEUfenM+L15nwRtItJSghZtbGNtdDEujTYtIsgMDFwWrYJIXRal
OWBjacuyHAIzGkt39mNFP5RtchFYkhJJzRTCKGV1Tue2eNz7ve/cv3PvffUd
Jw4cr3DO9eFU4uSSzjVA2QR9GHpbwrleADYE5+rx7SCHILcldb8QhClH0HHX
hTMO+0mcL9BnYbLd8ID9wxHflnauCrY7cd8H2Ye7kynZ/gBmL+634H4myM8z
yDqcZuj1kL+A6YDNSAxfQXFPVTt3GbIW5xJyy1RKZy0PgZnCdxXiriTlh7kV
4aOAcxD/buM04r7ghG2CXq4Qtsnwr2A/AfwA5Cfk2wm9lbYm64BZhj6Gs898
0BdtWdNcQtzsQd6dsG+EXEuofsYvAjMDOQ/8buRcQvyGIN/kiv7PxaqXdd/0
qrkL+hL81aQU90VaOWQhc2Y/DexT80nfUVq5kZvzOKPwcz0W38tW75Mg3QO7
v0r5MTferRjmYhDX971sWR9jlBLiitx+ACaJ3OaDfJSMW/Lz3fQZq5/6Rou3
q1o9pC37uI4Yq/D5Dv/bvXjPwue1WNz8jNRDcss+ruFfLfS3kXpVa/wcgm0e
3z34fxe+3nMOIO951cKa6Ic9+Yx8TuNfFpjHuF9Pa6Z/Q+a99qHb4iyZf87A
YkqzVQNMDrI7rf4sGoZ7xhxYV9bmYtb0JeNxR5AtfXBvaMO9W7ReF2x2xi3P
W16YP4h1BraD8HPDa68HbWdfp/TNuPRN3sk596/H9jeCbQvktyDemO9VYC7g
Ow/MhNdOX7G9Jn9T5od2o7aDxAxbXO4r//Ge/1tsXx4E1TsdxEfG3p/JoJp6
vPZmwXL7au8G34/eoLyOeNXM2j/irhzET0u13gXuy2HcTXrFjWze85Yn7XKW
J2MQ/z825dlYvuhzNQhDrjjnR4P0duOMM8m65qwvxGy2eZqyd4g9Zq8fBXHH
GeSssZeMx/3gPfnkfuRMJzfkkTlzPhiD/jn3jPkmEhfk5Hlae8/+8Zt7lDH+
OT/L1tfBoJy5T/3WA+7HLOybOSOQxaC4fHc5cyXb661e78FKpLeGb04/5His
9/FOrF612vzQhm8C/Q7YW3rMK48xyzNncV9CjnjN6xD8/AV87/Z+
         "]], PolygonBox[CompressedData["
1:eJwtk01sjVEQhkevT+/3nU/8RFJCtRexsOmqbHTBwkJiwcZCQ3IlXRJbP+1S
Q5uKuK2ypPSSFMktt4lFhdL4q9joQlIaaUTDLRFaf/G8mbt4k3fmnTNnzsyc
XP7oviM1ZrYLLAbtiVkB8jUyWwEfjc12Z8xu4esNZiV8b+Fz6Mvh+9EvkKCI
fRZ9IDXLo+/gzF20Stbs2BKzbnx12I+IOQcfQc9y/ga+S5xdD35jvwHz6CVq
WYX2nvgmYlvxTQePUWwD+At/iq8C31Nrtgy7AXs7dgtohA/HXtsgOINdm/jd
esND7FEwE3lNx9FaE79LNam2EfRm+EfeWIafAAXsCd40gL4Gext2mZyr4fNg
HdoM6IOPg0/oc5x/EjxGsbrzAfw1/akntk3NJ98XfDsz3sMKPKae2chzjGHf
B9PwSfQhtHux97qI3YN2EHRE3nP1vjPxuebwLQo+A81iAUyibcA3lvGZb4Sf
An2Rz1Sz3Qu64L34TqJdi52rB+rFFIi4qx77F/magr9VNRyCH1DOyGtW7bng
s/kONhHfjt0f+R26qz/13q6k5h9Z76F6qR4tBD+js+rJY+x/ie+C3qi3aie1
m9oJ7YZqUm1603Xy/6nuj+4sYp9OfbaqsRM+iO9idR8Vq5loNh+4/zZ6D74h
7FkwnviOalfb0Lei30k9Vn+moF0P/nc00zKxr3hTI/Gbyf8ZbctS390pfGtj
/3P6e9ph7XJH8NnqD9xEb079Lu1kXfAaVEsJnIc/By3kGsZ+of8BLtd4zc/g
E+pPNT4fO8S1sz+D55BdAS/hh2PPpTM62x28duXsgl9N/W/pTVdS30ntpv7E
t6zPULPUjrwj/j/kvqSK
         "]]}]}, 
     {RGBColor[0.6795220978816842, 0.7134651195938501, 0.9121363730106195], 
      EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFlluIVWUUx7ee697fPhUkVESmZYhBZaQ+FARh1IvOQ+CDFegoIfWQCiaU
YhFd9EGs5oxTjZcUlFITbzljF9OZnrpgTQ+SkmYvMz40pkK3yej/879AOJv1
7bXX9b8u35m8aOkTz4/Psuysnoqel4osuyDGsZRlj4qxu5Zl3Xrv1fvD+v64
6Km6+ZP1vkHve3Tuy7PsBukOSOeQaKfoF+LPkcznkhkQfUr0ZDXLzom/V9+H
RUf0fK9v52t+x/fh+Aa/Llt92JLunEaW/Sb+GfG3im7Ws17yg8l2GoV5W/Tc
KJnPcueQ6/uoeKfl+w/Jf6zzVD2bdD6azN9f2C/xEcPewjET+zzxp0l+l/gd
Oh8I3Y36dlDnY/IzWHFs2J/dyrKJwmhM339qGreNsrdA50OSuS+zjYNhB73R
0N0pO2f4lhm/o4HhtmT/CwtjNyuwutR0nMTbVuwP1RzLXYrhMeE1RXRD1Wfy
myg7D0rmNtFO6S7Us0LfVkpulfjzxb+gZ4LiH03GiTO1/lfvt+v8o3RG6s4R
PP4Uf7tiWZQ7xz7pLNFzXO9z9f3d5Hrin5jJr1+6q2vO95ToL+LPaPhM7pel
20svSXepbP4c/A+SMfkmt+zp0P1E/B+U54fCYY2+DYv3epllr4i/STJ7xDui
Z7Zsvh15jET8Pcl1+Ut0X+n6ZJK9o2ZdeuzeinuLvpokWq/7jH/8EkNb8S9X
rF2i94gONmyf92VRJ+oOHx/ghxwyg6EDdtjAFvhAuxvOv900vmB7ojDmixVn
v/yPVt2nYAteYEVdF0b/YRdd/OKrL/qwp2l5fDHTe2LeqRm1G8g90/Qm8wgG
YAEmW5LnohB9o3T/PJnct8w//UrMLzSML7iD/6e5/bYjrx0V47dD9o8n9/bN
yTgjTzxfJ8fBjqEniY3ZmSa/7+t8Mbefzua1vDsDK/DD13DUcXvV8Y9LPq8t
vCf2Vd3n1Gp5YPJeMn9B7v4G8xOx38CdHMGvJ3qUGNrhF7zbMfP47wmbF8FE
tX9EsW8NvLaLvsOMy+Z8+fmucE2/LVxXcqKOKxv2QRx1yU+Rbk10esX9Sl5g
Nil69frYyeB3Z80y+l3Fb2rscHYTttnxvTXrgvk/yT3KPuuMOi6JHFdGTa8U
xnQs9hK9Tp+Tb1dgjvyKiPnX5Nk5l6yD7i7lu6TqmeyImWf2L4k/U3rP1I3t
Tcn7YmbpPb039glzQ5z09GtV9wO9NC7sHii9K9BlLrCNHDL0XW/IM/PMxFDU
Bx/srH75PSv9I8lzwH3ELHBncHccIPfcd9Kryffbqtq1PQ0FkyHJXJb8kOQv
Vd0/9NHu3Li/LN1Wyzlf1/IMoH+LaLPwHflV8p4fjJkE46t36XjHeCbyXFc1
JT/wBeenC/f79Jjf5YVxOMy+z61zsvA8roud1p/7vnwr9mtv2Fxc9czQJ2DQ
F/HMKq07IfbSvNgD1KEjZnYs964vleOVpm3tLH3HY6emGCotx0aMayPu/wr3
NvL45Z5nXujz7uTdur/0fQo+/E+gb+gf6r4h6kntuCfI5yPRW3Njerd8nm+6
f9grz+nZJt1nS8842K6OelJfML+/NF0Te7Id/zHYH8viLiAnfON3Rul4Hijd
r9hnptaWvhPfLL1P2aspeW7AkNlhB7GLusS/mIwD+LFziYc7vFX4f9K0lv/3
UKPfY5dTA/Bn/4MV9Tic+//cjtL/LajV5vCPX/bCi4Xj/zJ5f9A/7BDuC+yz
Q4hrbpzZX9RlvfT+jruVO7YSO6gae45aUrv/AUvBfUs=
         "]], PolygonBox[CompressedData["
1:eJwtlElIlVEUx68+r77vfe/VwiAqqGwgbNGoLQqiiWphmyAosqgspBbVooEG
sKLJhRWVQZOmoNBglJq9kqxebaKCtIWkZNgmWzSoQYM2/P6cwOM7//s/53zn
nuHmbNi2fGu6c249koE8DJ07iXI34lxmzLkFCed2ZTlXjdF3uJWBc+XoNzx2
4N3w26PO7QcXgtfgUwZ/CXwA3IQcJt5F4vXjezcw3+vICbhjceeSmc51gUvg
ZoI3gfP5ZoLYuUgBehe5jZQ/Ph3Y5nE2AM7HvpbYpXxjFvoP+EZvOSv3AqQc
/QM5TYf3MbtbJ/Yt2M7jrAm8GJuJsoVPwvUhrejPsPnkLYcEuA5ph9tJjr3c
ewc+6/gtxmYptm3w/fAF5Hse/SlnH+G+8P294AzweDB/rhTciKT4/itwA3pf
YLVqJcYdbC8gPXxrDDKIPiFhuapHe7DPxr7BWc3yuMvrqNkWw6fB9SIXItaD
CL7NxOj2dgfdJQW/DP4W+DzcGc5WgD+DX6JXc/YA+2vkX4X+ImacaqRaFSJT
sM8mh+98+x4277z1ZHhoPVPvZnM2GrwaSTmbGc3OKXAd3CXir8V2MmdnM6wm
Q4l9CL7S20xptobo+956ot60x6z3Ndj/xv+Pcs6wnH6jf+M7c7zFHAVfS42K
0BfC3wOvIsY+bzVRbUYgs7zl2IfvV/CiiPn0og9J2Gy+xWYGsUo4u+htJ7Qb
8+M2G5opzZZ6rF5P4F8mtvGEza56pt5dDq22ufAV6EfiNqvK6Sj6o9BmRzk9
Rq+PW2/Vs8f414A7+F4O8QajJtKHcfYF+43aGdUe/Av8HNziraeV4Nv416NP
xecWelvUdO3Qz9B2VLuqbzQFNuOa9SrwFuzLuN818qngrA7ewU+LWA/S0NOR
cd5mPhLaG6G3Qjt/HP/NcYulHJVrfcx2Uz1WrzVTmq1MbN6HVnPVXjut3e4O
jRvL2d+Y5aBcLiMH4a7GbJc6wYNwA6HVQjul3bof2CzoDqfBNwJ7u5Szcj8T
2m5oBprhouBJ3mY2GdiOa9dV0ytwj7SP3mpaDg5D6+1cbN5EbcY167I5F1pO
yk1vmt423UF30UxdD+xN1NuonUrCLwkt1rr/b4/eDL0dPfBP4IoCe6u1w9rl
FGcfvL1BUXBWzGx1Jk41Uq20Yzfx/Rza7OiOuus/2BbfVw==
         "]]}]}, 
     {RGBColor[0.7414647558069031, 0.8129897351517837, 0.9135484748253205], 
      EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJw1l1eMVVUUhs9w55Zz97kkigqWGEFREWwMmJgYrDNIMRqjMWIQhXmgm6CI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         "]], PolygonBox[CompressedData["
1:eJwtlW1ollUYx4/Ps83nvs+5AwtTobctxZyps2kQhBG2hZUEkR8sStEFuuWk
SMNIiV60L30oaaRhpVs6U3S+bKa56YT6UpBa9mL1Sa2siJZmpGX9/vz7cHH/
r3O9nOtcb3ftgqUPtJdCCM9CVVBfCuHnmhB2wczPQrgAfwyF2uEh/AmeFUO4
A72FlRCWFejlIXwKf7o6hAFk/dg0lUPYhv1W9OdyNoh8CfrL0f8H/hf810GX
wS+hsw/8LfarsM04uwncA30Afx98G3gbOk+jezf8IvgD0JvgxznbVGOf8n0I
OoPsV2JeQWyLkXeWbNMKXp7s6yP4NvzvRf8E+EvoHHwD8oXIG3lvJN5T0W8Z
T/zt8NW533oK6ke2Hv1HkU/jzTuxX5bsezr6S/VevnW8fyQ+h9BfonjA+9F5
LHMOlcvF8Pcg/yM5169jcx5c4r4Z8LdDIwvrSFc+2pE/gfwr3ncz8jLy3Zz9
gKwB+2H4vxf91uAcKpdDmXUfRmcCupehdcRez1nA/t9kfJQ3bcF3FTad4Kno
lMGjVQNsm6FRyTlSrhbAX8T3BHSauKsZqge34ONJ7D+EP4r8Ic6eqXbNV2P/
ecW9sAidEvJLyN9HvgKfMwvnULls5f5jyPdgc3/ZPboPvD1zbI9g/xy2PZlr
0QX/IvwV8GuCYx6D/gniuVDlM8k64PfD13Pn1//XWLWejo9dyG+EbyKWXvjr
wSs5+77kmowufCbZXfC14LGFe+8p7hsHPoD+TnzvgF4lntXRsd2KzR5k7yXP
WjP8AHyOfB74IPpvgTdE43bNY24SPsTZRr2PO1q4qwubAvwK8lvAHcQwF3+f
QEfQHYTeRf9c9F0t+DgfHZNi+0Y9qfrhYy2yw/KHr5XQAPg78jUmc01UG83U
xeiZ1myrpqptp+YF2UT4rugZ1awqx8q1ek6914G/sxXHqFiVo9fQPQLfB+6F
3ojuGfXOFGgE/J3JudVOGcJ+cnKvbiTGSeBEPC/Dd8JfwnZKcm+qZqrd1tyy
Luy7c/eceu8ndPaiOw9+Q8kxrOO+56N7SzndgWxt9G6SjnQ/q3jW1LN/R8+0
Zls7qQ1/67ljdnANNiM/Hd1b2hlnoneIdol2Vk3uN+vtmuFBfG1Oro12iHbJ
pujaz8fH29E7U7tTPTAV3eP46Md3G/LjmXOm3DVAV4JvKNyrJ9HpQfevzLlb
A58Xzoly84VqgP6owrvnMGdXq7crxquQz9B+4mzicO8Q7ZLfoneddrh2+dnk
XaF/yI/g3uRca4Y1y93Rvame2aJ+yh2LdrB28e7cvah/jP41jcm9rhpPA0/C
ZpZ2JzQZHKNnWTOkWSqie1H/rJPE3p3c+/pHHeTt1cgby95xNeCPM+dWOXwn
uufV+7fh4xr4B6N3s3bcHPBV0blVjVXrvuh/iXaydvO1el/ZM3Ud+IXMuVPM
il07UrtSORxW+A16i3ZOnWqVXCvN4ExwnrwLtVMj+PfMtdI/TP+y/wAewwhm

         "]]}]}, 
     {RGBColor[0.7992509870701703, 0.8592097899137917, 0.8976252786089289], 
      EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFmH2slnUZx2+ec56X+7l/TwoGHJcVePCALUjQVuiK40sDNV2rJP9AIYgC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         "]], PolygonBox[CompressedData["
1:eJwllnmIllUUxq/fOPMt733LbWYMLdQxF9JKKwLNMrXFRClbqcQtS9NmTNEx
cSrcocCKwChzH80lsj21UcuwcCMbTYgcIycXKBNHK62s38Pzx3k55571Luc5
b8cxVcMrMyGEVVBzaEYhhJdgqkpC6BdD2JUPoQn+LPQFckvohaIQZmLTCr5N
EkLv4hBugErhS1mbi75VNoRG+J3QOXxrSTKS2COweRf9ZNZuRfcz8fcVO4Zi
DYNq0O9F3gjfBZuHsX0Iuhr+DWL0D67pS+QTuRAegZ9NPS2JtR6f3fjuRF6K
bVtsFhCvBvkK+Dehb7EvJcZf+LbA5/XgHF3RZdIQulP7YeptBn8n8cYRbzn6
8ei3Qr2xP438OfyGxLXuIv4K8j0VbbuGtceIfQx9Fnkx8R5FHoB8M/W8gnw/
8nFoHvJu/I/jewp9ij2lhT18ulHDPdRTh00X+OuwOYjtYHRTkPsi1yOvR98H
/gPifYf/KvLPI9Y+5K/ge0KXIU/DZj36zeSfiC6yNgbfHehXJz4znd156CD8
Wew7kP977J/D/hPkpfCniPGpYkFHS7w2Cv1a5B+Rj+h8tP/otzCLeBOJ15oc
2+An6I0oN2sbM65xXeIaVeu10OV6C/hvItZ+5CnEeyc6dgXnc4kzGI1/FfF2
ol+L/WxsfiXeAHJeldpGtm3xOYf+AvJI7GuxX4BcrzvP+kwO4HsHa52xH4Hd
VPzvQ55S7Bqex7Z5wbH7Q+3Q92BtFLrRUE/4xei3EL8HPj8Q4whrE4mXYt8A
/1M0v4Uaj8LvJefYIp/JGnL9w1oX9Cvx+Tv6TeltDSJ+I/GmYb8HuRybk+hn
RZ/N7eiepZ5Vie9SZ6KzOZ1zr72MXJZ3T6u3K6Fb4LdH92ZX5B3w9+K/MHjP
2nsOn6n4TqLGevjJxFxU5J5R75yBumVd80XtLfHe9ab0tvRm9HZk8y/6Fonv
Vj2sXlZPqDcayL8OfYA6l/gODlH7UOyfIdZNrEV0TYnvslyYpFzQ3cTrRfwc
+/8vGsvUwwG5hhyvUf8Q5Aj/jfaMPI6Y+8n9RMFv8XHMs8gzoWri3QVdQ+xe
0FD4YcIo+LLouxDGCes6R/euzqQCflLed6uaVXsHathP7IHk7wh/Mue7VY5u
0T2sXl6J/UXhA2vVxJ8BDdTbjL4bYc5h7AZF6xRzE7XX5X126jn1nu5Yd92P
fGWp96S93Yg+US8hrxCeQXMSY7qwXRj9NboqaEfGGCwsVg+oF4SBwsLh6Bdl
HGNu4jPR2QijumJbiM6lnlJv5VPfzXLiFcNfmbp39lFTe/gGYk+A74NPC2FH
znetN6e3N5/4q4udU7krUp/lb8id4Bcm7mVhqrB1WzQ2L0NfF43BwuJlrI3T
/UAd4VcL/+AfwGd6sWeIZolmjGaNMO93fN9CPlBiDH8fuXvi2SCfB+UbjaWT
kKvhhyTmNYM0izRjNGty+P+CPCfv2jUDNQsHQ09juxVaorceXZvWKvW28E9K
jFnCrsbEsVSTalMPq5f7Um8z3sOT0Xuth46r/6LPVnc6A7489dvYqPcLvyR6
FmnmvB09QzVLO2FzTrMm795XzxxCvoDcO2vME/YdpKZewWd6SfOFGhoytimk
vnPd/fXI2dQYJazSP8QxYpWk1mmGbcD3s+i7EwZshh9f8L+G/hH0rzC94F5R
DuVST6u31TPqnT+giqwxUliZKXivmpltyXU+em+vstYkvCl4duqfpzX6ssT/
MsLsZQXbyFYx/4Q/k/PbfRGb26IxSFikGbgt755Sb+kf4z3Nq8SzSRhfm/hO
dDe60xOJMUZYIwwTlh0q+F9lPvYn8W/H2vYiY1h7YWf0rBHGrcV2bMFYphmq
WaqZr9mvnvkQ/zap34ZmombjqejZoX+icv0/Rc9m/YOcQD83770J84R9H0fP
et3xR9FvVG9VM06z7n9l+09K
         "]]}]}, 
     {RGBColor[0.8548796980013278, 0.8777604827298388, 0.8727036659624733], 
      EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNmXmQVdURxm9m3nLve/chyKIJGmMluASVaKqAyIwwqGFGS0GwKqXiEo3C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         "]], PolygonBox[CompressedData["
1:eJwll1eQVFUQhq87szNzZ85IppCghQpLQaG+gWAJiFaBviBLqSgoQWDJsUiL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         "]]}]}, 
     {RGBColor[0.9105084089324854, 0.8963111755458858, 0.8477820533160175], 
      EdgeForm[None], GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxNnHe0FFW2xqv7hq7qrhbERBDTiAkwEU2jBPMIEgTUUVARszimpwKSkSiG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         "]], PolygonBox[CompressedData["
1:eJwll3lwltUVxt/k2/Iun6KFEXEDRbSCIyAYEJUdBIRAcCkgi4CQACFC65RO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         "]]}]}, 
     {RGBColor[0.293416, 0.0574044, 0.529412], EdgeForm[None], 
      GraphicsGroupBox[{PolygonBox[CompressedData["
1:eJxFmnmUVdWVxuu9V/Ve3fvey9BEJgUETExa7BiHaFEUoAIWYBWIkBYI6QgE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         "]], PolygonBox[CompressedData["
1:eJwtlmlsVlUQhu/Ht7T3fLdCqCGsrUUQkB3K0oLsYbFCWcoSAZUWQRQohLj8
MBFRNtmhgCji/hOiGEWMEjXG4C6GKIhCATcWF4wGjRF83rz+mOR9Z+bOOWfO
nJlbVls/eXGTKIr2IRmkeYiiw+koWoNyQhxFPeE/wU8glfAeyNJUFJ2Br8B2
JB9Ff2WjqENBFL0Mbod9B4HmwwcURVELfD7BN4NsxNYa/kXaMRW7Bz7T8J2B
dIbPSqIo8H2KmLPBZ9DVpKw7C+6INPLtcaQUPJ81V+M7mv2OJH5jsK2Ob06B
exF/F9+eQ9cL3j74LIXoumPrDv9R52P9cr4/Dx9LrL/RXdDZkUr4n/Bz4EWs
N5n1jhJ/Ibgidi6uEO9b7CeRq+BCfAaDh+NzG3gv/sPAx/Bfgv95pDf2eci9
GeuOY7sHnzVZ7+FucJlyhL0Zukvgh5En4K3gl7U3fMrB1+FfAa5H9xD2qhx3
Qf4mw0vhZcQfRfwE+R18CanANgJJZRxTsV9DlmKbSi28Cr6DGI9mnYMRfNsP
3UXs7ZAh4uRwLrl7kPXGJF5Da63Fvxo8Cf/irPcwBdwPXUPOOVfuByDXgHej
m8P305HNOdfU55xnKnwTfCNSk/hOdbfSTdP5kHXgq6w3KbGPfP+Bl+B7gfWe
grdmjz/LF/4IsVcgtXmfUWeVrg4+HHsF3x7Afzpnq8Hekv0dVI3CR2Mf18Qx
axPvWXuXTrYdyNqs7/Au3T32ndiLiVEOvxX+fs45mJn4zejtHMX/FfCSxLlc
Tbx6cBnxVsJPk783gs+gs0xAVwK+JXGtyme8coe8B17Cmbbw7UV4qwLXiGpl
E/wd7P9iL8W+GXkX/rZyjG1L4rekGFvB65FDOfcE9QblWLmWbgO4Afkw556g
3rAdfh/2D9DtAB/gm+WRc7KA9bfiswq8Erkz7z1oL9LNg3+U99u6Cv9K9x+M
ryBfwgcWube0IB/9wSfQ7cM/xXrfgD/N+60PKiQH2G9CFuJfgv8g8MXgt1Kr
nMAbC52rWfA+8KGqL/AZ/N8E9w22zUR6Yy9NnHudSWcbEhxrDtIXezl8doHf
SH9wT853OeuaVm13Qje9wD1PvU89T70vjc/34IH4H0rZpyf2/XnXxin2szr2
GXSWRdiHgudg/5i1Ir057EOKbNOb09urhC8ocE9Wb+6D3E/8/dqDYsFX5Owj
3+HKN7FehE+Cj4Kn+XYvvEZvvci9Uu+3R3BNq7Z1xs/A16KbiL0a6Yrvybzv
Jqf+CB4djF/CPhX78bzvVmscA8/Ue8u6Zy8PjqFYyklxcE9Tb1NNX0icE+Wm
KXvYBX4SOZvxjGkTvIbW0pl7xz6zzq4evpT13gq+a73x3bHfmN5atXpq7BpS
Laknfg1/AL4cXgKv5/sN6NJp93D18iqkacY9Ub1xp3pu2j15sXo3vBn8MHwZ
+Df1v4xr+FfwLzpzxncwDNwt9tnaI8/F7knqTW3gE4N7knqT3tw47F3QZdj7
D9i7gr8Lri3taVDsO9RdLmO9XrFniGaJZla74BmjWaM9jVMugmdxDdI/9kzT
bNMeZwTrZGuEvx48AzULj7B+S9WC+o/mo+ZB4ppSbWmmd1a95r0Xzciheedc
udebHVzkHClXmhGPg59G2oJTSAdwq+C1dOe6e80kzaYY2R67x6vXa4atV+zg
3tEcXkH8P8L/uIl7//jY/z5aQ2udLvQs08zU7Hws9tr6p9G/zZrYZ9MbXJf4
Teht6A50FwNiz37NgNsT9xD1EvUI9Qr1DPUO9Rz1njHB/yaa+Zr93YLvUm9K
b2tP7LvvhIwFV8WeFcrx4Lx7qnqr/om26b0H/2uox6vXP49cn3ZNdokdQ7H2
YK9jf9sS92719BewPYuUpl3jHcHPxK59zdwpiWtStama7g6+OfG/knpKFfhG
dEVpr6m1NWM0azSDNsHnJl5bM1GzsTL430T/JG3BB4NrSz1BvWFV7NmumIrd
EPuu9U+of8MbYv9ras/a++K8e6PerN7uf+HZSL0=
         "]]}]}}, {{}, 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwl1FlTlmUYwPHHs9xOUlssQDPLNdZXZXlBk1BEQRCQcAVU1BKwTjysZnJJ
UMGtXHL9Auq42ydoxuXEAs2l1KnErJkaT/1d08Gf/3Vd93Uvz/PcL+NbO+s6
hiRJ0ujPg2FJMg4tI5Mkiydi39AkWSbfz6VIqbXLZ3ABcsX5nMcPXkmS4Xp6
sWdEkvShF3Pl7cOTZC+v5T5ex1m82/hu3sV7OM9a66yVyz/LV4j7o1/ewzXy
iXwC72GxfBe/Zvwbrpa/y8ewCB/Lq/lV49326EEt6jBBfQkf507n2aK3g/Ox
Q62Fx5i3U8/2WJtrsBhH5SXGq7iYF8Ya6l2Yh5S1qswtVn/EjzEJH6i/z9k8
y9hd8ShMlY/maWgTT+FWnsqTYx7WyNeiwLzp8lR8G3s1Yw3aMF/te6Tj3ehZ
qn+O+F9xNQrlNTwj9sdMZBgv4kyussYCFOv5A7/jQ/XVsYfn7Ba38k5u4/PG
L+COvF/PAHdZ67qxHPWceF61L8TLcBmXYn+1h7zCnOWYqX++/Df8imfxvvTU
xvnFs/EXXkcTSnAPGXiBL+OceBtFWG9eIY+IfdzLinhucTnq1DfKl3AtSsVl
KEYaJRin74qx8XGPnG8h0vKn+BMfqW905k+wHgfkG/iisSy9mXiGp/G+uCLu
UzxnfGvxt/gch+IO2m86n8S0OJ/8O96Gs9Y8hzO4hZtYap1sY5v03ZAXYKXa
qlhffZZ8EmZjDtIoQym64rvoqTe33Fnmxu9MrR+30SD/iX/Ep9iEFDaj0Zw8
cz8T53KDvCLeBX5Ru4cB3MUdPFF/jr+xABv0V/I/8V4xD/lxl9XfibvPE+L7
qWXzWLyFw/I3+Y3YJ+5w/Pb5q/hdiPd57tO8lw9gf9xh+X/GK7nJuvXiI+If
+CquoSz2N1Ya/8t4MGp6Cp29CIPx/ZCBTmMdOGh8Mk5hCrai2dyvOdN4vd4G
NOL+sP//p74EM2ecaA==
         "]]},
       RowBox[{"-", "45500"}]],
      Annotation[#, -45500, "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwVzzsvg1EYB/AjNVCXD4DFyqcQlahFUhIGkZCwuLbCYiDhWxC3xIQymCwG
JW4lBlqJMhm0RgwWfu/wy3Oe5/zPed/TOjqTmq4KIcxzXxPCZ10Id+pEQwiT
dJAw66S/NoTN+hC22OBY/yubp2K/zI75NkP29tUD9jjV/8k98CP3zaF5lhF7
OYZ860yN8SSX0J9bj3Mud0GOS301RZm0PkM3SW7Jc8UN16zFQyjJNlo38Bjd
r46ZF9WCvqA+qetmU2qJYd9/UeO8Od+lf7WeZVE+rfZ6R5aD6O3Otpg308SH
/bI6Gd3JuzuS7iibL7Bkb5k+Z1McsStXlms3b+MreqszGfM5KvZ69N/RP7Ai
s8qgswOcsC/3TIx/N91LHA==
         "]], LineBox[CompressedData["
1:eJwVzr0uQ3EYgPFXqLRFfA866VVwByRi6S7E0rQDQ5uQMKiNe5CYDBaXIQza
GnVAfUytj0i0FvzO8OQ5z3v+//ec/OZ2YWsgItZwlYloZCNSnBqNGMIgrvUl
F7nODdygrofRSkdkdBq3aKJkXuEyV7mFO5zY33Z+aSzi3ruifuR1/cCn+sn7
Zf2sS7qMGXen8WLW5iq/c5ffuMPjeHU3r+fxiQ/smNd4lw/5B32c2dtxfsW3
vpP/1H3e0D0+1/s8of+S/fzLs+i6t2jHAqbMJ3FgfqRrfMw5szlc2PPl/Krn
rOe9ZC9yIxH/B5w4TQ==
         "]]},
       RowBox[{"-", "46000"}]],
      Annotation[#, -46000, "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwV0DkvhFEUBuAzCgZjDXoF/oeETmIpJSRjm0IIWrSWTjKFgmg0Kq19TRBb
Y4Zm7InlJ6h4FE/ee9977ncn05ge7x5LRMQg18mIxbKIK/ldHvHFaipihQXr
JnpKI1rlPHP8mL3k0/qDYbND9JobkRna9VMVEW0yy5I38u6Es1/7bblFn35f
HrDDHrtk9Q/mi6wTHHFIv/5UnnvrWJ7JE7msr/bdKiq50W/ItH6AEjPF3Oov
/n+jzMuczMk7maTgzZR9h7uj9s2yhWfdCwWeeGTNdxuc1VPHm/mMrkLWOq/h
lXf7Cf/FtPWk9YycpcudTjZZd++eP6coO8k=
         "]], LineBox[CompressedData["
1:eJwVzj1LQmEYxvFb0PJkUWhF0AtUpkIutqWG38AhojlaA23LHKMvEo32bdpb
Km2ycOwF+p3hz/+5rnM/5352L/unvUxEnKGwEFFZiqihiqNCRAP3ScQFdxYj
vvIRG/KW79vYRNa9Hb7Tr3JGbps9wcD5BiV98LGuiRZG8px+HjkkyKNu1yGG
/nfONbMf9hblH+dffKdvkf/4lmf8yQdcQRUr8rUdU96T91HGo27MY/07T3jC
V/pXfsMa1tOzvQ/6kXc8oYu++aFvPR6k+7Gc7sOL+UT/7M4/llYnTg==
         "]]},
       RowBox[{"-", "46500"}]],
      Annotation[#, -46500, "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Opacity[0.4], LineBox[CompressedData["
1:eJwVzj0yQ2EUgOETDfJTYAVZjkQjpQoTFbmpkixA2IKZMJqERBo/QZqwghTJ
SKXFBlBoZDyKd97vvPee7978brWUpCJiE3fLEUeZiAEfc4mbfMOHfM2tbMTP
UsSH+R2n5ls9yUW8mbecr7Qn7vKIezy38+35Fz7xrPf1bX7kIQZ4wD0W9Jmd
uXd/caDtY0+vcIKCXvPddT7DSTri1U7OOYsO2tjRu9zDBcbuuOSWvsarWMFE
L2uLnHF/Gi+Ymqu+U/v/B+c6N7Bhp4g+zu3N8AfH5TNP
         "]], 
        LineBox[{2536, 2773, 2318, 3097, 3096, 3095, 3305, 3304, 2421, 3318, 
         3319, 3315, 3317, 3316, 2321, 2279, 2900, 2901, 2857, 2858, 3329, 
         3330, 3326, 3328, 3327, 2727, 3118, 3117, 3116, 2553, 3338, 2677, 
         2678, 3120, 3339, 2554, 3442, 3119, 2429, 3352, 2562, 3349, 3351, 
         3350, 2326, 2286, 3134, 2909, 2435, 2861, 2862, 3362, 3363, 3359, 
         3361, 3360, 2736, 3140, 3139, 3138, 2572, 2685, 2329, 2844, 2843}]},
       RowBox[{"-", "47000"}]],
      Annotation[#, -47000, "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Opacity[0.4], 
        LineBox[{2281, 3113, 2545, 3331, 2673, 2998, 2547, 2996, 2546, 2997, 
         2728, 2729, 2556, 2999, 2555, 3340, 2323, 3124, 3123, 3341, 3342, 
         3122, 3404, 3121, 2430, 3205, 3206, 2906, 3446, 2905, 3003, 2733, 
         2289, 3137, 3136, 3365, 3364, 2681, 3007, 2566, 3005, 2565, 3006, 
         2737, 2738, 2574, 3017, 2573, 3369, 2330, 2846, 2845}], 
        LineBox[{2514, 2770, 2713, 2976, 2507, 2975, 2978, 2977, 2656, 2973, 
         2974, 2826, 2827, 2265, 2710, 2971, 2887, 3444, 2888, 3178, 3177, 
         2404, 3066, 3395, 3067, 2970, 3068, 2259, 2305, 3250, 2497, 2968, 
         2498, 2969, 2399, 2963, 2491, 2825, 3056, 3057, 2301, 3238, 2489, 
         2961, 2490, 2962, 2393, 2701, 2477, 2945, 2478, 2946, 2653, 2944, 
         2476, 2818, 2819, 2820, 2697, 2822, 2821}]},
       RowBox[{"-", "47500"}]],
      Annotation[#, -47500, "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Opacity[0.4], 
        LineBox[{2292, 2331, 3370, 2575, 3018, 2576, 2740, 2739, 3011, 2567, 
         3010, 2568, 3012, 2682, 3008, 3009, 2840, 2841, 2290, 2734, 3004, 
         2907, 3447, 2908, 3208, 3207, 2431, 3000, 3001, 2839, 3125, 3126, 
         2324, 2775, 2557}], 
        LineBox[{2769, 2709, 2764, 2765, 2707, 2403, 2767, 2402, 3063, 3394, 
         3064, 2967, 3065, 2258, 2304, 3248, 3249, 2965, 2496, 2966, 2398, 
         2960, 2488, 2824, 3054, 3055, 2300, 3237, 2486, 2958, 2487, 2959, 
         2392, 2943, 2475, 2815, 3041, 3042, 2295, 2652, 2474, 2811, 2813, 
         2814, 2696, 2817, 2816}]},
       RowBox[{"-", "48000"}]],
      Annotation[#, -48000, "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Opacity[0.4], 
        LineBox[{2472, 2812, 2473, 2942, 2385, 2940, 2470, 2939, 2469, 3225, 
         2294, 3040, 3039, 2810, 2471, 2941, 2391, 2955, 2485, 2954, 3236, 
         3235, 2299, 2256, 3053, 2823, 2957, 2956, 2397, 2762, 2763, 2704, 
         2703, 2760, 2706, 2766}], 
        LineBox[{2776, 2327, 2287, 2910, 2911, 2863, 2864, 3015, 3016, 3013, 
         2569, 3014, 2596, 2849, 2848, 2847, 2577, 2686, 2332, 2851, 2850}]},
       RowBox[{"-", "48500"}]],
      Annotation[#, -48500, "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Opacity[0.4], 
        LineBox[{2616, 2791, 2778, 3161, 3160, 2870, 3021, 3020, 2368, 2802, 
         2803, 2637, 3026, 2636, 3027, 3029, 3028}], 
        LineBox[{2761, 2702, 2756, 2757, 2700, 2390, 2759, 2389, 2934, 2935, 
         2809, 2852, 3392, 2248, 2293, 3141, 3142, 2931, 2933, 2932, 2384, 
         2937, 2938, 2936, 3224, 3223}]},
       RowBox[{"-", "49000"}]],
      Annotation[#, -49000, "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Opacity[0.4], 
        LineBox[{2249, 2695, 2247, 2808, 2649, 2751, 2750, 2779, 2754, 2755, 
         2646, 2753, 2752, 2699, 2758}]},
       RowBox[{"-", "49500"}]],
      Annotation[#, -49500, "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       {GrayLevel[0], Opacity[0.4], 
        LineBox[{2338, 2687, 2647, 2692, 2691, 2364, 2693, 2694, 2650, 2806, 
         2375}]},
       RowBox[{"-", "50000"}]],
      Annotation[#, -50000, "Tooltip"]& ], {}, {}, {}}}],
  AspectRatio->1,
  Epilog->{
    GrayLevel[1], 
    PointBox[{3.9863760348524226`, 12.503958090576328`}]},
  Frame->True,
  PlotRange->{{3, 5}, {10, 15}},
  PlotRangeClipping->True,
  PlotRangePadding->{
    Scaled[0.02], 
    Scaled[0.02]}]], "Output",
 ImageSize->{184, 182},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[17]=",
 CellID->425445513,ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  InterpretationBox[
   StyleBox[
    GraphicsBox[{},
     BaselinePosition->Baseline,
     ImageSize->{6, 0}],
    CacheGraphics->False],
   Spacer[6]]]],
 "\:0423\:0447\:0435\:0431\:043d\:044b\:0435 \:043c\:0430\:0442\:0435\:0440\
\:0438\:0430\:043b\:044b"
}], "TutorialsSection",
 WholeCellGroupOpener->True,
 CellID->250839057],

Cell["", "SectionHeaderSpacer"],

Cell[BoxData[
 TemplateBox[{
  Cell["Continuous Distributions"],"paclet:tutorial/ContinuousDistributions"},
  "RefLink",
  BaseStyle->"Tutorials"]], "Tutorials",
 CellID->341631938],

Cell[BoxData[
 TemplateBox[{
  Cell["Discrete Distributions"],"paclet:tutorial/DiscreteDistributions"},
  "RefLink",
  BaseStyle->"Tutorials"]], "Tutorials",
 CellID->99946372],

Cell[BoxData[
 TemplateBox[{
  Cell["Random Number Generation"],
   "paclet:tutorial/RandomNumberGenerationOverview"},
  "RefLink",
  BaseStyle->"Tutorials"]], "Tutorials",
 CellID->382326536],

Cell[BoxData[
 TemplateBox[{
  Cell["Multivariate Statistics Package"],
   "paclet:MultivariateStatistics/tutorial/MultivariateStatistics"},
  "RefLink",
  BaseStyle->"Tutorials"]], "Tutorials",
 CellID->1625208335],

Cell["", "SectionFooterSpacer"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\:0421\:043e\:043f\:0443\:0442\:0441\:0442\:0432\:0443\:044e\:0449\:0438\
\:0435 \:0434\:0435\:043c\:043e\:043d\:0441\:0442\:0440\:0430\:0446\:0438\
\:043e\:043d\:043d\:044b\:0435 \:043c\:043e\:0434\:0435\:043b\:0438", \
"RelatedDemonstrationsSection",
 CellID->1268215905],

Cell[TextData[Cell[BoxData[
 TemplateBox[{Cell[
    TextData["Sample versus Theoretical Distribution"]],
   "http://demonstrations.wolfram.com/SampleVersusTheoreticalDistribution/"},
  "WebLink",
  BaseStyle->{"RelatedDemonstrations"}]]]], "RelatedDemonstrations",
 CellID->2037062470],

Cell[TextData[Cell[BoxData[
 TemplateBox[{Cell[
    TextData["Area of a Normal Distribution"]],
   "http://demonstrations.wolfram.com/AreaOfANormalDistribution/"},
  "WebLink",
  BaseStyle->{"RelatedDemonstrations"}]]]], "RelatedDemonstrations",
 CellID->1724632816],

Cell[TextData[Cell[BoxData[
 TemplateBox[{Cell[
    TextData["Exploring the Tails of a Normal Distribution"]],
   "http://demonstrations.wolfram.com/\
ExploringTheTailsOfTheNormalDistribution/"},
  "WebLink",
  BaseStyle->{"RelatedDemonstrations"}]]]], "RelatedDemonstrations",
 CellID->1316954953],

Cell[TextData[Cell[BoxData[
 TemplateBox[{Cell[
    TextData["The Log Normal Distribution"]],
   "http://demonstrations.wolfram.com/TheLogNormalDistribution/"},
  "WebLink",
  BaseStyle->{"RelatedDemonstrations"}]]]], "RelatedDemonstrations",
 CellID->1292371670],

Cell[TextData[Cell[BoxData[
 TemplateBox[{Cell[
    TextData[
     StyleBox[{"Student's ", 
       StyleBox["t", FontSlant -> "Italic"], "-Distribution"}]]],
   "http://demonstrations.wolfram.com/StudentsTDistribution/"},
  "WebLink",
  BaseStyle->{"RelatedDemonstrations"}]]]], "RelatedDemonstrations",
 CellID->1241051932],

Cell[TextData[Cell[BoxData[
 TemplateBox[{Cell[
    TextData["Binomial Distribution"]],
   "http://demonstrations.wolfram.com/BinomialDistribution/"},
  "WebLink",
  BaseStyle->{"RelatedDemonstrations"}]]]], "RelatedDemonstrations",
 CellID->1129518860],

Cell[TextData[Cell[BoxData[
 TemplateBox[{Cell[
    TextData["The Negative Binomial Distribution"]],
   "http://demonstrations.wolfram.com/TheNegativeBinomialDistribution/"},
  "WebLink",
  BaseStyle->{"RelatedDemonstrations"}]]]], "RelatedDemonstrations",
 CellID->1998641460],

Cell[TextData[Cell[BoxData[
 TemplateBox[{Cell[
    TextData["Poisson Distribution"]],
   "http://demonstrations.wolfram.com/PoissonDistribution/"},
  "WebLink",
  BaseStyle->{"RelatedDemonstrations"}]]]], "RelatedDemonstrations",
 CellID->1286228366],

Cell[TextData[Cell[BoxData[
 TemplateBox[{Cell[
    TextData["The Chi-Squared Distribution"]],
   "http://demonstrations.wolfram.com/TheChiSquaredDistribution/"},
  "WebLink",
  BaseStyle->{"RelatedDemonstrations"}]]]], "RelatedDemonstrations",
 CellID->2095429089],

Cell[TextData[Cell[BoxData[
 TemplateBox[{Cell[
    TextData["The Gamma Distribution"]],
   "http://demonstrations.wolfram.com/TheGammaDistribution/"},
  "WebLink",
  BaseStyle->{"RelatedDemonstrations"}]]]], "RelatedDemonstrations",
 CellID->1980094226],

Cell[TextData[Cell[BoxData[
 TemplateBox[{Cell[
    TextData["The Exponential Distribution"]],
   "http://demonstrations.wolfram.com/TheExponentialDistribution/"},
  "WebLink",
  BaseStyle->{"RelatedDemonstrations"}]]]], "RelatedDemonstrations",
 CellID->227811846]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  InterpretationBox[
   StyleBox[
    GraphicsBox[{},
     BaselinePosition->Baseline,
     ImageSize->{6, 0}],
    CacheGraphics->False],
   Spacer[6]]]],
 "\:0421\:043e\:043f\:0443\:0442\:0441\:0442\:0432\:0443\:044e\:0449\:0438\
\:0435 \:0440\:0430\:0437\:0434\:0435\:043b\:044b \:043a\:0440\:0430\:0442\
\:043a\:043e\:0433\:043e \:043a\:0443\:0440\:0441\:0430"
}], "RelatedLinksSection",
 WholeCellGroupOpener->True,
 CellID->1584193535],

Cell["", "SectionHeaderSpacer"],

Cell[TextData[ButtonBox["\:041a\:0440\:0430\:0442\:043a\:0438\:0439 \:043a\
\:0443\:0440\:0441: \:0421\:0442\:0430\:0442\:0438\:0441\:0442\:0438\:0447\
\:0435\:0441\:043a\:0438\:0439 \:0430\:043d\:0430\:043b\:0456\:0437",
 BaseStyle->"Hyperlink",
 ButtonData->{"DoStatisticalAnalysisRU.nb", None}]], "RelatedLinks",
 FontFamily->"Verdana",
 FontSize->11,
 CellID->405226890],

Cell["", "SectionFooterSpacer"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  InterpretationBox[
   StyleBox[
    GraphicsBox[{},
     BaselinePosition->Baseline,
     ImageSize->{6, 0}],
    CacheGraphics->False],
   Spacer[6]]]],
 "\:0421\:043c\:043e\:0442\:0440\:0438 \:0442\:0430\:043a\:0436\:0435"
}], "SeeAlsoSection",
 WholeCellGroupOpener->True,
 CellID->1255426704],

Cell[TextData[{
 Cell[BoxData[
  TemplateBox[{Cell["NormalDistribution"],"paclet:ref/NormalDistribution"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  TemplateBox[{Cell["PDF"],"paclet:ref/PDF"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  TemplateBox[{Cell["Mean"],"paclet:ref/Mean"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  TemplateBox[{Cell["BinomialDistribution"],"paclet:ref/BinomialDistribution"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  TemplateBox[{Cell["RandomVariate"],"paclet:ref/RandomVariate"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  TemplateBox[{Cell["CauchyDistribution"],"paclet:ref/CauchyDistribution"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  TemplateBox[{Cell["ExpectedValue"],"paclet:ref/ExpectedValue"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  TemplateBox[{Cell["PoissonDistribution"],"paclet:ref/PoissonDistribution"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  TemplateBox[{
   Cell["ChiSquareDistribution"],"paclet:ref/ChiSquareDistribution"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  TemplateBox[{
   Cell["GeometricDistribution"],"paclet:ref/GeometricDistribution"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  TemplateBox[{Cell["GammaDistribution"],"paclet:ref/GammaDistribution"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  TemplateBox[{Cell["Histogram"],"paclet:ref/Histogram"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  TemplateBox[{
   Cell["CharacteristicFunction"],"paclet:ref/CharacteristicFunction"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  TemplateBox[{
   Cell["FindDistributionParameters"],"paclet:ref/FindDistributionParameters"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  TemplateBox[{
   Cell["EstimatedDistribution"],"paclet:ref/EstimatedDistribution"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  TemplateBox[{Cell["LogLikelihood"],"paclet:ref/LogLikelihood"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"],
 "\[NonBreakingSpace]",
 StyleBox["\[MediumSpace]\[FilledVerySmallSquare]\[MediumSpace]", 
  "InlineSeparator"],
 " ",
 Cell[BoxData[
  TemplateBox[{Cell["ContourPlot"],"paclet:ref/ContourPlot"},
   "RefLink",
   BaseStyle->{"InlineFormula", FontFamily -> "Verdana"}]], "InlineFormula"]
}], "SeeAlso",
 CellID->929782353]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  InterpretationBox[
   StyleBox[
    GraphicsBox[{},
     BaselinePosition->Baseline,
     ImageSize->{6, 0}],
    CacheGraphics->False],
   Spacer[6]]]],
 "\:0423\:0437\:043d\:0430\:0442\:044c \:0431\:043e\:043b\:044c\:0448\:0435"
}], "MoreAboutSection",
 WholeCellGroupOpener->True,
 CellID->38303248],

Cell["", "SectionHeaderSpacer"],

Cell[BoxData[
 TemplateBox[{
  Cell["Probability & Statistics"],"paclet:guide/ProbabilityAndStatistics"},
  "RefLink",
  BaseStyle->"MoreAbout"]], "MoreAbout",
 CellID->1688108611],

Cell[BoxData[
 TemplateBox[{
  Cell["Parametric Statistical Distributions"],
   "paclet:guide/ParametricStatisticalDistributions"},
  "RefLink",
  BaseStyle->"MoreAbout"]], "MoreAbout",
 CellID->1328014087],

Cell[BoxData[
 TemplateBox[{
  Cell["Derived Distributions"],"paclet:guide/DerivedDistributions"},
  "RefLink",
  BaseStyle->"MoreAbout"]], "MoreAbout",
 CellID->1135216938],

Cell[BoxData[
 TemplateBox[{
  Cell["Normal-Related Distributions"],
   "paclet:guide/NormalRelatedDistributions"},
  "RefLink",
  BaseStyle->"MoreAbout"]], "MoreAbout",
 CellID->1346357018],

Cell[BoxData[
 TemplateBox[{
  Cell["Discrete Univariate Distributions"],
   "paclet:guide/DiscreteUnivariateDistributions"},
  "RefLink",
  BaseStyle->"MoreAbout"]], "MoreAbout",
 CellID->187213087],

Cell[BoxData[
 TemplateBox[{
  Cell["Extreme Value Distributions"],
   "paclet:guide/ExtremeValueDistributions"},
  "RefLink",
  BaseStyle->"MoreAbout"]], "MoreAbout",
 CellID->1365197015],

Cell[BoxData[
 TemplateBox[{
  Cell["Exponential-Related Distributions"],
   "paclet:guide/ExponentialRelatedDistributions"},
  "RefLink",
  BaseStyle->"MoreAbout"]], "MoreAbout",
 CellID->1150946557],

Cell[BoxData[
 TemplateBox[{
  Cell["Heavy Tail Distributions"],"paclet:guide/HeavyTailDistributions"},
  "RefLink",
  BaseStyle->"MoreAbout"]], "MoreAbout",
 CellID->1573574970],

Cell[BoxData[
 TemplateBox[{
  Cell["Urn Model Distributions"],"paclet:guide/UrnModelDistributions"},
  "RefLink",
  BaseStyle->"MoreAbout"]], "MoreAbout",
 CellID->813407985],

Cell[BoxData[
 TemplateBox[{Cell["Statistics"],"paclet:guide/Statistics"},
  "RefLink",
  BaseStyle->"MoreAbout"]], "MoreAbout",
 CellID->29531070],

Cell[BoxData[
 TemplateBox[{
  Cell["Descriptive Statistics"],"paclet:guide/DescriptiveStatistics"},
  "RefLink",
  BaseStyle->"MoreAbout"]], "MoreAbout",
 CellID->369373140],

Cell[BoxData[
 TemplateBox[{
  Cell["Multivariate Statistics Package"],
   "paclet:MultivariateStatistics/guide/MultivariateStatisticsPackage"},
  "RefLink",
  BaseStyle->"MoreAbout"]], "MoreAbout",
 CellID->95779359],

Cell[BoxData[
 TemplateBox[{Cell["\"How to\" Topics"],"paclet:guide/HowToTopics"},
  "RefLink",
  BaseStyle->"MoreAbout"]], "MoreAbout",
 CellID->679812490]
}, Open  ]]
}, Open  ]],

Cell[" ", "FooterCell"]
},
FileChangeProtection->None,
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{Automatic, 510},
WindowMargins->{{312, Automatic}, {Automatic, 0}},
WindowFrame->"Normal",
WindowTitle->"Work with Statistical Distributions - Wolfram Mathematica",
DockedCells->FEPrivate`FrontEndResource["FEExpressions", "HelpViewerToolbar"],
TaggingRules->{
 "ModificationHighlight" -> False, "ColorType" -> "TutorialColor", 
  "LinkTrails" -> "", "ExampleCounter" -> 1, "ExamplePageLinks" -> {}, 
  "RootCaptions" -> "", 
  "Metadata" -> {
   "built" -> "{2013, 1, 24, 22, 49, 55.0854335}", 
    "history" -> {"8", "", "", ""}, "context" -> "System`", 
    "keywords" -> {
     "distribution", "statistical distribution", "probability distribution", 
      "Bernoulli distribution", "beta binomial distribution", 
      "beta distribution", "beta negative binomial distribution", 
      "binomial distribution", "Cauchy distribution", "chi distribution", 
      "chi square distribution", "chi squared distribution", 
      "discrete uniform distribution", "exponential distribution", 
      "extreme value distribution", "F ratio distribution", "F distribution", 
      "Fisher F distribution", "gamma distribution", "geometric distribution",
       "Gumbel distribution", "half normal distribution", 
      "hypergeometric distribution", "inverse chi square distribution", 
      "inverse gamma distribution", "inverse Gaussian distribution", 
      "Laplace distribution", "Levy distribution", "logistic distribution", 
      "log normal distribution", "log series distribution", 
      "log distribution", "Maxwell distribution", 
      "negative binomial distribution", "noncentral chi square distribution", 
      "noncentral F ratio distribution", "noncentral F distribution", 
      "noncentral Student t distribution", "noncentral t distribution", 
      "normal distribution", "Pareto distribution", "Poisson distribution", 
      "Rayleigh distribution", "Student t distribution", "t distribution", 
      "triangular distribution", "uniform distribution", 
      "Weibull distribution", "Zipf distribution"}, "specialkeywords" -> {}, 
    "tutorialcollectionlinks" -> {}, "index" -> True, "label" -> 
    "Mathematica How To", "language" -> "en", "paclet" -> "Mathematica", 
    "status" -> "None", "summary" -> 
    "Statistical distributions have applications in many fields, including \
the biological, social, and physical sciences. Mathematica represents \
statistical distributions as symbolic objects. You can obtain properties, \
results, and random numbers for hundreds of built-in or custom distributions \
by applying built-in functions to the objects.", "synonyms" -> {}, "title" -> 
    "Work with Statistical Distributions", "titlemodifier" -> "", 
    "windowtitle" -> "Work with Statistical Distributions", "type" -> "HowTo",
     "uri" -> "howto/WorkWithStatisticalDistributions"}, 
  "SearchTextTranslated" -> ""},
Magnification->1.,
FrontEndVersion->"10.1 for Microsoft Windows (64-bit) (March 23, 2015)",
StyleDefinitions->FrontEnd`FileName[{"Wolfram"}, "Reference.nb", 
  CharacterEncoding -> "WindowsANSI"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "RasterizedOutput"->{
  Cell[16003, 410, 3717, 69, 145, "Output",
   CellTags->"RasterizedOutput",
   CellID->9203570],
  Cell[59986, 1667, 2996, 57, 129, "Output",
   CellTags->"RasterizedOutput",
   CellID->258406253]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"RasterizedOutput", 226103, 5117}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[628, 21, 7452, 167, 48, "AnchorBarGrid",
 CellID->1],
Cell[CellGroupData[{
Cell[8105, 192, 402, 9, 91, "HowToTitle",
 CellID->509267359],
Cell[CellGroupData[{
Cell[8532, 205, 2176, 34, 90, "HowToAbstract",
 CellID->1045883471],
Cell[10711, 241, 386, 9, 38, "HowToText",
 CellID->1009846402],
Cell[CellGroupData[{
Cell[11122, 254, 148, 4, 28, "Input",
 CellID->827466675],
Cell[11273, 260, 234, 7, 36, "Output",
 CellID->355055]
}, Open  ]],
Cell[11522, 270, 656, 14, 40, "HowToText",
 CellID->1389965763],
Cell[CellGroupData[{
Cell[12203, 288, 204, 6, 28, "Input",
 CellID->411630083],
Cell[12410, 296, 476, 17, 77, "Output",
 CellID->66488460]
}, Open  ]],
Cell[12901, 316, 632, 16, 39, "HowToText",
 CellID->233545351],
Cell[13536, 334, 580, 15, 39, "HowToText",
 CellID->812217608],
Cell[CellGroupData[{
Cell[14141, 353, 196, 6, 28, "Input",
 CellID->1398028897],
Cell[14340, 361, 176, 5, 36, "Output",
 CellID->44861024]
}, Open  ]],
Cell[14531, 369, 528, 9, 38, "HowToText",
 CellID->778662110],
Cell[15062, 380, 579, 13, 39, "HowToText",
 CellID->672294008],
Cell[CellGroupData[{
Cell[15666, 397, 334, 11, 28, "Input",
 CellID->67990700],
Cell[16003, 410, 3717, 69, 145, "Output",
 CellTags->"RasterizedOutput",
 CellID->9203570]
}, Open  ]],
Cell[19735, 482, 1032, 17, 56, "HowToText",
 CellID->629632699],
Cell[20770, 501, 541, 9, 56, "HowToText",
 CellID->146791716],
Cell[CellGroupData[{
Cell[21336, 514, 173, 5, 28, "Input",
 CellID->57340868],
Cell[21512, 521, 161, 5, 36, "Output",
 CellID->306379219]
}, Open  ]],
Cell[21688, 529, 637, 10, 56, "HowToText",
 CellID->99175431],
Cell[22328, 541, 451, 8, 38, "HowToText",
 CellID->298294267],
Cell[CellGroupData[{
Cell[22804, 553, 223, 6, 28, "Input",
 CellID->687318132],
Cell[23030, 561, 342, 10, 36, "Output",
 CellID->799734107]
}, Open  ]],
Cell[23387, 574, 1973, 39, 97, "HowToText",
 CellID->402844773],
Cell[25363, 615, 794, 19, 60, "HowToText",
 CellID->630216976],
Cell[CellGroupData[{
Cell[26182, 638, 179, 6, 28, "Input",
 CellID->708638453],
Cell[26364, 646, 1707, 51, 48, "Output",
 CellID->2783892]
}, Open  ]],
Cell[28086, 700, 665, 13, 58, "HowToText",
 CellID->39677951],
Cell[28754, 715, 559, 11, 39, "HowToText",
 CellID->418309923],
Cell[CellGroupData[{
Cell[29338, 730, 186, 6, 28, "Input",
 CellID->157779646],
Cell[29527, 738, 478, 12, 36, "Output",
 CellID->259790926]
}, Open  ]],
Cell[30020, 753, 806, 14, 57, "HowToText",
 CellID->104295875],
Cell[30829, 769, 640, 14, 49, "HowToText",
 CellID->28617757],
Cell[CellGroupData[{
Cell[31494, 787, 207, 6, 28, "Input",
 CellID->258027569],
Cell[31704, 795, 394, 10, 36, "Output",
 CellID->56376169]
}, Open  ]],
Cell[32113, 808, 635, 10, 56, "HowToText",
 CellID->266275792],
Cell[32751, 820, 570, 14, 39, "HowToText",
 CellID->754271],
Cell[33324, 836, 284, 9, 28, "Input",
 CellID->280764772],
Cell[33611, 847, 706, 14, 58, "HowToText",
 CellID->556967493],
Cell[CellGroupData[{
Cell[34342, 865, 206, 6, 28, "Input",
 CellID->482111473],
Cell[34551, 873, 24463, 761, 161, "Output",
 CellID->28860006]
}, Open  ]],
Cell[59029, 1637, 581, 13, 40, "HowToText",
 CellID->694195944],
Cell[CellGroupData[{
Cell[59635, 1654, 348, 11, 28, "Input",
 CellID->69172925],
Cell[59986, 1667, 2996, 57, 129, "Output",
 CellTags->"RasterizedOutput",
 CellID->258406253]
}, Open  ]],
Cell[62997, 1727, 519, 11, 40, "HowToText",
 CellID->240448043],
Cell[CellGroupData[{
Cell[63541, 1742, 128, 4, 28, "Input",
 CellID->111337083],
Cell[63672, 1748, 35701, 934, 174, "Output",
 CellID->177235876]
}, Open  ]],
Cell[99388, 2685, 1379, 23, 76, "HowToText",
 CellID->728646805],
Cell[CellGroupData[{
Cell[100792, 2712, 265, 7, 28, "Input",
 CellID->57229847],
Cell[101060, 2721, 314, 9, 36, "Output",
 CellID->199766588]
}, Open  ]],
Cell[101389, 2733, 755, 14, 58, "HowToText",
 CellID->382640798],
Cell[CellGroupData[{
Cell[102169, 2751, 257, 7, 28, "Input",
 CellID->337779839],
Cell[102429, 2760, 265, 8, 36, "Output",
 CellID->646541239]
}, Open  ]],
Cell[102709, 2771, 751, 15, 58, "HowToText",
 CellID->303559119],
Cell[CellGroupData[{
Cell[103485, 2790, 141, 4, 28, "Input",
 CellID->260996726],
Cell[103629, 2796, 335, 10, 36, "Output",
 CellID->51635081]
}, Open  ]],
Cell[103979, 2809, 1955, 30, 94, "HowToText",
 CellID->415396916],
Cell[105937, 2841, 283, 4, 38, "HowToText",
 CellID->418167453],
Cell[CellGroupData[{
Cell[106245, 2849, 683, 20, 47, "Input",
 CellID->305665985],
Cell[106931, 2871, 102093, 1724, 261, 89398, 1512, "CachedBoxData", \
"BoxData", "Output",
 CellID->425445513]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[209073, 4601, 362, 13, 31, "TutorialsSection",
 CellID->250839057],
Cell[209438, 4616, 31, 0, 14, "SectionHeaderSpacer"],
Cell[209472, 4618, 181, 5, 19, "Tutorials",
 CellID->341631938],
Cell[209656, 4625, 176, 5, 19, "Tutorials",
 CellID->99946372],
Cell[209835, 4632, 192, 6, 19, "Tutorials",
 CellID->382326536],
Cell[210030, 4640, 215, 6, 19, "Tutorials",
 CellID->1625208335],
Cell[210248, 4648, 31, 0, 29, "SectionFooterSpacer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[210316, 4653, 279, 4, 30, "RelatedDemonstrationsSection",
 CellID->1268215905],
Cell[210598, 4659, 285, 6, 18, "RelatedDemonstrations",
 CellID->2037062470],
Cell[210886, 4667, 266, 6, 18, "RelatedDemonstrations",
 CellID->1724632816],
Cell[211155, 4675, 298, 7, 18, "RelatedDemonstrations",
 CellID->1316954953],
Cell[211456, 4684, 263, 6, 18, "RelatedDemonstrations",
 CellID->1292371670],
Cell[211722, 4692, 324, 8, 18, "RelatedDemonstrations",
 CellID->1241051932],
Cell[212049, 4702, 253, 6, 18, "RelatedDemonstrations",
 CellID->1129518860],
Cell[212305, 4710, 277, 6, 18, "RelatedDemonstrations",
 CellID->1998641460],
Cell[212585, 4718, 251, 6, 18, "RelatedDemonstrations",
 CellID->1286228366],
Cell[212839, 4726, 265, 6, 18, "RelatedDemonstrations",
 CellID->2095429089],
Cell[213107, 4734, 254, 6, 18, "RelatedDemonstrations",
 CellID->1980094226],
Cell[213364, 4742, 265, 6, 18, "RelatedDemonstrations",
 CellID->227811846]
}, Open  ]],
Cell[CellGroupData[{
Cell[213666, 4753, 472, 14, 31, "RelatedLinksSection",
 CellID->1584193535],
Cell[214141, 4769, 31, 0, 14, "SectionHeaderSpacer"],
Cell[214175, 4771, 374, 7, 18, "RelatedLinks",
 CellID->405226890],
Cell[214552, 4780, 31, 0, 29, "SectionFooterSpacer"]
}, Open  ]],
Cell[CellGroupData[{
Cell[214620, 4785, 329, 12, 31, "SeeAlsoSection",
 CellID->1255426704],
Cell[214952, 4799, 5010, 139, 109, "SeeAlso",
 CellID->929782353]
}, Open  ]],
Cell[CellGroupData[{
Cell[219999, 4943, 335, 12, 31, "MoreAboutSection",
 CellID->38303248],
Cell[220337, 4957, 31, 0, 14, "SectionHeaderSpacer"],
Cell[220371, 4959, 180, 5, 19, "MoreAbout",
 CellID->1688108611],
Cell[220554, 4966, 206, 6, 19, "MoreAbout",
 CellID->1328014087],
Cell[220763, 4974, 173, 5, 19, "MoreAbout",
 CellID->1135216938],
Cell[220939, 4981, 190, 6, 19, "MoreAbout",
 CellID->1346357018],
Cell[221132, 4989, 199, 6, 19, "MoreAbout",
 CellID->187213087],
Cell[221334, 4997, 188, 6, 19, "MoreAbout",
 CellID->1365197015],
Cell[221525, 5005, 200, 6, 19, "MoreAbout",
 CellID->1150946557],
Cell[221728, 5013, 178, 5, 19, "MoreAbout",
 CellID->1573574970],
Cell[221909, 5020, 175, 5, 19, "MoreAbout",
 CellID->813407985],
Cell[222087, 5027, 147, 4, 19, "MoreAbout",
 CellID->29531070],
Cell[222237, 5033, 174, 5, 19, "MoreAbout",
 CellID->369373140],
Cell[222414, 5040, 217, 6, 19, "MoreAbout",
 CellID->95779359],
Cell[222634, 5048, 156, 4, 19, "MoreAbout",
 CellID->679812490]
}, Open  ]]
}, Open  ]],
Cell[222817, 5056, 23, 0, 41, "FooterCell"]
}
]
*)

(* End of internal cache information *)
