(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    448195,      12982]
NotebookOptionsPosition[    343795,       9293]
NotebookOutlinePosition[    399207,      11109]
CellTagsIndexPosition[    397511,      11044]
WindowTitle->Working with String Patterns - Wolfram Mathematica
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[GridBox[{
   {Cell["MATHEMATICA TUTORIAL", "PacletNameCell"], Cell[TextData[{
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "Related Guides",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"Related Guides", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->False], {"\<\"String Patterns\"\>":>
       Documentation`HelpLookup["paclet:guide/StringPatterns"]},
       Appearance->None,
       MenuAppearance->Automatic,
       MenuStyle->"TutorialMoreAboutSection"]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "Functions",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"Functions", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->False], {"\<\"CharacterRange\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/CharacterRange"], "\<\"Characters\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/Characters"], "\<\"DatePattern\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/DatePattern"], "\<\"DigitCharacter\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/DigitCharacter"], "\<\"EndOfLine\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/EndOfLine"], "\<\"EndOfString\"\>":>
       Documentation`HelpLookup["paclet:ref/EndOfString"], "\<\"Except\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/Except"], "\<\"HexadecimalCharacter\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/HexadecimalCharacter"], "\<\"LetterCharacter\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/LetterCharacter"], "\<\"Longest\"\>":>
       Documentation`HelpLookup["paclet:ref/Longest"], "\<\"NumberString\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/NumberString"], "\<\"RegularExpression\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/RegularExpression"], "\<\"Shortest\"\>":>
       Documentation`HelpLookup["paclet:ref/Shortest"], "\<\"StartOfLine\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/StartOfLine"], "\<\"StartOfString\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/StartOfString"], "\<\"StringCases\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/StringCases"], "\<\"StringCount\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/StringCount"], "\<\"StringExpression\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/StringExpression"], "\<\"StringFreeQ\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/StringFreeQ"], "\<\"StringMatchQ\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/StringMatchQ"], "\<\"StringPosition\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/StringPosition"], "\<\"StringReplace\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/StringReplace"], "\<\"StringReplaceList\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/StringReplaceList"], "\<\"StringSplit\"\>":>
       Documentation`HelpLookup["paclet:ref/StringSplit"], "\<\"True\"\>":>
       Documentation`HelpLookup["paclet:ref/True"], "\<\"Whitespace\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/Whitespace"], "\<\"WhitespaceCharacter\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/WhitespaceCharacter"], "\<\"WordBoundary\"\>":>
       Documentation`HelpLookup[
       "paclet:ref/WordBoundary"], "\<\"WordCharacter\"\>":>
       Documentation`HelpLookup["paclet:ref/WordCharacter"]},
       Appearance->None,
       MenuAppearance->Automatic,
       MenuStyle->"TutorialFunction"]],
      LineSpacing->{1.4, 0}],
     "\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\[ThickSpace]\
\[ThickSpace]",
     Cell[BoxData[
      ActionMenuBox[
       FrameBox[
        InterpretationBox[Cell[TextData[{
          "URL",
          StyleBox[" \[FilledDownTriangle]", "AnchorBarArrow",
           StripOnInput->False]
         }]],
         TextCell[
          Row[{"URL", 
            Style[" \[FilledDownTriangle]", "AnchorBarArrow"]}]]],
        StripOnInput->False], {"\<\"tutorial/WorkingWithStringPatterns\"\>":>
       None, "\<\"Copy Mathematica URL\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell["tutorial/WorkingWithStringPatterns"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; Null], 
       Delimiter, "\<\"Copy web URL\"\>":>
       Module[{DocumentationSearch`Private`nb$}, 
        DocumentationSearch`Private`nb$ = NotebookPut[
           Notebook[{
             Cell[
              BoxData[
               MakeBoxes[
                Hyperlink[
                "http://reference.wolfram.com/mathematica/tutorial/\
WorkingWithStringPatterns.html"], StandardForm]], "Input", TextClipboardType -> 
              "PlainText"]}, Visible -> False]]; 
        SelectionMove[DocumentationSearch`Private`nb$, All, Notebook]; 
        FrontEndTokenExecute[DocumentationSearch`Private`nb$, "Copy"]; 
        NotebookClose[DocumentationSearch`Private`nb$]; 
        Null], "\<\"Go to web URL\"\>":>FrontEndExecute[{
         NotebookLocate[{
           URL[
            StringJoin[
            "http://reference.wolfram.com/mathematica/", 
             "tutorial/WorkingWithStringPatterns", ".html"]], None}]}]},
       Appearance->None,
       MenuAppearance->Automatic]],
      LineSpacing->{1.4, 0}]
    }], "AnchorBar"]}
  }]], "AnchorBarGrid",
 CellID->1],

Cell[CellGroupData[{

Cell["\:0420\:0430\:0431\:043e\:0442\:0430 \:0441 \:0448\:0430\:0431\:043b\
\:043e\:043d\:0430\:043c\:0438 \:0434\:043b\:044f \:0442\:0435\:043a\:0441\
\:0442\:043e\:0432\:044b\:0445 \:0444\:0440\:0430\:0433\:043c\:0435\:043d\
\:0442\:043e\:0432", "Title",
 CellID->174764828],

Cell[BoxData[GridBox[{
   {Cell[BoxData[
     ButtonBox[
      RowBox[{
      "\[RightGuillemet]", " ", 
       "\:0412\:0432\:0435\:0434\:0435\:043d\:0438\:0435"}],
      BaseStyle->"Hyperlink",
      ButtonData->{"WorkingWithStringPatternsRU.nb", "c:1"}]],
     FontFamily->"Arial",
     FontSize->13,
     FontWeight->Bold], Cell[BoxData[
     ButtonBox[
      RowBox[{
      "\[RightGuillemet]", " ", "\:0414\:043b\:044f", " ", 
       "\:043f\:043e\:043b\:044c\:0437\:043e\:0432\:0430\:0442\:0435\:043b\
\:0435\:0439", " ", "Perl"}],
      BaseStyle->"Hyperlink",
      ButtonData->{"WorkingWithStringPatternsRU.nb", "c:15"}]],
     FontFamily->"Arial",
     FontSize->13,
     FontWeight->Bold]},
   {Cell[BoxData[
     ButtonBox[
      RowBox[{
      "\[RightGuillemet]", " ", "\:041e\:0431\:0449\:0438\:0435", " ", 
       "\:0448\:0430\:0431\:043b\:043e\:043d\:044b", " ", 
       "\:0434\:043b\:044f", " ", 
       "\:0442\:0435\:043a\:0441\:0442\:043e\:0432\:044b\:0445", " ", 
       "\:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442\:043e\:0432"}],
      BaseStyle->"Hyperlink",
      ButtonData->{"WorkingWithStringPatternsRU.nb", "c:2"}]],
     FontFamily->"Arial",
     FontSize->13,
     FontWeight->Bold], Cell[BoxData[
     ButtonBox[
      RowBox[{
      "\[RightGuillemet]", " ", 
       "\:041d\:0435\:0441\:043a\:043e\:043b\:044c\:043a\:043e", " ", 
       "\:043f\:0440\:0438\:043c\:0435\:0440\:043e\:0432"}],
      BaseStyle->"Hyperlink",
      ButtonData->{"WorkingWithStringPatternsRU.nb", "c:20"}]],
     FontFamily->"Arial",
     FontSize->13,
     FontWeight->Bold]},
   {Cell[BoxData[
     ButtonBox[
      RowBox[{
      "\[RightGuillemet]", " ", 
       "\:0420\:0435\:0433\:0443\:043b\:044f\:0440\:043d\:044b\:0435", " ", 
       "\:0432\:044b\:0440\:0430\:0436\:0435\:043d\:0438\:044f"}],
      BaseStyle->"Hyperlink",
      ButtonData->{"WorkingWithStringPatternsRU.nb", "c:3"}]],
     FontFamily->"Arial",
     FontSize->13,
     FontWeight->Bold], Cell[BoxData[
     ButtonBox[
      RowBox[{
      "\[RightGuillemet]", " ", "\:0421\:043e\:0432\:0435\:0442\:044b", " ", 
       "\:0434\:043b\:044f", " ", 
       "\:044d\:0444\:0444\:0435\:043a\:0442\:0438\:0432\:043d\:043e\:0433\
\:043e", " ", "\:043f\:043e\:0438\:0441\:043a\:0430", " ", 
       "\:0441\:043e\:0432\:043f\:0430\:0434\:0435\:043d\:0438\:0439"}],
      BaseStyle->"Hyperlink",
      ButtonData->{"WorkingWithStringPatternsRU.nb", "c:25"}]],
     FontFamily->"Arial",
     FontSize->13,
     FontWeight->Bold]},
   {Cell[BoxData[
     ButtonBox[
      RowBox[{
      "\[RightGuillemet]", " ", 
       "\:0421\:0440\:0430\:0432\:043d\:0435\:043d\:0438\:0435", " ", 
       "RegularExpression", " ", "\:0438", " ", "StringExpression"}],
      BaseStyle->"Hyperlink",
      ButtonData->{"WorkingWithStringPatternsRU.nb", "c:4"}]],
     FontFamily->"Arial",
     FontSize->13,
     FontWeight->Bold], Cell[BoxData[
     ButtonBox[
      RowBox[{
      "\[RightGuillemet]", " ", 
       "\:041f\:043e\:0434\:0440\:043e\:0431\:043d\:043e\:0441\:0442\:0438", 
       " ", "\:043c\:0435\:0445\:0430\:043d\:0438\:0437\:043c\:0430", " ", 
       "\:0440\:0435\:0430\:043b\:0438\:0437\:0430\:0446\:0438\:0438"}],
      BaseStyle->"Hyperlink",
      ButtonData->{"WorkingWithStringPatternsRU.nb", "c:31"}]],
     FontFamily->"Arial",
     FontSize->13,
     FontWeight->Bold]},
   {Cell[BoxData[
     ButtonBox[
      RowBox[{
      "\[RightGuillemet]", " ", "\:0424\:0443\:043d\:043a\:0446\:0438\:0438", 
       " ", "\:0434\:043b\:044f", " ", "\:0440\:0430\:0431\:043e\:0442\:044b",
        " ", "\:0441", " ", 
       "\:0442\:0435\:043a\:0441\:0442\:043e\:0432\:044b\:043c\:0438", " ", 
       "\:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442\:0430\:043c\:0438"}],
      BaseStyle->"Hyperlink",
      ButtonData->{"WorkingWithStringPatternsRU.nb", "c:5"}]],
     FontFamily->"Arial",
     FontSize->13,
     FontWeight->Bold], Cell[BoxData[
     ButtonBox[
      RowBox[{
      "\[RightGuillemet]", " ", "\:0421\:0441\:044b\:043b\:043a\:0438"}],
      BaseStyle->"Hyperlink",
      ButtonData->{"WorkingWithStringPatternsRU.nb", "c:32"}]],
     FontFamily->"Arial",
     FontSize->13,
     FontWeight->Bold]}
  }]], "TutorialJumpBox",
 CellID->499765158],

Cell[CellGroupData[{

Cell["\:0412\:0432\:0435\:0434\:0435\:043d\:0438\:0435", "Section",
 CellTags->{"c:1", "b:0.0"},
 CellID->6475218],

Cell[TextData[{
 "\:041e\:0431\:0449\:0438\:0435 \:0441\:0438\:043c\:0432\:043e\:043b\:044c\
\:043d\:044b\:0435 \:0448\:0430\:0431\:043b\:043e\:043d\:044b ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " \:0434\:043b\:044f \:0442\:0435\:043a\:0441\:0442\:043e\:0432\:044b\:0445 \
\:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442\:043e\:0432 \:043f\:043e\
\:0437\:0432\:043e\:043b\:044f\:044e\:0442 \:044d\:0444\:0444\:0435\:043a\
\:0442\:0438\:0432\:043d\:043e \:0432\:044b\:043f\:043e\:043b\:043d\:044f\
\:0442\:044c \:043c\:043e\:0449\:043d\:044b\:0435 \:043e\:043f\:0435\:0440\
\:0430\:0446\:0438\:0438 \:043f\:043e \:043e\:0431\:0440\:0430\:0431\:043e\
\:0442\:043a\:0435 \:0442\:0435\:043a\:0441\:0442\:043e\:0432\:044b\:0445 \
\:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442\:043e\:0432. \:0412 \:043f\
\:0440\:0438\:0432\:0435\:0434\:0435\:043d\:043d\:043e\:043c \:0434\:0430\
\:043b\:0435\:0435 \:043c\:0430\:0442\:0435\:0440\:0438\:0430\:043b\:0435 \
\:043e\:0431\:0441\:0443\:0436\:0434\:0430\:044e\:0442\:0441\:044f \:0434\
\:0435\:0442\:0430\:043b\:0438 \:0448\:0430\:0431\:043b\:043e\:043d\:043e\
\:0432 \:0434\:043b\:044f \:0442\:0435\:043a\:0441\:0442\:043e\:0432\:044b\
\:0445 \:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442\:043e\:0432, \:0432 \
\:0442\:043e\:043c \:0447\:0438\:0441\:043b\:0435 \:0434\:0435\:0442\:0430\
\:043b\:0438 \:0438\:0445 \:0438\:0441\:043f\:043e\:043b\:044c\:0437\:043e\
\:0432\:0430\:043d\:0438\:044f \:0438 \:0442\:043e\:043d\:043a\:043e\:0441\
\:0442\:0438 \:043f\:0440\:0430\:043a\:0442\:0438\:0447\:0435\:0441\:043a\
\:043e\:0439 \:0440\:0435\:0430\:043b\:0438\:0437\:0430\:0446\:0438\:0438.  \
\:041e\:0441\:043d\:043e\:0432\:043d\:043e\:0439 \:0430\:043a\:0446\:0435\
\:043d\:0442 \:0434\:0435\:043b\:0430\:0435\:0442\:0441\:044f \:043d\:0430 \
\:0432\:043e\:043f\:0440\:043e\:0441\:044b, \:043d\:0435 \:0443\:043f\:043e\
\:043c\:044f\:043d\:0443\:0442\:044b\:0435 \:0432 \:0434\:0440\:0443\:0433\
\:0438\:0445 \:043c\:0435\:0441\:0442\:0430\:0445 \:0432 \:0441\:043f\:0440\
\:0430\:0432\:043e\:0447\:043d\:043e\:0439 \:0441\:0438\:0441\:0442\:0435\
\:043c\:0435."
}], "Text",
 CellTags->"b:0.0",
 CellID->879271277],

Cell[TextData[{
 "\:0412 \:043e\:0441\:043d\:043e\:0432\:0443 ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " \:0437\:0430\:043b\:043e\:0436\:0435\:043d \:043c\:043e\:0449\:043d\:044b\
\:0439 \:044f\:0437\:044b\:043a \:0434\:043b\:044f \:043e\:043f\:0438\:0441\
\:0430\:043d\:0438\:044f \:0448\:0430\:0431\:043b\:043e\:043d\:043e\:0432 \
\:0432 \:043e\:0431\:0449\:0438\:0445 \:0432\:044b\:0440\:0430\:0436\:0435\
\:043d\:0438\:044f\:0445. \:042d\:0442\:043e\:0442 \:044f\:0437\:044b\:043a \
\:043f\:0440\:0438\:043c\:0435\:043d\:044f\:0435\:0442\:0441\:044f \:0432 \
\:043e\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\:0438\:044f\:0445 \
\:0444\:0443\:043d\:043a\:0446\:0438\:0439, \:043e\:043f\:0435\:0440\:0430\
\:0446\:0438\:044f\:0445 \:0437\:0430\:043c\:0435\:043d\:044b \:0438 \:043f\
\:043e\:0438\:0441\:043a\:0430, \:0438\:0441\:043f\:043e\:043b\:044c\:0437\
\:0443\:0435\:0442\:0441\:044f \:0441 \:043a\:043e\:043d\:0441\:0442\:0440\
\:0443\:043a\:0446\:0438\:044f\:043c\:0438 \:0432\:0438\:0434\:0430 ",
 Cell[BoxData["x_"], "InlineFormula"],
 ", ",
 Cell[BoxData[
  RowBox[{"a", "|", "b"}]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  RowBox[{"x", ".."}]], "InlineFormula"],
 ", \:0438 \:0442\:0430\:043a \:0434\:0430\:043b\:0435\:0435. "
}], "MathCaption",
 CellTags->"b:0.0",
 CellID->217261366],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MatchQ", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "c", ",", "d"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"___", ",", "x_", ",", "x_", ",", "___"}], "}"}]}], 
  "]"}]], "Input",
 CellTags->"b:0.0",
 CellLabel->"In[1]:=",
 CellID->6793186],

Cell[BoxData["False"], "Output",
 ImageSize->{39, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.0",
 CellLabel->"Out[1]=",
 CellID->88064594]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MatchQ", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "c", ",", "c", ",", "d"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"___", ",", "x_", ",", "x_", ",", "___"}], "}"}]}], 
  "]"}]], "Input",
 CellTags->"b:0.0",
 CellLabel->"In[2]:=",
 CellID->397472003],

Cell[BoxData["True"], "Output",
 ImageSize->{32, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.0",
 CellLabel->"Out[2]=",
 CellID->293854130]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Cases", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"a", ",", "3", ",", "4", ",", "b", ",", "c", ",", "8"}], "}"}], 
   ",", "_Integer"}], "]"}]], "Input",
 CellTags->"b:0.0",
 CellLabel->"In[3]:=",
 CellID->108872960],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"3", ",", "4", ",", "8"}], "}"}]], "Output",
 ImageSize->{61, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.0",
 CellLabel->"Out[3]=",
 CellID->516087023]
}, Open  ]],

Cell[TextData[{
 "\:0428\:0430\:0431\:043b\:043e\:043d\:044b ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " \:0434\:043b\:044f \:0442\:0435\:043a\:0441\:0442\:043e\:0432\:044b\:0445 \
\:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442\:043e\:0432 \:0438\:0441\
\:043f\:043e\:043b\:044c\:0437\:0443\:044e\:0442 \:0442\:0430\:043a\:0438\
\:0435 \:0436\:0435 \:0441\:0430\:043c\:044b\:0435 \:043a\:043e\:043d\:0446\
\:0435\:043f\:0446\:0438\:0438 \:0434\:043b\:044f \:043e\:043f\:0438\:0441\
\:0430\:043d\:0438\:044f \:0448\:0430\:0431\:043b\:043e\:043d\:043e\:0432 \
\:043f\:0440\:0438\:043c\:0435\:043d\:044f\:0435\:043c\:044b\:0445 \:043a \
\:0441\:0442\:0440\:043e\:043a\:0430\:043c \:0442\:0435\:043a\:0441\:0442\
\:0430. \:0422\:0435\:043a\:0441\:0442\:043e\:0432\:044b\:0439 \:0444\:0440\
\:0430\:0433\:043c\:0435\:043d\:0442 \:043c\:043e\:0436\:043d\:043e \:043f\
\:0440\:0435\:0434\:0441\:0442\:0430\:0432\:0438\:0442\:044c \:043a\:0430\
\:043a \:043f\:043e\:0441\:043b\:0435\:0434\:043e\:0432\:0430\:0442\:0435\
\:043b\:044c\:043d\:043e\:0441\:0442\:044c \:0441\:0438\:043c\:0432\:043e\
\:043b\:043e\:0432, \:043a \:043a\:043e\:0442\:043e\:0440\:044b\:043c \:043c\
\:043e\:0436\:043d\:043e \:043f\:0440\:0438\:043c\:0435\:043d\:044f\:0442\
\:044c \:043c\:0435\:0442\:043e\:0434\:044b \:043e\:0431\:0449\:0438\:0445 \
\:0448\:0430\:0431\:043b\:043e\:043d\:043e\:0432 ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ". \:041f\:043e\:043c\:0438\:043c\:043e \:044d\:0442\:043e\:0433\:043e, \
\:0441\:0443\:0449\:0435\:0441\:0442\:0432\:0443\:0435\:0442 \:043d\:0435\
\:0441\:043a\:043e\:043b\:044c\:043a\:043e \:044d\:0444\:0444\:0435\:043a\
\:0442\:0438\:0432\:043d\:044b\:0445 \:043a\:043e\:043d\:0441\:0442\:0440\
\:0443\:043a\:0446\:0438\:0439 \:0448\:0430\:0431\:043b\:043e\:043d\:043e\
\:0432, \:0441\:043f\:0435\:0446\:0438\:0430\:043b\:044c\:043d\:043e \:043f\
\:0440\:0435\:0434\:043d\:0430\:0437\:043d\:0430\:0447\:0435\:043d\:043d\:044b\
\:0445 \:0434\:043b\:044f \:0442\:0435\:043a\:0441\:0442\:043e\:0432\:044b\
\:0445 \:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442\:043e\:0432."
}], "MathCaption",
 CellTags->"b:0.0",
 CellID->47601161],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringMatchQ", "[", 
  RowBox[{"\"\<abcd\>\"", ",", 
   RowBox[{"___", "~~", 
    RowBox[{"x_", "~~", 
     RowBox[{"x_", "~~", "___"}]}]}]}], "]"}]], "Input",
 CellTags->"b:0.0",
 CellLabel->"In[4]:=",
 CellID->164239912],

Cell[BoxData["False"], "Output",
 ImageSize->{39, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.0",
 CellLabel->"Out[4]=",
 CellID->22481105]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringMatchQ", "[", 
  RowBox[{"\"\<abccd\>\"", ",", 
   RowBox[{"___", "~~", 
    RowBox[{"x_", "~~", 
     RowBox[{"x_", "~~", "___"}]}]}]}], "]"}]], "Input",
 CellTags->"b:0.0",
 CellLabel->"In[5]:=",
 CellID->340018981],

Cell[BoxData["True"], "Output",
 ImageSize->{32, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.0",
 CellLabel->"Out[5]=",
 CellID->335521681]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringCases", "[", 
  RowBox[{"\"\<a34bc8\>\"", ",", "DigitCharacter"}], "]"}]], "Input",
 CellTags->"b:0.0",
 CellLabel->"In[6]:=",
 CellID->327756114],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"3\"\>", ",", "\<\"4\"\>", ",", "\<\"8\"\>"}], "}"}]], "Output",
 ImageSize->{61, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.0",
 CellLabel->"Out[6]=",
 CellID->365251227]
}, Open  ]],

Cell["\<\
\:0420\:0435\:0433\:0443\:043b\:044f\:0440\:043d\:044b\:0435 \:0432\:044b\
\:0440\:0430\:0436\:0435\:043d\:0438\:044f \:043c\:043e\:0433\:0443\:0442 \
\:0431\:044b\:0442\:044c \:0438\:0441\:043f\:043e\:043b\:044c\:0437\:043e\
\:0432\:0430\:043d\:044b \:0432 \:043a\:0430\:0447\:0435\:0441\:0442\:0432\
\:0435 \:0430\:043b\:044c\:0442\:0435\:0440\:043d\:0430\:0442\:0438\:0432\
\:043d\:043e\:0433\:043e \:0441\:043f\:043e\:0441\:043e\:0431\:0430 \:0437\
\:0430\:0434\:0430\:043d\:0438\:044f \:0448\:0430\:0431\:043b\:043e\:043d\
\:043e\:0432 \:0434\:043b\:044f \:0442\:0435\:043a\:0441\:0442\:043e\:0432\
\:044b\:0445 \:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442\:043e\:0432. \
\:041e\:043d\:0438, \:043a\:0430\:043a \:043f\:0440\:0430\:0432\:0438\:043b\
\:043e, \:0431\:043e\:043b\:0435\:0435 \:043a\:043e\:043c\:043f\:0430\:043a\
\:0442\:043d\:044b, \:043d\:043e \:0441\:043b\:043e\:0436\:043d\:0435\:0435 \
\:0434\:043b\:044f \:0432\:043e\:0441\:043f\:0440\:0438\:044f\:0442\:0438\
\:044f.\
\>", "MathCaption",
 CellTags->"b:0.0",
 CellID->7623660],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringMatchQ", "[", 
  RowBox[{"\"\<abcd\>\"", ",", 
   RowBox[{"RegularExpression", "[", "\"\<.*(.)\\\\1.*\>\"", "]"}]}], 
  "]"}]], "Input",
 CellTags->"b:0.0",
 CellLabel->"In[7]:=",
 CellID->257665367],

Cell[BoxData["False"], "Output",
 ImageSize->{39, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.0",
 CellLabel->"Out[7]=",
 CellID->1666481]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringMatchQ", "[", 
  RowBox[{"\"\<abccd\>\"", ",", 
   RowBox[{"RegularExpression", "[", "\"\<.*(.)\\\\1.*\>\"", "]"}]}], 
  "]"}]], "Input",
 CellTags->"b:0.0",
 CellLabel->"In[8]:=",
 CellID->15296355],

Cell[BoxData["True"], "Output",
 ImageSize->{32, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.0",
 CellLabel->"Out[8]=",
 CellID->816730330]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringCases", "[", 
  RowBox[{"\"\<a34bc8\>\"", ",", 
   RowBox[{"RegularExpression", "[", "\"\<\\\\d\>\"", "]"}]}], "]"}]], "Input",
 CellTags->"b:0.0",
 CellLabel->"In[9]:=",
 CellID->44443359],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"3\"\>", ",", "\<\"4\"\>", ",", "\<\"8\"\>"}], "}"}]], "Output",
 ImageSize->{61, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.0",
 CellLabel->"Out[9]=",
 CellID->259369629]
}, Open  ]],

Cell["\<\
\:042d\:0442\:043e \:0441\:043f\:0438\:0441\:043e\:043a \:0438\:0437 \:043d\
\:0435\:0441\:043a\:043e\:043b\:044c\:043a\:0438\:0445 \:0444\:0443\:043d\
\:043a\:0446\:0438\:0439, \:043a\:043e\:0442\:043e\:0440\:044b\:0435 \:0440\
\:0430\:0441\:043f\:043e\:0437\:043d\:0430\:044e\:0442 \:0438 \:0432\:043e\
\:0441\:043f\:0440\:0438\:043d\:0438\:043c\:0430\:044e\:0442 \:0448\:0430\
\:0431\:043b\:043e\:043d\:044b \:0442\:0435\:043a\:0441\:0442\:043e\:0432\
\:044b\:0445 \:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442\:043e\:0432.\
\>", "Text",
 CellTags->"b:0.0",
 CellID->131976413],

Cell[BoxData[GridBox[{
   {
    RowBox[{
     ButtonBox["StringMatchQ",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/StringMatchQ"], "[", 
     RowBox[{"\"\<\!\(\*
StyleBox[\"s\", \"TI\"]\)\>\"", ",", 
      StyleBox["\:0448\:0430\:0431\:043b\:043e\:043d", "TI"]}], "]"}], Cell[
    TextData[{
     "\:0442\:0435\:0441\:0442 \:043d\:0430 \:0441\:043e\:043e\:0442\:0432\
\:0435\:0442\:0441\:0442\:0432\:0438\:0435 ",
     Cell[BoxData["\"\<\!\(\*
StyleBox[\"s\", \"TI\"]\)\>\""], "InlineFormula"],
     " ",
     Cell[BoxData[
      StyleBox["\:0448\:0430\:0431\:043b\:043e\:043d\:0443", "TI"]], 
      "InlineFormula"]
    }], "TableText"]},
   {
    RowBox[{
     ButtonBox["StringFreeQ",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/StringFreeQ"], "[", 
     RowBox[{"\"\<\!\(\*
StyleBox[\"s\", \"TI\"]\)\>\"", ",", 
      StyleBox["\:0448\:0430\:0431\:043b\:043e\:043d", "TI"]}], "]"}], Cell[
    TextData[{
     "\:0442\:0435\:0441\:0442 \:043d\:0430 \:043e\:0442\:0441\:0443\:0442\
\:0441\:0442\:0432\:0438\:0438 \:0432 ",
     Cell[BoxData["\"\<\!\(\*
StyleBox[\"s\", \"TI\"]\)\>\""], "InlineFormula"],
     " \:0441\:0443\:0431\:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442\
\:043e\:0432, \:0441\:043e\:043e\:0442\:0432\:0435\:0442\:0441\:0442\:0432\
\:0443\:044e\:0449\:0438\:0445 ",
     Cell[BoxData[
      StyleBox["\:0448\:0430\:0431\:043b\:043e\:043d\:0443", "TI"]], 
      "InlineFormula"]
    }], "TableText"]},
   {
    RowBox[{
     ButtonBox["StringCases",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/StringCases"], "[", 
     RowBox[{"\"\<\!\(\*
StyleBox[\"s\", \"TI\"]\)\>\"", ",", 
      StyleBox["\:0448\:0430\:0431\:043b\:043e\:043d", "TI"]}], "]"}], Cell[
    TextData[{
     "\:0432\:043e\:0437\:0432\:0440\:0430\:0449\:0430\:0435\:0442 \:0438\
\:0437 ",
     Cell[BoxData["\"\<\!\(\*
StyleBox[\"s\", \"TI\"]\)\>\""], "InlineFormula"],
     " \:0441\:043f\:0438\:0441\:043e\:043a \:0441\:0443\:0431\:0444\:0440\
\:0430\:0433\:043c\:0435\:043d\:0442\:043e\:0432, \:043a\:043e\:0442\:043e\
\:0440\:044b\:0435 \:0441\:043e\:043e\:0442\:0432\:0435\:0442\:0441\:0442\
\:0432\:0443\:044e\:0442 ",
     Cell[BoxData[
      StyleBox["\:0448\:0430\:0431\:043b\:043e\:043d\:0443", "TI"]], 
      "InlineFormula"]
    }], "TableText"]},
   {
    RowBox[{
     ButtonBox["StringCases",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/StringCases"], "[", "\"\<\!\(\*
StyleBox[\"s\", \"TI\"]\)\>\"", ",", 
     StyleBox["lhs", "TI"], "->", 
     StyleBox["rhs", "TI"], "]"}], Cell[TextData[{
     "\:0437\:0430\:043c\:0435\:043d\:044f\:0435\:0442 \:043a\:0430\:0436\
\:0434\:043e\:0435 \:043f\:043e\:044f\:0432\:043b\:0435\:043d\:0438\:0435 ",
     Cell[BoxData[
      StyleBox["lhs", "TI"]], "InlineFormula"],
     " \:043d\:0430 ",
     Cell[BoxData[
      StyleBox["rhs", "TI"]], "InlineFormula"]
    }], "TableText"]},
   {
    RowBox[{
     ButtonBox["StringPosition",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/StringPosition"], "[", 
     RowBox[{"\"\<\!\(\*
StyleBox[\"s\", \"TI\"]\)\>\"", ",", 
      StyleBox["\:0448\:0430\:0431\:043b\:043e\:043d", "TI"]}], "]"}], Cell[
    TextData[{
     "\:0432\:043e\:0437\:0432\:0440\:0430\:0449\:0430\:0435\:0442 \:0441\
\:043f\:0438\:0441\:043e\:043a \:043f\:043e\:0437\:0438\:0446\:0438\:0439 \
\:0441\:0443\:0431\:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442\:043e\:0432\
, \:043a\:043e\:0442\:043e\:0440\:044b\:0435 \:0441\:043e\:043e\:0442\:0432\
\:0435\:0442\:0441\:0442\:0432\:0443\:044e\:0442 ",
     Cell[BoxData[
      StyleBox["\:0448\:0430\:0431\:043b\:043e\:043d\:0443", "TI"]], 
      "InlineFormula"],
     " "
    }], "TableText"]},
   {
    RowBox[{
     ButtonBox["StringCount",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/StringCount"], "[", 
     RowBox[{"\"\<\!\(\*
StyleBox[\"s\", \"TI\"]\)\>\"", ",", 
      StyleBox["\:0448\:0430\:0431\:043b\:043e\:043d", "TI"]}], "]"}], Cell[
    TextData[{
     "\:043f\:043e\:0434\:0441\:0447\:0438\:0442\:044b\:0432\:0430\:0435\:0442\
, \:0441\:043a\:043e\:043b\:044c\:043a\:043e \:0441\:0443\:0431\:0444\:0440\
\:0430\:0433\:043c\:0435\:043d\:0442\:043e\:0432 \:0441\:043e\:043e\:0442\
\:0432\:0435\:0442\:0441\:0442\:0432\:0443\:044e\:0442  ",
     Cell[BoxData[
      StyleBox["\:0448\:0430\:0431\:043b\:043e\:043d\:0443", "TI"]], 
      "InlineFormula"]
    }], "TableText"]},
   {
    RowBox[{
     ButtonBox["StringReplace",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/StringReplace"], "[", "\"\<\!\(\*
StyleBox[\"s\", \"TI\"]\)\>\"", ",", 
     StyleBox["lhs", "TI"], "->", 
     StyleBox["rhs", "TI"], "]"}], Cell[TextData[{
     "\:0437\:0430\:043c\:0435\:043d\:044f\:0435\:0442 \:043a\:0430\:0436\
\:0434\:044b\:0439 \:0441\:0443\:0431\:0444\:0440\:0430\:0433\:043c\:0435\
\:043d\:0442, \:0441\:043e\:043e\:0442\:0432\:0435\:0442\:0441\:0442\:0432\
\:0443\:044e\:0449\:0438\:0439 ",
     Cell[BoxData[
      StyleBox["lhs", "TI"]], "InlineFormula"]
    }], "TableText"]},
   {
    RowBox[{
     ButtonBox["StringReplaceList",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/StringReplaceList"], "[", "\"\<\!\(\*
StyleBox[\"s\", \"TI\"]\)\>\"", ",", 
     StyleBox["lhs", "TI"], "->", 
     StyleBox["rhs", "TI"], "]"}], Cell[TextData[{
     "\:0432\:043e\:0437\:0432\:0440\:0430\:0449\:0430\:0435\:0442 \:0441\
\:043f\:0438\:0441\:043e\:043a \:0440\:0435\:0437\:0443\:043b\:044c\:0442\
\:0430\:0442\:043e\:0432 \:0437\:0430\:043c\:0435\:043d\:044b ",
     Cell[BoxData[
      StyleBox["lhs", "TI"]], "InlineFormula"]
    }], "TableText"]},
   {
    RowBox[{
     ButtonBox["StringSplit",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/StringSplit"], "[", 
     RowBox[{"\"\<\!\(\*
StyleBox[\"s\", \"TI\"]\)\>\"", ",", 
      StyleBox["\:0448\:0430\:0431\:043b\:043e\:043d", "TI"]}], "]"}], Cell[
    TextData[{
     "\:0440\:0430\:0437\:0434\:0435\:043b\:044f\:0435\:0442 ",
     Cell[BoxData[
      StyleBox["s", "TI"]], "InlineFormula"],
     " \:043f\:043e \:043c\:0435\:0441\:0442\:0430\:043c \:0440\:0430\:0441\
\:043f\:043e\:043b\:043e\:0436\:0435\:043d\:0438\:044f \:043a\:0430\:0436\
\:0434\:043e\:0433\:043e \:0441\:0443\:0431\:0444\:0440\:0430\:0433\:043c\
\:0435\:043d\:0442\:0430, \:0441\:043e\:043e\:0442\:0432\:0435\:0442\:0441\
\:0442\:0432\:0443\:044e\:0449\:0435\:0433\:043e ",
     Cell[BoxData[
      StyleBox["\:0448\:0430\:0431\:043b\:043e\:043d\:0443", "TI"]], 
      "InlineFormula"]
    }], "TableText"]},
   {
    RowBox[{
     ButtonBox["StringSplit",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/StringSplit"], "[", "\"\<\!\(\*
StyleBox[\"s\", \"TI\"]\)\>\"", ",", 
     StyleBox["lhs", "TI"], "->", 
     StyleBox["rhs", "TI"], "]"}], Cell[TextData[{
     "\:0440\:0430\:0437\:0434\:0435\:043b\:044f\:0435\:0442 \:0432 \:043c\
\:0435\:0441\:0442\:0435 \:0440\:0430\:0441\:043f\:043e\:043b\:043e\:0436\
\:0435\:043d\:0438\:044f ",
     Cell[BoxData[
      StyleBox["lhs", "TI"]], "InlineFormula"],
     ", \:0432\:0441\:0442\:0430\:0432\:043b\:044f\:044f ",
     Cell[BoxData[
      StyleBox["rhs", "TI"]], "InlineFormula"],
     " \:043d\:0430 \:0435\:0433\:043e \:043c\:0435\:0441\:0442\:043e"
    }], "TableText"]}
  }]], "DefinitionBox",
 GridBoxOptions->{
 GridBoxDividers->{
  "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
   "Rows" -> {
    False, False, True, False, False, False, True, False, True, False, False, 
     False}, "RowsIndexed" -> {}}},
 CellID->28981],

Cell["\:0424\:0443\:043d\:043a\:0446\:0438\:0438, \:043f\:043e\:0434\:0434\
\:0435\:0440\:0436\:0438\:0432\:0430\:044e\:0449\:0438\:0435 \:0448\:0430\
\:0431\:043b\:043e\:043d\:044b \:0434\:043b\:044f \:0442\:0435\:043a\:0441\
\:0442\:043e\:0432\:044b\:0445 \:0444\:0440\:0430\:0433\:043c\:0435\:043d\
\:0442\:043e\:0432. ", "Caption",
 CellTags->"b:0.0",
 CellID->49176434]
}, Open  ]],

Cell[CellGroupData[{

Cell["\:041e\:0431\:0449\:0438\:0435 \:0448\:0430\:0431\:043b\:043e\:043d\
\:044b \:0434\:043b\:044f \:0442\:0435\:043a\:0441\:0442\:043e\:0432\:044b\
\:0445 \:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442\:043e\:0432", \
"Section",
 CellTags->{"c:2", "b:0.1"},
 CellID->316252289],

Cell[TextData[{
 "\:041e\:0431\:0449\:0438\:0439 \:0448\:0430\:0431\:043b\:043e\:043d \:0434\
\:043b\:044f \:0442\:0435\:043a\:0441\:0442\:043e\:0432\:044b\:0445 \:0444\
\:0440\:0430\:0433\:043c\:0435\:043d\:0442\:043e\:0432 \:0441\:043e\:0437\
\:0434\:0430\:0435\:0442\:0441\:044f \:0438\:0437 \:043e\:0431\:044a\:0435\
\:043a\:0442\:043e\:0432, \:043f\:043e\:0445\:043e\:0436\:0438\:0445 \:043d\
\:0430 \:043e\:0431\:044a\:0435\:043a\:0442\:044b \:043e\:0431\:0449\:0438\
\:0445 \:0448\:0430\:0431\:043b\:043e\:043d\:043e\:0432 ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ". \:0414\:043b\:044f \:0442\:043e\:0433\:043e, \:0447\:0442\:043e\:0431\
\:044b \:0441\:043e\:0435\:0434\:0438\:043d\:0438\:0442\:044c \:043d\:0435\
\:0441\:043a\:043e\:043b\:044c\:043a\:043e \:043e\:0431\:044a\:0435\:043a\
\:0442\:043e\:0432 \:0448\:0430\:0431\:043b\:043e\:043d\:0430, \:0438\:0441\
\:043f\:043e\:043b\:044c\:0437\:0443\:0435\:0442\:0441\:044f \:043e\:043f\
\:0435\:0440\:0430\:0442\:043e\:0440 ",
 Cell[BoxData[
  TemplateBox[{Cell["StringExpression"],"paclet:ref/StringExpression"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 ", \:0438\:043c\:0435\:044e\:0449\:0438\:0439 \:0430\:043b\:044c\:0442\:0435\
\:0440\:043d\:0430\:0442\:0438\:0432\:043d\:0443\:044e \:043d\:043e\:0442\
\:0430\:0446\:0438\:044e ",
 Cell[BoxData["~~"], "InlineFormula"],
 "."
}], "MathCaption",
 CellTags->"b:0.1",
 CellID->775969280],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullForm", "[", 
  RowBox[{"\"\<a\>\"", "~~", "_"}], "]"}]], "Input",
 CellTags->"b:0.1",
 CellLabel->"In[10]:=",
 CellID->14216555],

Cell[BoxData[
 TagBox[
  StyleBox[
   RowBox[{"StringExpression", "[", 
    RowBox[{"\"\<a\>\"", ",", 
     RowBox[{"Blank", "[", "]"}]}], "]"}],
   ShowSpecialCharacters->False,
   ShowStringCharacters->True,
   NumberMarks->True],
  FullForm]], "Output",
 ImageSize->{211, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.1",
 CellLabel->"Out[10]//FullForm=",
 CellID->577426259]
}, Open  ]],

Cell[TextData[{
 "\:041a\:043e\:043c\:0430\:043d\:0434\:0430 ",
 Cell[BoxData[
  TemplateBox[{Cell["StringExpression"],"paclet:ref/StringExpression"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " \:0430\:043d\:0430\:043b\:043e\:0433\:0438\:0447\:043d\:0430 ",
 Cell[BoxData[
  TemplateBox[{Cell["StringJoin"],"paclet:ref/StringJoin"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 ", \:043d\:043e \:043f\:043e\:0441\:043b\:0435\:0434\:043d\:044f\:044f \
\:043e\:0431\:0440\:0430\:0431\:0430\:0442\:044b\:0432\:0430\:0435\:0442 \
\:0438\:0441\:043a\:043b\:044e\:0447\:0438\:0442\:0435\:043b\:044c\:043d\:043e\
 \:0442\:0435\:043a\:0441\:0442\:043e\:0432\:044b\:0435 \:0444\:0440\:0430\
\:0433\:043c\:0435\:043d\:0442\:044b \:0438 \:0438\:0433\:043d\:043e\:0440\
\:0438\:0440\:0443\:0435\:0442 \:0432\:043b\:043e\:0436\:0435\:043d\:043d\
\:044b\:0435 \:0441\:043f\:0438\:0441\:043a\:0438. \:0414\:043b\:044f \:0447\
\:0438\:0441\:0442\:044b\:0445 \:0442\:0435\:043a\:0441\:0442\:043e\:0432\
\:044b\:0445 \:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442\:043e\:0432 \
\:043e\:043d\:0438 \:044d\:043a\:0432\:0438\:0432\:0430\:043b\:0435\:043d\
\:0442\:043d\:044b."
}], "MathCaption",
 CellTags->"b:0.1",
 CellID->143628873],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\"\<aa\>\"", "~~", 
  RowBox[{"\"\<bbb\>\"", "~~", "\"\<c\>\""}]}]], "Input",
 CellTags->"b:0.1",
 CellLabel->"In[11]:=",
 CellID->220445018],

Cell[BoxData["\<\"aabbbc\"\>"], "Output",
 ImageSize->{46, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.1",
 CellLabel->"Out[11]=",
 CellID->109635832]
}, Open  ]],

Cell[TextData[{
 "\:041f\:0435\:0440\:0435\:0447\:0435\:043d\:044c \:043e\:0431\:044a\:0435\
\:043a\:0442\:043e\:0432, \:043a\:043e\:0442\:043e\:0440\:044b\:0435 \:043c\
\:043e\:0433\:0443\:0442 \:043f\:0440\:0438\:0441\:0443\:0442\:0441\:0442\
\:0432\:043e\:0432\:0430\:0442\:044c \:0432 \:0448\:0430\:0431\:043b\:043e\
\:043d\:0430\:0445 \:0434\:043b\:044f \:0442\:0435\:043a\:0441\:0442\:043e\
\:0432\:044b\:0445 \:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442\:043e\
\:0432, \:0432 \:0442\:043e\:0447\:043d\:043e\:0441\:0442\:0438 \:0441\:043e\
\:0432\:043f\:0430\:0434\:0430\:0435\:0442 \:0441 \:043f\:0435\:0440\:0435\
\:0447\:043d\:0435\:043c \:043e\:0431\:044a\:0435\:043a\:0442\:043e\:0432 \
\:043e\:0431\:044b\:0447\:043d\:044b\:0445 \:0448\:0430\:0431\:043b\:043e\
\:043d\:043e\:0432 ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ". \:0413\:043e\:0432\:043e\:0440\:044f \:044f\:0437\:044b\:043a\:043e\:043c \
\:0448\:0430\:0431\:043b\:043e\:043d\:043e\:0432 \:0434\:043b\:044f \:0442\
\:0435\:043a\:0441\:0442\:043e\:0432\:044b\:0445 \:0444\:0440\:0430\:0433\
\:043c\:0435\:043d\:0442\:043e\:0432, \:0442\:0435\:043a\:0441\:0442\:043e\
\:0432\:044b\:043c \:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442\:043e\
\:043c \:0441\:0447\:0438\:0442\:0430\:0435\:0442\:0441\:044f \:043f\:043e\
\:0441\:043b\:0435\:0434\:043e\:0432\:0430\:0442\:0435\:043b\:044c\:043d\:043e\
\:0441\:0442\:044c \:0441\:0438\:043c\:0432\:043e\:043b\:043e\:0432, \:0442\
\:043e \:0435\:0441\:0442\:044c, ",
 Cell[BoxData["\<\"abc\"\>"], "InlineFormula"],
 " \:043c\:043e\:0436\:043d\:043e \:0440\:0430\:0441\:0441\:043c\:0430\:0442\
\:0440\:0438\:0432\:0430\:0442\:044c \:043a\:0430\:043a \:0432\:044b\:0440\
\:0430\:0436\:0435\:043d\:0438\:0435 \:0432\:0438\:0434\:0430  ",
 Cell[BoxData[
  RowBox[{
   TemplateBox[{Cell["String"],"paclet:ref/String"},
    "RefLink",
    BaseStyle->"InlineFormula"], "[", 
   RowBox[{
    StyleBox["a", "TI"], ",", 
    StyleBox["b", "TI"], ",", 
    StyleBox["c", "TI"]}], "]"}]], "InlineFormula"],
 ", \:043a \:043a\:043e\:0442\:043e\:0440\:043e\:043c\:0443 \
\:043f\:0440\:0438\:043c\:0435\:043d\:044f\:044e\:0442\:0441\:044f \:043e\
\:0431\:044b\:0447\:043d\:044b\:0435 \:043c\:043e\:0434\:0435\:043b\:0438 \
\:0448\:0430\:0431\:043b\:043e\:043d\:043e\:0432."
}], "Text",
 CellTags->"b:0.1",
 CellID->100231778],

Cell["\<\
\:0421\:043b\:0435\:0434\:0443\:044e\:0449\:0438\:0435 \:043e\:0431\:044a\
\:0435\:043a\:0442\:044b \:043c\:043e\:0433\:0443\:0442 \:043f\:0440\:0438\
\:0441\:0443\:0442\:0441\:0442\:0432\:043e\:0432\:0430\:0442\:044c \:0432 \
\:0448\:0430\:0431\:043b\:043e\:043d\:0430\:0445 \:0434\:043b\:044f \:0441\
\:0438\:043c\:0432\:043e\:043b\:044c\:043d\:044b\:0445 \:0442\:0435\:043a\
\:0441\:0442\:043e\:0432\:044b\:0445 \:0444\:0440\:0430\:0433\:043c\:0435\
\:043d\:0442\:043e\:0432:\
\>", "Text",
 CellTags->"b:0.1",
 CellID->206331185],

Cell[BoxData[GridBox[{
   {"\"\<\!\(\*
StyleBox[\"\:0442\:0435\:043a\:0441\:0442\", \"TI\"]\)\>\"", Cell[
    "\:0442\:0435\:043a\:0441\:0442\:043e\:0432\:044b\:0439 \
\:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442 \:0441 \:0431\:0443\:043a\
\:0432\:0435\:043d\:043d\:044b\:043c\:0438 \:0441\:0438\:043c\:0432\:043e\
\:043b\:0430\:043c\:0438 ", "TableText"]},
   {"_", Cell[
    "\:043b\:044e\:0431\:043e\:0439 \
\:0435\:0434\:0438\:043d\:0438\:0447\:043d\:044b\:0439 \:0441\:0438\:043c\
\:0432\:043e\:043b ", "TableText"]},
   {"__", Cell[
    "\:043b\:044e\:0431\:0430\:044f \
\:043f\:043e\:0441\:043b\:0435\:0434\:043e\:0432\:0430\:0442\:0435\:043b\:044c\
\:043d\:043e\:0441\:0442\:044c \:0438\:0437 \:043e\:0434\:043d\:043e\:0433\
\:043e \:0438\:043b\:0438 \:0431\:043e\:043b\:0435\:0435 \:0441\:0438\:043c\
\:0432\:043e\:043b\:043e\:0432", "TableText"]},
   {"___", Cell[
    "\:043b\:044e\:0431\:0430\:044f \
\:043f\:043e\:0441\:043b\:0435\:0434\:043e\:0432\:0430\:0442\:0435\:043b\:044c\
\:043d\:043e\:0441\:0442\:044c \:0438\:0437 \:043d\:0443\:043b\:044f \:0438\
\:043b\:0438 \:0431\:043e\:043b\:0435\:0435 \:0441\:0438\:043c\:0432\:043e\
\:043b\:043e\:0432 ", "TableText"]},
   {
    RowBox[{
     StyleBox[
      RowBox[{
       StyleBox["x", "TI"], "_"}]], Cell[",", "TableText"], 
     StyleBox[
      RowBox[{
       StyleBox["x", "TI"], "__"}]], Cell[",", "TableText"], 
     StyleBox[
      RowBox[{
       StyleBox["x", "TI"], "___"}]]}], Cell[TextData[{
     "\:0441\:0443\:0431\:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442, \
\:043a\:043e\:0442\:043e\:0440\:043e\:043c\:0443 \:0437\:0430\:0434\:0430\
\:043d\:043e \:0438\:043c\:044f ",
     Cell[BoxData[
      StyleBox["x", "TI"]], "InlineFormula"]
    }], "TableText"]},
   {
    RowBox[{
     StyleBox["x", "TI"], ":", 
     StyleBox["\:0448\:0430\:0431\:043b\:043e\:043d", "TI"]}], Cell[TextData[{
     "\:0448\:0430\:0431\:043b\:043e\:043d, \:043a\:043e\:0442\:043e\:0440\
\:043e\:043c\:0443 \:0437\:0430\:0434\:0430\:043d\:043e \:0438\:043c\:044f ",
     Cell[BoxData[
      StyleBox["x", "TI"]], "InlineFormula"]
    }], "TableText"]},
   {
    RowBox[{
     StyleBox["\:0448\:0430\:0431\:043b\:043e\:043d", "TI"], ".."}], Cell[
    "\:0448\:0430\:0431\:043b\:043e\:043d, \:043f\:043e\:0432\:0442\:043e\
\:0440\:044f\:044e\:0449\:0438\:0439\:0441\:044f \:043e\:0434\:0438\:043d \
\:0438\:043b\:0438 \:0431\:043e\:043b\:0435\:0435 \:0440\:0430\:0437 ", 
     "TableText"]},
   {
    RowBox[{
     StyleBox["\:0448\:0430\:0431\:043b\:043e\:043d", "TI"], "..."}], Cell[
    "\:0448\:0430\:0431\:043b\:043e\:043d, \:043f\:043e\:0432\:0442\:043e\
\:0440\:044f\:044e\:0449\:0438\:0439\:0441\:044f \:043d\:043e\:043b\:044c \
\:0438\:043b\:0438 \:0431\:043e\:043b\:0435\:0435 \:0440\:0430\:0437 ", 
     "TableText"]},
   {
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        SubscriptBox[
         StyleBox["\:0448\:0430\:0431\:043b\:043e\:043d", "TI"], 
         StyleBox["1", "TR"]], ",", 
        SubscriptBox[
         StyleBox["\:0448\:0430\:0431\:043b\:043e\:043d", "TI"], 
         StyleBox["2", "TR"]], ",", 
        StyleBox["\[Ellipsis]", "TR"]}], "}"}], Cell[
      " \:0438\:043b\:0438 ", "TableText"], 
      SubscriptBox[
       StyleBox["\:0448\:0430\:0431\:043b\:043e\:043d", "TI"], 
       StyleBox["1", "TR"]]}], "|", 
     SubscriptBox[
      StyleBox["\:0448\:0430\:0431\:043b\:043e\:043d", "TI"], 
      StyleBox["2", "TR"]], "|", 
     StyleBox["\[Ellipsis]", "TR"]}], Cell[TextData[{
     "\:0448\:0430\:0431\:043b\:043e\:043d, \:0442\:0440\:0435\:0431\:0443\
\:044e\:0449\:0438\:0439 \:0441\:043e\:0432\:043f\:0430\:0434\:0435\:043d\
\:0438\:044f \:043b\:0438\:0448\:044c \:0441 \:043e\:0434\:043d\:0438\:043c \
\:0438\:0437 ",
     Cell[BoxData[
      SubscriptBox[
       StyleBox["\:0448\:0430\:0431\:043b\:043e\:043d\:043e\:0432", "TI"], 
       StyleBox["i", "TI"]]], "InlineFormula"]
    }], "TableText"]},
   {
    RowBox[{
     StyleBox["\:0448\:0430\:0431\:043b\:043e\:043d", "TI"], "/;", 
     StyleBox["\:0443\:0441\:043b\:043e\:0432\:0438\:0435", "TI"]}], Cell[
    TextData[{
     "\:0448\:0430\:0431\:043b\:043e\:043d, \:0441\:0440\:0430\:0431\:0430\
\:0442\:044b\:0432\:0430\:044e\:0449\:0438\:0439 \:043b\:0438\:0448\:044c \
\:043a\:043e\:0433\:0434\:0430 \:0440\:0435\:0437\:0443\:043b\:044c\:0442\
\:0430\:0442\:043e\:043c \:0432\:044b\:0447\:0438\:0441\:043b\:0435\:043d\
\:0438\:044f ",
     Cell[BoxData[
      StyleBox["\:0443\:0441\:043b\:043e\:0432\:0438\:044f", "TI"]], 
      "InlineFormula"],
     " \:044f\:0432\:043b\:044f\:0435\:0442\:0441\:044f ",
     Cell[BoxData[
      TemplateBox[{Cell["True"],"paclet:ref/True"},
       "RefLink",
       BaseStyle->"InlineFormula"]], "InlineFormula"],
     " (\:0418\:0441\:0442\:0438\:043d\:0430)"
    }], "TableText"]},
   {
    RowBox[{
     StyleBox["\:0448\:0430\:0431\:043b\:043e\:043d", "TI"], "?", 
     StyleBox["\:0442\:0435\:0441\:0442", "TI"]}], Cell[TextData[{
     "\:0448\:0430\:0431\:043b\:043e\:043d, \:0441\:0440\:0430\:0431\:0430\
\:0442\:044b\:0432\:0430\:044e\:0449\:0438\:0439 \:043b\:0438\:0448\:044c \
\:043a\:043e\:0433\:0434\:0430 ",
     Cell[BoxData[
      StyleBox["\:0442\:0435\:0441\:0442", "TI"]], "InlineFormula"],
     " \:0432\:043e\:0437\:0432\:0440\:0430\:0449\:0430\:0435\:0442 ",
     Cell[BoxData[
      TemplateBox[{Cell["True"],"paclet:ref/True"},
       "RefLink",
       BaseStyle->"InlineFormula"]], "InlineFormula"],
     " (\:0418\:0441\:0442\:0438\:043d\:0430) \:0434\:043b\:044f \:043a\:0430\
\:0436\:0434\:043e\:0433\:043e \:0441\:0438\:043c\:0432\:043e\:043b\:0430",
     " "
    }], "TableText"]},
   {
    ButtonBox["Whitespace",
     BaseStyle->"Link",
     ButtonData->"paclet:ref/Whitespace"], Cell[
    "\:043f\:043e\:0441\:043b\:0435\:0434\:043e\:0432\:0430\:0442\:0435\:043b\
\:044c\:043d\:043e\:0441\:0442\:044c \:0441\:0438\:043c\:0432\:043e\:043b\
\:043e\:0432 \:043f\:0440\:043e\:0431\:0435\:043b\:0430 ", "TableText"]},
   {
    ButtonBox["NumberString",
     BaseStyle->"Link",
     ButtonData->"paclet:ref/NumberString"], Cell[
    "\:0447\:0438\:0441\:043b\:043e\:0432\:044b\:0435 \
\:0441\:0438\:043c\:0432\:043e\:043b\:044b ", "TableText"]},
   {
    RowBox[{
     ButtonBox["DatePattern",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/DatePattern"], "[", 
     StyleBox[
      "\:0441\:043f\:0435\:0446\:0438\:0444\:0438\:043a\:0430\:0446\:0438\
\:044f", "TI"], "]"}], Cell[
    "\:0441\:0438\:043c\:0432\:043e\:043b\:044b \:0434\:0430\:0442\:044b", 
     "TableText"]},
   {
    StyleBox["charobj", "TI"], Cell["\<\
\:043e\:0431\:044a\:0435\:043a\:0442, \:043f\:0440\:0435\:0434\:0441\:0442\
\:0430\:0432\:043b\:044f\:044e\:0449\:0438\:0439 \:043a\:043b\:0430\:0441\
\:0441 \:0437\:043d\:0430\:043a\:0430 \:0438\:043b\:0438 \:0441\:0438\:043c\
\:0432\:043e\:043b\:0430 (\:0441\:043c\:043e\:0442\:0440\:0438 \:043d\:0438\
\:0436\:0435) \
\>", "TableText"]},
   {
    RowBox[{
     ButtonBox["RegularExpression",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/RegularExpression"], "[", "\"\<\!\(\*
StyleBox[\"regexp\", \"TI\"]\)\>\"", "]"}], Cell["\<\
\:0442\:0435\:043a\:0441\:0442\:043e\:0432\:044b\:0439 \:0441\:0443\:0431\
\:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442, \:0441\:043e\:043e\:0442\
\:0432\:0435\:0442\:0441\:0442\:0432\:0443\:044e\:0449\:0438\:0439 \:0440\
\:0435\:0433\:0443\:043b\:044f\:0440\:043d\:043e\:043c\:0443 \:0432\:044b\
\:0440\:0430\:0436\:0435\:043d\:0438\:044e \
\>", "TableText"]},
   {
    RowBox[{
     ButtonBox["StringExpression",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/StringExpression"], "[", 
     StyleBox["\[Ellipsis]", "TR"], "]"}], Cell[
    "\:043f\:0440\:043e\:0438\:0437\:0432\:043e\:043b\:044c\:043d\:043e\:0435 \
\:0432\:044b\:0440\:0430\:0436\:0435\:043d\:0438\:0435, \:0441\:043e\:0441\
\:0442\:043e\:044f\:0449\:0435\:0435 \:0438\:0437 \:0441\:0438\:043c\:0432\
\:043e\:043b\:043e\:0432", "TableText"]}
  },
  GridBoxAlignment->{
   "Columns" -> {Left, {Left}}, "ColumnsIndexed" -> {}, 
    "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}]], "DefinitionBox",
 CellID->31675],

Cell["\:041d\:0438\:0436\:0435 \:043f\:0435\:0440\:0435\:0447\:0438\:0441\
\:043b\:0435\:043d\:044b \:043a\:043b\:0430\:0441\:0441\:044b \:0441\:0438\
\:043c\:0432\:043e\:043b\:043e\:0432: ", "Text",
 CellTags->"b:0.1",
 CellID->104465889],

Cell[BoxData[GridBox[{
   {
    RowBox[{"{", 
     RowBox[{
      SubscriptBox[
       StyleBox["c", "TI"], 
       StyleBox["1", "TR"]], ",", 
      SubscriptBox[
       StyleBox["c", "TI"], 
       StyleBox["2", "TR"]], ",", 
      StyleBox["\[Ellipsis]", "TR"]}], "}"}], Cell[TextData[{
     "\:043b\:044e\:0431\:043e\:0439 \:0438\:0437",
     " ",
     Cell[BoxData["\"\<\!\(\*SubscriptBox[
StyleBox[\"c\", \"TI\"], 
StyleBox[\"i\", \"TI\"]]\)\>\""], "InlineFormula"],
     StyleBox[" ", "TR"]
    }], "TableText"]},
   {
    RowBox[{
     ButtonBox["Characters",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/Characters"], "[", "\"\<\!\(\*SubscriptBox[
StyleBox[\"c\", \"TI\"], 
StyleBox[\"1\", \"TR\"]]\)\!\(\*SubscriptBox[
StyleBox[\"c\", \"TI\"], 
StyleBox[\"2\", \"TR\"]]\)\!\(\*
StyleBox[\"\[Ellipsis]\", \"TR\"]\)\>\"", "]"}], Cell[TextData[{
     "\:043b\:044e\:0431\:043e\:0439 \:0438\:0437",
     " ",
     Cell[BoxData["\"\<\!\(\*SubscriptBox[
StyleBox[\"c\", \"TI\"], 
StyleBox[\"i\", \"TI\"]]\)\>\""], "InlineFormula"],
     StyleBox[" ", "TR"]
    }], "TableText"]},
   {
    RowBox[{
     ButtonBox["CharacterRange",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/CharacterRange"], "[", 
     RowBox[{"\"\<\!\(\*SubscriptBox[
StyleBox[\"c\", \"TI\"], 
StyleBox[\"1\", \"TR\"]]\)\>\"", ",", "\"\<\!\(\*SubscriptBox[
StyleBox[\"c\", \"TI\"], 
StyleBox[\"2\", \"TR\"]]\)\>\""}], "]"}], Cell[TextData[{
     "\:043b\:044e\:0431\:043e\:0439 \:0441\:0438\:043c\:0432\:043e\:043b \
\:0432 \:0434\:0438\:0430\:043f\:0430\:0437\:043e\:043d\:0435 \:043e\:0442 ",
     Cell[BoxData["\"\<\!\(\*SubscriptBox[
StyleBox[\"c\", \"TI\"], 
StyleBox[\"1\", \"TR\"]]\)\>\""], "InlineFormula"],
     StyleBox[" ", "TR"],
     "\:0434\:043e",
     StyleBox[" ", "TR"],
     Cell[BoxData["\"\<\!\(\*SubscriptBox[
StyleBox[\"c\", \"TI\"], 
StyleBox[\"2\", \"TR\"]]\)\>\""], "InlineFormula"],
     " "
    }], "TableText"]},
   {
    ButtonBox["HexadecimalCharacter",
     BaseStyle->"Link",
     ButtonData->"paclet:ref/HexadecimalCharacter"], Cell[
    "\:0448\:0435\:0441\:0442\:043d\:0430\:0434\:0446\:0430\:0442\:0435\:0440\
\:0438\:0447\:043d\:044b\:0435 \:0446\:0438\:0444\:0440\:044b 0\[Dash]9, a\
\[Dash]f, A\[Dash]F ", "TableText"]},
   {
    ButtonBox["DigitCharacter",
     BaseStyle->"Link",
     ButtonData->"paclet:ref/DigitCharacter"], Cell[
    "\:0446\:0438\:0444\:0440\:044b \:043e\:0442 0 \:0434\:043e 9", 
     "TableText"]},
   {
    ButtonBox["LetterCharacter",
     BaseStyle->"Link",
     ButtonData->"paclet:ref/LetterCharacter"], Cell[
    "\:0431\:0443\:043a\:0432\:0430 ", "TableText"]},
   {
    ButtonBox["WhitespaceCharacter",
     BaseStyle->"Link",
     ButtonData->"paclet:ref/WhitespaceCharacter"], Cell["\<\
\:0441\:0438\:043c\:0432\:043e\:043b\:044b \:043f\:0440\:043e\:0431\:0435\
\:043b\:043e\:0432, \:0442\:0430\:0431\:0443\:043b\:044f\:0446\:0438\:0438, \
\:043d\:043e\:0432\:043e\:0439 \:0441\:0442\:0440\:043e\:043a\:0438, \:0438\
\:043b\:0438 \:0438\:043d\:044b\:0435  \:0441\:0438\:043c\:0432\:043e\:043b\
\:044b-\:0440\:0430\:0437\:0434\:0435\:043b\:0438\:0442\:0435\:043b\:0438 \
\>", "TableText"]},
   {
    ButtonBox["WordCharacter",
     BaseStyle->"Link",
     ButtonData->"paclet:ref/WordCharacter"], Cell[
    "\:0431\:0443\:043a\:0432\:0430 \:0438\:043b\:0438 \:0446\:0438\:0444\
\:0440\:0430 ", "TableText"]},
   {
    RowBox[{
     ButtonBox["Except",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/Except"], "[", 
     StyleBox["p", "TI"], "]"}], Cell[TextData[{
     "\:043b\:044e\:0431\:043e\:0439 \:0441\:0438\:043c\:0432\:043e\:043b, \
\:0437\:0430 \:0438\:0441\:043a\:043b\:044e\:0447\:0435\:043d\:0438\:0435\
\:043c ",
     Cell[BoxData[
      StyleBox["p", "TI"]], "InlineFormula"]
    }], "TableText"]}
  },
  GridBoxAlignment->{
   "Columns" -> {Left, {Left}}, "ColumnsIndexed" -> {}, 
    "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}]], "DefinitionBox",
 CellID->9253],

Cell["\:041d\:0438\:0436\:0435 \:043f\:0435\:0440\:0435\:0447\:0438\:0441\
\:043b\:0435\:043d\:044b \:043f\:043e\:0437\:0438\:0446\:0438\:0438 \:0432 \
\:0442\:0435\:043a\:0441\:0442\:043e\:0432\:044b\:0445 \:0444\:0440\:0430\
\:0433\:043c\:0435\:043d\:0442\:0430\:0445: ", "Text",
 CellTags->"b:0.1",
 CellID->97881266],

Cell[BoxData[GridBox[{
   {
    ButtonBox["StartOfString",
     BaseStyle->"Link",
     ButtonData->"paclet:ref/StartOfString"], Cell[
    "\:043d\:0430\:0447\:0430\:043b\:043e \
\:0446\:0435\:043b\:043e\:0441\:0442\:043d\:043e\:0433\:043e \:0442\:0435\
\:043a\:0441\:0442\:043e\:0432\:043e\:0433\:043e \:0444\:0440\:0430\:0433\
\:043c\:0435\:043d\:0442\:0430 ", "TableText"]},
   {
    ButtonBox["EndOfString",
     BaseStyle->"Link",
     ButtonData->"paclet:ref/EndOfString"], Cell[
    "\:043a\:043e\:043d\:0435\:0446 \
\:0446\:0435\:043b\:043e\:0441\:0442\:043d\:043e\:0433\:043e \:0442\:0435\
\:043a\:0441\:0442\:043e\:0432\:043e\:0433\:043e \:0444\:0440\:0430\:0433\
\:043c\:0435\:043d\:0442\:0430", "TableText"]},
   {
    ButtonBox["StartOfLine",
     BaseStyle->"Link",
     ButtonData->"paclet:ref/StartOfLine"], Cell[
    "\:043d\:0430\:0447\:0430\:043b\:043e \
\:0441\:0442\:0440\:043e\:043a\:0438 ", "TableText"]},
   {
    ButtonBox["EndOfLine",
     BaseStyle->"Link",
     ButtonData->"paclet:ref/EndOfLine"], Cell[
    "\:043a\:043e\:043d\:0435\:0446 \:0441\:0442\:0440\:043e\:043a\:0438 ", 
     "TableText"]},
   {
    ButtonBox["WordBoundary",
     BaseStyle->"Link",
     ButtonData->"paclet:ref/WordBoundary"], Cell["\<\
\:0433\:0440\:0430\:043d\:0438\:0446\:0430 \:043c\:0435\:0436\:0434\:0443 \
\:0441\:043b\:043e\:0432\:0430\:043c\:0438 \:0438 \:0434\:0440\:0443\:0433\
\:0438\:043c\:0438 \:0447\:0430\:0441\:0442\:044f\:043c\:0438 \:0442\:0435\
\:043a\:0441\:0442\:043e\:0432\:043e\:0433\:043e \:0444\:0440\:0430\:0433\
\:043c\:0435\:043d\:0442\:0430 \
\>", "TableText"]},
   {
    RowBox[{
     ButtonBox["Except",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/Except"], "[", 
     ButtonBox["WordBoundary",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/WordBoundary"], "]"}], Cell[
    "\:0433\:0434\:0435 \:0443\:0433\:043e\:0434\:043d\:043e, \:0437\:0430 \
\:0438\:0441\:043a\:043b\:044e\:0447\:0435\:043d\:0438\:0435\:043c \:0433\
\:0440\:0430\:043d\:0438\:0446 \:043c\:0435\:0436\:0434\:0443 \:0441\:043b\
\:043e\:0432\:0430\:043c\:0438", "TableText"]}
  },
  GridBoxAlignment->{
   "Columns" -> {Left, {Left}}, "ColumnsIndexed" -> {}, 
    "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}]], "DefinitionBox",
 CellID->25418],

Cell["\<\
\:0421\:043b\:0435\:0434\:0443\:044e\:0449\:0438\:0435 \:043a\:043e\:043c\
\:0430\:043d\:0434\:044b \:043e\:043f\:0440\:0435\:0434\:0435\:043b\:044f\
\:044e\:0442, \:043a\:0430\:043a\:043e\:0435 \:0438\:0437 \:0441\:043e\:0432\
\:043f\:0430\:0434\:0435\:043d\:0438\:0439 \:0431\:0443\:0434\:0435\:0442 \
\:0438\:0441\:043f\:043e\:043b\:044c\:0437\:043e\:0432\:0430\:0442\:044c\:0441\
\:044f, \:0435\:0441\:043b\:0438 \:0441\:0443\:0449\:0435\:0441\:0442\:0432\
\:0443\:0435\:0442 \:043d\:0435\:0441\:043a\:043e\:043b\:044c\:043a\:043e \
\:0432\:043e\:0437\:043c\:043e\:0436\:043d\:043e\:0441\:0442\:0435\:0439:\
\>", "Text",
 CellTags->"b:0.1",
 CellID->138112839],

Cell[BoxData[GridBox[{
   {
    RowBox[{
     ButtonBox["Shortest",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/Shortest"], "[", 
     StyleBox["\:0448\:0430\:0431\:043b\:043e\:043d", "TI"], "]"}], Cell[
    TextData[{
     "\:0441\:0430\:043c\:0430\:044f \:043a\:043e\:0440\:043e\:0442\:043a\
\:0430\:044f \:043f\:043e\:0441\:043b\:0435\:0434\:043e\:0432\:0430\:0442\
\:0435\:043b\:044c\:043d\:043e\:0441\:0442\:044c, \:0441\:043e\:043e\:0442\
\:0432\:0435\:0442\:0441\:0442\:0432\:0443\:044e\:0449\:0430\:044f   ",
     Cell[BoxData[
      StyleBox["\:0448\:0430\:0431\:043b\:043e\:043d\:0443", "TI"]], 
      "InlineFormula"]
    }], "TableText"]},
   {
    RowBox[{
     ButtonBox["Longest",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/Longest"], "[", 
     StyleBox["\:0448\:0430\:0431\:043b\:043e\:043d", "TI"], "]"}], Cell[
    TextData[{
     "\:0441\:0430\:043c\:0430\:044f \:0434\:043b\:0438\:043d\:043d\:0430\
\:044f \:043f\:043e\:0441\:043b\:0435\:0434\:043e\:0432\:0430\:0442\:0435\
\:043b\:044c\:043d\:043e\:0441\:0442\:044c, \:0441\:043e\:043e\:0442\:0432\
\:0435\:0442\:0441\:0442\:0432\:0443\:044e\:0449\:0430\:044f   ",
     Cell[BoxData[
      StyleBox["\:0448\:0430\:0431\:043b\:043e\:043d\:0443", "TI"]], 
      "InlineFormula"],
     " (\:0438\:0441\:043f\:043e\:043b\:044c\:0437\:0443\:0435\:0442\:0441\
\:044f \:043f\:043e \:0443\:043c\:043e\:043b\:0447\:0430\:043d\:0438\:044e)",
     " "
    }], "TableText"]}
  },
  GridBoxAlignment->{
   "Columns" -> {Left, {Left}}, "ColumnsIndexed" -> {}, 
    "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}]], "DefinitionBox",
 CellID->20324],

Cell["", "Text",
 CellTags->"b:0.1",
 CellID->833514613],

Cell["\<\
\:041d\:0435\:043a\:043e\:0442\:043e\:0440\:044b\:0435 \:043d\:0435\:0442\
\:0440\:0438\:0432\:0438\:0430\:043b\:044c\:043d\:044b\:0435 \:0432\:043e\
\:043f\:0440\:043e\:0441\:044b, \:043a\:0430\:0441\:0430\:044e\:0449\:0438\
\:0435\:0441\:044f \:0440\:0430\:0441\:0441\:043c\:0430\:0442\:0440\:0438\
\:0432\:0430\:0435\:043c\:044b\:0445 \:043e\:0431\:044a\:0435\:043a\:0442\
\:043e\:0432.\
\>", "Text",
 CellTags->"b:0.1",
 CellID->691886255],

Cell[TextData[{
 "\:0417\:043d\:0430\:043a\:0430\:043c \:0448\:0430\:0431\:043b\:043e\:043d\
\:0430 ",
 Cell[BoxData["_"], "InlineFormula"],
 ", ",
 Cell[BoxData["__"], "InlineFormula"],
 " \:0438 ",
 Cell[BoxData["___"], "InlineFormula"],
 " \:0441\:043e\:043e\:0442\:0432\:0435\:0442\:0441\:0442\:0432\:0443\:044e\
\:0442 \:043b\:044e\:0431\:044b\:0435 \:0441\:0438\:043c\:0432\:043e\:043b\
\:044b, \:0432\:043a\:043b\:044e\:0447\:0430\:044f \:0441\:0438\:043c\:0432\
\:043e\:043b \:043d\:043e\:0432\:043e\:0439 \:0441\:0442\:0440\:043e\:043a\
\:0438. \:0427\:0442\:043e\:0431\:044b  \:043e\:043f\:0440\:0435\:0434\:0435\
\:043b\:0438\:0442\:044c \:0441\:043e\:043e\:0442\:0432\:0435\:0442\:0441\
\:0442\:0432\:0438\:0435 \:043b\:044e\:0431\:043e\:043c\:0443 \:0441\:0438\
\:043c\:0432\:043e\:043b\:0443, \:0437\:0430 \:0438\:0441\:043a\:043b\:044e\
\:0447\:0435\:043d\:0438\:0435\:043c \:0441\:0438\:043c\:0432\:043e\:043b\
\:0430 \:043d\:043e\:0432\:043e\:0439 \:0441\:0442\:0440\:043e\:043a\:0438 (\
\:0430\:043d\:0430\:043b\:043e\:0433\:0438\:0447\:043d\:043e\:043c\:0443 \
\".\" \:0432 \:0440\:0435\:0433\:0443\:043b\:044f\:0440\:043d\:044b\:0445 \
\:0432\:044b\:0440\:0430\:0436\:0435\:043d\:0438\:044f\:0445), \:043d\:0443\
\:0436\:043d\:043e \:0432\:043e\:0441\:043f\:043e\:043b\:044c\:0437\:043e\
\:0432\:0430\:0442\:044c\:0441\:044f \:043a\:043e\:043d\:0441\:0442\:0440\
\:0443\:043a\:0446\:0438\:044f\:043c\:0438 ",
 Cell[BoxData[
  RowBox[{
   TemplateBox[{Cell["Except"],"paclet:ref/Except"},
    "RefLink",
    BaseStyle->"InlineFormula"], "[", "\<\"\\n\"\>", "]"}]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    TemplateBox[{Cell["Except"],"paclet:ref/Except"},
     "RefLink",
     BaseStyle->"InlineFormula"], "[", "\<\"\\n\"\>", "]"}], ".."}]], 
  "InlineFormula"],
 ", \:0438 ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    TemplateBox[{Cell["Except"],"paclet:ref/Except"},
     "RefLink",
     BaseStyle->"InlineFormula"], "[", "\<\"\\n\"\>", "]"}], "..."}]], 
  "InlineFormula"],
 "."
}], "MathCaption",
 CellTags->"b:0.1",
 CellID->110717692],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringCases", "[", 
  RowBox[{"\"\<line1\\nline2\\n\>\"", ",", "__"}], "]"}]], "Input",
 CellTags->"b:0.1",
 CellLabel->"In[12]:=",
 CellID->32115820],

Cell[BoxData[
 RowBox[{"{", "\<\"line1\\nline2\\n\"\>", "}"}]], "Output",
 ImageSize->{46, 50},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.1",
 CellLabel->"Out[12]=",
 CellID->140880394]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringCases", "[", 
  RowBox[{"\"\<line1\\nline2\\n\>\"", ",", 
   RowBox[{
    RowBox[{"Except", "[", "\"\<\\n\>\"", "]"}], ".."}]}], "]"}]], "Input",
 CellTags->"b:0.1",
 CellLabel->"In[13]:=",
 CellID->280132484],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"line1\"\>", ",", "\<\"line2\"\>"}], "}"}]], "Output",
 ImageSize->{99, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.1",
 CellLabel->"Out[13]=",
 CellID->269517925]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringCases", "[", 
  RowBox[{"\"\<line1\\nline2\\n\>\"", ",", 
   RowBox[{"RegularExpression", "[", "\"\<.+\>\"", "]"}]}], "]"}]], "Input",
 CellTags->"b:0.1",
 CellLabel->"In[14]:=",
 CellID->406476748],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"line1\"\>", ",", "\<\"line2\"\>"}], "}"}]], "Output",
 ImageSize->{99, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.1",
 CellLabel->"Out[14]=",
 CellID->59754046]
}, Open  ]],

Cell[TextData[{
 "\:0421\:043f\:0438\:0441\:043e\:043a \:0448\:0430\:0431\:043b\:043e\:043d\
\:043e\:0432, \:0442\:0430\:043a\:043e\:0439 \:043a\:0430\:043a ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{"\<\"a\"\>", ",", "\<\"b\"\>", ",", "\<\"c\"\>"}], "}"}]], 
  "InlineFormula"],
 ", \:044d\:043a\:0432\:0438\:0432\:0430\:043b\:0435\:043d\:0442\:0435\:043d \
\:0441\:043f\:0438\:0441\:043a\:0443 \:0430\:043b\:044c\:0442\:0435\:0440\
\:043d\:0430\:0442\:0438\:0432 ",
 Cell[BoxData[
  RowBox[{"\<\"a\"\>", "|", "\<\"b\"\>", "|", "\<\"c\"\>"}]], "InlineFormula"],
 ". \:042d\:0442\:043e \:0443\:0434\:043e\:0431\:043d\:043e \
\:0442\:0435\:043c, \:0447\:0442\:043e \:0444\:0443\:043d\:043a\:0446\:0438\
\:0438  ",
 Cell[BoxData[
  TemplateBox[{Cell["Characters"],"paclet:ref/Characters"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " \:0438 ",
 Cell[BoxData[
  TemplateBox[{Cell["CharacterRange"],"paclet:ref/CharacterRange"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " \:043c\:043e\:0433\:0443\:0442 \:0431\:044b\:0442\:044c \:0438\:0441\:043f\
\:043e\:043b\:044c\:0437\:043e\:0432\:0430\:043d\:044b \:0434\:043b\:044f \
\:0443\:043a\:0430\:0437\:0430\:043d\:0438\:044f \:043a\:043b\:0430\:0441\
\:0441\:043e\:0432 \:0441\:0438\:043c\:0432\:043e\:043b\:043e\:0432."
}], "MathCaption",
 CellTags->"b:0.1",
 CellID->694363556],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringReplace", "[", 
  RowBox[{"\"\<the cat in the hat\>\"", ",", 
   RowBox[{
    RowBox[{"x", ":", 
     RowBox[{"Characters", "[", "\"\<aeiou\>\"", "]"}]}], "\[RuleDelayed]", 
    RowBox[{"x", "<>", "x"}]}]}], "]"}]], "Input",
 CellTags->"b:0.1",
 CellLabel->"In[15]:=",
 CellID->140507535],

Cell[BoxData["\<\"thee caat iin thee haat\"\>"], "Output",
 ImageSize->{165, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.1",
 CellLabel->"Out[15]=",
 CellID->669388833]
}, Open  ]],

Cell[TextData[{
 "\:041f\:0440\:0438 \:0438\:0441\:043f\:043e\:043b\:044c\:0437\:043e\:0432\
\:0430\:043d\:0438\:0438 \:0443\:0441\:043b\:043e\:0432\:0438\:0439 ",
 Cell[BoxData[
  TemplateBox[{Cell["Condition"],"paclet:ref/Condition"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " (",
 Cell[BoxData["/;"], "InlineFormula"],
 "), \:0440\:0435\:0437\:0443\:043b\:044c\:0442\:0430\:0442\:044b, \:0432\
\:043e\:0437\:0432\:0440\:0430\:0449\:0430\:0435\:043c\:044b\:0435 \:043f\
\:0440\:0438\:043c\:0435\:043d\:0435\:043d\:043d\:044b\:043c\:0438 \:0432 \
\:043d\:0438\:0445 \:0448\:0430\:0431\:043b\:043e\:043d\:0430\:043c\:0438, \
\:0440\:0430\:0441\:0441\:043c\:0430\:0442\:0440\:0438\:0432\:0430\:044e\:0442\
\:0441\:044f \:043a\:0430\:043a \:0442\:0435\:043a\:0441\:0442\:043e\:0432\
\:044b\:0435 \:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442\:044b, \:0447\
\:0442\:043e \:043c\:043e\:0436\:0435\:0442 \:043f\:0440\:0435\:043f\:044f\
\:0442\:0441\:0442\:0432\:043e\:0432\:0430\:0442\:044c \:043d\:043e\:0440\
\:043c\:0430\:043b\:044c\:043d\:043e\:0439 \:0440\:0430\:0431\:043e\:0442\
\:0435 \:0434\:0440\:0443\:0433\:0438\:0445 \:0437\:0430\:0434\:0435\:0439\
\:0441\:0442\:0432\:043e\:0432\:0430\:043d\:043d\:044b\:0445 \:0444\:0443\
\:043d\:043a\:0446\:0438\:0439 \:0438 \:043a\:043e\:043c\:0430\:043d\:0434 ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ". \:041f\:043e\:044d\:0442\:043e\:043c\:0443, \:0432 \:043e\:043f\:0440\
\:0435\:0434\:0435\:043b\:0435\:043d\:043d\:044b\:0445 \:0441\:043b\:0443\
\:0447\:0430\:044f\:0445 \:0442\:0440\:0435\:0431\:0443\:0435\:0442\:0441\
\:044f \:043f\:0440\:0438\:043c\:0435\:043d\:0435\:043d\:0438\:0435 \:043a\
\:043e\:043c\:0430\:043d\:0434\:044b ",
 Cell[BoxData[
  TemplateBox[{Cell["ToExpression"],"paclet:ref/ToExpression"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 "."
}], "MathCaption",
 CellTags->"b:0.1",
 CellID->48865639],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringCases", "[", 
  RowBox[{"\"\<a13 a18 a41 a42\>\"", ",", 
   RowBox[{
    RowBox[{
     RowBox[{"\"\<a\>\"", "~~", 
      RowBox[{
       RowBox[{"x", ":", 
        RowBox[{"DigitCharacter", ".."}]}], "~~", "WordBoundary"}]}], "/;", 
     RowBox[{"PrimeQ", "[", 
      RowBox[{"ToExpression", "[", "x", "]"}], "]"}]}], "\[RuleDelayed]", 
    "x"}]}], "]"}]], "Input",
 CellTags->"b:0.1",
 CellLabel->"In[16]:=",
 CellID->134667756],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"13\"\>", ",", "\<\"41\"\>"}], "}"}]], "Output",
 ImageSize->{57, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.1",
 CellLabel->"Out[16]=",
 CellID->252805576]
}, Open  ]],

Cell[TextData[{
 "\:041a\:0430\:043a \:0438 \:0432 \:043e\:0431\:044b\:0447\:043d\:044b\:0445 \
\:0448\:0430\:0431\:043b\:043e\:043d\:0430\:0445 ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", \:0432 \:043a\:043e\:043d\:0441\:0442\:0440\:0443\:043a\:0446\:0438\:0438 \
",
 Cell[BoxData[
  TemplateBox[{Cell["PatternTest"],"paclet:ref/PatternTest"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " (",
 Cell[BoxData["?"], "InlineFormula"],
 ")  \:0444\:0443\:043d\:043a\:0446\:0438\:044f \
\:043f\:0440\:0438\:043c\:0435\:043d\:044f\:0435\:0442\:0441\:044f \:043a \
\:043a\:0430\:0436\:0434\:043e\:043c\:0443 \:043e\:0442\:0434\:0435\:043b\
\:044c\:043d\:043e\:043c\:0443 \:0441\:0438\:043c\:0432\:043e\:043b\:0443."
}], "MathCaption",
 CellTags->"b:0.1",
 CellID->408165015],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringCases", "[", 
  RowBox[{"\"\<125378132\>\"", ",", 
   RowBox[{"__", "?", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"ToExpression", "[", "#", "]"}], "<", "5"}], "&"}], ")"}]}]}], 
  "]"}]], "Input",
 CellTags->"b:0.1",
 CellLabel->"In[17]:=",
 CellID->149685880],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"12\"\>", ",", "\<\"3\"\>", ",", "\<\"132\"\>"}], 
  "}"}]], "Output",
 ImageSize->{82, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.1",
 CellLabel->"Out[17]=",
 CellID->25020691]
}, Open  ]],

Cell[TextData[{
 "\:041a\:043e\:043d\:0441\:0442\:0440\:0443\:043a\:0446\:0438\:044f ",
 Cell[BoxData[
  TemplateBox[{Cell["Whitespace"],"paclet:ref/Whitespace"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " \:044d\:043a\:0432\:0438\:0432\:0430\:043b\:0435\:043d\:0442\:043d\:0430 ",
 Cell[BoxData[
  RowBox[{
   TemplateBox[{Cell["WhitespaceCharacter"],"paclet:ref/WhitespaceCharacter"},
    "RefLink",
    BaseStyle->"InlineFormula"], ".."}]], "InlineFormula"],
 "."
}], "MathCaption",
 CellTags->"b:0.1",
 CellID->212294979],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringReplace", "[", 
  RowBox[{"\"\<13   \\t 17 \\n22   19\>\"", ",", 
   RowBox[{"Whitespace", "\[Rule]", "\"\<,\>\""}]}], "]"}]], "Input",
 CellTags->"b:0.1",
 CellLabel->"In[18]:=",
 CellID->318389946],

Cell[BoxData["\<\"13,17,22,19\"\>"], "Output",
 ImageSize->{81, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.1",
 CellLabel->"Out[18]=",
 CellID->150923485]
}, Open  ]],

Cell[TextData[{
 "\:041c\:043e\:0436\:043d\:043e \:0432\:0441\:0442\:0430\:0432\:0438\:0442\
\:044c \:043e\:0431\:044a\:0435\:043a\:0442 ",
 Cell[BoxData[
  TemplateBox[{Cell["RegularExpression"],"paclet:ref/RegularExpression"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " \:0432 \:043e\:0431\:044b\:0447\:043d\:044b\:0439 \:0448\:0430\:0431\:043b\
\:043e\:043d \:0434\:043b\:044f \:0442\:0435\:043a\:0441\:0442\:043e\:0432\
\:044b\:0445 \:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442\:043e\:0432."
}], "MathCaption",
 CellTags->"b:0.1",
 CellID->384134564],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringCases", "[", 
  RowBox[{"\"\<a13b12c17a32\>\"", ",", 
   RowBox[{
    RowBox[{"\"\<a\>\"", "~~", 
     RowBox[{"x", ":", 
      RowBox[{"RegularExpression", "[", "\"\<\\\\d+\>\"", "]"}]}]}], 
    "\[RuleDelayed]", "x"}]}], "]"}]], "Input",
 CellTags->"b:0.1",
 CellLabel->"In[19]:=",
 CellID->23848909],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"13\"\>", ",", "\<\"32\"\>"}], "}"}]], "Output",
 ImageSize->{57, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.1",
 CellLabel->"Out[19]=",
 CellID->262077309]
}, Open  ]],

Cell[TextData[{
 "\:0417\:0434\:0435\:0441\:044c \:0432\:0432\:0435\:0434\:0435\:043d\:043e \
\:0443\:0441\:043b\:043e\:0432\:0438\:0435 \:0434\:043b\:044f \:0441\:0443\
\:0431\:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442\:0430, \:043f\:0440\
\:0435\:0434\:0448\:0435\:0441\:0442\:0432\:0443\:044e\:0449\:0435\:0433\:043e\
 \:0438\:0441\:043a\:043e\:043c\:043e\:043c\:0443 (\:0441\:043c. \"",
 ButtonBox["\:0420\:0435\:0433\:0443\:043b\:044f\:0440\:043d\:044b\:0435 \
\:0432\:044b\:0440\:0430\:0436\:0435\:043d\:0438\:044f",
  BaseStyle->"Hyperlink",
  ButtonData->{"WorkingWithStringPatternsRU.nb", "c:3"}],
 "\"), \:0447\:0442\:043e\:0431\:044b \:043e\:0431\:0435\:0441\:043f\:0435\
\:0447\:0438\:0442\:044c \:0432\:044b\:0431\:043e\:0440\:043a\:0443 \:043b\
\:0438\:0448\:044c \:0442\:0435\:0445 \:0441\:043b\:043e\:0432, \:043f\:0435\
\:0440\:0435\:0434 \:043a\:043e\:0442\:043e\:0440\:044b\:043c\:0438 \:043d\
\:0430\:0445\:043e\:0434\:0438\:0442\:0441\:044f \:0441\:0443\:0431\:0444\
\:0440\:0430\:0433\:043c\:0435\:043d\:0442 ",
 Cell[BoxData["\<\"the \"\>"], "InlineFormula"],
 "."
}], "MathCaption",
 CellTags->"b:0.1",
 CellID->603056891],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringCases", "[", 
  RowBox[{"\"\<the cat in the hat\>\"", ",", 
   RowBox[{
    RowBox[{"RegularExpression", "[", "\"\<(?<=the )\>\"", "]"}], "~~", 
    RowBox[{"WordCharacter", ".."}]}]}], "]"}]], "Input",
 CellTags->"b:0.1",
 CellLabel->"In[20]:=",
 CellID->291672169],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"cat\"\>", ",", "\<\"hat\"\>"}], "}"}]], "Output",
 ImageSize->{71, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.1",
 CellLabel->"Out[20]=",
 CellID->674525324]
}, Open  ]],

Cell[TextData[{
 "\:041e\:0431\:044a\:0435\:043a\:0442\:044b ",
 Cell[BoxData[
  TemplateBox[{Cell["StringExpression"],"paclet:ref/StringExpression"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " \:043c\:043e\:0433\:0443\:0442 \:0441\:043e\:0434\:0435\:0440\:0436\:0430\
\:0442\:044c \:0438\:0435\:0440\:0430\:0440\:0445\:0438\:0447\:0435\:0441\
\:043a\:0443\:044e \:0441\:0442\:0440\:0443\:043a\:0442\:0443\:0440\:0443 (\
\:0432\:043b\:043e\:0436\:0435\:043d\:043d\:043e\:0441\:0442\:044c)."
}], "MathCaption",
 CellTags->"b:0.1",
 CellID->344292962],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringCases", "[", 
  RowBox[{"\"\<ba3a1a78a2b7ba9\>\"", ",", 
   RowBox[{"\"\<b\>\"", "~~", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"\"\<a\>\"", "~~", "DigitCharacter"}], ")"}], ".."}]}]}], 
  "]"}]], "Input",
 CellTags->"b:0.1",
 CellLabel->"In[21]:=",
 CellID->57194593],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"ba3a1a7\"\>", ",", "\<\"ba9\"\>"}], "}"}]], "Output",
 ImageSize->{99, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.1",
 CellLabel->"Out[21]=",
 CellID->137492503]
}, Open  ]],

Cell[TextData[{
 "\:041a\:043e\:043d\:0441\:0442\:0440\:0443\:043a\:0446\:0438\:044f ",
 Cell[BoxData[
  TemplateBox[{Cell["Except"],"paclet:ref/Except"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " \:0434\:043b\:044f \:0442\:0435\:043a\:0441\:0442\:043e\:0432\:044b\:0445 \
\:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442\:043e\:0432 \:043f\:0440\
\:0435\:0434\:043f\:043e\:043b\:0430\:0433\:0430\:0435\:0442 \:043e\:0434\
\:0438\:043d\:043e\:0447\:043d\:044b\:0439 \:0430\:0440\:0433\:0443\:043c\
\:0435\:043d\:0442, \:043a\:043e\:0442\:043e\:0440\:044b\:0439 \:043c\:043e\
\:0436\:0435\:0442 \:0431\:044b\:0442\:044c \:043e\:0434\:0438\:043d\:043e\
\:0447\:043d\:044b\:043c \:0441\:0438\:043c\:0432\:043e\:043b\:043e\:043c \
\:0438\:043b\:0438 \:043e\:0442\:0434\:0435\:043b\:044c\:043d\:044b\:043c \
\:043a\:043b\:0430\:0441\:0441\:043e\:043c \:0441\:0438\:043c\:0432\:043e\
\:043b\:043e\:0432."
}], "Text",
 CellTags->"b:0.1",
 CellID->2661260],

Cell["\<\
\:0422\:0430\:043a \:0438\:0437 \:0442\:0435\:043a\:0441\:0442\:043e\:0432\
\:043e\:0433\:043e \:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442\:0430 \
\:0443\:0434\:0430\:043b\:044f\:044e\:0442\:0441\:044f \:0432\:0441\:0435 \
\:0441\:0438\:043c\:0432\:043e\:043b\:044b, \:043d\:0435 \:044f\:0432\:043b\
\:044f\:044e\:0449\:0438\:0435\:0441\:044f \:0433\:043b\:0430\:0441\:043d\
\:044b\:043c\:0438 \:0431\:0443\:043a\:0432\:0430\:043c\:0438.\
\>", "MathCaption",
 CellTags->"b:0.1",
 CellID->704437595],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringReplace", "[", 
  RowBox[{"\"\<the cat in the hat\>\"", ",", 
   RowBox[{
    RowBox[{"Except", "[", 
     RowBox[{"Characters", "[", "\"\<aeiou\>\"", "]"}], "]"}], "\[Rule]", 
    "\"\<\>\""}]}], "]"}]], "Input",
 CellTags->"b:0.1",
 CellLabel->"In[22]:=",
 CellID->190390204],

Cell[BoxData["\<\"eaiea\"\>"], "Output",
 ImageSize->{39, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.1",
 CellLabel->"Out[22]=",
 CellID->36878244]
}, Open  ]],

Cell[TextData[{
 "\:041f\:0440\:0438 \:043f\:043e\:0438\:0441\:043a\:0435 \:0441\:043e\:043e\
\:0442\:0432\:0435\:0442\:0441\:0442\:0432\:0438\:0439 \:0448\:0430\:0431\
\:043b\:043e\:043d\:0430\:043c \:043d\:0435\:043e\:043f\:0440\:0435\:0434\
\:0435\:043b\:0435\:043d\:043d\:043e\:0439 \:0434\:043b\:0438\:043d\:044b (\
\:0442\:0430\:043a\:0438\:043c \:043a\:0430\:043a  ",
 Cell[BoxData["__"], "InlineFormula"],
 " \:0438 ",
 Cell[BoxData[
  RowBox[{"\:0448\:0430\:0431\:043b\:043e\:043d", ".."}]], "InlineFormula"],
 "), \:043f\:043e \:0443\:043c\:043e\:043b\:0447\:0430\:043d\:0438\:044e, \
\:043f\:0435\:0440\:0432\:044b\:043c \:0432\:044b\:043f\:043e\:043b\:043d\
\:044f\:0435\:0442\:0441\:044f \:043f\:043e\:0438\:0441\:043a \:0441\:0430\
\:043c\:044b\:0445 \:0434\:043b\:0438\:043d\:043d\:044b\:0445 \:0438\:0437 \
\:0441\:043e\:043e\:0442\:0432\:0435\:0442\:0441\:0442\:0432\:0443\:044e\:0449\
\:0438\:0445 \:0448\:0430\:0431\:043b\:043e\:043d\:0443 \:0441\:0443\:0431\
\:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442\:043e\:0432. \:0427\:0442\
\:043e\:0431\:044b \:0437\:0430\:0441\:0442\:0430\:0432\:0438\:0442\:044c ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " \:0432\:044b\:043f\:043e\:043b\:043d\:044f\:0442\:044c \:043f\:043e\:0438\
\:0441\:043a \:0441\:0430\:043c\:044b\:0445 \:043a\:043e\:0440\:043e\:0442\
\:043a\:0438\:0445 \:0438\:0437 \:0441\:043e\:043e\:0442\:0432\:0435\:0442\
\:0441\:0442\:0432\:0443\:044e\:0449\:0438\:0445 \:0448\:0430\:0431\:043b\
\:043e\:043d\:0443 \:0441\:0443\:0431\:0444\:0440\:0430\:0433\:043c\:0435\
\:043d\:0442\:043e\:0432,  \:043d\:0443\:0436\:043d\:043e \
\"\:043e\:0431\:0435\:0440\:043d\:0443\:0442\:044c\" \:0441\:043e\:043e\:0442\
\:0432\:0435\:0442\:0441\:0442\:0432\:0443\:044e\:0449\:0443\:044e \:0447\
\:0430\:0441\:0442\:044c \:0448\:0430\:0431\:043b\:043e\:043d\:0430 \:043a\
\:043e\:043c\:0430\:043d\:0434\:043e\:0439  ",
 Cell[BoxData[
  RowBox[{
   TemplateBox[{Cell["Shortest"],"paclet:ref/Shortest"},
    "RefLink",
    BaseStyle->"InlineFormula"], "[", " ", "]"}]], "InlineFormula"],
 "."
}], "MathCaption",
 CellTags->"b:0.1",
 CellID->422987297],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringCases", "[", 
  RowBox[{"\"\<(ab) (cde)\>\"", ",", 
   RowBox[{"\"\<(\>\"", "~~", 
    RowBox[{"__", "~~", "\"\<)\>\""}]}]}], "]"}]], "Input",
 CellTags->"b:0.1",
 CellLabel->"In[23]:=",
 CellID->262589375],

Cell[BoxData[
 RowBox[{"{", "\<\"(ab) (cde)\"\>", "}"}]], "Output",
 ImageSize->{88, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.1",
 CellLabel->"Out[23]=",
 CellID->446243857]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringCases", "[", 
  RowBox[{"\"\<(ab) (cde)\>\"", ",", 
   RowBox[{"Shortest", "[", 
    RowBox[{"\"\<(\>\"", "~~", "__", "~~", "\"\<)\>\""}], "]"}]}], 
  "]"}]], "Input",
 CellTags->"b:0.1",
 CellLabel->"In[24]:=",
 CellID->87767072],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"(ab)\"\>", ",", "\<\"(cde)\"\>"}], "}"}]], "Output",
 ImageSize->{92, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.1",
 CellLabel->"Out[24]=",
 CellID->10974229]
}, Open  ]],

Cell[TextData[{
 "\:0415\:0441\:043b\:0438, \:043f\:043e \
\:043a\:0430\:043a\:0438\:043c-\:043b\:0438\:0431\:043e \:043f\:0440\:0438\
\:0447\:0438\:043d\:0430\:043c, \:0442\:0440\:0435\:0431\:0443\:0435\:0442\
\:0441\:044f \:043d\:0430\:0439\:0442\:0438 \:0441\:0430\:043c\:043e\:0435 \
\:0434\:043b\:0438\:043d\:043d\:043e\:0435 \:0441\:043e\:0432\:043f\:0430\
\:0434\:0435\:043d\:0438\:0435 \:0441\:0440\:0435\:0434\:0438 \:043a\:043e\
\:0440\:043e\:0442\:043a\:0438\:0445 , \:043c\:043e\:0436\:043d\:043e \:0432\
\:043e\:0441\:043f\:043e\:043b\:044c\:0437\:043e\:0432\:0430\:0442\:044c\:0441\
\:044f ",
 Cell[BoxData[
  TemplateBox[{Cell["Longest"],"paclet:ref/Longest"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 "."
}], "MathCaption",
 CellTags->"b:0.1",
 CellID->30079273],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringCases", "[", 
  RowBox[{"\"\<(ab132cd)137(ef576gh)\>\"", ",", 
   RowBox[{
    RowBox[{"Shortest", "[", 
     RowBox[{"\"\<(\>\"", "~~", "___", "~~", 
      RowBox[{"x", ":", 
       RowBox[{"DigitCharacter", ".."}]}], "~~", "___", "~~", "\"\<)\>\""}], 
     "]"}], "\[RuleDelayed]", "x"}]}], "]"}]], "Input",
 CellTags->"b:0.1",
 CellLabel->"In[25]:=",
 CellID->336262030],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"1\"\>", ",", "\<\"5\"\>"}], "}"}]], "Output",
 ImageSize->{43, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.1",
 CellLabel->"Out[25]=",
 CellID->124605047]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringCases", "[", 
  RowBox[{"\"\<(ab132cd)(ef576gh)\>\"", ",", 
   RowBox[{
    RowBox[{"Shortest", "[", 
     RowBox[{"\"\<(\>\"", "~~", "___", "~~", 
      RowBox[{"Longest", "[", 
       RowBox[{"x", ":", 
        RowBox[{"DigitCharacter", ".."}]}], "]"}], "~~", "___", "~~", 
      "\"\<)\>\""}], "]"}], "\[RuleDelayed]", "x"}]}], "]"}]], "Input",
 CellTags->"b:0.1",
 CellLabel->"In[26]:=",
 CellID->46781425],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"132\"\>", ",", "\<\"576\"\>"}], "}"}]], "Output",
 ImageSize->{71, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.1",
 CellLabel->"Out[26]=",
 CellID->35253798]
}, Open  ]],

Cell[TextData[{
 "\:0412 \:043a\:0430\:0447\:0435\:0441\:0442\:0432\:0435 \:0430\:043b\:044c\
\:0442\:0435\:0440\:043d\:0430\:0442\:0438\:0432\:044b, \:043c\:043e\:0436\
\:043d\:043e \:043f\:0435\:0440\:0435\:043f\:0438\:0441\:0430\:0442\:044c \
\:0448\:0430\:0431\:043b\:043e\:043d, \:043e\:0442\:043a\:0430\:0437\:0430\
\:0432\:0448\:0438\:0441\:044c \:043e\:0442 \:0438\:0441\:043f\:043e\:043b\
\:044c\:0437\:043e\:0432\:0430\:043d\:0438\:044f ",
 Cell[BoxData[
  TemplateBox[{Cell["Longest"],"paclet:ref/Longest"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 "."
}], "MathCaption",
 CellTags->"b:0.1",
 CellID->165376289],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringCases", "[", 
  RowBox[{"\"\<(ab132cd)(ef576gh)\>\"", ",", 
   RowBox[{
    RowBox[{"\"\<(\>\"", "~~", 
     RowBox[{"Shortest", "[", "___", "]"}], "~~", 
     RowBox[{"x", ":", 
      RowBox[{"DigitCharacter", ".."}]}], "~~", 
     RowBox[{"Shortest", "[", "___", "]"}], "~~", "\"\<)\>\""}], 
    "\[RuleDelayed]", "x"}]}], "]"}]], "Input",
 CellTags->"b:0.1",
 CellLabel->"In[27]:=",
 CellID->33998707],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"132\"\>", ",", "\<\"576\"\>"}], "}"}]], "Output",
 ImageSize->{71, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.1",
 CellLabel->"Out[27]=",
 CellID->266461623]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\:0420\:0435\:0433\:0443\:043b\:044f\:0440\:043d\:044b\:0435 \:0432\
\:044b\:0440\:0430\:0436\:0435\:043d\:0438\:044f", "Section",
 CellTags->{"Regular Expressions", "c:3", "b:0.2"},
 CellID->274403895],

Cell[TextData[{
 "\:0421\:0438\:043d\:0442\:0430\:043a\:0441\:0438\:0441 \:0440\:0435\:0433\
\:0443\:043b\:044f\:0440\:043d\:044b\:0445 \:0432\:044b\:0440\:0430\:0436\
\:0435\:043d\:0438\:0439 \:043f\:043e\:0441\:0442\:0440\:043e\:0435\:043d \
\:043d\:0430 \:043e\:0441\:043d\:043e\:0432\:0435 \:0431\:0438\:0431\:043b\
\:0438\:043e\:0442\:0435\:043a\:0438 Perl Compatible Regular Expressions \
(PCRE), \:043a\:043e\:0442\:043e\:0440\:0430\:044f \:0442\:0435\:0441\:043d\
\:043e \:0441\:0432\:044f\:0437\:0430\:043d\:0430 \:0441 \:0441\:0438\:043d\
\:0442\:0430\:043a\:0441\:0438\:0441\:043e\:043c Perl. (\:0421\:043c. ",
 ButtonBox["[1]",
  BaseStyle->"Link",
  ButtonData->"paclet:tutorial/WorkingWithStringPatterns#872737084"],
 " \:0434\:043b\:044f \:043f\:043e\:043b\:0443\:0447\:0435\:043d\:0438\:044f \
\:0434\:043e\:043f\:043e\:043b\:043d\:0438\:0442\:0435\:043b\:044c\:043d\:043e\
\:0439 \:0438\:043d\:0444\:043e\:0440\:043c\:0430\:0446\:0438\:0438 \:0438 \
\:0434\:043e\:043a\:0443\:043c\:0435\:043d\:0442\:0430\:0446\:0438\:0438.) \
\:0412 ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", \:0440\:0435\:0433\:0443\:043b\:044f\:0440\:043d\:043e\:0435 \:0432\:044b\
\:0440\:0430\:0436\:0435\:043d\:0438\:0435 \:043e\:0431\:043e\:0437\:043d\
\:0430\:0447\:0430\:0435\:0442\:0441\:044f \:0437\:0430\:0433\:043e\:043b\
\:043e\:0432\:043a\:043e\:043c ",
 Cell[BoxData[
  TemplateBox[{Cell["RegularExpression"],"paclet:ref/RegularExpression"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 "."
}], "Text",
 CellTags->"b:0.2",
 CellID->179324024],

Cell["\<\
\:0421\:043b\:0435\:0434\:0443\:044e\:0449\:0438\:0435 \:0431\:0430\:0437\
\:043e\:0432\:044b\:0435 \:044d\:043b\:0435\:043c\:0435\:043d\:0442\:044b \
\:043c\:043e\:0433\:0443\:0442 \:0431\:044b\:0442\:044c \:0438\:0441\:043f\
\:043e\:043b\:044c\:0437\:043e\:0432\:0430\:043d\:044b \:0432\:043d\:0443\
\:0442\:0440\:0438 \:0440\:0435\:0433\:0443\:043b\:044f\:0440\:043d\:044b\
\:0445 \:0432\:044b\:0440\:0430\:0436\:0435\:043d\:0438\:0439:\
\>", "Text",
 CellFrame->{{0, 0}, {0, 0.25}},
 CellTags->"b:0.2",
 CellID->311647046],

Cell[BoxData[GridBox[{
   {"\<\"\\!\\(\\* StyleBox[\"c\", \"TI\"]\\)\"\>", Cell[TextData[{
     "\:0437\:043d\:0430\:043a\:043e\:0432\:044b\:0439 \:043b\:0438\:0442\
\:0435\:0440\:0430\:043b",
     " ",
     Cell[BoxData[
      StyleBox["c", "TI"]], "InlineFormula"]
    }], "TableText"]},
   {"\<\".\"\>", Cell[
    "\:043b\:044e\:0431\:043e\:0439 \:0441\:0438\:043c\:0432\:043e\:043b, \
\:043a\:0440\:043e\:043c\:0435 \:0441\:0438\:043c\:0432\:043e\:043b\:0430 \
\:043d\:043e\:0432\:043e\:0439 \:0441\:0442\:0440\:043e\:043a\:0438 ", 
     "TableText"]},
   {"\<\"[\!\(\*SubscriptBox[
StyleBox[\\\"c\\\", \\\"TI\\\"], 
StyleBox[\\\"1\\\", \\\"TR\\\"]]\)\!\(\*SubscriptBox[
StyleBox[\\\"c\\\", \\\"TI\\\"], 
StyleBox[\\\"2\\\", \\\"TR\\\"]]\)\!\(\*
StyleBox[\\\"\[Ellipsis]\\\", \\\"TR\\\"]\)]\"\>", Cell[TextData[{
     "\:043b\:044e\:0431\:043e\:0439 \:0438\:0437 \:0441\:0438\:043c\:0432\
\:043e\:043b\:043e\:0432",
     " ",
     Cell[BoxData[
      SubscriptBox[
       StyleBox["c", "TI"], 
       StyleBox["i", "TI"]]], "InlineFormula"]
    }], "TableText"]},
   {"\<\"[\!\(\*SubscriptBox[
StyleBox[\\\"c\\\", \\\"TI\\\"], 
StyleBox[\\\"1\\\", \\\"TR\\\"]]\)-\!\(\*SubscriptBox[
StyleBox[\\\"c\\\", \\\"TI\\\"], 
StyleBox[\\\"2\\\", \\\"TR\\\"]]\)]\"\>", Cell[TextData[{
     "\:043b\:044e\:0431\:043e\:0439 \:0441\:0438\:043c\:0432\:043e\:043b \
\:0432 \:0434\:0438\:0430\:043f\:0430\:0437\:043e\:043d\:0435",
     " ",
     Cell[BoxData[
      SubscriptBox[
       StyleBox["c", "TI"], 
       StyleBox["1", "TR"]]], "InlineFormula"],
     "\[Dash]",
     Cell[BoxData[
      SubscriptBox[
       StyleBox["c", "TI"], 
       StyleBox["2", "TR"]]], "InlineFormula"],
     " "
    }], "TableText"]},
   {"\<\"[^\!\(\*SubscriptBox[
StyleBox[\\\"c\\\", \\\"TI\\\"], 
StyleBox[\\\"1\\\", \\\"TR\\\"]]\)\!\(\*SubscriptBox[
StyleBox[\\\"c\\\", \\\"TI\\\"], 
StyleBox[\\\"2\\\", \\\"TR\\\"]]\)\!\(\*
StyleBox[\\\"\[Ellipsis]\\\", \\\"TR\\\"]\)]\"\>", Cell[TextData[{
     "\:043b\:044e\:0431\:043e\:0439 \:0441\:0438\:043c\:0432\:043e\:043b, \
\:043a\:0440\:043e\:043c\:0435",
     " ",
     Cell[BoxData[
      SubscriptBox[
       StyleBox["c", "TI"], 
       StyleBox["i", "TI"]]], "InlineFormula"]
    }], "TableText"]},
   {"\<\"\\!\\(\\* StyleBox[\\\"p\\\", \\\"TI\\\"]\\)*\"\>", Cell[TextData[{
     Cell[BoxData[
      StyleBox["p", "TI"]], "InlineFormula"],
     " ",
     "\:043f\:043e\:0432\:0442\:043e\:0440\:044f\:0435\:043c\:044b\:0439 \
\:043d\:043e\:043b\:044c \:0438\:043b\:0438 \:0431\:043e\:043b\:0435\:0435 \
\:0440\:0430\:0437",
     " "
    }], "TableText"]},
   {"\<\"\\!\\(\\* StyleBox[\\\"p\\\", \\\"TI\\\"]\\)+\"\>", Cell[TextData[{
     Cell[BoxData[
      StyleBox["p", "TI"]], "InlineFormula"],
     " ",
     "\:043f\:043e\:0432\:0442\:043e\:0440\:044f\:0435\:043c\:044b\:0439 \
\:043e\:0434\:0438\:043d \:0438\:043b\:0438 \:0431\:043e\:043b\:0435\:0435 \
\:0440\:0430\:0437",
     " "
    }], "TableText"]},
   {"\<\"\\!\\(\\* StyleBox[\\\"p\\\", \\\"TI\\\"]\\)?\"\>", Cell[TextData[{
     "\:043d\:0443\:043b\:0435\:0432\:043e\:0439 \:0438\:043b\:0438 \:0435\
\:0434\:0438\:043d\:0438\:0447\:043d\:044b\:0439 \:0441\:043b\:0443\:0447\
\:0430\:0439 \:043f\:0440\:0438\:0441\:0443\:0442\:0441\:0442\:0432\:0438\
\:044f",
     " ",
     Cell[BoxData[
      StyleBox["p", "TI"]], "InlineFormula"]
    }], "TableText"]},
   {"\<\"\\!\\(\\* StyleBox[\\\"p\\\", \\\"TI\\\"]\\){\\!\\(\\* \
StyleBox[\\\"m\\\", \\\"TI\\\"]\\),\\!\\(\\* StyleBox[\\\"n\\\", \
\\\"TI\\\"]\\)}\"\>", Cell[TextData[{
     Cell[BoxData[
      StyleBox["p", "TI"]], "InlineFormula"],
     " ",
     "\:043f\:043e\:0432\:0442\:043e\:0440\:044f\:0435\:043c\:044b\:0439 \
\:043e\:0442 ",
     Cell[BoxData[
      StyleBox["m", "TI"]], "InlineFormula"],
     " \:0434\:043e ",
     Cell[BoxData[
      StyleBox["n", "TI"]], "InlineFormula"],
     " \:0440\:0430\:0437"
    }], "TableText"]},
   {
    RowBox[{
     StyleBox["p", "TI"], "*", 
     RowBox[{"?", 
      RowBox[{
       RowBox[{Cell[",", "TableText"], 
        StyleBox["p", "TI"]}], "+", 
       RowBox[{"?", 
        RowBox[{Cell[",", "TableText"], 
         StyleBox["p", "TI"], "??"}]}]}]}]}], Cell["\<\
\:043a\:0440\:0430\:0442\:0447\:0430\:0439\:0448\:0438\:0439 \:0446\:0435\
\:043b\:043e\:0441\:0442\:043d\:044b\:0439 \:0442\:0435\:043a\:0441\:0442\
\:043e\:0432\:044b\:0439 \:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442, \
\:043a\:043e\:0442\:043e\:0440\:043e\:043c\:0443 \:0432\:044b\:043f\:043e\
\:043b\:043d\:044f\:0435\:0442\:0441\:044f \:0441\:043e\:043f\:043e\:0441\
\:0442\:0430\:0432\:043b\:0435\:043d\:0438\:0435 \
\>", "TableText"]},
   {
    RowBox[{
     StyleBox["p", "TI"], "*", 
     RowBox[{"+", Cell[",", "TableText"]}], 
     RowBox[{
      StyleBox["p", "TI"], "++"}], Cell[",", "TableText"], 
     RowBox[{
      StyleBox["p", "TI"], "?", "+"}]}], Cell[
    "\:043f\:0440\:0438\:0442\:044f\:0436\:0430\:0442\:0435\:043b\:044c\:043d\
\:044b\:0435 \:0441\:043e\:043e\:0442\:0432\:0435\:0442\:0441\:0442\:0432\
\:0438\:044f", "TableText"]},
   {"\<\"(\!\(\*SubscriptBox[
StyleBox[\\\"p\\\", \\\"TI\\\"], 
StyleBox[\\\"1\\\", \\\"TR\\\"]]\)\!\(\*SubscriptBox[
StyleBox[\\\"p\\\", \\\"TI\\\"], 
StyleBox[\\\"2\\\", \\\"TR\\\"]]\)\!\(\*
StyleBox[\\\"\[Ellipsis]\\\", \\\"TR\\\"]\))\"\>", Cell[TextData[{
     "\:043f\:043e\:0438\:0441\:043a \:0442\:0435\:043a\:0441\:0442\:043e\
\:0432\:044b\:0445 \:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442\:043e\
\:0432, \:0441\:043e\:043e\:0442\:0432\:0435\:0442\:0441\:0442\:0432\:0443\
\:044e\:0449\:0438\:0445 \:043f\:043e\:0441\:043b\:0435\:0434\:043e\:0432\
\:0430\:0442\:0435\:043b\:044c\:043d\:043e\:0441\:0442\:0438",
     " ",
     Cell[BoxData[
      SubscriptBox[
       StyleBox["p", "TI"], 
       StyleBox["1", "TR"]]], "InlineFormula"],
     ", ",
     Cell[BoxData[
      SubscriptBox[
       StyleBox["p", "TI"], 
       StyleBox["2", "TR"]]], "InlineFormula"],
     ", \[Ellipsis]"
    }], "TableText"]},
   {"\<\"\!\(\*SubscriptBox[
StyleBox[\\\"p\\\", \\\"TI\\\"], 
StyleBox[\\\"1\\\", \\\"TR\\\"]]\)|\!\(\*SubscriptBox[
StyleBox[\\\"p\\\", \\\"TI\\\"], 
StyleBox[\\\"2\\\", \\\"TR\\\"]]\)\"\>", Cell[TextData[{
     "\:043f\:043e\:0438\:0441\:043a \:0441\:0443\:0431\:0444\:0440\:0430\
\:0433\:043c\:0435\:043d\:0442\:043e\:0432, \:0441\:043e\:043e\:0442\:0432\
\:0435\:0442\:0441\:0442\:0432\:0443\:044e\:0449\:0438\:0445 ",
     Cell[BoxData[
      SubscriptBox[
       StyleBox["p", "TI"], 
       StyleBox["1", "TR"]]], "InlineFormula"],
     " \:0438\:043b\:0438 ",
     Cell[BoxData[
      SubscriptBox[
       StyleBox["p", "TI"], 
       StyleBox["2", "TR"]]], "InlineFormula"],
     " "
    }], "TableText"]}
  },
  GridBoxAlignment->{
   "Columns" -> {Left, {Left}}, "ColumnsIndexed" -> {}, 
    "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}]], "DefinitionBox",
 ShowStringCharacters->False,
 CellID->30983],

Cell["\:041a\:043b\:0430\:0441\:0441\:044b \:0441\:0438\:043c\:0432\:043e\
\:043b\:043e\:0432, \:0438\:0441\:043f\:043e\:043b\:044c\:0437\:0443\:0435\
\:043c\:044b\:0435 \:0432 \:0440\:0435\:0433\:0443\:043b\:044f\:0440\:043d\
\:044b\:0445 \:0432\:044b\:0440\:0430\:0436\:0435\:043d\:0438\:044f\:0445: ", \
"Text",
 CellTags->"b:0.2",
 CellID->326926809],

Cell[BoxData[GridBox[{
   {"\<\"\\\\\\\\d\"\>", Cell[
    "\:0446\:0438\:0444\:0440\:044b 0\[Dash]9 ", "TableText"]},
   {"\<\"\\\\\\\\D\"\>", Cell[
    "\:0432\:0441\:0435, \:043a\:0440\:043e\:043c\:0435 \:0446\:0438\:0444\
\:0440 ", "TableText"]},
   {"\<\"\\\\\\\\s\"\>", Cell["\<\
\:043f\:0440\:043e\:0431\:0435\:043b\:044b, \:043d\:043e\:0432\:0430\:044f \
\:0441\:0442\:0440\:043e\:043a\:0430, \:0442\:0430\:0431\:0443\:043b\:044f\
\:0442\:043e\:0440 \:0438\:043b\:0438 \:0434\:0440\:0443\:0433\:0438\:0435 \
\:0440\:0430\:0437\:0434\:0435\:043b\:0438\:0442\:0435\:043b\:044c\:043d\:044b\
\:0435 \:0441\:0438\:043c\:0432\:043e\:043b\:044b \
\>", "TableText"]},
   {"\<\"\\\\\\\\S\"\>", Cell[
    "\:0441\:0438\:043c\:0432\:043e\:043b\:044b, \:043d\:0435 \:043e\:0442\
\:043d\:043e\:0441\:044f\:0449\:0438\:0435\:0441\:044f \:043a \:0440\:0430\
\:0437\:0434\:0435\:043b\:0438\:0442\:0435\:043b\:044c\:043d\:044b\:043c  ", 
     "TableText"]},
   {"\<\"\\\\\\\\w\"\>", Cell[TextData[{
     "\:0441\:043b\:043e\:0432\:043e\:043e\:0431\:0440\:0430\:0437\:0443\:044e\
\:0449\:0438\:0435 \:0441\:0438\:043c\:0432\:043e\:043b\:044b (\:0431\:0443\
\:043a\:0432\:044b, \:0446\:0438\:0444\:0440\:044b \:0438\:043b\:0438 ",
     Cell[BoxData["_"], "InlineFormula"],
     ")",
     " "
    }], "TableText"]},
   {"\<\"\\\\\\\\W\"\>", Cell[
    "\:0441\:0438\:043c\:0432\:043e\:043b\:044b, \:043d\:0435 \:043e\:0442\
\:043d\:043e\:0441\:044f\:0449\:0438\:0435\:0441\:044f \:043a \:0441\:043b\
\:043e\:0432\:043e\:043e\:0431\:0440\:0430\:0437\:0443\:044e\:0449\:0438\:043c\
", "TableText"]},
   {"\<\"[[:\\!\\(\\* StyleBox[\\\"class\\\", \\\"TI\\\"]\\):]]\"\>", Cell[
    "\:0441\:0438\:043c\:0432\:043e\:043b\:044b \:0432 \:0438\:043c\:0435\
\:043d\:043e\:0432\:0430\:043d\:043d\:043e\:043c \:043a\:043b\:0430\:0441\
\:0441\:0435", "TableText"]},
   {"\<\"[^[:\!\(\*
StyleBox[\\\"class\\\",
\\\"TI\\\"]\):]]\"\>", Cell[
    "\:0441\:0438\:043c\:0432\:043e\:043b\:044b, \:043d\:0435 \:043e\:0442\
\:043d\:043e\:0441\:044f\:0449\:0438\:0435\:0441\:044f \:043a \:0438\:043c\
\:0435\:043d\:043e\:0432\:0430\:043d\:043d\:043e\:043c\:0443 \:043a\:043b\
\:0430\:0441\:0441\:0443 ", "TableText"]}
  },
  GridBoxAlignment->{
   "Columns" -> {Left, {Left}}, "ColumnsIndexed" -> {}, 
    "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}]], "DefinitionBox",
 ShowStringCharacters->False,
 CellID->3341],

Cell[TextData[{
 "\:041c\:043e\:0436\:043d\:043e \:0438\:0441\:043f\:043e\:043b\:044c\:0437\
\:043e\:0432\:0430\:0442\:044c \:0441\:043b\:0435\:0434\:0443\:044e\:0449\
\:0438\:0435 \:0438\:043c\:0435\:043d\:043e\:0432\:0430\:043d\:043d\:044b\
\:0435 \:043a\:043b\:0430\:0441\:0441\:044b: ",
 Cell[BoxData[
  StyleBox["alnum", "TI"]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  StyleBox["alpha", "TI"]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  StyleBox["ascii", "TI"]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  StyleBox["blank", "TI"]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  StyleBox["cntrl", "TI"]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  StyleBox["digit", "TI"]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  StyleBox["graph", "TI"]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  StyleBox["lower", "TI"]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  StyleBox["print", "TI"]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  StyleBox["punct", "TI"]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  StyleBox["space", "TI"]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  StyleBox["upper", "TI"]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  StyleBox["word", "TI"]], "InlineFormula"],
 " \:0438 ",
 Cell[BoxData[
  StyleBox["xdigit", "TI"]], "InlineFormula"],
 ". "
}], "Text",
 CellTags->"b:0.2",
 CellID->423328124],

Cell["\<\
\:041e\:0431\:043e\:0437\:043d\:0430\:0447\:0435\:043d\:0438\:044f \:043f\
\:043e\:0437\:0438\:0446\:0438\:0439 \:0432 \:0442\:0435\:043a\:0441\:0442\
\:043e\:0432\:044b\:0445 \:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442\
\:0430\:0445, \:0438\:0441\:043f\:043e\:043b\:044c\:0437\:0443\:0435\:043c\
\:044b\:0435 \:0432 \:0440\:0435\:0433\:0443\:043b\:044f\:0440\:043d\:044b\
\:0445 \:0432\:044b\:0440\:0430\:0436\:0435\:043d\:0438\:044f\:0445: \
\>", "Text",
 CellTags->"b:0.2",
 CellID->53679581],

Cell[BoxData[GridBox[{
   {"^", Cell[
    "\:043d\:0430\:0447\:0430\:043b\:043e \
\:0442\:0435\:043a\:0441\:0442\:043e\:0432\:043e\:0433\:043e \:0444\:0440\
\:0430\:0433\:043c\:0435\:043d\:0442\:0430 (\:0438\:043b\:0438 \:0441\:0442\
\:0440\:043e\:043a\:0438) ", "TableText"]},
   {"$", Cell[
    "\:043a\:043e\:043d\:0435\:0446 \
\:0442\:0435\:043a\:0441\:0442\:043e\:0432\:043e\:0433\:043e \:0444\:0440\
\:0430\:0433\:043c\:0435\:043d\:0442\:0430 (\:0438\:043b\:0438 \:0441\:0442\
\:0440\:043e\:043a\:0438) ", "TableText"]},
   {
    RowBox[{"\\\\", "A"}], Cell[
    "\:043d\:0430\:0447\:0430\:043b\:043e \
\:0442\:0435\:043a\:0441\:0442\:043e\:0432\:043e\:0433\:043e \:0444\:0440\
\:0430\:0433\:043c\:0435\:043d\:0442\:0430 ", "TableText"]},
   {
    RowBox[{"\\\\", "z"}], Cell[
    "\:043a\:043e\:043d\:0435\:0446 \
\:0442\:0435\:043a\:0441\:0442\:043e\:0432\:043e\:0433\:043e \:0444\:0440\
\:0430\:0433\:043c\:0435\:043d\:0442\:0430 ", "TableText"]},
   {
    RowBox[{"\\\\", "Z"}], Cell["\<\
\:043a\:043e\:043d\:0435\:0446 \:0442\:0435\:043a\:0441\:0442\:043e\:0432\
\:043e\:0433\:043e \:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442\:0430 (\
\:0434\:043e\:043f\:0443\:0441\:043a\:0430\:044e\:0449\:0438\:0439 \:043d\
\:0430\:043b\:0438\:0447\:0438\:0435 \:043e\:0434\:043d\:043e\:0433\:043e \
\:0441\:0438\:043c\:0432\:043e\:043b\:0430 \:043d\:043e\:0432\:043e\:0439 \
\:0441\:0442\:0440\:043e\:043a\:0438 \:0432 \:043a\:043e\:043d\:0446\:0435) \
\>", "TableText"]},
   {
    RowBox[{"\\\\", "b"}], Cell[
    "\:0433\:0440\:0430\:043d\:0438\:0446\:0430 \
\:0441\:043b\:043e\:0432\:0430 ", "TableText"]},
   {
    RowBox[{"\\\\", "B"}], Cell[
    "\:0432 \:043b\:044e\:0431\:043e\:043c \:043c\:0435\:0441\:0442\:0435, \
\:043a\:0440\:043e\:043c\:0435 \:0433\:0440\:0430\:043d\:0438\:0446\:044b \
\:0441\:043b\:043e\:0432\:0430 ", "TableText"]}
  },
  GridBoxAlignment->{
   "Columns" -> {Left, {Left}}, "ColumnsIndexed" -> {}, 
    "Rows" -> {{Baseline}}, "RowsIndexed" -> {}}]], "DefinitionBox",
 CellTags->"b:0.2",
 CellID->438051314],

Cell["\:041e\:043f\:0435\:0440\:0430\:0442\:043e\:0440\:044b \:043e\:043f\
\:0446\:0438\:0439 \:0434\:043b\:044f \:0432\:0441\:0435\:0445 \:044d\:043b\
\:0435\:043c\:0435\:043d\:0442\:043e\:0432 \:0440\:0435\:0433\:0443\:043b\
\:044f\:0440\:043d\:044b\:0445 \:0432\:044b\:0440\:0430\:0436\:0435\:043d\
\:0438\:0439: ", "Text",
 CellTags->"b:0.2",
 CellID->446511798],

Cell[BoxData[GridBox[{
   {
    RowBox[{"(", 
     RowBox[{"?", "i)"}]}], Cell["\<\
\:0442\:0440\:0430\:043a\:0442\:0443\:0435\:0442 \:0437\:0430\:0433\:043b\
\:0430\:0432\:043d\:044b\:0435 \:0438 \:0441\:0442\:0440\:043e\:0447\:043d\
\:044b\:0435 \:0441\:0438\:043c\:0432\:043e\:043b\:044b \:043a\:0430\:043a \
\:044d\:043a\:0432\:0438\:0432\:0430\:043b\:0435\:043d\:0442\:043d\:044b\:0435\
 (\:0438\:0433\:043d\:043e\:0440\:0438\:0440\:043e\:0432\:0430\:043d\:0438\
\:0435 \:0440\:0435\:0433\:0438\:0441\:0442\:0440\:0430)\
\>", "TableText"]},
   {
    RowBox[{"(", 
     RowBox[{"?", "m)"}]}], Cell[TextData[{
     "\:0432\:044b\:043d\:0443\:0436\:0434\:0430\:0435\:0442 ",
     Cell[BoxData["^"], "InlineFormula"],
     " \:0438 ",
     Cell[BoxData["$"], "InlineFormula"],
     " \:0441\:043e\:043e\:0442\:0432\:0435\:0442\:0441\:0442\:0432\:043e\
\:0432\:0430\:0442\:044c \:043d\:0430\:0447\:0430\:043b\:0430\:043c \:0438 \
\:043a\:043e\:043d\:0446\:0430\:043c \:0441\:0442\:0440\:043e\:043a (\:043c\
\:043d\:043e\:0433\:043e\:0441\:0442\:0440\:043e\:0447\:043d\:044b\:0439 \
\:0440\:0435\:0436\:0438\:043c) "
    }], "TableText"]},
   {
    RowBox[{"(", 
     RowBox[{"?", "s)"}]}], Cell[TextData[{
     "\:043f\:043e\:0437\:0432\:043e\:043b\:044f\:0435\:0442 \:043d\:043e\
\:0432\:043e\:0439 \:0441\:0442\:0440\:043e\:043a\:0435 \:0441\:043e\:043e\
\:0442\:0432\:0435\:0442\:0441\:0442\:0432\:043e\:0432\:0430\:0442\:044c ",
     Cell[BoxData["."], "InlineFormula"],
     " "
    }], "TableText"]},
   {
    RowBox[{"(", 
     RowBox[{"?", "x)"}]}], Cell[TextData[{
     "\:0438\:0433\:043d\:043e\:0440\:0438\:0440\:0443\:0435\:0442 \:0432\
\:0441\:0435 \:043f\:0440\:043e\:0431\:0435\:043b\:044b \:0438 \:0440\:0430\
\:0441\:0441\:043c\:0430\:0442\:0440\:0438\:0432\:0430\:0435\:0442 \:0432\
\:0441\:0435, \:0447\:0442\:043e \:043d\:0430\:0445\:043e\:0434\:0438\:0442\
\:0441\:044f \:043c\:0435\:0436\:0434\:0443 ",
     Cell[BoxData["\"\<#\>\""], "InlineFormula"],
     " \:0438 ",
     Cell[BoxData["\"\<\\n\>\""], "InlineFormula"],
     "  \:0432 \:043a\:0430\:0447\:0435\:0441\:0442\:0432\:0435 \:043a\:043e\
\:043c\:043c\:0435\:043d\:0442\:0430\:0440\:0438\:0435\:0432"
    }], "TableText"]},
   {
    RowBox[{"(", 
     RowBox[{"?", "-\[Backslash]#c)"}]}], Cell[
    "\:0441\:0431\:0440\:043e\:0441 \:043e\:043f\:0446\:0438\:0439", 
     "TableText"]}
  },
  GridBoxAlignment->{
   "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
    "RowsIndexed" -> {}}]], "DefinitionBox",
 CellTags->"b:0.2",
 CellID->103937476],

Cell["\:041a\:043e\:043d\:0441\:0442\:0440\:0443\:043a\:0446\:0438\:0438, \
\:043e\:043f\:0440\:0435\:0434\:0435\:043b\:044f\:044e\:0449\:0438\:0435 \
\:043d\:0430\:043f\:0440\:0430\:0432\:043b\:0435\:043d\:0438\:0435 \:043f\
\:0440\:043e\:0441\:043c\:043e\:0442\:0440\:0430:", "Text",
 CellTags->"b:0.2",
 CellID->725709264],

Cell[BoxData[GridBox[{
   {
    RowBox[{"(", 
     RowBox[{"?", 
      RowBox[{
       RowBox[{"=", 
        StyleBox["p", "TI",
         FontSlant->"Italic"]}], ")"}]}]}], Cell[TextData[{
     "\:0441\:043b\:0435\:0434\:0443\:044e\:0449\:0438\:0439 \:0434\:0430\
\:043b\:0435\:0435 \:0442\:0435\:043a\:0441\:0442 \:0434\:043e\:043b\:0436\
\:0435\:043d \:0441\:043e\:0432\:043f\:0430\:0434\:0430\:0442\:044c \:0441 ",
     Cell[BoxData[
      StyleBox["p", "TI"]], "InlineFormula"]
    }], "TableText"]},
   {
    RowBox[{"(", 
     RowBox[{"?", 
      RowBox[{
       RowBox[{"!", 
        StyleBox["p", "TI",
         FontSlant->"Italic"]}], ")"}]}]}], Cell[TextData[{
     "\:0441\:043b\:0435\:0434\:0443\:044e\:0449\:0438\:0439 \:0434\:0430\
\:043b\:0435\:0435 \:0442\:0435\:043a\:0441\:0442 \:043d\:0435 \:0434\:043e\
\:043b\:0436\:0435\:043d \:0441\:043e\:0432\:043f\:0430\:0434\:0430\:0442\
\:044c \:0441 ",
     Cell[BoxData[
      StyleBox["p", "TI"]], "InlineFormula"]
    }], "TableText"]},
   {
    RowBox[{"(", 
     RowBox[{"?", 
      RowBox[{
       RowBox[{"<=", " ", 
        StyleBox["p", "TI",
         FontSlant->"Italic"]}], ")"}]}]}], Cell[TextData[{
     "\:043f\:0440\:0435\:0434\:0448\:0435\:0441\:0442\:0432\:0443\:044e\:0449\
\:0438\:0439 \:0442\:0435\:043a\:0441\:0442 \:0434\:043e\:043b\:0436\:0435\
\:043d \:0441\:043e\:0432\:043f\:0430\:0434\:0430\:0442\:044c \:0441 ",
     Cell[BoxData[
      StyleBox["p", "TI"]], "InlineFormula"]
    }], "TableText"]},
   {
    RowBox[{"(", 
     RowBox[{"?", 
      RowBox[{
       RowBox[{"<", 
        RowBox[{"!", 
         StyleBox["p", "TI",
          FontSlant->"Italic"]}]}], ")"}]}]}], Cell[TextData[{
     "\:043f\:0440\:0435\:0434\:0448\:0435\:0441\:0442\:0432\:0443\:044e\:0449\
\:0438\:0439 \:0442\:0435\:043a\:0441\:0442 \:043d\:0435 \:0434\:043e\:043b\
\:0436\:0435\:043d \:0441\:043e\:0432\:043f\:0430\:0434\:0430\:0442\:044c \
\:0441 ",
     Cell[BoxData[
      StyleBox["p", "TI"]], "InlineFormula"]
    }], "TableText"]}
  },
  GridBoxAlignment->{
   "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
    "RowsIndexed" -> {}}]], "DefinitionBox",
 CellTags->"b:0.2",
 CellID->324529988],

Cell["\<\
\:041d\:0438\:0436\:0435 \:0440\:0430\:0441\:0441\:043c\:0430\:0442\:0440\
\:0438\:0432\:0430\:044e\:0442\:0441\:044f \:043d\:0435\:043a\:043e\:0442\
\:043e\:0440\:044b\:0435 \:0432\:043e\:043f\:0440\:043e\:0441\:044b, \:043a\
\:0430\:0441\:0430\:044e\:0449\:0438\:0435\:0441\:044f \:0440\:0435\:0433\
\:0443\:043b\:044f\:0440\:043d\:044b\:0445 \:0432\:044b\:0440\:0430\:0436\
\:0435\:043d\:0438\:0439.\
\>", "Text",
 CellTags->"b:0.2",
 CellID->36188322],

Cell["\<\
\:0422\:0430\:043a \:0432\:044b\:043f\:043e\:043b\:043d\:044f\:0435\:0442\
\:0441\:044f \:043f\:043e\:0438\:0441\:043a \:043f\:043e\:0441\:043b\:0435\
\:0434\:043e\:0432\:0430\:0442\:0435\:043b\:044c\:043d\:043e\:0441\:0442\:0435\
\:0439 \:0441\:043b\:043e\:0432\:043e\:043e\:0431\:0440\:0430\:0437\:0443\
\:044e\:0449\:0438\:0445 \:0441\:0438\:043c\:0432\:043e\:043b\:043e\:0432 \
\:0434\:043b\:0438\:043d\:043e\:0439 \:043e\:0442 2 \:0434\:043e 4.\
\>", "MathCaption",
 CellTags->"b:0.2",
 CellID->17419283],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringCases", "[", 
  RowBox[{"\"\<a bb ccc dddd eeeee\>\"", ",", 
   RowBox[{"RegularExpression", "[", "\"\<\\\\b\\\\w{2,4}\\\\b\>\"", "]"}]}], 
  "]"}]], "Input",
 CellTags->"b:0.2",
 CellLabel->"In[28]:=",
 CellID->636896070],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"bb\"\>", ",", "\<\"ccc\"\>", ",", "\<\"dddd\"\>"}], 
  "}"}]], "Output",
 ImageSize->{103, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.2",
 CellLabel->"Out[28]=",
 CellID->179137521]
}, Open  ]],

Cell[TextData[{
 "\:041f\:0440\:0438 \:0438\:0441\:043f\:043e\:043b\:044c\:0437\:043e\:0432\
\:0430\:043d\:0438\:0438 \:043f\:0440\:0438\:0442\:044f\:0436\:0430\:0442\
\:0435\:043b\:044c\:043d\:043e\:0433\:043e \:043a\:0432\:0430\:043d\:0442\
\:043e\:0440\:0430 ",
 Cell[BoxData["\<\"+\"\>"], "InlineFormula"],
 " , \:043e\:0442\:0431\:0438\:0440\:0430\:044e\:0442\:0441\:044f \
\:043c\:0430\:043a\:0441\:0438\:043c\:0430\:043b\:044c\:043d\:043e \:0432\
\:043e\:0437\:043c\:043e\:0436\:043d\:043e\:0435 \:0447\:0438\:0441\:043b\
\:043e \:0441\:0438\:043c\:0432\:043e\:043b\:043e\:0432, \:0434\:043e\:043f\
\:0443\:0441\:043a\:0430\:0435\:043c\:044b\:0445 \:0448\:0430\:0431\:043b\
\:043e\:043d\:043e\:043c. \:041f\:0440\:0438 \:044d\:0442\:043e\:043c \:043d\
\:0438\:043a\:0430\:043a\:0438\:0435 \:0441\:0438\:043c\:0432\:043e\:043b\
\:044b \:043d\:0435 \:043e\:0442\:0431\:0440\:0430\:0441\:044b\:0432\:0430\
\:044e\:0442\:0441\:044f, \:0434\:0430\:0436\:0435 \:0435\:0441\:043b\:0438 \
\:043e\:0441\:0442\:0430\:043b\:044c\:043d\:044b\:0435 \:0447\:0430\:0441\
\:0442\:0438 \:0448\:0430\:0431\:043b\:043e\:043d\:0430 \:0442\:0440\:0435\
\:0431\:0443\:044e\:0442 \:044d\:0442\:043e\:0433\:043e."
}], "MathCaption",
 CellTags->"b:0.2",
 CellID->228635176],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringCases", "[", 
  RowBox[{"\"\<a2 b6\>\"", ",", 
   RowBox[{"RegularExpression", "[", "\"\<\\\\w+\\\\d\>\"", "]"}]}], 
  "]"}]], "Input",
 CellTags->"b:0.2",
 CellLabel->"In[29]:=",
 CellID->149453386],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"a2\"\>", ",", "\<\"b6\"\>"}], "}"}]], "Output",
 ImageSize->{57, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.2",
 CellLabel->"Out[29]=",
 CellID->134310985]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringCases", "[", 
  RowBox[{"\"\<a2 b6\>\"", ",", 
   RowBox[{"RegularExpression", "[", "\"\<\\\\w++\\\\d\>\"", "]"}]}], 
  "]"}]], "Input",
 CellTags->"b:0.2",
 CellLabel->"In[30]:=",
 CellID->27057531],

Cell[BoxData[
 RowBox[{"{", "}"}]], "Output",
 ImageSize->{18, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.2",
 CellLabel->"Out[30]=",
 CellID->167625736]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringCases", "[", 
  RowBox[{"\"\<a2 b6\>\"", ",", 
   RowBox[{"RegularExpression", "[", "\"\<\\\\D++\\\\d\>\"", "]"}]}], 
  "]"}]], "Input",
 CellTags->"b:0.2",
 CellLabel->"In[31]:=",
 CellID->72747825],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"a2\"\>", ",", "\<\" b6\"\>"}], "}"}]], "Output",
 ImageSize->{64, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.2",
 CellLabel->"Out[31]=",
 CellID->136763727]
}, Open  ]],

Cell[TextData[{
 "\:0412\:044b\:0440\:0430\:0436\:0435\:043d\:0438\:044e",
 Cell[BoxData[
  RowBox[{"[", 
   RowBox[{"[", 
    RowBox[{":", 
     RowBox[{
      StyleBox["xdigit", "TI"], ":"}]}], "]"}], "]"}]], "InlineFormula"],
 " \:0441\:043e\:043e\:0442\:0432\:0435\:0442\:0441\:0442\:0432\:0443\:044e\
\:0442 \:0441\:0438\:043c\:0432\:043e\:043b\:044b \:0432 \:0448\:0435\:0441\
\:0442\:043d\:0430\:0434\:0446\:0430\:0442\:0435\:0440\:0438\:0447\:043d\:044b\
\:0445 \:0447\:0438\:0441\:043b\:0430\:0445."
}], "MathCaption",
 CellTags->"b:0.2",
 CellID->574029527],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringCases", "[", 
  RowBox[{"\"\<ff, 13, 1a3, xyz, 3b\>\"", ",", 
   RowBox[{"RegularExpression", "[", "\"\<[[:xdigit:]]+\>\"", "]"}]}], 
  "]"}]], "Input",
 CellTags->"b:0.2",
 CellLabel->"In[32]:=",
 CellID->972490785],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"ff\"\>", ",", "\<\"13\"\>", ",", "\<\"1a3\"\>", 
   ",", "\<\"3b\"\>"}], "}"}]], "Output",
 ImageSize->{114, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.2",
 CellLabel->"Out[32]=",
 CellID->467284740]
}, Open  ]],

Cell[TextData[{
 "\:041f\:043e\:043b\:043d\:044b\:0439 \:0441\:043f\:0438\:0441\:043e\:043a \
\:0441\:0438\:043c\:0432\:043e\:043b\:043e\:0432, \:043a\:043e\:0442\:043e\
\:0440\:044b\:0445 \:043d\:0443\:0436\:043d\:043e \:0438\:0437\:0431\:0435\
\:0433\:0430\:0442\:044c \:0432 \:0440\:0435\:0433\:0443\:043b\:044f\:0440\
\:043d\:044b\:0445 \:0432\:044b\:0440\:0430\:0436\:0435\:043d\:0438\:044f\
\:0445, \:0441\:043e\:0441\:0442\:043e\:0438\:0442 \:0438\:0437 ",
 Cell[BoxData["."], "InlineFormula"],
 ", ",
 Cell[BoxData["\\"], "InlineFormula"],
 ", ",
 Cell[BoxData["?"], "InlineFormula"],
 ", ",
 Cell[BoxData["("], "InlineFormula"],
 ", ",
 Cell[BoxData[")"], "InlineFormula"],
 ", ",
 Cell[BoxData["{"], "InlineFormula"],
 ", ",
 Cell[BoxData["}"], "InlineFormula"],
 ", ",
 Cell[BoxData["["], "InlineFormula"],
 ", ",
 Cell[BoxData["]"], "InlineFormula"],
 ", ",
 Cell[BoxData["^"], "InlineFormula"],
 ", ",
 Cell[BoxData["$"], "InlineFormula"],
 ", ",
 Cell[BoxData["*"], "InlineFormula"],
 ", ",
 Cell[BoxData["+"], "InlineFormula"],
 " \:0438 ",
 Cell[BoxData["|"], "InlineFormula"],
 ". \:041a \:043f\:0440\:0438\:043c\:0435\:0440\:0443, \:0447\:0442\:043e\
\:0431\:044b \:0437\:0430\:043f\:0438\:0441\:0430\:0442\:044c \:0431\:0443\
\:043a\:0432\:0435\:043d\:043d\:0443\:044e \:0442\:043e\:0447\:043a\:0443, \
\:043d\:0443\:0436\:043d\:043e \:0438\:0441\:043f\:043e\:043b\:044c\:0437\
\:043e\:0432\:0430\:0442\:044c ",
 Cell[BoxData["\<\"\\\\.\"\>"], "InlineFormula"],
 ", \:0430 \:0447\:0442\:043e\:0431\:044b \
\:0437\:0430\:043f\:0438\:0441\:0430\:0442\:044c \:0431\:0443\:043a\:0432\
\:0435\:043d\:043d\:044b\:0439 \:043e\:0431\:0440\:0430\:0442\:043d\:044b\
\:0439 \:0441\:043b\:0435\:0448, \:043d\:0443\:0436\:043d\:043e \:0438\:0441\
\:043f\:043e\:043b\:044c\:0437\:043e\:0432\:0430\:0442\:044c ",
 Cell[BoxData["\<\"\\\\\\\\\"\>"], "InlineFormula"],
 "."
}], "Text",
 CellTags->"b:0.2",
 CellID->645192577],

Cell[TextData[{
 "\:041f\:043e\:043b\:043d\:044b\:0439 \:0441\:043f\:0438\:0441\:043e\:043a \
\:0441\:0438\:043c\:0432\:043e\:043b\:043e\:0432, \:043a\:043e\:0442\:043e\
\:0440\:044b\:0445 \:043d\:0443\:0436\:043d\:043e \:0438\:0437\:0431\:0435\
\:0433\:0430\:0442\:044c \:0432\:043d\:0443\:0442\:0440\:0438 \:043a\:043b\
\:0430\:0441\:0441\:0430 \:0441\:0438\:043c\:0432\:043e\:043b\:043e\:0432 ",
 Cell[BoxData["\<\"[\!\(\*
StyleBox[\"\[Ellipsis]\", \"TR\"]\)]\"\>"], "InlineFormula"],
 ", \:0441\:043e\:0441\:0442\:043e\:0438\:0442 \:0438\:0437 ",
 Cell[BoxData["^"], "InlineFormula"],
 ", ",
 Cell[BoxData["-"], "InlineFormula"],
 ", ",
 Cell[BoxData["\\"], "InlineFormula"],
 ", ",
 Cell[BoxData["["], "InlineFormula"],
 ", \:0430 \:0442\:0430\:043a\:0436\:0435 ",
 Cell[BoxData["]"], "InlineFormula"],
 "."
}], "Text",
 CellTags->"b:0.2",
 CellID->38350545],

Cell["\<\
\:041f\:043e \:0443\:043c\:043e\:043b\:0447\:0430\:043d\:0438\:044e, ^ \:0438 \
$ \:043e\:0431\:043e\:0437\:043d\:0430\:0447\:0430\:044e\:0442, \:0441\:043e\
\:043e\:0442\:0432\:0435\:0442\:0441\:0442\:0432\:0435\:043d\:043d\:043e, \
\:043d\:0430\:0447\:0430\:043b\:043e \:0438 \:043a\:043e\:043d\:0435\:0446 \
\:0442\:0435\:043a\:0441\:0442\:043e\:0432\:043e\:0433\:043e \:0444\:0440\
\:0430\:0433\:043c\:0435\:043d\:0442\:0430. \:0412 \:043e\:0442\:043b\:0438\
\:0447\:0438\:0435 \:043e\:0442 \:044d\:0442\:043e\:0433\:043e, \:0432 \:043c\
\:043d\:043e\:0433\:043e\:0441\:0442\:0440\:043e\:0447\:043d\:043e\:043c \
\:0440\:0435\:0436\:0438\:043c\:0435, \:043e\:043d\:0438 \:043e\:0431\:043e\
\:0437\:043d\:0430\:0447\:0430\:044e\:0442 \:043d\:0430\:0447\:0430\:043b\
\:043e/\:043a\:043e\:043d\:0435\:0446 \:0441\:0442\:0440\:043e\:043a.\
\>", "MathCaption",
 CellTags->"b:0.2",
 CellID->87518571],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringCases", "[", 
  RowBox[{"\"\<line1\\nline2\>\"", ",", 
   RowBox[{"RegularExpression", "[", "\"\<^.*\>\"", "]"}]}], "]"}]], "Input",
 CellTags->"b:0.2",
 CellLabel->"In[33]:=",
 CellID->310325877],

Cell[BoxData[
 RowBox[{"{", "\<\"line1\"\>", "}"}]], "Output",
 ImageSize->{53, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.2",
 CellLabel->"Out[33]=",
 CellID->252964877]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringCases", "[", 
  RowBox[{"\"\<line1\\nline2\>\"", ",", 
   RowBox[{"RegularExpression", "[", "\"\<(?m)^.*\>\"", "]"}]}], 
  "]"}]], "Input",
 CellTags->"b:0.2",
 CellLabel->"In[34]:=",
 CellID->47695904],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"line1\"\>", ",", "\<\"line2\"\>"}], "}"}]], "Output",
 ImageSize->{99, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.2",
 CellLabel->"Out[34]=",
 CellID->25259495]
}, Open  ]],

Cell[TextData[{
 "\:0412 \:043c\:043d\:043e\:0433\:043e\:0441\:0442\:0440\:043e\:0447\:043d\
\:043e\:043c \:0440\:0435\:0436\:0438\:043c\:0435, \:0434\:043b\:044f \:043e\
\:0431\:043e\:0437\:043d\:0430\:0447\:0435\:043d\:0438\:044f \:043d\:0430\
\:0447\:0430\:043b\:0430 \:0438 \:043a\:043e\:043d\:0446\:0430 \:0442\:0435\
\:043a\:0441\:0442\:043e\:0432\:043e\:0433\:043e \:0444\:0440\:0430\:0433\
\:043c\:0435\:043d\:0442\:0430 \:043c\:043e\:0433\:0443\:0442 \:0431\:044b\
\:0442\:044c \:0438\:0441\:043f\:043e\:043b\:044c\:0437\:043e\:0432\:0430\
\:043d\:044b ",
 Cell[BoxData[
  RowBox[{"\\\\", "A"}]], "InlineFormula"],
 " \:0438 ",
 Cell[BoxData[
  RowBox[{"\\\\", "Z"}]], "InlineFormula"],
 "."
}], "MathCaption",
 CellTags->"b:0.2",
 CellID->428461048],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringCases", "[", 
  RowBox[{"\"\<line1\\nline2\>\"", ",", 
   RowBox[{"RegularExpression", "[", "\"\<(?m)\\\\A.*\>\"", "]"}]}], 
  "]"}]], "Input",
 CellTags->"b:0.2",
 CellLabel->"In[35]:=",
 CellID->1001621228],

Cell[BoxData[
 RowBox[{"{", "\<\"line1\"\>", "}"}]], "Output",
 ImageSize->{53, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.2",
 CellLabel->"Out[35]=",
 CellID->377933075]
}, Open  ]],

Cell[TextData[{
 "\:041e\:043f\:0435\:0440\:0430\:0442\:043e\:0440 ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{"?", "x)"}]}]], "InlineFormula"],
 " \:043f\:043e\:0437\:0432\:043e\:043b\:044f\:0435\:0442 \:0434\:043e\:0431\
\:0430\:0432\:043b\:044f\:0442\:044c \:0432 \:0440\:0435\:0433\:0443\:043b\
\:044f\:0440\:043d\:044b\:0435 \:0432\:044b\:0440\:0430\:0436\:0435\:043d\
\:0438\:044f \:043f\:0440\:043e\:0431\:0435\:043b\:044b \:0438 \:043a\:043e\
\:043c\:043c\:0435\:043d\:0442\:0430\:0440\:0438\:0438 \:0434\:043b\:044f \
\:0443\:0434\:043e\:0431\:0441\:0442\:0432\:0430 \:0432\:043e\:0441\:043f\
\:0440\:0438\:044f\:0442\:0438\:044f. "
}], "MathCaption",
 CellTags->"b:0.2",
 CellID->667194970],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"StringCases", "[", 
   RowBox[{"\"\<12.45  bc58.11\>\"", ",", "\[IndentingNewLine]", 
    RowBox[{
    "RegularExpression", "[", 
     "\"\<\\<(?x)\n\\\\d+  \\\\.  #remember to escape the period\n\\\\d+\\>\>\
\"", "]"}]}], "]"}], "  "}]], "Input",
 CellTags->"b:0.2",
 CellLabel->"In[36]:=",
 CellID->562254777],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"12.45\"\>", ",", "\<\"58.11\"\>"}], "}"}]], "Output",
 ImageSize->{99, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.2",
 CellLabel->"Out[36]=",
 CellID->72339243]
}, Open  ]],

Cell[TextData[{
 "\:041f\:0440\:0438\:0441\:0432\:043e\:0435\:043d\:0438\:0435 \:0438\:043c\
\:0435\:043d \:0448\:0430\:0431\:043b\:043e\:043d\:0430\:043c \:0434\:043e\
\:0441\:0442\:0438\:0433\:0430\:0435\:0442\:0441\:044f \:043f\:0443\:0442\
\:0435\:043c \"\:0432\:0437\:044f\:0442\:0438\:044f\" \:0438\:0445 \:0432 \
\:043a\:0440\:0443\:0433\:043b\:044b\:0435 \:0441\:043a\:043e\:0431\:043a\
\:0438 (\:0441\:0443\:0431\:0448\:0430\:0431\:043b\:043e\:043d); \:0442\:043e\
\:0433\:0434\:0430 \:043e\:043d\:0438 \:043f\:0440\:0435\:0432\:0440\:0430\
\:0449\:0430\:044e\:0442\:0441\:044f \:0432 \:043d\:0443\:043c\:0435\:0440\
\:043e\:0432\:0430\:043d\:043d\:044b\:0435 \:0441\:0443\:0431\:0448\:0430\
\:0431\:043b\:043e\:043d\:044b. \:041d\:043e\:043c\:0435\:0440 \:043a\:043e\
\:043d\:043a\:0440\:0435\:0442\:043d\:043e\:0433\:043e \:0441\:0443\:0431\
\:0448\:0430\:0431\:043b\:043e\:043d\:0430 \:043e\:0442\:0441\:0447\:0438\
\:0442\:044b\:0432\:0430\:0435\:0442\:0441\:044f \:043e\:0442 \:043e\:0442\
\:043a\:0440\:044b\:0432\:0430\:044e\:0449\:0435\:0439 \:0441\:043a\:043e\
\:0431\:043a\:0438. \:041a \:044d\:0442\:0438\:043c \:0441\:0443\:0431\:0448\
\:0430\:0431\:043b\:043e\:043d\:0430\:043c \:043c\:043e\:0436\:043d\:043e \
\:043e\:0431\:0440\:0430\:0442\:0438\:0442\:044c\:0441\:044f \:043f\:0440\
\:0438 \:043f\:043e\:043c\:043e\:0449\:0438 ",
 Cell[BoxData[
  RowBox[{"\\\\", 
   StyleBox["n", "TI"]}]], "InlineFormula"],
 " \:0434\:043b\:044f ",
 Cell[BoxData[
  StyleBox["n", "TI"]], "InlineFormula"],
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Null]", "\:0433\:043e"], TraditionalForm]]],
 " \:0441\:0443\:0431\:0448\:0430\:0431\:043b\:043e\:043d\:0430 \:0434\:0430\
\:043b\:0435\:0435 \:0432 \:043e\:0431\:0449\:0435\:043c \:0448\:0430\:0431\
\:043b\:043e\:043d\:0435, \:0438\:043b\:0438 \:0441 \:043f\:043e\:043c\:043e\
\:0449\:044c\:044e ",
 Cell[BoxData["\<\"\!\(\*
StyleBox[\($\*
StyleBox[\"n\", \"TI\"]\)]\)\"\>"], "InlineFormula"],
 " \:0432 \:043f\:0440\:0430\:0432\:043e\:0439 \:0447\:0430\:0441\:0442\:0438 \
\:043f\:0440\:0430\:0432\:0438\:043b\:0430. ",
 Cell[BoxData["\<\"$0\"\>"], "InlineFormula"],
 " \:043e\:0437\:043d\:0430\:0447\:0430\:0435\:0442 \:0441\:043e\:043e\:0442\
\:0432\:0435\:0442\:0441\:0442\:0432\:0438\:0435 \:0432\:0441\:0435\:043c \
\:0441\:0443\:0431\:0448\:0430\:0431\:043b\:043e\:043d\:0430\:043c. "
}], "MathCaption",
 CellTags->"b:0.2",
 CellID->1379250],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringCases", "[", 
  RowBox[{"\"\<a1b6a3b3a3c3a8b8\>\"", ",", 
   RowBox[{"RegularExpression", "[", "\"\<(a(\\\\d))b\\\\2\>\"", "]"}]}], 
  "]"}]], "Input",
 CellTags->"b:0.2",
 CellLabel->"In[37]:=",
 CellID->425844705],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"a3b3\"\>", ",", "\<\"a8b8\"\>"}], "}"}]], "Output",
 ImageSize->{85, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.2",
 CellLabel->"Out[37]=",
 CellID->104389920]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringCases", "[", 
  RowBox[{"\"\<a1b6a3b3a3c3a8b8\>\"", ",", 
   RowBox[{
    RowBox[{"RegularExpression", "[", "\"\<(a(\\\\d))b\\\\2\>\"", "]"}], 
    "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<$0\>\"", ",", "\"\<$1\>\"", ",", "\"\<Number:$2\>\""}], 
     "}"}]}]}], "]"}]], "Input",
 CellTags->"b:0.2",
 CellLabel->"In[38]:=",
 CellID->25483089],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"a3b3\"\>", ",", "\<\"a3\"\>", ",", "\<\"Number:3\"\>"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"a8b8\"\>", ",", "\<\"a8\"\>", ",", "\<\"Number:8\"\>"}], 
    "}"}]}], "}"}]], "Output",
 ImageSize->{297, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.2",
 CellLabel->"Out[38]=",
 CellID->19980348]
}, Open  ]],

Cell[TextData[{
 "\:0415\:0441\:043b\:0438 \:0442\:0440\:0435\:0431\:0443\:0435\:0442\:0441\
\:044f \:0432\:0441\:0442\:0430\:0432\:0438\:0442\:044c \:043b\:0438\:0442\
\:0435\:0440\:0430\:043b $ \:0432 \:0434\:0430\:043d\:043d\:044b\:0439 \:043a\
\:043e\:043d\:0442\:0435\:043a\:0441\:0442 (\:0433\:0434\:0435 \:0437\:0430\
\:0433\:043e\:043b\:043e\:0432\:043a\:043e\:043c \:043b\:0435\:0432\:043e\
\:0439 \:0447\:0430\:0441\:0442\:0438 \:044f\:0432\:043b\:044f\:0435\:0442\
\:0441\:044f ",
 Cell[BoxData[
  TemplateBox[{Cell["RegularExpression"],"paclet:ref/RegularExpression"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 "), \:043c\:043e\:0436\:043d\:043e \:043e\:0431\:043e\:0439\:0442\:0438 \
\:043e\:0433\:0440\:0430\:043d\:0438\:0447\:0435\:043d\:0438\:044f \:0441 \
\:043f\:043e\:043c\:043e\:0449\:044c\:044e \:043e\:0431\:0440\:0430\:0442\
\:043d\:043e\:0439 \:043a\:043e\:0441\:043e\:0439 \:0447\:0435\:0440\:0442\
\:044b (\:043a \:043f\:0440\:0438\:043c\:0435\:0440\:0443,  ",
 Cell[BoxData["\<\"\\\\$2\"\>"], "InlineFormula"],
 ")."
}], "MathCaption",
 CellTags->"b:0.2",
 CellID->251858179],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringCases", "[", 
  RowBox[{"\"\<a1b6a3b3a3c3a8b8\>\"", ",", 
   RowBox[{
    RowBox[{"RegularExpression", "[", "\"\<(a(\\\\d))b\\\\2\>\"", "]"}], 
    "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<$0\>\"", ",", "\"\<$1\>\"", ",", "\"\<Number:$2\>\"", ",", 
      "\"\<Literal:\\\\$2\>\""}], "}"}]}]}], "]"}]], "Input",
 CellTags->"b:0.2",
 CellLabel->"In[39]:=",
 CellID->84036725],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"a3b3\"\>", ",", "\<\"a3\"\>", ",", "\<\"Number:3\"\>", 
     ",", "\<\"Literal:$2\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"a8b8\"\>", ",", "\<\"a8\"\>", ",", "\<\"Number:8\"\>", 
     ",", "\<\"Literal:$2\"\>"}], "}"}]}], "}"}]], "Output",
 ImageSize->{459, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.2",
 CellLabel->"Out[39]=",
 CellID->759065165]
}, Open  ]],

Cell[TextData[{
 "\:0415\:0441\:043b\:0438 \:0441\:043b\:0443\:0447\:0438\:043b\:043e\:0441\
\:044c \:0442\:0430\:043a, \:0447\:0442\:043e \:0442\:0440\:0435\:0431\:0443\
\:0435\:0442\:0441\:044f \:043b\:0438\:0442\:0435\:0440\:0430\:043b \"\:043e\
\:0434\:0438\:043d\:043e\:0447\:043d\:044b\:0439 \:043e\:0431\:0440\:0430\
\:0442\:043d\:044b\:0439 \:0441\:043b\:0435\:0448\", \:0437\:0430 \
\:043a\:043e\:0442\:043e\:0440\:044b\:043c \:0441\:043b\:0435\:0434\:0443\
\:0435\:0442 \:043b\:0438\:0442\:0435\:0440\:0430\:043b ",
 Cell[BoxData["$"], "InlineFormula"],
 ", \:0432 \:044d\:0442\:0438\:0445 \
\:043e\:0431\:0441\:0442\:043e\:044f\:0442\:0435\:043b\:044c\:0441\:0442\:0432\
\:0430\:0445 \:043f\:043e\:043d\:0430\:0434\:043e\:0431\:0438\:0442\:0441\
\:044f \:0431\:044b\:0442\:044c \:043d\:0435\:043c\:043d\:043e\:0433\:043e \
\:0438\:0437\:043e\:0431\:0440\:0435\:0442\:0430\:0442\:0435\:043b\:044c\:043d\
\:0435\:0435, \:0432\:044b\:043f\:043e\:043b\:043d\:0438\:0432 \:0432\:0440\
\:0435\:043c\:0435\:043d\:043d\:0443\:044e \:0440\:0430\:0437\:0431\:0438\
\:0432\:043a\:0443 \:043d\:0430 \:0434\:0432\:0430 \:0442\:0435\:043a\:0441\
\:0442\:043e\:0432\:044b\:0445 \:0441\:0443\:0431\:0444\:0440\:0430\:0433\
\:043c\:0435\:043d\:0442\:0430."
}], "MathCaption",
 CellTags->"b:0.2",
 CellID->695998127],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringCases", "[", 
  RowBox[{"\"\<a1b6a3b3a3c3a8b8\>\"", ",", 
   RowBox[{
    RowBox[{"RegularExpression", "[", "\"\<(a(\\\\d))b\\\\2\>\"", "]"}], ":>", 
    RowBox[{"{", 
     RowBox[{"\"\<$0\>\"", ",", "\"\<$1\>\"", ",", "\"\<Number:$2\>\"", ",", 
      RowBox[{"\"\<Literal:\\\\\>\"", "<>", "\"\<\\\\$2\>\""}]}], "}"}]}]}], 
  "]"}]], "Input",
 CellTags->"b:0.2",
 CellLabel->"In[40]:=",
 CellID->28505115],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"a3b3\"\>", ",", "\<\"a3\"\>", ",", "\<\"Number:3\"\>", 
     ",", "\<\"Literal:\\\\$2\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"a8b8\"\>", ",", "\<\"a8\"\>", ",", "\<\"Number:8\"\>", 
     ",", "\<\"Literal:\\\\$2\"\>"}], "}"}]}], "}"}]], "Output",
 ImageSize->{473, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.2",
 CellLabel->"Out[40]=",
 CellID->693657665]
}, Open  ]],

Cell[TextData[{
 "\:0415\:0441\:043b\:0438 \:043d\:0443\:0436\:043d\:043e \:0440\:0430\:0437\
\:0434\:0435\:043b\:0438\:0442\:044c \:043d\:0430 \:0433\:0440\:0443\:043f\
\:043f\:044b \:0447\:0430\:0441\:0442\:044c \:0448\:0430\:0431\:043b\:043e\
\:043d\:0430, \:043d\:043e \:0432\:044b \:043d\:0435 \:0445\:043e\:0442\:0438\
\:0442\:0435 \:043f\:043e\:0434\:0441\:0447\:0438\:0442\:044b\:0432\:0430\
\:0442\:044c \:0433\:0440\:0443\:043f\:043f\:044b \:043a\:0430\:043a \:043d\
\:0443\:043c\:0435\:0440\:043e\:0432\:0430\:043d\:043d\:044b\:0435 \:0441\
\:0443\:0431\:0448\:0430\:0431\:043b\:043e\:043d\:044b, \:043c\:043e\:0436\
\:043d\:043e \:0432\:043e\:0441\:043f\:043e\:043b\:044c\:0437\:043e\:0432\
\:0430\:0442\:044c\:0441\:044f \:043a\:043e\:043d\:0441\:0442\:0440\:0443\
\:043a\:0446\:0438\:0435\:0439 ",
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{"?", ":patt)"}]}]], "InlineFormula"],
 "."
}], "MathCaption",
 CellTags->"b:0.2",
 CellID->465786935],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringCases", "[", 
  RowBox[{"\"\<a11b16c22b77\>\"", ",", 
   RowBox[{"RegularExpression", "[", "\"\<(?:a|b)(\\\\d)\\\\1\>\"", "]"}]}], 
  "]"}]], "Input",
 CellTags->"b:0.2",
 CellLabel->"In[41]:=",
 CellID->38936688],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"a11\"\>", ",", "\<\"b77\"\>"}], "}"}]], "Output",
 ImageSize->{71, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.2",
 CellLabel->"Out[41]=",
 CellID->486204157]
}, Open  ]],

Cell["\<\
\:0428\:0430\:0431\:043b\:043e\:043d\:044b, \:043e\:043f\:0440\:0435\:0434\
\:0435\:043b\:044f\:044e\:0449\:0438\:0435 \:043d\:0430\:043f\:0440\:0430\
\:0432\:043b\:0435\:043d\:0438\:0435 \:043f\:0440\:043e\:0441\:043c\:043e\
\:0442\:0440\:0430, \:0438\:0441\:043f\:043e\:043b\:044c\:0437\:0443\:044e\
\:0442\:0441\:044f \:0434\:043b\:044f \:043e\:0431\:0435\:0441\:043f\:0435\
\:0447\:0435\:043d\:0438\:044f \:0441\:043e\:043e\:0442\:0432\:0435\:0442\
\:0441\:0442\:0432\:0438\:044f \:0448\:0430\:0431\:043b\:043e\:043d\:0443 \
\:0431\:0435\:0437 \:0444\:0430\:043a\:0442\:0438\:0447\:0435\:0441\:043a\
\:043e\:0433\:043e \:0432\:043a\:043b\:044e\:0447\:0435\:043d\:0438\:044f \
\:043f\:0440\:043e\:0432\:0435\:0440\:044f\:0435\:043c\:043e\:0433\:043e \
\:0442\:0435\:043a\:0441\:0442\:0430 \:0432 \:0432\:043e\:0437\:0432\:0440\
\:0430\:0449\:0430\:0435\:043c\:044b\:0439 \:0448\:0430\:0431\:043b\:043e\
\:043d\:043e\:043c \:0440\:0435\:0437\:0443\:043b\:044c\:0442\:0430\:0442.\
\>", "Text",
 CellTags->"b:0.2",
 CellID->377461404],

Cell[TextData[{
 "\:0422\:0430\:043a \:0438\:0437\:0432\:043b\:0435\:043a\:0430\:044e\:0442\
\:0441\:044f \:0441\:043b\:043e\:0432\:0430, \:043a\:043e\:0442\:043e\:0440\
\:044b\:0435 \:0440\:0430\:0441\:043f\:043e\:043b\:0430\:0433\:0430\:044e\
\:0442\:0441\:044f \:0432\:0441\:043b\:0435\:0434 \:0437\:0430 \:0442\:0435\
\:043a\:0441\:0442\:043e\:0432\:044b\:043c \:0444\:0440\:0430\:0433\:043c\
\:0435\:043d\:0442\:043e\:043c ",
 Cell[BoxData["\<\"the \"\>"], "InlineFormula"],
 "."
}], "MathCaption",
 CellTags->"b:0.2",
 CellID->114009367],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringCases", "[", 
  RowBox[{"\"\<the cat in the hat\>\"", ",", 
   RowBox[{"RegularExpression", "[", "\"\<(?<=the )\\\\w+\>\"", "]"}]}], 
  "]"}]], "Input",
 CellTags->"b:0.2",
 CellLabel->"In[42]:=",
 CellID->635063856],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"cat\"\>", ",", "\<\"hat\"\>"}], "}"}]], "Output",
 ImageSize->{71, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.2",
 CellLabel->"Out[42]=",
 CellID->206193907]
}, Open  ]],

Cell["\<\
\:0422\:0430\:043a \:0438\:0437 \:0442\:0435\:043a\:0441\:0442\:043e\:0432\
\:043e\:0433\:043e \:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442\:0430 \
\:0434\:0435\:043b\:0430\:0435\:0442\:0441\:044f \:0432\:044b\:0431\:043e\
\:0440\:043a\:0430 \:0432\:0441\:0435\:0445 \:0447\:0435\:0442\:043d\:044b\
\:0445 \:0447\:0438\:0441\:0435\:043b, \:043d\:043e, \:043f\:0440\:0438 \
\:044d\:0442\:043e\:043c, \:0438\:0437\:0432\:043b\:0435\:043a\:0430\:044e\
\:0442\:0441\:044f \:0442\:0430\:043a\:0436\:0435 \:0438 \:043e\:0442\:0434\
\:0435\:043b\:044c\:043d\:044b\:0435 \:0446\:0438\:0444\:0440\:044b \:043f\
\:043e\:043b\:043d\:044b\:0445 \:0447\:0438\:0441\:0435\:043b. \
\>", "MathCaption",
 CellTags->"b:0.2",
 CellID->142585462],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringCases", "[", 
  RowBox[{"\"\<a23b42c63d80, 123\>\"", ",", 
   RowBox[{
    RowBox[{"x", ":", 
     RowBox[{"RegularExpression", "[", "\"\<\\\\d+\>\"", "]"}]}], "/;", 
    RowBox[{
     RowBox[{"Mod", "[", 
      RowBox[{
       RowBox[{"ToExpression", "[", "x", "]"}], ",", "2"}], "]"}], "\[Equal]",
      "0"}]}]}], "]"}]], "Input",
 CellTags->"b:0.2",
 CellLabel->"In[43]:=",
 CellID->4084787],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"2\"\>", ",", "\<\"42\"\>", ",", "\<\"6\"\>", ",", "\<\"80\"\>",
    ",", "\<\"12\"\>"}], "}"}]], "Output",
 ImageSize->{118, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.2",
 CellLabel->"Out[43]=",
 CellID->20535323]
}, Open  ]],

Cell[TextData[{
 "\:0418\:0441\:043f\:043e\:043b\:044c\:0437\:0443\:044f \:0448\:0430\:0431\
\:043b\:043e\:043d\:044b, \:043e\:043f\:0440\:0435\:0434\:0435\:043b\:044f\
\:044e\:0449\:0438\:0435 \:043d\:0430\:043f\:0440\:0430\:0432\:043b\:0435\
\:043d\:0438\:0435 \:043f\:0440\:043e\:0441\:043c\:043e\:0442\:0440\:0430, \
\:043c\:043e\:0436\:043d\:043e \:0434\:043e\:0431\:0438\:0442\:044c\:0441\
\:044f \:0442\:043e\:0433\:043e, \:0447\:0442\:043e\:0431\:044b \:043f\:0435\
\:0440\:0435\:0434 \:0438 \:0437\:0430 \:0438\:0441\:043a\:043e\:043c\:044b\
\:043c \:0447\:0435\:0442\:043d\:044b\:043c \:0447\:0438\:0441\:043b\:043e\
\:043c \:043e\:0442\:0441\:0443\:0442\:0441\:0442\:0432\:043e\:0432\:0430\
\:043b\:0438 \:0446\:0438\:0444\:0440\:044b.  \:041e\:0431\:0440\:0430\:0442\
\:0438\:0442\:0435 \:0432\:043d\:0438\:043c\:0430\:043d\:0438\:0435, \:0447\
\:0442\:043e \:043f\:0440\:043e\:0441\:043c\:043e\:0442\:0440 ",
 StyleBox["\:0437\:0430",
  FontWeight->"Bold"],
 " \:0438\:0441\:043a\:043e\:043c\:044b\:043c \:0444\:0440\:0430\:0433\:043c\
\:0435\:043d\:0442\:043e\:043c \:044f\:0432\:043b\:044f\:0435\:0442\:0441\
\:044f \:0438\:0437\:043b\:0438\:0448\:043d\:0438\:043c \:0432 \:0434\:0430\
\:043d\:043d\:043e\:043c \:043a\:043e\:043d\:043a\:0440\:0435\:0442\:043d\
\:043e\:043c \:0441\:043b\:0443\:0447\:0430\:0435."
}], "MathCaption",
 CellTags->"b:0.2",
 CellID->68612708],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringCases", "[", 
  RowBox[{"\"\<a23b42c63d80, 123\>\"", ",", 
   RowBox[{
    RowBox[{"x", ":", 
     RowBox[{
     "RegularExpression", "[", "\"\<(?<!\\\\d)\\\\d+(?!\\\\d)\>\"", "]"}]}], "/;", 
    RowBox[{
     RowBox[{"Mod", "[", 
      RowBox[{
       RowBox[{"ToExpression", "[", "x", "]"}], ",", "2"}], "]"}], "\[Equal]",
      "0"}]}]}], "]"}]], "Input",
 CellTags->"b:0.2",
 CellLabel->"In[44]:=",
 CellID->373128525],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"42\"\>", ",", "\<\"80\"\>"}], "}"}]], "Output",
 ImageSize->{57, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.2",
 CellLabel->"Out[44]=",
 CellID->43881256]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\:0421\:0440\:0430\:0432\:043d\:0435\:043d\:0438\:0435 \
RegularExpression \:0438 StringExpression", "Section",
 CellTags->{"c:4", "b:0.3"},
 CellID->182364929],

Cell["\<\
\:0421\:0443\:0449\:0435\:0441\:0442\:0432\:0443\:0435\:0442 \:0442\:0435\
\:0441\:043d\:043e\:0435 \:0441\:043e\:043e\:0442\:0432\:0435\:0442\:0441\
\:0442\:0432\:0438\:0435 \:043c\:0435\:0436\:0434\:0443 \:0440\:0430\:0437\
\:043b\:0438\:0447\:043d\:044b\:043c\:0438 \:043e\:0431\:044a\:0435\:043a\
\:0442\:0430\:043c\:0438, \:0438\:0441\:043f\:043e\:043b\:044c\:0437\:0443\
\:0435\:043c\:044b\:043c\:0438 \:0432 \:043e\:0431\:044b\:0447\:043d\:044b\
\:0445 \:0441\:0438\:043c\:0432\:043e\:043b\:044c\:043d\:044b\:0445 \:0448\
\:0430\:0431\:043b\:043e\:043d\:0430\:0445 \:0438 \:0432 \:0440\:0435\:0433\
\:0443\:043b\:044f\:0440\:043d\:044b\:0445 \:0432\:044b\:0440\:0430\:0436\
\:0435\:043d\:0438\:044f\:0445. \:0412\:043e\:0442 \:043f\:0435\:0440\:0435\
\:0447\:0435\:043d\:044c, \:0441\:043e\:0434\:0435\:0440\:0436\:0430\:0449\
\:0438\:0439 \:043f\:0440\:0438\:043c\:0435\:0440\:044b \:0448\:0430\:0431\
\:043b\:043e\:043d\:043e\:0432, \:0437\:0430\:0434\:0430\:043d\:043d\:044b\
\:0445 \:043a\:0430\:043a \:0441 \:043f\:043e\:043c\:043e\:0449\:044c\:044e \
\:0440\:0435\:0433\:0443\:043b\:044f\:0440\:043d\:044b\:0445 \:0432\:044b\
\:0440\:0430\:0436\:0435\:043d\:0438\:0439, \:0442\:0430\:043a \:0438 \:0441 \
\:043f\:043e\:043c\:043e\:0449\:044c\:044e \:0441\:0438\:043c\:0432\:043e\
\:043b\:044c\:043d\:044b\:0445 \:0448\:0430\:0431\:043b\:043e\:043d\:043e\
\:0432 \:0434\:043b\:044f \:0442\:0435\:043a\:0441\:0442\:043e\:0432\:044b\
\:0445 \:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442\:043e\:0432.\
\>", "Text",
 CellTags->"b:0.3",
 CellID->100369965],

Cell[BoxData[GridBox[{
   {Cell["\:0440\:0435\:0433\:0443\:043b\:044f\:0440\:043d\:043e\:0435 \:0432\
\:044b\:0440\:0430\:0436\:0435\:043d\:0438\:0435", "TableHeader"], Cell[
    "\:0448\:0430\:0431\:043b\:043e\:043d \:0434\:043b\:044f \:0442\:0435\
\:043a\:0441\:0442\:043e\:0432\:044b\:0445 \:0444\:0440\:0430\:0433\:043c\
\:0435\:043d\:0442\:043e\:0432", "TableHeader"], Cell[
    "\:043f\:043e\:044f\:0441\:043d\:0435\:043d\:0438\:0435", "TableHeader"]},
   {"\"\<abc\>\"", "\"\<abc\>\"", Cell[TextData[{
     "\:0431\:0443\:043a\:0432\:0435\:043d\:043d\:044b\:0439 \:0442\:0435\
\:043a\:0441\:0442\:043e\:0432\:044b\:0439 \:0444\:0440\:0430\:0433\:043c\
\:0435\:043d\:0442 ",
     Cell[BoxData["\"\<abc\>\""], "InlineFormula"],
     StyleBox[" ", "TR"]
    }], "TableText"]},
   {"\"\<.\>\"", 
    RowBox[{
     ButtonBox["Except",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/Except"], "[", "\"\<\\n\>\"", "]"}], Cell[
    TextData[{
     "\:043b\:044e\:0431\:043e\:0439 \:0441\:0438\:043c\:0432\:043e\:043b, \
\:043a\:0440\:043e\:043c\:0435 \:0441\:0438\:043c\:0432\:043e\:043b\:0430 \
\:043d\:043e\:0432\:043e\:0439 \:0441\:0442\:0440\:043e\:043a\:0438",
     StyleBox[" ", "TR"]
    }], "TableText"]},
   {"\"\<(?s).\>\"", "_", Cell[
    "\:043b\:044e\:0431\:043e\:0439 \:0441\:0438\:043c\:0432\:043e\:043b ", 
     "TableText"]},
   {"\"\<(?s).+\>\"", "__", Cell[
    "\:043e\:0434\:0438\:043d \:0438\:043b\:0438 \:0431\:043e\:043b\:0435\
\:0435 \:0441\:0438\:043c\:0432\:043e\:043b\:043e\:0432 (\:0436\:0430\:0434\
\:043d\:044b\:0439) ", "TableText"]},
   {"\"\<(?s).+?\>\"", 
    RowBox[{
     ButtonBox["Shortest",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/Shortest"], "[", "__", "]"}], Cell[
    "\:043e\:0434\:0438\:043d \:0438\:043b\:0438 \:0431\:043e\:043b\:0435\
\:0435 \:0441\:0438\:043c\:0432\:043e\:043b\:043e\:0432 (\:043d\:0435 \:0436\
\:0430\:0434\:043d\:044b\:0439) ", "TableText"]},
   {"\"\<(?s).*\>\"", "___", Cell[
    "\:043d\:043e\:043b\:044c \:0438\:043b\:0438 \:0431\:043e\:043b\:0435\
\:0435 \:0441\:0438\:043c\:0432\:043e\:043b\:043e\:0432 ", "TableText"]},
   {"\"\<.*\>\"", 
    RowBox[{
     RowBox[{
      ButtonBox["Except",
       BaseStyle->"Link",
       ButtonData->"paclet:ref/Except"], "[", "\"\<\\n\>\"", "]"}], "..."}], 
    Cell["\:043d\:043e\:043b\:044c \:0438\:043b\:0438 \
\:0431\:043e\:043b\:0435\:0435 \:0441\:0438\:043c\:0432\:043e\:043b\:043e\
\:0432 (\:043a\:0440\:043e\:043c\:0435 \:0441\:0438\:043c\:0432\:043e\:043b\
\:043e\:0432 \:043d\:043e\:0432\:043e\:0439 \:0441\:0442\:0440\:043e\:043a\
\:0438)", "TableText"]},
   {"\"\<a?b\>\"", 
    RowBox[{
     RowBox[{"\"\<a\>\"", "|", "\"\<\>\""}], "~~", "\"\<b\>\""}], Cell[
    TextData[{
     "\:043d\:043e\:043b\:044c \:0438\:043b\:0438 \:043e\:0434\:0438\:043d ",
     Cell[BoxData["\"\<a\>\""], "InlineFormula"],
     ", \:0437\:0430 \:043a\:043e\:0442\:043e\:0440\:044b\:043c \:0441\:043b\
\:0435\:0434\:0443\:0435\:0442 ",
     Cell[BoxData["\"\<b\>\""], "InlineFormula"],
     " (\:0442\:043e \:0435\:0441\:0442\:044c, ",
     Cell[BoxData["\"\<b\>\""], "InlineFormula"],
     " \:0438\:043b\:0438 ",
     Cell[BoxData["\"\<ab\>\""], "InlineFormula"],
     ")"
    }], "TableText"]},
   {"\"\<[abef]\>\"", 
    RowBox[{
     ButtonBox["Characters",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/Characters"], "[", "\"\<abef\>\"", "]"}], Cell[
    TextData[{
     "\:043b\:044e\:0431\:043e\:0439 \:0438\:0437 \:0441\:0438\:043c\:0432\
\:043e\:043b\:043e\:0432 ",
     Cell[BoxData["\"\<a\>\""], "InlineFormula"],
     ", ",
     Cell[BoxData["\"\<b\>\""], "InlineFormula"],
     ", ",
     Cell[BoxData["\"\<e\>\""], "InlineFormula"],
     " \:0438\:043b\:0438 ",
     Cell[BoxData["\"\<f\>\""], "InlineFormula"],
     " "
    }], "TableText"]},
   {"\"\<[abef]+\>\"", 
    RowBox[{
     RowBox[{
      ButtonBox["Characters",
       BaseStyle->"Link",
       ButtonData->"paclet:ref/Characters"], "[", "\"\<abef\>\"", "]"}], 
     ".."}], Cell[TextData[{
     "\:043e\:0434\:0438\:043d \:0438\:043b\:0438 \:0431\:043e\:043b\:0435\
\:0435 \:0438\:0437 \:0441\:0438\:043c\:0432\:043e\:043b\:043e\:0432 ",
     Cell[BoxData["\"\<a\>\""], "InlineFormula"],
     ", ",
     Cell[BoxData["\"\<b\>\""], "InlineFormula"],
     ", ",
     Cell[BoxData["\"\<e\>\""], "InlineFormula"],
     " \:0438\:043b\:0438 ",
     Cell[BoxData["\"\<f\>\""], "InlineFormula"],
     " "
    }], "TableText"]},
   {"\"\<[a-f]\>\"", 
    RowBox[{
     ButtonBox["CharacterRange",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/CharacterRange"], "[", 
     RowBox[{"\"\<a\>\"", ",", "\"\<f\>\""}], "]"}], Cell[TextData[{
     "\:043b\:044e\:0431\:043e\:0439 \:0441\:0438\:043c\:0432\:043e\:043b \
\:0432 \:0434\:0438\:0430\:043f\:0430\:0437\:043e\:043d\:0435 \:043e\:0442 ",
     Cell[BoxData["\"\<a\>\""], "InlineFormula"],
     " \:0434\:043e ",
     Cell[BoxData["\"\<f\>\""], "InlineFormula"]
    }], "TableText"]},
   {"\"\<[^abef]\>\"", 
    RowBox[{
     ButtonBox["Except",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/Except"], "[", 
     RowBox[{
      ButtonBox["Characters",
       BaseStyle->"Link",
       ButtonData->"paclet:ref/Characters"], "[", "\"\<abef\>\"", "]"}], 
     "]"}], Cell[TextData[{
     "\:043b\:044e\:0431\:043e\:0439 \:0441\:0438\:043c\:0432\:043e\:043b, \
\:043a\:0440\:043e\:043c\:0435 ",
     Cell[BoxData["\"\<a\>\""], "InlineFormula"],
     ", ",
     Cell[BoxData["\"\<b\>\""], "InlineFormula"],
     ", ",
     Cell[BoxData["\"\<e\>\""], "InlineFormula"],
     " \:0438\:043b\:0438 ",
     Cell[BoxData["\"\<f\>\""], "InlineFormula"],
     " "
    }], "TableText"]},
   {"\"\<ab|efg\>\"", 
    RowBox[{"\"\<ab\>\"", "|", "\"\<efg\>\""}], Cell[TextData[{
     "\:0441\:043e\:043e\:0442\:0432\:0435\:0442\:0441\:0442\:0432\:0438\:0435\
 \:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442\:0443 ",
     Cell[BoxData["\"\<ab\>\""], "InlineFormula"],
     " \:0438\:043b\:0438 ",
     Cell[BoxData["\"\<efg\>\""], "InlineFormula"]
    }], "TableText"]},
   {
    RowBox[{
    "\"\<(ab|ef)gh\>\"", Cell["\:0438\:043b\:0438", "TableText"], 
     "\"\<(?:ab|ef)gh\>\""}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"\"\<ab\>\"", "|", "\"\<ef\>\""}], ")"}], "~~", "\"\<gh\>\""}], 
    Cell[TextData[{
     Cell[BoxData["\"\<ab\>\""], "InlineFormula"],
     " \:0438\:043b\:0438 ",
     Cell[BoxData["\"\<ef\>\""], "InlineFormula"],
     " \:0437\:0430 \:043a\:043e\:0442\:043e\:0440\:044b\:043c \:0441\:043b\
\:0435\:0434\:0443\:0435\:0442 ",
     Cell[BoxData["\"\<gh\>\""], "InlineFormula"],
     " (\:0442\:043e \:0435\:0441\:0442\:044c, ",
     Cell[BoxData["\"\<abgh\>\""], "InlineFormula"],
     " \:0438\:043b\:0438 ",
     Cell[BoxData["\"\<efgh\>\""], "InlineFormula"],
     ")"
    }], "TableText"]},
   {"\"\<\\\\s\>\"", 
    ButtonBox["WhitespaceCharacter",
     BaseStyle->"Link",
     ButtonData->"paclet:ref/WhitespaceCharacter"], Cell[
    "\:043b\:044e\:0431\:043e\:0439 \
\:0440\:0430\:0437\:0434\:0435\:043b\:0438\:0442\:0435\:043b\:044c\:043d\:044b\
\:0439 \:0441\:0438\:043c\:0432\:043e\:043b", "TableText"]},
   {"\"\<\\\\s+\>\"", 
    ButtonBox["Whitespace",
     BaseStyle->"Link",
     ButtonData->"paclet:ref/Whitespace"], Cell[
    "\:043e\:0434\:0438\:043d \:0438\:043b\:0438 \:0431\:043e\:043b\:0435\
\:0435 \:0440\:0430\:0437\:0434\:0435\:043b\:0438\:0442\:0435\:043b\:044c\
\:043d\:044b\:0445 \:0441\:0438\:043c\:0432\:043e\:043b\:043e\:0432", 
     "TableText"]},
   {"\"\<(a|b)\\\\1\>\"", 
    RowBox[{
     RowBox[{"x", ":", 
      RowBox[{"\"\<a\>\"", "|", "\"\<b\>\""}]}], "~~", "x_"}], Cell[TextData[{
     "\:044d\:0442\:043e\:043c\:0443 \:0441\:043e\:043e\:0442\:0432\:0435\
\:0442\:0441\:0442\:0432\:0443\:044e\:0442 \:043b\:0438\:0431\:043e ",
     Cell[BoxData["\"\<aa\>\""], "InlineFormula"],
     " \:043b\:0438\:0431\:043e ",
     Cell[BoxData["\"\<bb\>\""], "InlineFormula"],
     " "
    }], "TableText"]},
   {"\"\<\\\\d\>\"", 
    ButtonBox["DigitCharacter",
     BaseStyle->"Link",
     ButtonData->"paclet:ref/DigitCharacter"], Cell[
    "\:043b\:044e\:0431\:0430\:044f \:0446\:0438\:0444\:0440\:0430 (0-9)", 
     "TableText"]},
   {"\"\<\\\\D\>\"", 
    RowBox[{
     ButtonBox["Except",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/Except"], "[", 
     ButtonBox["DigitCharacter",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/DigitCharacter"], "]"}], Cell[
    "\:043b\:044e\:0431\:043e\:0439 \:0441\:0438\:043c\:0432\:043e\:043b, \
\:043a\:0440\:043e\:043c\:0435 \:0446\:0438\:0444\:0440", "TableText"]},
   {"\"\<\\\\d+\>\"", 
    RowBox[{
     ButtonBox["DigitCharacter",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/DigitCharacter"], ".."}], Cell[
    "\:043e\:0434\:043d\:0430 \:0446\:0438\:0444\:0440\:0430 \:0438\:043b\
\:0438 \:0431\:043e\:043b\:0435\:0435", "TableText"]},
   {"\"\<\\\\w\>\"", 
    RowBox[{
     ButtonBox["WordCharacter",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/WordCharacter"], "|", "\"\<_\>\""}], Cell[
    TextData[{
     "\:043b\:044e\:0431\:0430\:044f \:0446\:0438\:0444\:0440\:0430, \:0431\
\:0443\:043a\:0432\:0430 \:0438\:043b\:0438 \:0441\:0438\:043c\:0432\:043e\
\:043b ",
     Cell[BoxData["\"\<_\>\""], "InlineFormula"]
    }], "TableText"]},
   {"\"\<[[:alpha:]]\>\"", 
    ButtonBox["LetterCharacter",
     BaseStyle->"Link",
     ButtonData->"paclet:ref/LetterCharacter"], Cell[
    "\:043b\:044e\:0431\:043e\:0439 \
\:0431\:0443\:043a\:0432\:0435\:043d\:043d\:044b\:0439 \:0441\:0438\:043c\
\:0432\:043e\:043b", "TableText"]},
   {"\"\<[^[:alpha:]]\>\"", 
    RowBox[{
     ButtonBox["Except",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/Except"], "[", 
     ButtonBox["LetterCharacter",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/LetterCharacter"], "]"}], Cell[
    "\:043b\:044e\:0431\:043e\:0439 \:043d\:0435 \:0431\:0443\:043a\:0432\
\:0435\:043d\:043d\:044b\:0439 \:0441\:0438\:043c\:0432\:043e\:043b", 
     "TableText"]},
   {
    RowBox[{
    "\"\<^abf\>\"", Cell["\:0438\:043b\:0438", "TableText"], 
     "\"\<\\\\Aabc\>\""}], 
    RowBox[{
     ButtonBox["StartOfString",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/StartOfString"], "~~", "\"\<abf\>\""}], Cell[
    TextData[{
     "\:0441\:0443\:0431\:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442 ",
     Cell[BoxData["\"\<abf\>\""], "InlineFormula"],
     " \:0432 \:043d\:0430\:0447\:0430\:043b\:0435 \:0442\:0435\:043a\:0441\
\:0442\:043e\:0432\:043e\:0433\:043e \:0444\:0440\:0430\:0433\:043c\:0435\
\:043d\:0442\:0430"
    }], "TableText"]},
   {"\"\<(?m)^abf\>\"", 
    RowBox[{
     ButtonBox["StartOfLine",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/StartOfLine"], "~~", "\"\<abf\>\""}], Cell[
    TextData[{
     "\:0441\:0443\:0431\:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442 ",
     Cell[BoxData["\"\<abf\>\""], "InlineFormula"],
     " \:0432 \:043d\:0430\:0447\:0430\:043b\:0435 \:0441\:0442\:0440\:043e\
\:043a\:0438"
    }], "TableText"]},
   {
    RowBox[{
    "\"\<wxz$\>\"", Cell["\:0438\:043b\:0438", "TableText"], 
     "\"\<wxz\\\\z\>\""}], 
    RowBox[{"\"\<wxz\>\"", "~~", 
     ButtonBox["EndOfString",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/EndOfString"]}], Cell[TextData[{
     "\:0441\:0443\:0431\:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442 ",
     Cell[BoxData["\"\<wxz\>\""], "InlineFormula"],
     " \:0432 \:043a\:043e\:043d\:0446\:0435 \:0442\:0435\:043a\:0441\:0442\
\:043e\:0432\:043e\:0433\:043e \:0444\:0440\:0430\:0433\:043c\:0435\:043d\
\:0442\:0430"
    }], "TableText"]},
   {"\"\<wxz\\\\Z\>\"", 
    RowBox[{"\"\<wxz\>\"", "~~", 
     RowBox[{"\"\<\\n\>\"", "|", "\"\<\>\""}], "~~", 
     ButtonBox["EndOfString",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/EndOfString"]}], Cell[TextData[{
     "\:0441\:0443\:0431\:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442 ",
     Cell[BoxData["\"\<wxz\>\""], "InlineFormula"],
     " \:0432 \:043a\:043e\:043d\:0446\:0435 \:0442\:0435\:043a\:0441\:0442\
\:043e\:0432\:043e\:0433\:043e \:0444\:0440\:0430\:0433\:043c\:0435\:043d\
\:0442\:0430 \:0438\:043b\:0438 \:043f\:0435\:0440\:0435\:0434 \:0441\:0438\
\:043c\:0432\:043e\:043b\:043e\:043c \:043d\:043e\:0432\:043e\:0439 \:0441\
\:0442\:0440\:043e\:043a\:0438, \:0440\:0430\:0441\:043f\:043e\:043b\:043e\
\:0436\:0435\:043d\:043d\:044b\:043c \:0432 \:043a\:043e\:043d\:0446\:0435 \
\:0442\:0435\:043a\:0441\:0442\:043e\:0432\:043e\:0433\:043e \:0444\:0440\
\:0430\:0433\:043c\:0435\:043d\:0442\:0430"
    }], "TableText"]}
  },
  GridBoxAlignment->{
   "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
    "RowsIndexed" -> {}}]], "DefinitionBox3Col",
 GridBoxOptions->{
 GridBoxDividers->{
  "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
   "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}}},
 CellTags->"b:0.3",
 CellID->195821352],

Cell[TextData[{
 "\:041e\:0431\:044a\:0435\:043a\:0442\:044b \:0448\:0430\:0431\:043b\:043e\
\:043d\:043e\:0432, \:0438\:0441\:043f\:043e\:043b\:044c\:0437\:0443\:0435\
\:043c\:044b\:0435 \:0432 \:043e\:0431\:044b\:0447\:043d\:044b\:0445 \:0448\
\:0430\:0431\:043b\:043e\:043d\:0430\:0445 \:0434\:043b\:044f \:0442\:0435\
\:043a\:0441\:0442\:043e\:0432\:044b\:0445 \:0444\:0440\:0430\:0433\:043c\
\:0435\:043d\:0442\:043e\:0432, \:043d\:043e \:043e\:0442\:0441\:0443\:0442\
\:0441\:0442\:0432\:0443\:044e\:0449\:0438\:0435 \:0432 \:0440\:0435\:0433\
\:0443\:043b\:044f\:0440\:043d\:044b\:0445 \:0432\:044b\:0440\:0430\:0436\
\:0435\:043d\:0438\:044f\:0445, \:0441\:043e\:0434\:0435\:0440\:0436\:0430\
\:0442 ",
 StyleBox["\:0443\:0441\:043b\:043e\:0432\:0438\:044f",
  FontWeight->"Bold"],
 " (",
 Cell[BoxData["/;"], "InlineFormula"],
 ") \:0438 ",
 StyleBox["\:0442\:0435\:0441\:0442\:044b",
  FontWeight->"Bold"],
 " (",
 Cell[BoxData["?"], "InlineFormula"],
 "), \:043a\:043e\:0442\:043e\:0440\:044b\:0435 \
\:043c\:043e\:0433\:0443\:0442 \:043e\:0431\:0440\:0430\:0449\:0430\:0442\
\:044c\:0441\:044f \:043a \:043e\:0431\:0449\:0435\:043c\:0443 \:043a\:043e\
\:0434\:0443 ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " \:0432\:043e \:0432\:0440\:0435\:043c\:044f \:0441\:043e\:043f\:043e\:0441\
\:0442\:0430\:0432\:043b\:0435\:043d\:0438\:044f."
}], "Text",
 CellTags->"b:0.3",
 CellID->143238647],

Cell[TextData[{
 "\:041d\:0435\:043a\:043e\:0442\:043e\:0440\:044b\:0435 \:0441\:043f\:0435\
\:0446\:0438\:0430\:043b\:044c\:043d\:044b\:0435 \:043a\:043e\:043d\:0441\
\:0442\:0440\:0443\:043a\:0446\:0438\:0438 \:0438\:0437 \:0440\:0435\:0433\
\:0443\:043b\:044f\:0440\:043d\:044b\:0445 \:0432\:044b\:0440\:0430\:0436\
\:0435\:043d\:0438\:0439 \:043d\:0430\:043f\:0440\:044f\:043c\:0443\:044e \
\:043d\:0435\:0434\:043e\:0441\:0442\:0443\:043f\:043d\:044b \:0434\:043b\
\:044f \:043e\:0431\:044b\:0447\:043d\:044b\:0445 \:0448\:0430\:0431\:043b\
\:043e\:043d\:043e\:0432. \:0421\:0440\:0435\:0434\:0438 \:0442\:0430\:043a\
\:0438\:0445 \:0441\:0442\:043e\:0438\:0442 \:043e\:0442\:043c\:0435\:0442\
\:0438\:0442\:044c \:043a\:043e\:043d\:0441\:0442\:0440\:0443\:043a\:0446\
\:0438\:0438, \:043e\:043f\:0440\:0435\:0434\:0435\:043b\:044f\:044e\:0449\
\:0438\:0435 \:043d\:0430\:043f\:0440\:0430\:0432\:043b\:0435\:043d\:0438\
\:0435 \:043f\:0440\:043e\:0441\:043c\:043e\:0442\:0440\:0430, \:0430 \:0442\
\:0430\:043a\:0436\:0435 \:043f\:043e\:0432\:0442\:043e\:0440\:044b \:0437\
\:0430\:0434\:0430\:043d\:043d\:043e\:0439 \:0434\:043b\:0438\:043d\:044b. \
\:041e\:043d\:0438 \:043c\:043e\:0433\:0443\:0442 \:0431\:044b\:0442\:044c \
\:0432\:0441\:0442\:0440\:043e\:0435\:043d\:044b \:0432 \:043e\:0431\:044b\
\:0447\:043d\:044b\:0439 \:0448\:0430\:0431\:043b\:043e\:043d \:0434\:043b\
\:044f \:0442\:0435\:043a\:0441\:0442\:043e\:0432\:044b\:0445 \:0444\:0440\
\:0430\:0433\:043c\:0435\:043d\:0442\:043e\:0432, \:043f\:0443\:0442\:0435\
\:043c \:0432\:0441\:0442\:0430\:0432\:043a\:0438 \:043e\:0431\:044a\:0435\
\:043a\:0442\:0430  ",
 Cell[BoxData[
  TemplateBox[{Cell["RegularExpression"],"paclet:ref/RegularExpression"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 "."
}], "Text",
 CellTags->"b:0.3",
 CellID->121646424]
}, Open  ]],

Cell[CellGroupData[{

Cell["\:0424\:0443\:043d\:043a\:0446\:0438\:0438 \:0434\:043b\:044f \:0440\
\:0430\:0431\:043e\:0442\:044b \:0441 \:0442\:0435\:043a\:0441\:0442\:043e\
\:0432\:044b\:043c\:0438 \:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442\
\:0430\:043c\:0438", "Section",
 CellTags->"c:5",
 CellID->393353162],

Cell["\<\
\:041d\:0438\:0436\:0435 \:0440\:0430\:0441\:0441\:043c\:0430\:0442\:0440\
\:0438\:0432\:0430\:044e\:0442\:0441\:044f \:043d\:0435\:043a\:043e\:0442\
\:043e\:0440\:044b\:0435 \:043e\:0441\:043e\:0431\:0435\:043d\:043d\:043e\
\:0441\:0442\:0438 \:0438 \:0442\:043e\:043d\:043a\:043e\:0441\:0442\:0438 \
\:0438\:0441\:043f\:043e\:043b\:044c\:0437\:043e\:0432\:0430\:043d\:0438\:044f\
 \:0440\:0430\:0437\:043b\:0438\:0447\:043d\:044b\:0445 \:0444\:0443\:043d\
\:043a\:0446\:0438\:0439 \:0434\:043b\:044f \:043e\:0431\:0440\:0430\:0431\
\:043e\:0442\:043a\:0438 \:0442\:0435\:043a\:0441\:0442\:043e\:0432\:044b\
\:0445 \:0444\:043f\:0430\:0433\:043c\:0435\:043d\:0442\:043e\:0432 (\:0441\
\:043c. \:0441\:043e\:043e\:0442\:0432\:0435\:0442\:0441\:0442\:0432\:0443\
\:044e\:0449\:0438\:0435 \:0441\:0442\:0440\:0430\:043d\:0438\:0446\:044b \
\:0434\:043e\:043a\:0443\:043c\:0435\:043d\:0442\:0430\:0446\:0438\:0438 \
\:0434\:043b\:044f \:043f\:043e\:043b\:0443\:0447\:0435\:043d\:0438\:044f \
\:0431\:043e\:043b\:0435\:0435 \:043f\:043e\:0434\:0440\:043e\:0431\:043d\
\:043e\:0439 \:0438\:043d\:0444\:043e\:0440\:043c\:0430\:0446\:0438\:0438 \
\:043e\:0431 \:044d\:0442\:0438\:0445 \:0444\:0443\:043d\:043a\:0446\:0438\
\:044f\:0445).\
\>", "Text",
 CellID->447203085],

Cell[CellGroupData[{

Cell["StringMatchQ", "Subsection",
 CellTags->{"c:6", "b:0.4.0"},
 CellID->115748480],

Cell[TextData[{
 Cell[BoxData[
  TemplateBox[{Cell["StringMatchQ"],"paclet:ref/StringMatchQ"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " \:0438\:0441\:043f\:043e\:043b\:044c\:0437\:0443\:0435\:0442\:0441\:044f \
\:0434\:043b\:044f \:043f\:0440\:043e\:0432\:0435\:0440\:043a\:0438 \:0442\
\:043e\:0433\:043e, \:0441\:043e\:043e\:0442\:0432\:0435\:0442\:0441\:0442\
\:0432\:0443\:0435\:0442 \:043b\:0438 \:0446\:0435\:043b\:044b\:0439 \:0442\
\:0435\:043a\:0441\:0442\:043e\:0432\:044b\:0439 \:0444\:0440\:0430\:0433\
\:043c\:0435\:043d\:0442 \:043e\:043f\:0440\:0435\:0434\:0435\:043b\:0435\
\:043d\:043d\:043e\:043c\:0443 \:0448\:0430\:0431\:043b\:043e\:043d\:0443."
}], "MathCaption",
 CellTags->"b:0.4.0",
 CellID->88806953],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringMatchQ", "[", 
  RowBox[{"\"\<test\>\"", ",", 
   RowBox[{"\"\<t\>\"", "~~", 
    RowBox[{"__", "~~", "\"\<t\>\""}]}]}], "]"}]], "Input",
 CellTags->"b:0.4.0",
 CellLabel->"In[45]:=",
 CellID->631912780],

Cell[BoxData["True"], "Output",
 ImageSize->{32, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.4.0",
 CellLabel->"Out[45]=",
 CellID->700553192]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringMatchQ", "[", 
  RowBox[{"\"\<tester\>\"", ",", 
   RowBox[{"\"\<t\>\"", "~~", 
    RowBox[{"__", "~~", "\"\<t\>\""}]}]}], "]"}]], "Input",
 CellTags->"b:0.4.0",
 CellLabel->"In[46]:=",
 CellID->116558020],

Cell[BoxData["False"], "Output",
 ImageSize->{39, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.4.0",
 CellLabel->"Out[46]=",
 CellID->90928558]
}, Open  ]],

Cell[TextData[{
 "\:0424\:0443\:043d\:043a\:0446\:0438\:044f ",
 Cell[BoxData[
  TemplateBox[{Cell["StringMatchQ"],"paclet:ref/StringMatchQ"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " \:043e\:0442\:043b\:0438\:0447\:0430\:0435\:0442\:0441\:044f \:0442\:0435\
\:043c, \:0447\:0442\:043e \:043e\:043d\:0430 \:0434\:043e\:043f\:0443\:0441\
\:043a\:0430\:0435\:0442 \:0438\:0441\:043f\:043e\:043b\:044c\:0437\:043e\
\:0432\:0430\:043d\:0438\:0435 \:043c\:0435\:0442\:0430\:0441\:0438\:043c\
\:0432\:043e\:043b\:043e\:0432 ",
 Cell[BoxData["*"], "InlineFormula"],
 " \:0438 ",
 Cell[BoxData["@"], "InlineFormula"],
 ", \:0432\:0432\:043e\:0434\:0438\:043c\:044b\:0445 \:0432 \
\:043a\:0430\:0447\:0435\:0441\:0442\:0432\:0435 \:043f\:043e\:0434\:0441\
\:0442\:0430\:043d\:043e\:0432\:043e\:0447\:043d\:044b\:0445 \:0437\:043d\
\:0430\:043a\:043e\:0432 (\:0432 \:0446\:0435\:043b\:044f\:0445 \:043e\:0431\
\:0440\:0430\:0442\:043d\:043e\:0439 \:0441\:043e\:0432\:043c\:0435\:0441\
\:0442\:0438\:043c\:043e\:0441\:0442\:0438). \:0421\:0438\:043c\:0432\:043e\
\:043b ",
 Cell[BoxData["*"], "InlineFormula"],
 " \:044d\:043a\:0432\:0438\:0432\:0430\:043b\:0435\:043d\:0442\:0435\:043d \
\:0432\:044b\:0440\:0430\:0436\:0435\:043d\:0438\:044e  ",
 Cell[BoxData[
  RowBox[{
   TemplateBox[{Cell["Shortest"],"paclet:ref/Shortest"},
    "RefLink",
    BaseStyle->"InlineFormula"], "[", "___", "]"}]], "InlineFormula"],
 " \:0438\:043b\:0438 ",
 Cell[BoxData[
  RowBox[{
   TemplateBox[{Cell["RegularExpression"],"paclet:ref/RegularExpression"},
    "RefLink",
    BaseStyle->"InlineFormula"], "[", "\<\"(?s).*?\"\>", "]"}]], 
  "InlineFormula"],
 ", \:0430 \:0441\:0438\:043c\:0432\:043e\:043b ",
 Cell[BoxData["@"], "InlineFormula"],
 " \:044d\:043a\:0432\:0438\:0432\:0430\:043b\:0435\:043d\:0442\:0435\:043d \
\:0432\:044b\:0440\:0430\:0436\:0435\:043d\:0438\:044e  ",
 Cell[BoxData[
  RowBox[{
   TemplateBox[{Cell["Except"],"paclet:ref/Except"},
    "RefLink",
    BaseStyle->"InlineFormula"], "[", 
   RowBox[{
    TemplateBox[{Cell["CharacterRange"],"paclet:ref/CharacterRange"},
     "RefLink",
     BaseStyle->"InlineFormula"], "[", 
    RowBox[{"\<\"A\"\>", ",", "\<\"Z\"\>"}], "]"}], "]"}]], "InlineFormula"],
 " \:0438\:043b\:0438 ",
 Cell[BoxData[
  RowBox[{
   TemplateBox[{Cell["RegularExpression"],"paclet:ref/RegularExpression"},
    "RefLink",
    BaseStyle->"InlineFormula"], "[", "\<\"[^A-Z]\"\>", "]"}]], 
  "InlineFormula"],
 "."
}], "Text",
 CellTags->"b:0.4.0",
 CellID->406868558],

Cell["\<\
\:0412 \:0441\:0438\:043b\:0443 \:0432\:044b\:0448\:0435\:0441\:043a\:0430\
\:0437\:0430\:043d\:043d\:043e\:0433\:043e, \:0441\:043b\:0435\:0434\:0443\
\:044e\:0449\:0438\:0435 \:0442\:0440\:0438 \:0448\:0430\:0431\:043b\:043e\
\:043d\:0430 \:043f\:043e\:043b\:043d\:043e\:0441\:0442\:044c\:044e \:0440\
\:0430\:0432\:043d\:043e\:0437\:043d\:0430\:0447\:043d\:044b.\
\>", "MathCaption",
 CellTags->"b:0.4.0",
 CellID->90376082],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringMatchQ", "[", 
  RowBox[{"\"\<test\>\"", ",", 
   RowBox[{"_", "~~", "\"\<e*\>\""}]}], "]"}]], "Input",
 CellTags->"b:0.4.0",
 CellLabel->"In[47]:=",
 CellID->996820522],

Cell[BoxData["True"], "Output",
 ImageSize->{32, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.4.0",
 CellLabel->"Out[47]=",
 CellID->324203704]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringMatchQ", "[", 
  RowBox[{"\"\<test\>\"", ",", 
   RowBox[{"_", "~~", "\"\<e\>\"", "~~", 
    RowBox[{"Shortest", "[", "___", "]"}]}]}], "]"}]], "Input",
 CellTags->"b:0.4.0",
 CellLabel->"In[48]:=",
 CellID->44778046],

Cell[BoxData["True"], "Output",
 ImageSize->{32, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.4.0",
 CellLabel->"Out[48]=",
 CellID->2677979]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringMatchQ", "[", 
  RowBox[{"\"\<test\>\"", ",", 
   RowBox[{"RegularExpression", "[", "\"\<(?s).e.*?\>\"", "]"}]}], 
  "]"}]], "Input",
 CellTags->"b:0.4.0",
 CellLabel->"In[49]:=",
 CellID->22423222],

Cell[BoxData["True"], "Output",
 ImageSize->{32, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.4.0",
 CellLabel->"Out[49]=",
 CellID->299266338]
}, Open  ]],

Cell[TextData[{
 "\:0421\:0442\:043e\:0438\:0442 \:0437\:0430\:043c\:0435\:0442\:0438\:0442\
\:044c, \:0447\:0442\:043e, \:0432 \:043f\:0440\:0438\:043d\:0446\:0438\:043f\
\:0435, \:043f\:0440\:0438\:0441\:0443\:0442\:0441\:0442\:0432\:0438\:0435  ",
 Cell[BoxData[
  TemplateBox[{Cell["Shortest"],"paclet:ref/Shortest"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " \:0432 \:043f\:0440\:0438\:0432\:0435\:0434\:0435\:043d\:043d\:043e\:043c \
\:043f\:0440\:0438\:043c\:0435\:0440\:0435 \:043d\:0435 \:0438\:043c\:0435\
\:0435\:0442 \:0431\:043e\:043b\:044c\:0448\:043e\:0433\:043e \:0437\:043d\
\:0430\:0447\:0435\:043d\:0438\:044f, \:0442\:0430\:043a \:043a\:0430\:043a \
\:0437\:0434\:0435\:0441\:044c \:0432\:044b\:043f\:043e\:043b\:043d\:044f\
\:0435\:0442\:0441\:044f \:043f\:0440\:043e\:0432\:0435\:0440\:043a\:0430, \
\:0441\:043e\:043e\:0442\:0432\:0435\:0442\:0441\:0442\:0432\:0443\:0435\:0442\
 \:043b\:0438 \:0446\:0435\:043b\:044b\:0439 \:0442\:0435\:043a\:0441\:0442\
\:043e\:0432\:044b\:0439 \:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442 \
\:0448\:0430\:0431\:043b\:043e\:043d\:0443 \:0438\:043b\:0438 \:043d\:0435\
\:0442. "
}], "Text",
 CellTags->"b:0.4.0",
 CellID->60232086],

Cell[TextData[{
 "\:0415\:0441\:043b\:0438 \:0440\:0435\:0447\:044c \:0438\:0434\:0435\:0442 \
\:043e \:043f\:043e\:0438\:0441\:043a\:0435 \:0441\:043e\:043e\:0442\:0432\
\:0435\:0442\:0441\:0442\:0432\:0443\:044e\:0449\:0438\:0445  \:0437\:0430\
\:0434\:0430\:043d\:043d\:043e\:043c\:0443 \:0448\:0430\:0431\:043b\:043e\
\:043d\:0443 \:0441\:0443\:0431\:0444\:0440\:0430\:0433\:043c\:0435\:043d\
\:0442\:043e\:0432 \:0442\:0435\:043a\:0441\:0442\:043e\:0432\:043e\:0433\
\:043e \:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442\:0430, \:0432\:043c\
\:0435\:0441\:0442\:043e ",
 Cell[BoxData[
  TemplateBox[{Cell["StringMatchQ"],"paclet:ref/StringMatchQ"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " \:0441\:043b\:0435\:0434\:0443\:0435\:0442 \:0438\:0441\:043f\:043e\:043b\
\:044c\:0437\:043e\:0432\:0430\:0442\:044c \:0444\:0443\:043d\:043a\:0446\
\:0438\:044e ",
 Cell[BoxData[
  TemplateBox[{Cell["StringCases"],"paclet:ref/StringCases"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 "."
}], "Text",
 CellTags->"b:0.4.0",
 CellID->716869318],

Cell[TextData[{
 "\:0424\:0443\:043d\:043a\:0446\:0438\:044f ",
 Cell[BoxData[
  TemplateBox[{Cell["StringMatchQ"],"paclet:ref/StringMatchQ"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " \:0438\:043c\:0435\:0435\:0442 \:043e\:043f\:0446\:0438\:044e ",
 Cell[BoxData[
  TemplateBox[{Cell["SpellingCorrection"],"paclet:ref/SpellingCorrection"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 ", \:043f\:0440\:0435\:0434\:043d\:0430\:0437\:043d\:0430\:0447\:0435\:043d\
\:043d\:0443\:044e \:0434\:043b\:044f \:043f\:043e\:0438\:0441\:043a\:0430 \
\:0441\:043e\:0432\:043f\:0430\:0434\:0435\:043d\:0438\:0439, \:0441\:043e\
\:0434\:0435\:0440\:0436\:0430\:0449\:0438\:0445 \:043d\:0435\:0437\:043d\
\:0430\:0447\:0438\:0442\:0435\:043b\:044c\:043d\:044b\:0435 \:0440\:0430\
\:0441\:0445\:043e\:0436\:0434\:0435\:043d\:0438\:044f \:0441 \:0437\:0430\
\:0434\:0430\:043d\:043d\:044b\:043c \:0448\:0430\:0431\:043b\:043e\:043d\
\:043e\:043c (\:044d\:0444\:0444\:0435\:043a\:0442\:0438\:0432\:043d\:043e\
\:0435 \:0440\:0435\:0448\:0435\:043d\:0438\:0435 \:0434\:043b\:044f \:043d\
\:0438\:0432\:0435\:043b\:0438\:0440\:043e\:0432\:0430\:043d\:0438\:044f \
\:043d\:0435\:0443\:0434\:043e\:0431\:0441\:0442\:0432, \:0441\:043e\:0437\
\:0434\:0430\:0432\:0430\:0435\:043c\:044b\:0445 \:043e\:043f\:0435\:0447\
\:0430\:0442\:043a\:0430\:043c\:0438 - \:043f\:0440\:0438\:043c. \:043f\:0435\
\:0440\:0435\:0432\:043e\:0434\:0447\:0438\:043a\:0430). \:042d\:0442\:0430 \
\:043e\:043f\:0446\:0438\:044f \:0440\:0430\:0431\:043e\:0442\:0430\:0435\
\:0442 \:0442\:043e\:043b\:044c\:043a\:043e \:0432 \:0448\:0430\:0431\:043b\
\:043e\:043d\:0430\:0445, \:0441\:043e\:0441\:0442\:043e\:044f\:0449\:0438\
\:0445 \:0438\:0437 \:0435\:0434\:0438\:043d\:043e\:0439 \:043b\:0438\:0442\
\:0435\:0440\:043d\:043e\:0439 \:0441\:0442\:0440\:043e\:043a\:0438."
}], "MathCaption",
 CellTags->"b:0.4.0",
 CellID->554439476],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringMatchQ", "[", 
  RowBox[{"\"\<alpha\>\"", ",", "\"\<alpa\>\"", ",", 
   RowBox[{"SpellingCorrection", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"b:0.4.0",
 CellLabel->"In[50]:=",
 CellID->70925498],

Cell[BoxData["True"], "Output",
 ImageSize->{32, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.4.0",
 CellLabel->"Out[50]=",
 CellID->36702422]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["StringFreeQ", "Subsection",
 CellTags->{"c:7", "b:0.4.1"},
 CellID->221687989],

Cell[TextData[{
 "\:0424\:0443\:043d\:043a\:0446\:0438\:044f ",
 Cell[BoxData[
  TemplateBox[{Cell["StringFreeQ"],"paclet:ref/StringFreeQ"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " \:043f\:0440\:043e\:0432\:0435\:0440\:044f\:0435\:0442 \:0442\:0435\:043a\
\:0441\:0442\:043e\:0432\:044b\:0439 \:0444\:0440\:0430\:0433\:043c\:0435\
\:043d\:0442 \:043d\:0430 \:043f\:0440\:0435\:0434\:043c\:0435\:0442 \:043e\
\:0442\:0441\:0443\:0442\:0441\:0442\:0432\:0438\:044f \:0432 \:043d\:0435\
\:043c \:0441\:0443\:0431\:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442\
\:0430, \:0441\:043e\:043e\:0442\:0432\:0435\:0442\:0441\:0442\:0432\:0443\
\:044e\:0449\:0435\:0433\:043e \:0437\:0430\:0434\:0430\:043d\:043d\:043e\
\:043c\:0443 \:0448\:0430\:0431\:043b\:043e\:043d\:0443. \:042d\:0442\:0430 \
\:0444\:0443\:043d\:043a\:0446\:0438\:044f \:0432\:043e\:0437\:0432\:0440\
\:0430\:0449\:0430\:0435\:0442 \:0440\:0435\:0437\:0443\:043b\:044c\:0442\
\:0430\:0442 \:0432 \:0432\:0438\:0434\:0435 \:0437\:043d\:0430\:0447\:0435\
\:043d\:0438\:0439 \:0418\:0441\:0442\:0438\:043d\:0430 (",
 Cell[BoxData[
  TemplateBox[{Cell["True"],"paclet:ref/True"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 ") \:0438\:043b\:0438 \:041b\:043e\:0436\:044c (",
 Cell[BoxData[
  TemplateBox[{Cell["False"],"paclet:ref/False"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 "). \:041e\:043d\:0430 \:043d\:0435 \:0432\:043e\:0437\:0432\:0440\:0430\
\:0449\:0430\:0435\:0442 \:043d\:0430\:0439\:0434\:0435\:043d\:043d\:044b\
\:0439 \:0441\:0443\:0431\:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442, \
\:0434\:043b\:044f \:044d\:0442\:043e\:0433\:043e \:0438\:0441\:043f\:043e\
\:043b\:044c\:0437\:0443\:0435\:0442\:0441\:044f \:0444\:0443\:043d\:043a\
\:0446\:0438\:044f ",
 Cell[BoxData[
  TemplateBox[{Cell["StringCases"],"paclet:ref/StringCases"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 "."
}], "MathCaption",
 CellTags->"b:0.4.1",
 CellID->58760444],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringFreeQ", "[", 
  RowBox[{"\"\<abcde\>\"", ",", 
   RowBox[{"\"\<b\>\"", "~~", 
    RowBox[{"__", "~~", "\"\<d\>\""}]}]}], "]"}]], "Input",
 CellTags->"b:0.4.1",
 CellLabel->"In[51]:=",
 CellID->208914080],

Cell[BoxData["False"], "Output",
 ImageSize->{39, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.4.1",
 CellLabel->"Out[51]=",
 CellID->419298952]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringFreeQ", "[", 
  RowBox[{"\"\<abcde\>\"", ",", 
   RowBox[{"RegularExpression", "[", "\"\<b.*d\>\"", "]"}]}], "]"}]], "Input",
 CellTags->"b:0.4.1",
 CellLabel->"In[52]:=",
 CellID->113974042],

Cell[BoxData["False"], "Output",
 ImageSize->{39, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.4.1",
 CellLabel->"Out[52]=",
 CellID->180843643]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["StringCases", "Subsection",
 CellTags->{"c:8", "b:0.4.2"},
 CellID->3968257],

Cell[TextData[{
 Cell[BoxData[
  TemplateBox[{Cell["StringCases"],"paclet:ref/StringCases"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " \:044f\:0432\:043b\:044f\:0435\:0442\:0441\:044f \:0444\:0443\:043d\:043a\
\:0446\:0438\:0435\:0439 \:043e\:0431\:0449\:0435\:0433\:043e \:043d\:0430\
\:0437\:043d\:0430\:0447\:0435\:043d\:0438\:044f, \:0438\:0441\:043f\:043e\
\:043b\:044c\:0437\:0443\:0435\:043c\:043e\:0439 \:0434\:043b\:044f \:043f\
\:043e\:0438\:0441\:043a\:0430 \:0441\:043b\:0443\:0447\:0430\:0435\:0432 \
\:0441\:043e\:043e\:0442\:0432\:0435\:0442\:0441\:0442\:0432\:0438\:044f \
\:0448\:0430\:0431\:043b\:043e\:043d\:0430\:043c, \:0438\:0437\:0432\:043b\
\:0435\:0447\:0435\:043d\:0438\:044f \:0438\:0441\:043a\:043e\:043c\:044b\
\:0445 \:0441\:0443\:0431\:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442\
\:043e\:0432 \:0438 \:043e\:0431\:0440\:0430\:0431\:043e\:0442\:043a\:0438 \
\:0432\:043e\:0437\:0432\:0440\:0430\:0449\:0430\:0435\:043c\:044b\:0445 \
\:0440\:0435\:0437\:0443\:043b\:044c\:0442\:0430\:0442\:043e\:0432. "
}], "Text",
 CellTags->"b:0.4.2",
 CellID->46676764],

Cell["\:041f\:043e\:0438\:0441\:043a \:0441\:0443\:0431\:0444\:0440\:0430\
\:0433\:043c\:0435\:043d\:0442\:043e\:0432, \:0441\:043e\:043e\:0442\:0432\
\:0435\:0442\:0441\:0442\:0432\:0443\:044e\:0449\:0438\:0445 \:0448\:0430\
\:0431\:043b\:043e\:043d\:0443.", "MathCaption",
 CellTags->"b:0.4.2",
 CellID->143958968],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringCases", "[", 
  RowBox[{"\"\<a1b2a26d15a42\>\"", ",", 
   RowBox[{"\"\<a\>\"", "~~", "_"}]}], "]"}]], "Input",
 CellTags->"b:0.4.2",
 CellLabel->"In[53]:=",
 CellID->459256047],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"a1\"\>", ",", "\<\"a2\"\>", ",", "\<\"a4\"\>"}], 
  "}"}]], "Output",
 ImageSize->{82, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.4.2",
 CellLabel->"Out[53]=",
 CellID->265787987]
}, Open  ]],

Cell["\<\
\:0418\:0437\:0432\:043b\:0435\:0447\:0435\:043d\:0438\:0435 \:043e\:0442\
\:0434\:0435\:043b\:044c\:043d\:044b\:0445 \:0447\:0430\:0441\:0442\:0435\
\:0439 \:0438\:0437 \:043d\:0430\:0439\:0434\:0435\:043d\:043d\:044b\:0445, \
\:0441\:043e\:043e\:0442\:0432\:0435\:0442\:0441\:0442\:0432\:0443\:044e\:0449\
\:0438\:0445 \:0448\:0430\:0431\:043b\:043e\:043d\:0443 \:0441\:0443\:0431\
\:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442\:043e\:0432. \
\>", "MathCaption",
 CellTags->"b:0.4.2",
 CellID->697884743],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringCases", "[", 
  RowBox[{"\"\<a1b2a26d15a42\>\"", ",", 
   RowBox[{
    RowBox[{"\"\<a\>\"", "~~", 
     RowBox[{"x", ":", 
      RowBox[{"DigitCharacter", ".."}]}]}], "\[Rule]", "x"}]}], 
  "]"}]], "Input",
 CellTags->"b:0.4.2",
 CellLabel->"In[54]:=",
 CellID->85500109],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"1\"\>", ",", "\<\"26\"\>", ",", "\<\"42\"\>"}], 
  "}"}]], "Output",
 ImageSize->{75, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.4.2",
 CellLabel->"Out[54]=",
 CellID->32377990]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringCases", "[", 
  RowBox[{"\"\<a1b2a26d15a42\>\"", ",", 
   RowBox[{
    RowBox[{"RegularExpression", "[", "\"\<a(\\\\d+)\>\"", "]"}], "\[Rule]", 
    "\"\<$1\>\""}]}], "]"}]], "Input",
 CellTags->"b:0.4.2",
 CellLabel->"In[55]:=",
 CellID->493985103],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"1\"\>", ",", "\<\"26\"\>", ",", "\<\"42\"\>"}], 
  "}"}]], "Output",
 ImageSize->{75, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.4.2",
 CellLabel->"Out[55]=",
 CellID->82819926]
}, Open  ]],

Cell["\:041a\:043e\:043b\:0438\:0447\:0435\:0441\:0442\:0432\:0435\:043d\:043d\
\:043e\:0435 \:043e\:0433\:0440\:0430\:043d\:0438\:0447\:0435\:043d\:0438\
\:0435 \:043d\:0430\:0439\:0434\:0435\:043d\:043d\:044b\:0445 \:0441\:043e\
\:0432\:043f\:0430\:0434\:0435\:043d\:0438\:0439.", "MathCaption",
 CellTags->"b:0.4.2",
 CellID->121882887],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringCases", "[", 
  RowBox[{"\"\<a b c d e\>\"", ",", "LetterCharacter", ",", "3"}], 
  "]"}]], "Input",
 CellTags->"b:0.4.2",
 CellLabel->"In[56]:=",
 CellID->240722779],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"a\"\>", ",", "\<\"b\"\>", ",", "\<\"c\"\>"}], "}"}]], "Output",
 ImageSize->{61, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.4.2",
 CellLabel->"Out[56]=",
 CellID->266942857]
}, Open  ]],

Cell["\:041c\:043e\:0436\:043d\:043e \:0438\:0441\:043f\:043e\:043b\:044c\
\:0437\:043e\:0432\:0430\:0442\:044c \:0441\:043f\:0438\:0441\:043e\:043a \
\:043f\:0440\:0430\:0432\:0438\:043b.", "MathCaption",
 CellTags->"b:0.4.2",
 CellID->608581590],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringCases", "[", 
  RowBox[{"\"\<a13bF5b1Aa33\>\"", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"\"\<a\>\"", "~~", 
       RowBox[{"x", ":", 
        RowBox[{"DigitCharacter", ".."}]}]}], "\[Rule]", 
      RowBox[{"f1", "[", "x", "]"}]}], ",", 
     RowBox[{
      RowBox[{"\"\<b\>\"", "~~", 
       RowBox[{"x", ":", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"DigitCharacter", "|", 
           RowBox[{"CharacterRange", "[", 
            RowBox[{"\"\<A\>\"", ",", "\"\<F\>\""}], "]"}]}], ")"}], 
         ".."}]}]}], "\[Rule]", 
      RowBox[{"hex", "[", "x", "]"}]}]}], "}"}]}], "]"}]], "Input",
 CellTags->"b:0.4.2",
 CellLabel->"In[57]:=",
 CellID->94888225],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"f1", "[", "\<\"13\"\>", "]"}], ",", 
   RowBox[{"hex", "[", "\<\"F5\"\>", "]"}], ",", 
   RowBox[{"hex", "[", "\<\"1A\"\>", "]"}], ",", 
   RowBox[{"f1", "[", "\<\"33\"\>", "]"}]}], "}"}]], "Output",
 ImageSize->{233, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.4.2",
 CellLabel->"Out[57]=",
 CellID->628308907]
}, Open  ]],

Cell[TextData[{
 "\:0412 \:043a\:0430\:0447\:0435\:0441\:0442\:0432\:0435 \:043f\:0435\:0440\
\:0432\:043e\:0433\:043e \:0430\:0440\:0433\:0443\:043c\:0435\:043d\:0442\
\:0430 \:0444\:0443\:043d\:043a\:0446\:0438\:0438 ",
 Cell[BoxData[
  TemplateBox[{Cell["StringCases"],"paclet:ref/StringCases"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " \:043c\:043e\:0436\:043d\:043e \:0443\:043a\:0430\:0437\:0430\:0442\:044c \
\:0441\:043f\:0438\:0441\:043e\:043a \:0442\:0435\:043a\:0441\:0442\:043e\
\:0432\:044b\:0445 \:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442\:043e\
\:0432, \:0434\:043b\:044f \:044d\:0444\:0444\:0435\:043a\:0442\:0438\:0432\
\:043d\:043e\:0439 \:043e\:0431\:0440\:0430\:0431\:043e\:0442\:043a\:0438 \
\:043c\:043d\:043e\:0433\:0438\:0445 \:0441\:0442\:0440\:043e\:043a (\:0441\
\:043c. \:0442\:0430\:043a\:0436\:0435 \:0440\:0430\:0437\:0434\:0435\:043b \
\"",
 ButtonBox["\:0421\:043e\:0432\:0435\:0442\:044b \:0438 \:0440\:0435\:043a\
\:043e\:043c\:0435\:043d\:0434\:0430\:0446\:0438\:0438 \:0434\:043b\:044f \
\:044d\:0444\:0444\:0435\:043a\:0442\:0438\:0432\:043d\:043e\:0433\:043e \
\:043f\:043e\:0438\:0441\:043a\:0430 \:0441\:043e\:0432\:043f\:0430\:0434\
\:0435\:043d\:0438\:0439",
  BaseStyle->"Hyperlink",
  ButtonData->{"WorkingWithStringPatternsRU.nb", "c:25"}],
 "\")."
}], "MathCaption",
 CellTags->"b:0.4.2",
 CellID->255423450],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringCases", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "\"\<cat\>\"", ",", "\"\<in\>\"", ",", "\"\<the\>\"", ",", 
     "\"\<hat\>\""}], "}"}], ",", 
   RowBox[{"__", "~~", 
    RowBox[{"\"\<t\>\"", "~~", "EndOfString"}]}]}], "]"}]], "Input",
 CellTags->"b:0.4.2",
 CellLabel->"In[58]:=",
 CellID->1009786679],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", "\<\"cat\"\>", "}"}], ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"{", "}"}], ",", 
   RowBox[{"{", "\<\"hat\"\>", "}"}]}], "}"}]], "Output",
 ImageSize->{149, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.4.2",
 CellLabel->"Out[58]=",
 CellID->686212242]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Flatten", "[", "%", "]"}]], "Input",
 CellTags->"b:0.4.2",
 CellLabel->"In[59]:=",
 CellID->51924450],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"cat\"\>", ",", "\<\"hat\"\>"}], "}"}]], "Output",
 ImageSize->{71, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.4.2",
 CellLabel->"Out[59]=",
 CellID->15829095]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\:041e\:043f\:0446\:0438\:044f \:043f\:0435\:0440\:0435\:043a\:0440\
\:044b\:0442\:0438\:044f (Overlaps)", "Subsection",
 CellTags->{"c:9", "b:0.4.3"},
 CellID->351610464],

Cell[TextData[{
 "\:041e\:043f\:0446\:0438\:044f ",
 Cell[BoxData[
  TemplateBox[{Cell["Overlaps"],"paclet:ref/Overlaps"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " \:0434\:043b\:044f \:0444\:0443\:043d\:043a\:0446\:0438\:0439 ",
 Cell[BoxData[
  TemplateBox[{Cell["StringCases"],"paclet:ref/StringCases"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  TemplateBox[{Cell["StringPosition"],"paclet:ref/StringPosition"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " \:0438 ",
 Cell[BoxData[
  TemplateBox[{Cell["StringCount"],"paclet:ref/StringCount"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " \:043e\:043f\:0440\:0435\:0434\:0435\:043b\:044f\:0435\:0442, \:043a\:0430\
\:043a \:0434\:043e\:043b\:0436\:0435\:043d \:0434\:0435\:0439\:0441\:0442\
\:0432\:043e\:0432\:0430\:0442\:044c \:0430\:043d\:0430\:043b\:0438\:0437\
\:0430\:0442\:043e\:0440 \:0441\:043e\:043e\:0442\:0432\:0435\:0442\:0441\
\:0442\:0432\:0438\:044f \:043f\:043e\:0441\:043b\:0435 \:0442\:043e\:0433\
\:043e, \:043a\:0430\:043a \:043d\:0430\:0439\:0434\:0435\:043d\:043e \:0441\
\:043e\:0432\:043f\:0430\:0434\:0435\:043d\:0438\:0435. \:042d\:0442\:0430 \
\:043e\:043f\:0446\:0438\:044f \:0438\:043c\:0435\:0435\:0442 \:0442\:0440\
\:0438 \:0432\:043e\:0437\:043c\:043e\:0436\:043d\:044b\:0435 \:043d\:0430\
\:0441\:0442\:0440\:043e\:0439\:043a\:0438:  ",
 Cell[BoxData[
  TemplateBox[{Cell["False"],"paclet:ref/False"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 ", ",
 Cell[BoxData[
  TemplateBox[{Cell["True"],"paclet:ref/True"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " \:0438\:043b\:0438 ",
 Cell[BoxData[
  TemplateBox[{Cell["All"],"paclet:ref/All"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 ". \:0414\:043b\:044f \:0444\:0443\:043d\:043a\:0446\:0438\:0439 ",
 Cell[BoxData[
  TemplateBox[{Cell["StringCases"],"paclet:ref/StringCases"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " \:0438 ",
 Cell[BoxData[
  TemplateBox[{Cell["StringCount"],"paclet:ref/StringCount"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " \:0437\:043d\:0430\:0447\:0435\:043d\:0438\:0435\:043c \:043f\:043e \:0443\
\:043c\:043e\:043b\:0447\:0430\:043d\:0438\:044e \:044f\:0432\:043b\:044f\
\:0435\:0442\:0441\:044f ",
 Cell[BoxData[
  TemplateBox[{Cell["False"],"paclet:ref/False"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 ", \:0430 \:0434\:043b\:044f \:0444\:0443\:043d\:043a\:0446\:0438\:0438 ",
 Cell[BoxData[
  TemplateBox[{Cell["StringPosition"],"paclet:ref/StringPosition"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " \:0437\:043d\:0430\:0447\:0435\:043d\:0438\:0435\:043c \:043f\:043e \:0443\
\:043c\:043e\:043b\:0447\:0430\:043d\:0438\:044e \:044f\:0432\:043b\:044f\
\:0435\:0442\:0441\:044f ",
 Cell[BoxData[
  TemplateBox[{Cell["True"],"paclet:ref/True"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 "."
}], "Text",
 CellTags->"b:0.4.3",
 CellID->542672475],

Cell[TextData[{
 "\:041f\:0440\:0438 \:043d\:0430\:0441\:0442\:0440\:043e\:0439\:043a\:0435 ",
 Cell[BoxData[
  RowBox[{
   TemplateBox[{Cell["Overlaps"],"paclet:ref/Overlaps"},
    "RefLink",
    BaseStyle->"InlineFormula"], "->", 
   TemplateBox[{Cell["False"],"paclet:ref/False"},
    "RefLink",
    BaseStyle->"InlineFormula"]}]], "InlineFormula"],
 ", \:0430\:043d\:0430\:043b\:0438\:0437\:0430\:0442\:043e\:0440 \:0441\:043e\
\:043e\:0442\:0432\:0435\:0442\:0441\:0442\:0432\:0438\:044f \:043f\:0440\
\:043e\:0434\:043e\:043b\:0436\:0430\:0435\:0442 \:0438\:0441\:043a\:0430\
\:0442\:044c \:0441\:043e\:0432\:043f\:0430\:0434\:0435\:043d\:0438\:044f \
\:043d\:0430\:0447\:0438\:043d\:0430\:044f \:0441 \:0441\:0438\:043c\:0432\
\:043e\:043b\:0430, \:0441\:043b\:0435\:0434\:0443\:044e\:0449\:0435\:0433\
\:043e \:0437\:0430 \:043f\:043e\:0441\:043b\:0435\:0434\:043d\:0438\:043c \
\:043d\:0430\:0439\:0434\:0435\:043d\:043d\:044b\:043c \:0441\:0443\:0431\
\:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442\:043e\:043c."
}], "MathCaption",
 CellTags->"b:0.4.3",
 CellID->271649068],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringCases", "[", 
  RowBox[{"\"\<(a(b)c(d)\>\"", ",", 
   RowBox[{"Shortest", "[", 
    RowBox[{"\"\<(\>\"", "~~", "__", "~~", "\"\<)\>\""}], "]"}]}], 
  "]"}]], "Input",
 CellTags->"b:0.4.3",
 CellLabel->"In[60]:=",
 CellID->323915583],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"(a(b)\"\>", ",", "\<\"(d)\"\>"}], "}"}]], "Output",
 ImageSize->{85, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.4.3",
 CellLabel->"Out[60]=",
 CellID->595622412]
}, Open  ]],

Cell[TextData[{
 "\:041f\:0440\:0438 \:043d\:0430\:0441\:0442\:0440\:043e\:0439\:043a\:0435 ",
 Cell[BoxData[
  RowBox[{
   TemplateBox[{Cell["Overlaps"],"paclet:ref/Overlaps"},
    "RefLink",
    BaseStyle->"InlineFormula"], "->", 
   TemplateBox[{Cell["True"],"paclet:ref/True"},
    "RefLink",
    BaseStyle->"InlineFormula"]}]], "InlineFormula"],
 ", \:0430\:043d\:0430\:043b\:0438\:0437\:0430\:0442\:043e\:0440 \:0441\:043e\
\:043e\:0442\:0432\:0435\:0442\:0441\:0442\:0432\:0438\:044f \:043f\:0440\
\:043e\:0434\:043e\:043b\:0436\:0430\:0435\:0442 \:0438\:0441\:043a\:0430\
\:0442\:044c \:0441\:043e\:0432\:043f\:0430\:0434\:0435\:043d\:0438\:044f \
\:043d\:0430\:0447\:0438\:043d\:0430\:044f \:0441 \:0441\:0438\:043c\:0432\
\:043e\:043b\:0430, \:0441\:043b\:0435\:0434\:0443\:044e\:0449\:0435\:0433\
\:043e \:0437\:0430 \:043f\:0435\:0440\:0432\:044b\:043c \:0441\:0438\:043c\
\:0432\:043e\:043b\:043e\:043c \:043f\:043e\:0441\:043b\:0435\:0434\:043d\
\:0435\:0433\:043e \:043d\:0430\:0439\:0434\:0435\:043d\:043d\:043e\:0433\
\:043e \:0441\:0443\:0431\:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442\
\:0430 (\:043f\:0440\:0438 \:0438\:0441\:043f\:043e\:043b\:044c\:0437\:043e\
\:0432\:0430\:043d\:0438\:0438 \:043e\:0434\:043d\:043e\:0433\:043e \:0448\
\:0430\:0431\:043b\:043e\:043d\:0430)."
}], "MathCaption",
 CellTags->"b:0.4.3",
 CellID->18408293],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringCases", "[", 
  RowBox[{"\"\<(a(b)c(d)\>\"", ",", 
   RowBox[{"Shortest", "[", 
    RowBox[{"\"\<(\>\"", "~~", "__", "~~", "\"\<)\>\""}], "]"}], ",", 
   RowBox[{"Overlaps", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"b:0.4.3",
 CellLabel->"In[61]:=",
 CellID->123426060],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"(a(b)\"\>", ",", "\<\"(b)\"\>", ",", "\<\"(d)\"\>"}], 
  "}"}]], "Output",
 ImageSize->{117, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.4.3",
 CellLabel->"Out[61]=",
 CellID->59960422]
}, Open  ]],

Cell[TextData[{
 "\:041f\:0440\:0438 \:043d\:0430\:0441\:0442\:0440\:043e\:0439\:043a\:0435 ",
 Cell[BoxData[
  RowBox[{
   TemplateBox[{Cell["Overlaps"],"paclet:ref/Overlaps"},
    "RefLink",
    BaseStyle->"InlineFormula"], "->", 
   TemplateBox[{Cell["All"],"paclet:ref/All"},
    "RefLink",
    BaseStyle->"InlineFormula"]}]], "InlineFormula"],
 ", \:0430\:043d\:0430\:043b\:0438\:0437\:0430\:0442\:043e\:0440 \:0441\:043e\
\:043e\:0442\:0432\:0435\:0442\:0441\:0442\:0432\:0438\:044f \:043f\:0440\
\:043e\:0434\:043e\:043b\:0436\:0430\:0435\:0442 \:0438\:0441\:043a\:0430\
\:0442\:044c, \:043d\:0430\:0447\:0438\:043d\:0430\:044f \:0441 \:0442\:043e\
\:0439 \:0436\:0435 \:0441\:0430\:043c\:043e\:0439 \:043f\:043e\:0437\:0438\
\:0446\:0438\:0438, \:0434\:043e \:0442\:0435\:0445 \:043f\:043e\:0440, \
\:043f\:043e\:043a\:0430 \:043d\:0435 \:043f\:0435\:0440\:0435\:0441\:0442\
\:0430\:0435\:0442 \:043d\:0430\:0445\:043e\:0434\:0438\:0442\:044c \:043d\
\:043e\:0432\:044b\:0435 \:0441\:043e\:0432\:043f\:0430\:0434\:0435\:043d\
\:0438\:044f."
}], "MathCaption",
 CellTags->"b:0.4.3",
 CellID->326611308],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringCases", "[", 
  RowBox[{"\"\<(a(b)c(d)\>\"", ",", 
   RowBox[{"Shortest", "[", 
    RowBox[{"\"\<(\>\"", "~~", "__", "~~", "\"\<)\>\""}], "]"}], ",", 
   RowBox[{"Overlaps", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellTags->"b:0.4.3",
 CellLabel->"In[62]:=",
 CellID->237410754],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"(a(b)\"\>", ",", "\<\"(a(b)c(d)\"\>", ",", "\<\"(b)\"\>", 
   ",", "\<\"(b)c(d)\"\>", ",", "\<\"(d)\"\>"}], "}"}]], "Output",
 ImageSize->{251, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.4.3",
 CellLabel->"Out[62]=",
 CellID->634444596]
}, Open  ]],

Cell[TextData[{
 "\:0415\:0441\:043b\:0438 \:043d\:0435\:0441\:043a\:043e\:043b\:044c\:043a\
\:043e \:0448\:0430\:0431\:043b\:043e\:043d\:043e\:0432 \:0437\:0430\:0434\
\:0430\:043d\:044b \:0441\:043f\:0438\:0441\:043a\:043e\:043c, \:043d\:0430\
\:0441\:0442\:0440\:043e\:0439\:043a\:0430 ",
 Cell[BoxData[
  RowBox[{
   TemplateBox[{Cell["Overlaps"],"paclet:ref/Overlaps"},
    "RefLink",
    BaseStyle->"InlineFormula"], "->", 
   TemplateBox[{Cell["True"],"paclet:ref/True"},
    "RefLink",
    BaseStyle->"InlineFormula"]}]], "InlineFormula"],
 " \:0431\:0443\:0434\:0435\:0442 \:0437\:0430\:0441\:0442\:0430\:0432\:043b\
\:044f\:0442\:044c \:0430\:043d\:0430\:043b\:0438\:0437\:0430\:0442\:043e\
\:0440 \:0441\:043e\:043e\:0442\:0432\:0435\:0442\:0441\:0442\:0432\:0438\
\:0439 \:043d\:0430\:0447\:0438\:043d\:0430\:0442\:044c \:043f\:0440\:043e\
\:0432\:0435\:0440\:043a\:0443 \:043a\:0430\:0436\:0434\:043e\:0433\:043e \
\:0448\:0430\:0431\:043b\:043e\:043d\:0430 \:0441 \:043e\:0434\:043d\:043e\
\:0439 \:0438 \:0442\:043e\:0439 \:0436\:0435 \:043f\:043e\:0437\:0438\:0446\
\:0438\:0438, \:043f\:0435\:0440\:0435\:0434 \:0442\:0435\:043c \:043a\:0430\
\:043a \:043f\:0435\:0440\:0435\:0439\:0442\:0438 \:043a \:0441\:043b\:0435\
\:0434\:0443\:044e\:0449\:0435\:043c\:0443 \:0441\:0438\:043c\:0432\:043e\
\:043b\:0443."
}], "MathCaption",
 CellTags->"b:0.4.3",
 CellID->627314046],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringCases", "[", 
  RowBox[{"\"\<(a(b)c(d)\>\"", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Shortest", "[", 
      RowBox[{"\"\<(\>\"", "~~", "__", "~~", "\"\<)\>\""}], "]"}], ",", 
     RowBox[{"Shortest", "[", 
      RowBox[{"\"\<(\>\"", "~~", "__", "~~", "\"\<(\>\""}], "]"}]}], "}"}], 
   ",", 
   RowBox[{"Overlaps", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"b:0.4.3",
 CellLabel->"In[63]:=",
 CellID->87536172],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"(a(b)\"\>", ",", "\<\"(a(\"\>", ",", "\<\"(b)\"\>", 
   ",", "\<\"(b)c(\"\>", ",", "\<\"(d)\"\>"}], "}"}]], "Output",
 ImageSize->{195, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.4.3",
 CellLabel->"Out[63]=",
 CellID->71742834]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringCases", "[", 
  RowBox[{"\"\<(a(b)c(d)\>\"", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Shortest", "[", 
      RowBox[{"\"\<(\>\"", "~~", "__", "~~", "\"\<)\>\""}], "]"}], ",", 
     RowBox[{"Shortest", "[", 
      RowBox[{"\"\<(\>\"", "~~", "__", "~~", "\"\<(\>\""}], "]"}]}], "}"}], 
   ",", 
   RowBox[{"Overlaps", "\[Rule]", "False"}]}], "]"}]], "Input",
 CellTags->"b:0.4.3",
 CellLabel->"In[64]:=",
 CellID->31744191],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"(a(b)\"\>", ",", "\<\"(d)\"\>"}], "}"}]], "Output",
 ImageSize->{85, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.4.3",
 CellLabel->"Out[64]=",
 CellID->8853572]
}, Open  ]],

Cell[TextData[{
 "\:041e\:0431\:0440\:0430\:0442\:0438\:0442\:0435 \:0432\:043d\:0438\:043c\
\:0430\:043d\:0438\:0435, \:0447\:0442\:043e, \:043d\:0435\:0441\:043c\:043e\
\:0442\:0440\:044f \:043d\:0430 \:043a\:0430\:0436\:0443\:0449\:0443\:044e\
\:0441\:044f \:044d\:043a\:0432\:0438\:0432\:0430\:043b\:0435\:043d\:0442\
\:043d\:043e\:0441\:0442\:044c, \:043f\:0440\:0438 \:043d\:0430\:0441\:0442\
\:0440\:043e\:0439\:043a\:0435 ",
 Cell[BoxData[
  RowBox[{
   TemplateBox[{Cell["Overlaps"],"paclet:ref/Overlaps"},
    "RefLink",
    BaseStyle->"InlineFormula"], "->", 
   TemplateBox[{Cell["True"],"paclet:ref/True"},
    "RefLink",
    BaseStyle->"InlineFormula"]}]], "InlineFormula"],
 ", \:0443\:043a\:0430\:0437\:0430\:043d\:0438\:0435 \:0441\:043f\:0438\:0441\
\:043a\:0430 \:0448\:0430\:0431\:043b\:043e\:043d\:043e\:0432 \:0438 \:0438\
\:0441\:043f\:043e\:043b\:044c\:0437\:043e\:0432\:0430\:043d\:0438\:0435 \
\:043e\:043f\:0435\:0440\:0430\:0442\:043e\:0440\:0430 \:0430\:043b\:044c\
\:0442\:0435\:0440\:043d\:0430\:0442\:0438\:0432\:044b (",
 Cell[BoxData["|"], "InlineFormula"],
 ") \:043c\:043e\:0433\:0443\:0442 \:0434\:0430\:0442\:044c \
\:0440\:0430\:0437\:043d\:044b\:0435 \:0440\:0435\:0437\:0443\:043b\:044c\
\:0442\:0430\:0442\:044b. "
}], "MathCaption",
 CellTags->"b:0.4.3",
 CellID->1005472710],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringCases", "[", 
  RowBox[{"\"\<ab\>\"", ",", 
   RowBox[{"{", 
    RowBox[{"_", ",", "__"}], "}"}], ",", 
   RowBox[{"Overlaps", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"b:0.4.3",
 CellLabel->"In[65]:=",
 CellID->168142260],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"a\"\>", ",", "\<\"ab\"\>", ",", "\<\"b\"\>", 
   ",", "\<\"b\"\>"}], "}"}]], "Output",
 ImageSize->{86, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.4.3",
 CellLabel->"Out[65]=",
 CellID->238296370]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringCases", "[", 
  RowBox[{"\"\<ab\>\"", ",", 
   RowBox[{"_", "|", "__"}], ",", 
   RowBox[{"Overlaps", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellTags->"b:0.4.3",
 CellLabel->"In[66]:=",
 CellID->42485134],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"a\"\>", ",", "\<\"b\"\>"}], "}"}]], "Output",
 ImageSize->{43, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.4.3",
 CellLabel->"Out[66]=",
 CellID->252851274]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["StringPosition", "Subsection",
 CellTags->{"c:10", "b:0.4.4"},
 CellID->363493082],

Cell[TextData[{
 "\:0424\:0443\:043d\:043a\:0446\:0438\:044f ",
 Cell[BoxData[
  TemplateBox[{Cell["StringPosition"],"paclet:ref/StringPosition"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " \:0440\:0430\:0431\:043e\:0442\:0430\:0435\:0442 \:0442\:0430\:043a \:0436\
\:0435, \:043a\:0430\:043a ",
 Cell[BoxData[
  TemplateBox[{Cell["StringCases"],"paclet:ref/StringCases"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 ", \:0437\:0430 \:0438\:0441\:043a\:043b\:044e\:0447\:0435\:043d\:0438\:0435\
\:043c \:0442\:043e\:0433\:043e, \:0447\:0442\:043e \:043e\:043d\:0430 \:0432\
\:043e\:0437\:0432\:0440\:0430\:0449\:0430\:0435\:0442 \:043f\:043e\:0437\
\:0438\:0446\:0438\:0438 \:043d\:0430\:0439\:0434\:0435\:043d\:043d\:044b\
\:0445 \:0441\:0443\:0431\:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442\
\:043e\:0432, \:0441\:043e\:043e\:0442\:0432\:0435\:0442\:0441\:0442\:0432\
\:0443\:044e\:0449\:0438\:0445 \:0448\:0430\:0431\:043b\:043e\:043d\:0443."
}], "MathCaption",
 CellTags->"b:0.4.4",
 CellID->3234460],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringPosition", "[", 
  RowBox[{"\"\<a1b2a26d15a42\>\"", ",", 
   RowBox[{"\"\<a\>\"", "~~", "_"}]}], "]"}]], "Input",
 CellTags->"b:0.4.4",
 CellLabel->"In[67]:=",
 CellID->175418910],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"11", ",", "12"}], "}"}]}], "}"}]], "Output",
 ImageSize->{171, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.4.4",
 CellLabel->"Out[67]=",
 CellID->480693168]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"StringTake", "[", 
    RowBox[{"\"\<a1b2a26d15a42\>\"", ",", "#"}], "]"}], "&"}], "/@", 
  "%"}]], "Input",
 CellTags->"b:0.4.4",
 CellLabel->"In[68]:=",
 CellID->352798794],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"a1\"\>", ",", "\<\"a2\"\>", ",", "\<\"a4\"\>"}], 
  "}"}]], "Output",
 ImageSize->{82, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.4.4",
 CellLabel->"Out[68]=",
 CellID->69188359]
}, Open  ]],

Cell[TextData[{
 "\:041f\:043e \:0443\:043c\:043e\:043b\:0447\:0430\:043d\:0438\:044e, \:043e\
\:043f\:0446\:0438\:044f ",
 Cell[BoxData[
  TemplateBox[{Cell["Overlaps"],"paclet:ref/Overlaps"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " \:0438\:043c\:0435\:0435\:0442 \:043d\:0430\:0441\:0442\:0440\:043e\:0439\
\:043a\:0443 ",
 Cell[BoxData[
  TemplateBox[{Cell["True"],"paclet:ref/True"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " (\:0441\:043c. \
\:043f\:0440\:0435\:0434\:044b\:0434\:0443\:0449\:0438\:0439 \:0440\:0430\
\:0437\:0434\:0435\:043b \:0434\:043b\:044f \:043f\:043e\:043b\:0443\:0447\
\:0435\:043d\:0438\:044f \:0431\:043e\:043b\:0435\:0435 \:0434\:0435\:0442\
\:0430\:043b\:044c\:043d\:043e\:0439 \:0438\:043d\:0444\:043e\:0440\:043c\
\:0430\:0446\:0438\:0438 \:043f\:043e \:044d\:0442\:043e\:0439 \:043e\:043f\
\:0446\:0438\:0438)."
}], "MathCaption",
 CellTags->"b:0.4.4",
 CellID->771123683],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringPosition", "[", 
  RowBox[{"\"\<(a(b)c(d)\>\"", ",", 
   RowBox[{"Shortest", "[", 
    RowBox[{"\"\<(\>\"", "~~", "__", "~~", "\"\<)\>\""}], "]"}]}], 
  "]"}]], "Input",
 CellTags->"b:0.4.4",
 CellLabel->"In[69]:=",
 CellID->227693171],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7", ",", "9"}], "}"}]}], "}"}]], "Output",
 ImageSize->{157, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.4.4",
 CellLabel->"Out[69]=",
 CellID->177581636]
}, Open  ]],

Cell["\<\
\:041e\:0431\:0440\:0430\:0442\:0438\:0442\:0435 \:0432\:043d\:0438\:043c\
\:0430\:043d\:0438\:0435, \:0447\:0442\:043e \:0434\:0430\:0436\:0435 \:043f\
\:0443\:0441\:0442\:044b\:0435 \:0442\:0435\:043a\:0441\:0442\:043e\:0432\
\:044b\:0435 \:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442\:044b \:043c\
\:043e\:0433\:0443\:0442 \:0441\:043e\:043e\:0442\:0432\:0435\:0442\:0441\
\:0442\:0432\:043e\:0432\:0430\:0442\:044c \:0448\:0430\:0431\:043b\:043e\
\:043d\:0443.\
\>", "MathCaption",
 CellTags->"b:0.4.4",
 CellID->141395505],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringPosition", "[", 
  RowBox[{"\"\<abc\>\"", ",", "___"}], "]"}]], "Input",
 CellTags->"b:0.4.4",
 CellLabel->"In[70]:=",
 CellID->695066864],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "3"}], "}"}]}], "}"}]], "Output",
 ImageSize->{207, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.4.4",
 CellLabel->"Out[70]=",
 CellID->130484574]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["StringCount", "Subsection",
 CellTags->{"c:11", "b:0.4.5"},
 CellID->401719377],

Cell[TextData[{
 "\:0424\:0443\:043d\:043a\:0446\:0438\:044f ",
 Cell[BoxData[
  TemplateBox[{Cell["StringCount"],"paclet:ref/StringCount"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " \:0432\:043e\:0437\:0432\:0440\:0430\:0449\:0430\:0435\:0442 \:043a\:043e\
\:043b\:0438\:0447\:0435\:0441\:0442\:0432\:043e \:0441\:043e\:043e\:0442\
\:0432\:0435\:0442\:0441\:0442\:0432\:0443\:044e\:0449\:0438\:0445 \:0448\
\:0430\:0431\:043b\:043e\:043d\:0443 \:0441\:0443\:0431\:0444\:0440\:0430\
\:0433\:043c\:0435\:043d\:0442\:043e\:0432 (\:043a\:043e\:0442\:043e\:0440\
\:044b\:0435 \:043c\:043e\:0433\:0443\:0442 \:0431\:044b\:0442\:044c \:043d\
\:0430\:0439\:0434\:0435\:043d\:044b \:0444\:0443\:043d\:043a\:0446\:0438\
\:044f\:043c\:0438 ",
 Cell[BoxData[
  TemplateBox[{Cell["StringPosition"],"paclet:ref/StringPosition"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " \:0438\:043b\:0438 ",
 Cell[BoxData[
  TemplateBox[{Cell["StringCases"],"paclet:ref/StringCases"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 "). \:041e\:043d\:0430 \:043f\:043e\:043b\:0435\:0437\:043d\:0430 \:0432 \
\:0441\:043b\:0443\:0447\:0430\:0435 \:043d\:0430\:043b\:0438\:0447\:0438\
\:044f \:0431\:043e\:043b\:044c\:0448\:043e\:0433\:043e \:043a\:043e\:043b\
\:0438\:0447\:0435\:0441\:0442\:0432\:0430 \:0441\:043e\:0432\:043f\:0430\
\:0434\:0435\:043d\:0438\:0439, \:0433\:0434\:0435 \:043f\:043e\:0442\:0440\
\:0435\:0431\:043d\:043e\:0441\:0442\:044c \:0432 \:043f\:0430\:043c\:044f\
\:0442\:0438, \:0434\:043b\:044f \:0445\:0440\:0430\:043d\:0435\:043d\:0438\
\:044f \:0432\:0441\:0435\:0445 \:043d\:0430\:0439\:0434\:0435\:043d\:043d\
\:044b\:0445 \:0441\:0443\:0431\:0444\:0440\:0430\:0433\:043c\:0435\:043d\
\:0442\:043e\:0432, \:043c\:043e\:0436\:0435\:0442 \:043f\:0440\:0435\:0432\
\:044b\:0441\:0438\:0442\:044c \:0432\:043e\:0437\:043c\:043e\:0436\:043d\
\:043e\:0441\:0442\:0438 \:0441\:0438\:0441\:0442\:0435\:043c\:044b."
}], "MathCaption",
 CellTags->"b:0.4.5",
 CellID->771573730],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringCount", "[", 
  RowBox[{"\"\<abaababba\>\"", ",", 
   RowBox[{"\"\<a\>\"", "~~", 
    RowBox[{"___", "~~", "\"\<b\>\""}]}], ",", 
   RowBox[{"Overlaps", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellTags->"b:0.4.5",
 CellLabel->"In[71]:=",
 CellID->175837266],

Cell[BoxData["12"], "Output",
 ImageSize->{18, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.4.5",
 CellLabel->"Out[71]=",
 CellID->20751351]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"StringCases", "[", 
   RowBox[{"\"\<abaababba\>\"", ",", 
    RowBox[{"\"\<a\>\"", "~~", 
     RowBox[{"___", "~~", "\"\<b\>\""}]}], ",", 
    RowBox[{"Overlaps", "\[Rule]", "All"}]}], "]"}], "//", 
  "Length"}]], "Input",
 CellTags->"b:0.4.5",
 CellLabel->"In[72]:=",
 CellID->16340890],

Cell[BoxData["12"], "Output",
 ImageSize->{18, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.4.5",
 CellLabel->"Out[72]=",
 CellID->993559588]
}, Open  ]],

Cell[TextData[{
 "\:041e\:0431\:0440\:0430\:0442\:0438\:0442\:0435 \:0432\:043d\:0438\:043c\
\:0430\:043d\:0438\:0435, \:0447\:0442\:043e, \:0434\:043b\:044f \:0444\:0443\
\:043d\:043a\:0446\:0438\:0438 ",
 Cell[BoxData[
  TemplateBox[{Cell["StringCount"],"paclet:ref/StringCount"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 ", \:043e\:043f\:0446\:0438\:044f ",
 Cell[BoxData[
  TemplateBox[{Cell["Overlaps"],"paclet:ref/Overlaps"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " \:0438\:043c\:0435\:0435\:0442 \:043d\:0430\:0441\:0442\:0440\:043e\:0439\
\:043a\:0443 ",
 Cell[BoxData[
  TemplateBox[{Cell["False"],"paclet:ref/False"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " \:043f\:043e \:0443\:043c\:043e\:043b\:0447\:0430\:043d\:0438\:044e. "
}], "Text",
 CellTags->"b:0.4.5",
 CellID->12491824]
}, Open  ]],

Cell[CellGroupData[{

Cell["StringReplace", "Subsection",
 CellTags->{"c:12", "b:0.4.6"},
 CellID->1274428],

Cell[TextData[{
 "\:0424\:0443\:043d\:043a\:0446\:0438\:044f ",
 Cell[BoxData[
  TemplateBox[{Cell["StringReplace"],"paclet:ref/StringReplace"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " \:0438\:0441\:043f\:043e\:043b\:044c\:0437\:0443\:0435\:0442\:0441\:044f \
\:0434\:043b\:044f \:0437\:0430\:043c\:0435\:043d\:044b \:0441\:0443\:0431\
\:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442\:043e\:0432, \:0441\:043e\
\:043e\:0442\:0432\:0435\:0442\:0441\:0442\:0432\:0443\:044e\:0449\:0438\:0445\
 \:0437\:0430\:0434\:0430\:043d\:043d\:043e\:043c\:0443 \:0448\:0430\:0431\
\:043b\:043e\:043d\:0443."
}], "MathCaption",
 CellTags->"b:0.4.6",
 CellID->45121066],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringReplace", "[", 
  RowBox[{"\"\<abcde\>\"", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"\"\<a\>\"", "\[Rule]", "\"\<A\>\""}], ",", 
     RowBox[{"\"\<cd\>\"", "\[Rule]", "\"\<XX\>\""}]}], "}"}]}], 
  "]"}]], "Input",
 CellTags->"b:0.4.6",
 CellLabel->"In[73]:=",
 CellID->67067787],

Cell[BoxData["\<\"AbXXe\"\>"], "Output",
 ImageSize->{39, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.4.6",
 CellLabel->"Out[73]=",
 CellID->72659497]
}, Open  ]],

Cell[TextData[{
 "\:0412\:043c\:0435\:0441\:0442\:043e \:0442\:0435\:043a\:0441\:0442\:043e\
\:0432\:044b\:0445 \:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442\:043e\
\:0432, \:0432 \:043b\:0435\:0432\:043e\:0439 \:0447\:0430\:0441\:0442\:0438 \
\:043f\:0440\:0430\:0432\:0438\:043b \:043f\:0440\:0435\:043e\:0431\:0440\
\:0430\:0437\:043e\:0432\:0430\:043d\:0438\:044f \:043c\:043e\:0433\:0443\
\:0442 \:0438\:0441\:043f\:043e\:043b\:044c\:0437\:043e\:0432\:0430\:0442\
\:044c\:0441\:044f \:0438\:043c\:0435\:043d\:043e\:0432\:0430\:043d\:043d\
\:044b\:0435 \:0448\:0430\:0431\:043b\:043e\:043d\:044b. \:041e\:0431\:0440\
\:0430\:0442\:0438\:0442\:0435 \:0432\:043d\:0438\:043c\:0430\:043d\:0438\
\:0435, \:0447\:0442\:043e, \:0434\:0430\:0431\:044b \:0438\:0437\:0431\:0435\
\:0436\:0430\:0442\:044c \:043f\:0440\:0435\:0436\:0434\:0435\:0432\:0440\
\:0435\:043c\:0435\:043d\:043d\:043e\:0433\:043e \:0432\:044b\:0447\:0438\
\:0441\:043b\:0435\:043d\:0438\:044f, \:0438\:0441\:043f\:043e\:043b\:044c\
\:0437\:0443\:0435\:0442\:0441\:044f \:043e\:0442\:043b\:043e\:0436\:0435\
\:043d\:043d\:043e\:0435 \:043f\:0440\:0430\:0432\:0438\:043b\:043e ",
 Cell[BoxData[
  TemplateBox[{Cell["RuleDelayed"],"paclet:ref/RuleDelayed"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " (",
 Cell[BoxData["\[RuleDelayed]"], "InlineFormula"],
 ")."
}], "MathCaption",
 CellTags->"b:0.4.6",
 CellID->21617589],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringReplace", "[", 
  RowBox[{"\"\<this is a test\>\"", ",", 
   RowBox[{
    RowBox[{"x", ":", 
     RowBox[{"WordCharacter", ".."}]}], "\[RuleDelayed]", 
    RowBox[{"StringReverse", "[", "x", "]"}]}]}], "]"}]], "Input",
 CellTags->"b:0.4.6",
 CellLabel->"In[74]:=",
 CellID->801931404],

Cell[BoxData["\<\"siht si a tset\"\>"], "Output",
 ImageSize->{102, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.4.6",
 CellLabel->"Out[74]=",
 CellID->789854925]
}, Open  ]],

Cell[TextData[{
 "\:041f\:0440\:0438 \:0438\:0441\:043f\:043e\:043b\:044c\:0437\:043e\:0432\
\:0430\:043d\:0438\:0438 \:0440\:0435\:0433\:0443\:043b\:044f\:0440\:043d\
\:044b\:0445 \:0432\:044b\:0440\:0430\:0436\:0435\:043d\:0438\:0439, \:043d\
\:0435 \:043b\:0438\:0448\:043d\:0438\:043c \:0431\:0443\:0434\:0435\:0442 \
\:043f\:043e\:043c\:043d\:0438\:0442\:044c, \:0447\:0442\:043e \:0440\:0430\
\:0441\:043f\:043e\:043b\:043e\:0436\:0435\:043d\:043d\:043e\:0435 \:0432 \
\:043f\:0440\:0430\:0432\:043e\:0439 \:0447\:0430\:0441\:0442\:0438 \:043f\
\:0440\:0430\:0432\:0438\:043b\:0430 \:0432\:044b\:0440\:0430\:0436\:0435\
\:043d\:0438\:0435 ",
 Cell[BoxData["\<\"$0\"\>"], "InlineFormula"],
 " \:0443\:043a\:0430\:0437\:044b\:0432\:0430\:0435\:0442 \:043d\:0430 \:0446\
\:0435\:043b\:044b\:0439 \:0441\:0443\:0431\:0444\:0440\:0430\:0433\:043c\
\:0435\:043d\:0442, \:0441\:043e\:043e\:0442\:0432\:0435\:0442\:0441\:0442\
\:0432\:0443\:044e\:0449\:0438\:0439 \:0448\:0430\:0431\:043b\:043e\:043d\
\:0443."
}], "MathCaption",
 CellTags->"b:0.4.6",
 CellID->150245402],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringReplace", "[", 
  RowBox[{"\"\<this is a test\>\"", ",", 
   RowBox[{
    RowBox[{"RegularExpression", "[", "\"\<\\\\w+\>\"", "]"}], 
    "\[RuleDelayed]", 
    RowBox[{"StringReverse", "[", "\"\<$0\>\"", "]"}]}]}], "]"}]], "Input",
 CellTags->"b:0.4.6",
 CellLabel->"In[75]:=",
 CellID->85246728],

Cell[BoxData["\<\"siht si a tset\"\>"], "Output",
 ImageSize->{102, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.4.6",
 CellLabel->"Out[75]=",
 CellID->264349508]
}, Open  ]],

Cell["\<\
\:041c\:043e\:0436\:043d\:043e \:043e\:0433\:0440\:0430\:043d\:0438\:0447\
\:0438\:0442\:044c \:043a\:043e\:043b\:0438\:0447\:0435\:0441\:0442\:0432\
\:043e \:0432\:044b\:043f\:043e\:043b\:043d\:044f\:0435\:043c\:044b\:0445 \
\:0437\:0430\:043c\:0435\:043d, \:0443\:043a\:0430\:0437\:0430\:0432 \:0442\
\:0440\:0435\:0442\:0438\:0439 \:0430\:0440\:0433\:0443\:043c\:0435\:043d\
\:0442.\
\>", "MathCaption",
 CellTags->"b:0.4.6",
 CellID->203144771],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringReplace", "[", 
  RowBox[{"\"\<this is a test\>\"", ",", 
   RowBox[{
    RowBox[{"x", ":", 
     RowBox[{"WordCharacter", ".."}]}], "\[RuleDelayed]", 
    RowBox[{"StringReverse", "[", "x", "]"}]}], ",", "1"}], "]"}]], "Input",
 CellTags->"b:0.4.6",
 CellLabel->"In[76]:=",
 CellID->17461363],

Cell[BoxData["\<\"siht is a test\"\>"], "Output",
 ImageSize->{102, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.4.6",
 CellLabel->"Out[76]=",
 CellID->216313918]
}, Open  ]],

Cell[TextData[{
 "\:0421\:0442\:043e\:0438\:0442 \:0443\:043f\:043e\:043c\:044f\:043d\:0443\
\:0442\:044c, \:0447\:0442\:043e \:0437\:0430\:043c\:0435\:043d\:044f\:044e\
\:0449\:0438\:0439 \:043e\:0431\:044a\:0435\:043a\:0442 \:043d\:0435 \:043e\
\:0431\:044f\:0437\:0430\:0442\:0435\:043b\:044c\:043d\:043e \:0434\:043e\
\:043b\:0436\:0435\:043d \:0431\:044b\:0442\:044c \:0442\:0435\:043a\:0441\
\:0442\:043e\:0432\:044b\:043c \:0444\:0440\:0430\:0433\:043c\:0435\:043d\
\:0442\:043e\:043c. \:0418 \:0435\:0441\:043b\:0438 \:0440\:0435\:0437\:0443\
\:043b\:044c\:0442\:0430\:0442 \:0437\:0430\:043c\:0435\:043d\:044b \:043d\
\:0435 \:044f\:0432\:043b\:044f\:0435\:0442\:0441\:044f \:0431\:043e\:043b\
\:0435\:0435 \:0442\:0435\:043a\:0441\:0442\:043e\:0432\:043e\:0439 \:0441\
\:0442\:0440\:043e\:043a\:043e\:0439, \:043e\:043d \:0432\:043e\:0437\:0432\
\:0440\:0430\:0449\:0430\:0435\:0442\:0441\:044f \:0432 \:0432\:0438\:0434\
\:0435 \:0432\:044b\:0440\:0430\:0436\:0435\:043d\:0438\:044f ",
 Cell[BoxData[
  TemplateBox[{Cell["StringExpression"],"paclet:ref/StringExpression"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 "."
}], "MathCaption",
 CellTags->"b:0.4.6",
 CellID->131051894],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringReplace", "[", 
  RowBox[{"\"\<some <b>bold</b> and <i>italics</i>.\>\"", ",", 
   RowBox[{
    RowBox[{"Shortest", "[", 
     RowBox[{"\"\<<\>\"", "~~", "x___", "~~", "\"\<>\>\""}], "]"}], 
    "\[RuleDelayed]", 
    RowBox[{"Tag", "[", "x", "]"}]}]}], "]"}]], "Input",
 CellTags->"b:0.4.6",
 CellLabel->"In[77]:=",
 CellID->459415768],

Cell[BoxData[
 RowBox[{"\<\"some \"\>", "~~", 
  RowBox[{"Tag", "[", "\<\"b\"\>", "]"}], "~~", "\<\"bold\"\>", "~~", 
  RowBox[{"Tag", "[", "\<\"/b\"\>", "]"}], "~~", "\<\" and \"\>", "~~", 
  RowBox[{"Tag", "[", "\<\"i\"\>", "]"}], "~~", "\<\"italics\"\>", "~~", 
  RowBox[{"Tag", "[", "\<\"/i\"\>", "]"}], "~~", "\<\".\"\>"}]], "Output",
 ImageSize->{516, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.4.6",
 CellLabel->"Out[77]=",
 CellID->29452506]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullForm", "[", "%", "]"}]], "Input",
 CellTags->"b:0.4.6",
 CellLabel->"In[78]:=",
 CellID->28871706],

Cell[BoxData[
 TagBox[
  StyleBox[
   RowBox[{"StringExpression", "[", 
    RowBox[{"\"\<some \>\"", ",", 
     RowBox[{"Tag", "[", "\"\<b\>\"", "]"}], ",", "\"\<bold\>\"", ",", 
     RowBox[{"Tag", "[", "\"\</b\>\"", "]"}], ",", "\"\< and \>\"", ",", 
     RowBox[{"Tag", "[", "\"\<i\>\"", "]"}], ",", "\"\<italics\>\"", ",", 
     RowBox[{"Tag", "[", "\"\</i\>\"", "]"}], ",", "\"\<.\>\""}], "]"}],
   ShowSpecialCharacters->False,
   ShowStringCharacters->True,
   NumberMarks->True],
  FullForm]], "Output",
 ImageSize->{389, 33},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.4.6",
 CellLabel->"Out[78]//FullForm=",
 CellID->18384563]
}, Open  ]],

Cell[TextData[{
 "\:0412\:0441\:0435 \:0435\:0449\:0435 \:0441\:0443\:0449\:0435\:0441\:0442\
\:0432\:0443\:0435\:0442 \:043e\:0433\:0440\:0430\:043d\:0438\:0447\:0435\
\:043d\:043d\:0430\:044f \:043f\:043e\:0434\:0434\:0435\:0440\:0436\:043a\
\:0430 \:0434\:043b\:044f \:0438\:0441\:043f\:043e\:043b\:044c\:0437\:043e\
\:0432\:0430\:043d\:0438\:044f \:0441\:0442\:0430\:0440\:043e\:0439 \:043e\
\:043f\:0446\:0438\:0438 \:043c\:0435\:0442\:0430\:0441\:0438\:043c\:0432\
\:043e\:043b\:043e\:0432  ",
 Cell[BoxData["MetaCharacters"], "InlineFormula"],
 " \:0432 \:0441\:043e\:0447\:0435\:0442\:0430\:043d\:0438\:0438 \:0441 \
\:043e\:0431\:044b\:0447\:043d\:044b\:043c\:0438 \:0448\:0430\:0431\:043b\
\:043e\:043d\:0430\:043c\:0438 \:0434\:043b\:044f \:0442\:0435\:043a\:0441\
\:0442\:043e\:0432\:044b\:0445 \:0444\:0440\:0430\:0433\:043c\:0435\:043d\
\:0442\:043e\:0432, \:043d\:043e \:044d\:0442\:0430 \:043e\:043f\:0446\:0438\
\:044f \:0441\:0447\:0438\:0442\:0430\:0435\:0442\:0441\:044f \:0443\:0441\
\:0442\:0430\:0440\:0435\:0432\:0448\:0435\:0439 \:0438 \:0435\:0435 \:0441\
\:043b\:0435\:0434\:0443\:0435\:0442 \:0438\:0437\:0431\:0435\:0433\:0430\
\:0442\:044c."
}], "Text",
 CellTags->"b:0.4.6",
 CellID->623263418]
}, Open  ]],

Cell[CellGroupData[{

Cell["StringReplaceList", "Subsection",
 CellTags->{"c:13", "b:0.4.7"},
 CellID->239124212],

Cell[TextData[{
 "\:0424\:0443\:043d\:043a\:0446\:0438\:044f ",
 Cell[BoxData[
  TemplateBox[{Cell["StringReplaceList"],"paclet:ref/StringReplaceList"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " \:0432\:043e\:0437\:0432\:0440\:0430\:0449\:0430\:0435\:0442 \:0441\:043f\
\:0438\:0441\:043e\:043a \:0442\:0435\:043a\:0441\:0442\:043e\:0432\:044b\
\:0445 \:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442\:043e\:0432, \:0433\
\:0434\:0435 ",
 StyleBox["\:043e\:0434\:043d\:0430",
  FontSlant->"Italic"],
 " \:043e\:043f\:0435\:0440\:0430\:0446\:0438\:044f \:0437\:0430\:043c\:0435\
\:043d\:044b \:0431\:044b\:043b\:0430 \:0432\:044b\:043f\:043e\:043b\:043d\
\:0435\:043d\:0430 \:0432\:0441\:0435\:043c\:0438 \:0432\:043e\:0437\:043c\
\:043e\:0436\:043d\:044b\:043c\:0438 \:0441\:043f\:043e\:0441\:043e\:0431\
\:0430\:043c\:0438."
}], "MathCaption",
 CellTags->"b:0.4.7",
 CellID->758815075],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringReplaceList", "[", 
  RowBox[{"\"\<abaac\>\"", ",", 
   RowBox[{
    RowBox[{"\"\<a\>\"", "~~", "x_"}], "\[RuleDelayed]", 
    RowBox[{"ToUpperCase", "[", "x", "]"}]}]}], "]"}]], "Input",
 CellTags->"b:0.4.7",
 CellLabel->"In[79]:=",
 CellID->34244212],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"Baac\"\>", ",", "\<\"abAc\"\>", ",", "\<\"abaC\"\>"}], 
  "}"}]], "Output",
 ImageSize->{124, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.4.7",
 CellLabel->"Out[79]=",
 CellID->76378783]
}, Open  ]],

Cell["\<\
\:0415\:0441\:043b\:0438 \:0432\:0432\:043e\:0434\:0438\:043c\:044b\:043c\
\:0438 \:0438\:0441\:0445\:043e\:0434\:043d\:044b\:043c\:0438 \:0434\:0430\
\:043d\:043d\:044b\:043c\:0438 \:044f\:0432\:043b\:044f\:0435\:0442\:0441\
\:044f \:0441\:043f\:0438\:0441\:043e\:043a \:0442\:0435\:043a\:0441\:0442\
\:043e\:0432\:044b\:0445 \:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442\
\:043e\:0432, \:0440\:0435\:0437\:0443\:043b\:044c\:0442\:0430\:0442 \:043d\
\:0430 \:0432\:044b\:0445\:043e\:0434\:0435 \:0431\:0443\:0434\:0435\:0442 \
\:043f\:0440\:0435\:0434\:0441\:0442\:0430\:0432\:043b\:0435\:043d \:0432 \
\:0432\:0438\:0434\:0435 \:0432\:043b\:043e\:0436\:0435\:043d\:043d\:043e\
\:0433\:043e \:0441\:043f\:0438\:0441\:043a\:0430.\
\>", "MathCaption",
 CellTags->"b:0.4.7",
 CellID->578481874],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringReplaceList", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\"\<abaac\>\"", ",", "\"\<baaba\>\""}], "}"}], ",", 
   RowBox[{
    RowBox[{"\"\<a\>\"", "~~", "x_"}], "\[RuleDelayed]", 
    RowBox[{"ToUpperCase", "[", "x", "]"}]}]}], "]"}]], "Input",
 CellTags->"b:0.4.7",
 CellLabel->"In[80]:=",
 CellID->80963487],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"Baac\"\>", ",", "\<\"abAc\"\>", ",", "\<\"abaC\"\>"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"\<\"bAba\"\>", ",", "\<\"baBa\"\>"}], "}"}]}], "}"}]], "Output",
 ImageSize->{230, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.4.7",
 CellLabel->"Out[80]=",
 CellID->228987248]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["StringSplit", "Subsection",
 CellTags->{"c:14", "b:0.4.8"},
 CellID->343107939],

Cell[TextData[{
 "\:0424\:0443\:043d\:043a\:0446\:0438\:044f ",
 Cell[BoxData[
  TemplateBox[{Cell["StringSplit"],"paclet:ref/StringSplit"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " \:043f\:0440\:0438\:043c\:0435\:043d\:044f\:0435\:0442\:0441\:044f \:0434\
\:043b\:044f \:0440\:0430\:0437\:0431\:0438\:0432\:043a\:0438 \:0442\:0435\
\:043a\:0441\:0442\:043e\:0432\:043e\:0433\:043e \:0444\:0440\:0430\:0433\
\:043c\:0435\:043d\:0442\:0430 \:043d\:0430 \:043d\:0435\:0441\:043a\:043e\
\:043b\:044c\:043a\:043e \:0441\:0443\:0431\:0444\:0440\:0430\:0433\:043c\
\:0435\:043d\:0442\:043e\:0432, \:0432 \:0442\:0435\:0445 \:043c\:0435\:0441\
\:0442\:0430\:0445, \:0433\:0434\:0435 \:0440\:0430\:0437\:0434\:0435\:043b\
\:0438\:0442\:0435\:043b\:044c \:0441\:043e\:043e\:0442\:0432\:0435\:0442\
\:0441\:0442\:0432\:0443\:0435\:0442 \:0448\:0430\:0431\:043b\:043e\:043d\
\:0443. \:041f\:043e \:0443\:043c\:043e\:043b\:0447\:0430\:043d\:0438\:044e, \
\:0440\:0430\:0437\:0431\:0438\:0432\:043a\:0430 \:0432\:044b\:043f\:043e\
\:043b\:043d\:044f\:0435\:0442\:0441\:044f \:043f\:043e \:043f\:0440\:043e\
\:0431\:0435\:043b\:0430\:043c \:043c\:0435\:0436\:0434\:0443 \:0441\:043b\
\:043e\:0432\:0430\:043c\:0438 (\:043d\:0430\:0431\:043e\:0440\:0430\:043c\
\:0438 \:0441\:0438\:043c\:0432\:043e\:043b\:043e\:0432). "
}], "MathCaption",
 CellTags->"b:0.4.8",
 CellID->19737335],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringSplit", "[", "\"\<this is a test\>\"", "]"}]], "Input",
 CellTags->"b:0.4.8",
 CellLabel->"In[81]:=",
 CellID->20551734],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"this\"\>", ",", "\<\"is\"\>", ",", "\<\"a\"\>", 
   ",", "\<\"test\"\>"}], "}"}]], "Output",
 ImageSize->{128, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.4.8",
 CellLabel->"Out[81]=",
 CellID->713279886]
}, Open  ]],

Cell["\<\
\:041d\:0430\:043f\:0440\:0438\:043c\:0435\:0440, \:0447\:0442\:043e\:0431\
\:044b \:0440\:0430\:0437\:0431\:0438\:0442\:044c \:043e\:0431\:044b\:0447\
\:043d\:043e\:0435 \:043f\:0440\:0435\:0434\:043b\:043e\:0436\:0435\:043d\
\:0438\:0435 \:043d\:0430 \:0441\:043b\:043e\:0432\:0430, \:043f\:043e\:0442\
\:0440\:0435\:0431\:0443\:0435\:0442\:0441\:044f \:0434\:043e\:0431\:0430\
\:0432\:0438\:0442\:044c \:0437\:043d\:0430\:043a\:0438 \:043f\:0440\:0435\
\:043f\:0438\:043d\:0430\:043d\:0438\:044f \:0432 \:0441\:043f\:0438\:0441\
\:043e\:043a \:0440\:0430\:0437\:0434\:0435\:043b\:0438\:0442\:0435\:043b\
\:0435\:0439.\
\>", "MathCaption",
 CellTags->"b:0.4.8",
 CellID->27447488],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringSplit", "[", 
  RowBox[{"\"\<A sentence: with commas, semicolons; etc...!?\>\"", ",", 
   RowBox[{
    RowBox[{"Characters", "[", "\"\<:,;.!? \>\"", "]"}], ".."}]}], 
  "]"}]], "Input",
 CellTags->"b:0.4.8",
 CellLabel->"In[82]:=",
 CellID->107169258],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"A\"\>", ",", "\<\"sentence\"\>", ",", "\<\"with\"\>", 
   ",", "\<\"commas\"\>", ",", "\<\"semicolons\"\>", ",", "\<\"etc\"\>"}], 
  "}"}]], "Output",
 ImageSize->{297, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.4.8",
 CellLabel->"Out[82]=",
 CellID->176497510]
}, Open  ]],

Cell["\<\
\:041f\:043e \:0443\:043c\:043e\:043b\:0447\:0430\:043d\:0438\:044e, \:043f\
\:0443\:0441\:0442\:044b\:0435 \:0441\:0443\:0431\:0444\:0440\:0430\:0433\
\:043c\:0435\:043d\:0442\:044b, \:0432 \:043d\:0430\:0447\:0430\:043b\:0435 \
\:0438 \:0432 \:043a\:043e\:043d\:0446\:0435 \:043f\:043e\:043b\:0443\:0447\
\:0435\:043d\:043d\:043e\:0433\:043e \:0440\:0435\:0437\:0443\:043b\:044c\
\:0442\:0430\:0442\:0430, \:0443\:0434\:0430\:043b\:044f\:044e\:0442\:0441\
\:044f.\
\>", "MathCaption",
 CellTags->"b:0.4.8",
 CellID->60098082],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringSplit", "[", 
  RowBox[{"\"\<:a:b:c:\>\"", ",", "\"\<:\>\""}], "]"}]], "Input",
 CellTags->"b:0.4.8",
 CellLabel->"In[83]:=",
 CellID->72110840],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"a\"\>", ",", "\<\"b\"\>", ",", "\<\"c\"\>"}], "}"}]], "Output",
 ImageSize->{61, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.4.8",
 CellLabel->"Out[83]=",
 CellID->362458191]
}, Open  ]],

Cell[TextData[{
 "\:041e\:043d\:0438 \:043c\:043e\:0433\:0443\:0442 \:0431\:044b\:0442\:044c \
\:0432\:043a\:043b\:044e\:0447\:0435\:043d\:044b \:0432 \:0440\:0435\:0437\
\:0443\:043b\:044c\:0442\:0430\:0442, \:0435\:0441\:043b\:0438 \:0443\:043a\
\:0430\:0437\:0430\:0442\:044c ",
 Cell[BoxData[
  TemplateBox[{Cell["All"],"paclet:ref/All"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " \:0432 \:043a\:0430\:0447\:0435\:0441\:0442\:0432\:0435 \:0442\:0440\:0435\
\:0442\:044c\:0435\:0433\:043e \:0430\:0440\:0433\:0443\:043c\:0435\:043d\
\:0442\:0430."
}], "MathCaption",
 CellTags->"b:0.4.8",
 CellID->103751328],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringSplit", "[", 
  RowBox[{"\"\<:a:b:c:\>\"", ",", "\"\<:\>\"", ",", "All"}], "]"}]], "Input",
 CellTags->"b:0.4.8",
 CellLabel->"In[84]:=",
 CellID->460561670],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"\"\>", ",", "\<\"a\"\>", ",", "\<\"b\"\>", ",", "\<\"c\"\>", 
   ",", "\<\"\"\>"}], "}"}]], "Output",
 ImageSize->{83, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.4.8",
 CellLabel->"Out[84]=",
 CellID->236770642]
}, Open  ]],

Cell["\<\
\:0422\:0440\:0435\:0442\:0438\:043c \:0430\:0440\:0433\:0443\:043c\:0435\
\:043d\:0442\:043e\:043c \:043c\:043e\:0436\:0435\:0442 \:0431\:044b\:0442\
\:044c \:0442\:0430\:043a\:0436\:0435 \:0438 \:0447\:0438\:0441\:043b\:043e, \
\:0437\:0430\:0434\:0430\:044e\:0449\:0435\:0435 \:043c\:0430\:043a\:0441\
\:0438\:043c\:0430\:043b\:044c\:043d\:043e\:0435 \:043a\:043e\:043b\:0438\
\:0447\:0435\:0441\:0442\:0432\:043e \:0441\:0443\:0431\:0444\:0440\:0430\
\:0433\:043c\:0435\:043d\:0442\:043e\:0432, \:043d\:0430 \:043a\:043e\:0442\
\:043e\:0440\:044b\:0435 \:0440\:0430\:0437\:0431\:0438\:0432\:0430\:0435\
\:0442\:0441\:044f \:0438\:0441\:0445\:043e\:0434\:043d\:044b\:0439 \:0442\
\:0435\:043a\:0441\:0442\:043e\:0432\:044b\:0439 \:0444\:0440\:0430\:0433\
\:043c\:0435\:043d\:0442.\
\>", "MathCaption",
 CellTags->"b:0.4.8",
 CellID->656954062],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringSplit", "[", 
  RowBox[{"\"\<this is a test\>\"", ",", "Whitespace", ",", "2"}], 
  "]"}]], "Input",
 CellTags->"b:0.4.8",
 CellLabel->"In[85]:=",
 CellID->1019234],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"this\"\>", ",", "\<\"is a test\"\>"}], "}"}]], "Output",
 ImageSize->{120, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.4.8",
 CellLabel->"Out[85]=",
 CellID->14534217]
}, Open  ]],

Cell["\<\
\:0422\:0430\:043a \:0432\:044b\:043f\:043e\:043b\:043d\:044f\:0435\:0442\
\:0441\:044f \:0440\:0430\:0437\:0431\:0438\:0432\:043a\:0430 \:0442\:0435\
\:043a\:0441\:0442\:043e\:0432\:043e\:0433\:043e \:0444\:0440\:0430\:0433\
\:043c\:0435\:043d\:0442\:0430 \:043f\:043e \:043e\:0442\:0434\:0435\:043b\
\:044c\:043d\:044b\:043c \:0441\:0442\:0440\:043e\:043a\:0430\:043c.\
\>", "MathCaption",
 CellTags->"b:0.4.8",
 CellID->241434771],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringSplit", "[", 
  RowBox[{"\"\<line1\\nthis is line 2\\nline3\>\"", ",", "\"\<\\n\>\""}], 
  "]"}]], "Input",
 CellTags->"b:0.4.8",
 CellLabel->"In[86]:=",
 CellID->171055668],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"line1\"\>", ",", "\<\"this is line 2\"\>", 
   ",", "\<\"line3\"\>"}], "}"}]], "Output",
 ImageSize->{208, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.4.8",
 CellLabel->"Out[86]=",
 CellID->204773299]
}, Open  ]],

Cell[TextData[{
 "\:041c\:043e\:0436\:043d\:043e \:0442\:0430\:043a\:0436\:0435 \:0432\:044b\
\:043f\:043e\:043b\:043d\:0438\:0442\:044c \:0440\:0430\:0437\:0431\:0438\
\:0432\:043a\:0443 \:0441 \:0438\:0441\:043f\:043e\:043b\:044c\:0437\:043e\
\:0432\:0430\:043d\:0438\:0435\:043c \:0448\:0430\:0431\:043b\:043e\:043d\
\:043e\:0432, \:043e\:043f\:0440\:0435\:0434\:0435\:043b\:044f\:044e\:0449\
\:0438\:0445 \:043f\:043e\:0437\:0438\:0446\:0438\:044e, \:0442\:0430\:043a\
\:0438\:0445 \:043a\:0430\:043a ",
 Cell[BoxData[
  TemplateBox[{Cell["StartOfLine"],"paclet:ref/StartOfLine"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " (\:043d\:0430\:0447\:0430\:043b\:043e \
\:0441\:0442\:0440\:043e\:043a\:0438). \:041f\:0440\:0438 \:044d\:0442\:043e\
\:043c, \:0441\:0438\:043c\:0432\:043e\:043b\:044b \:043d\:043e\:0432\:043e\
\:0439 \:0441\:0442\:0440\:043e\:043a\:0438 \:0441\:043e\:0445\:0440\:0430\
\:043d\:044f\:044e\:0442\:0441\:044f \:0432 \:043f\:043e\:043b\:0443\:0447\
\:0430\:0435\:043c\:043e\:043c \:0440\:0435\:0437\:0443\:043b\:044c\:0442\
\:0430\:0442\:0435."
}], "MathCaption",
 CellTags->"b:0.4.8",
 CellID->590437369],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringSplit", "[", 
  RowBox[{"\"\<line1\\nthis is line 2\\nline3\>\"", ",", "StartOfLine"}], 
  "]"}]], "Input",
 CellTags->"b:0.4.8",
 CellLabel->"In[87]:=",
 CellID->4669335],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"line1\\n\"\>", ",", "\<\"this is line 2\\n\"\>", 
   ",", "\<\"line3\"\>"}], "}"}]], "Output",
 ImageSize->{113, 50},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.4.8",
 CellLabel->"Out[87]=",
 CellID->1024030217]
}, Open  ]],

Cell["\<\
\:0421\:043e\:0445\:0440\:0430\:043d\:0438\:0442\:044c \:0432 \:043f\:043e\
\:043b\:0443\:0447\:0430\:0435\:043c\:043e\:043c \:0440\:0435\:0437\:0443\
\:043b\:044c\:0442\:0430\:0442\:0435 \:0440\:0430\:0437\:0434\:0435\:043b\
\:0438\:0442\:0435\:043b\:044c\:043d\:044b\:0435 \:0437\:043d\:0430\:043a\
\:0438, \:043b\:0438\:0431\:043e \:0441\:043e\:0441\:0442\:0430\:0432\:043d\
\:044b\:0435 \:0447\:0430\:0441\:0442\:0438 \:0440\:0430\:0437\:0434\:0435\
\:043b\:0438\:0442\:0435\:043b\:0435\:0439, \:043c\:043e\:0436\:043d\:043e \
\:0441 \:043f\:043e\:043c\:043e\:0449\:044c\:044e \:043f\:0440\:0430\:0432\
\:0438\:043b\:0430 \:043f\:0440\:0435\:043e\:0431\:0440\:0430\:0437\:043e\
\:0432\:0430\:043d\:0438\:044f \:0432 \:043a\:0430\:0447\:0435\:0441\:0442\
\:0432\:0435 \:0432\:0442\:043e\:0440\:043e\:0433\:043e \:0430\:0440\:0433\
\:0443\:043c\:0435\:043d\:0442\:0430.\
\>", "MathCaption",
 CellTags->"b:0.4.8",
 CellID->11065132],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringSplit", "[", 
  RowBox[{"\"\<this is a test\>\"", ",", 
   RowBox[{"\"\< \>\"", "\[Rule]", "\"\< \>\""}]}], "]"}]], "Input",
 CellTags->"b:0.4.8",
 CellLabel->"In[88]:=",
 CellID->386084822],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"this\"\>", ",", "\<\" \"\>", ",", "\<\"is\"\>", 
   ",", "\<\" \"\>", ",", "\<\"a\"\>", ",", "\<\" \"\>", 
   ",", "\<\"test\"\>"}], "}"}]], "Output",
 ImageSize->{182, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.4.8",
 CellLabel->"Out[88]=",
 CellID->245134745]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringSplit", "[", 
  RowBox[{"\"\<this is a test\>\"", ",", 
   RowBox[{"\"\< \>\"", "\[Rule]", "\"\<:\>\""}]}], "]"}]], "Input",
 CellTags->"b:0.4.8",
 CellLabel->"In[89]:=",
 CellID->60902233],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"this\"\>", ",", "\<\":\"\>", ",", "\<\"is\"\>", 
   ",", "\<\":\"\>", ",", "\<\"a\"\>", ",", "\<\":\"\>", 
   ",", "\<\"test\"\>"}], "}"}]], "Output",
 ImageSize->{182, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.4.8",
 CellLabel->"Out[89]=",
 CellID->132373715]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringSplit", "[", 
  RowBox[{"\"\<the <tag1>first</tag1> and the <tag2>second</tag2>\>\"", ",", 
   RowBox[{"Shortest", "[", 
    RowBox[{"\"\<<\>\"", "~~", "__", "~~", "\"\<>\>\""}], "]"}]}], 
  "]"}]], "Input",
 CellTags->"b:0.4.8",
 CellLabel->"In[90]:=",
 CellID->73670271],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"the \"\>", ",", "\<\"first\"\>", ",", "\<\" and the \"\>", 
   ",", "\<\"second\"\>"}], "}"}]], "Output",
 ImageSize->{219, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.4.8",
 CellLabel->"Out[90]=",
 CellID->169972716]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringSplit", "[", 
  RowBox[{"\"\<the <tag1>first</tag1> and the <tag2>second</tag2>\>\"", ",", 
   RowBox[{
    RowBox[{"Shortest", "[", 
     RowBox[{"\"\<<\>\"", "~~", "x__", "~~", "\"\<>\>\""}], "]"}], 
    "\[RuleDelayed]", 
    RowBox[{"Tag", "[", "x", "]"}]}]}], "]"}]], "Input",
 CellTags->"b:0.4.8",
 CellLabel->"In[91]:=",
 CellID->153068299],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"the \"\>", ",", 
   RowBox[{"Tag", "[", "\<\"tag1\"\>", "]"}], ",", "\<\"first\"\>", ",", 
   RowBox[{"Tag", "[", "\<\"/tag1\"\>", "]"}], ",", "\<\" and the \"\>", ",", 
   RowBox[{"Tag", "[", "\<\"tag2\"\>", "]"}], ",", "\<\"second\"\>", ",", 
   RowBox[{"Tag", "[", "\<\"/tag2\"\>", "]"}]}], "}"}]], "Output",
 ImageSize->{529, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.4.8",
 CellLabel->"Out[91]=",
 CellID->41820933]
}, Open  ]],

Cell["\<\
\:041a\:0441\:0442\:0430\:0442\:0438, \:043c\:043e\:0436\:043d\:043e \:0437\
\:0430\:0434\:0430\:0442\:044c \:0441\:043f\:0438\:0441\:043e\:043a \:0438\
\:0437 \:0448\:0430\:0431\:043b\:043e\:043d\:043e\:0432 \:0438 \:043f\:0440\
\:0430\:0432\:0438\:043b \:043f\:0440\:0435\:043e\:0431\:0440\:0430\:0437\
\:043e\:0432\:0430\:043d\:0438\:044f; \:043f\:0440\:0438 \:044d\:0442\:043e\
\:043c, \:0440\:0430\:0437\:0434\:0435\:043b\:0438\:0442\:0435\:043b\:0438, \
\:0441\:043e\:0432\:043f\:0430\:0434\:0430\:044e\:0449\:0438\:0435 \:0441 \
\:0448\:0430\:0431\:043b\:043e\:043d\:0430\:043c\:0438, \:0431\:0443\:0434\
\:0443\:0442 \:0438\:0441\:043a\:043b\:044e\:0447\:0435\:043d\:044b \:0438\
\:0437 \:0432\:043e\:0437\:0432\:0440\:0430\:0449\:0430\:0435\:043c\:043e\
\:0433\:043e \:0440\:0435\:0437\:0443\:043b\:044c\:0442\:0430\:0442\:0430.\
\>", "MathCaption",
 CellTags->"b:0.4.8",
 CellID->307113028],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"StringSplit", "[", 
   RowBox[{"\"\<the <tag1>first</tag1> and the <tag2>second</tag2>\>\"", ",", 
    RowBox[{"{", 
     RowBox[{"Whitespace", ",", 
      RowBox[{
       RowBox[{"Shortest", "[", 
        RowBox[{"\"\<<\>\"", "~~", "x__", "~~", "\"\<>\>\""}], "]"}], 
       "\[RuleDelayed]", 
       RowBox[{"Tag", "[", "x", "]"}]}]}], "}"}]}], "]"}], "//", 
  "InputForm"}]], "Input",
 CellTags->"b:0.4.8",
 CellLabel->"In[92]:=",
 CellID->36223674],

Cell["\<\
{\"the\", \"\", Tag[\"tag1\"], \"first\", Tag[\"/tag1\"], \"\", \"and\", \
\"the\", \"\", Tag[\"tag2\"], \"second\", Tag[\"/tag2\"]}\
\>", "Output",
 ImageSize->{742, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.4.8",
 CellLabel->"Out[92]//InputForm=",
 CellID->894580067]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\:0414\:043b\:044f \:043f\:043e\:043b\:044c\:0437\:043e\:0432\:0430\
\:0442\:0435\:043b\:0435\:0439 Perl", "Section",
 CellTags->"c:15",
 CellID->759470019],

Cell[CellGroupData[{

Cell["\:041a\:0440\:0430\:0442\:043a\:0438\:0439 \:043e\:0431\:0437\:043e\
\:0440", "Subsection",
 CellTags->{"c:15.5", "b:0.5.0"},
 CellID->20697950],

Cell[TextData[{
 "\:0420\:0430\:0441\:043f\:043e\:043b\:0430\:0433\:0430\:044f \:0432 \:0441\
\:0432\:043e\:0435\:043c \:0430\:0440\:0441\:0435\:043d\:0430\:043b\:0435 \
\:043e\:0431\:0449\:0438\:043c\:0438 \:0448\:0430\:0431\:043b\:043e\:043d\
\:0430\:043c\:0438 \:0434\:043b\:044f \:0442\:0435\:043a\:0441\:0442\:043e\
\:0432\:044b\:0445 \:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442\:043e\
\:0432, ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " \:043b\:0435\:0433\:043a\:043e \:043c\:043e\:0436\:0435\:0442 \:0431\:044b\
\:0442\:044c \:043c\:043e\:0449\:043d\:043e\:0439 \:0430\:043b\:044c\:0442\
\:0435\:0440\:043d\:0430\:0442\:0438\:0432\:043e\:0439 \:0442\:0430\:043a\
\:0438\:043c \:044f\:0437\:044b\:043a\:0430\:043c \:043a\:0430\:043a Perl \
\:0438 Python \:043f\:0440\:0438 \:0440\:0435\:0448\:0435\:043d\:0438\:0438 \
\:043c\:043d\:043e\:0433\:0438\:0445 \:0448\:0438\:0440\:043e\:043a\:043e \
\:0440\:0430\:0441\:043f\:0440\:043e\:0441\:0442\:0440\:0430\:043d\:0435\:043d\
\:043d\:044b\:0445, \:043f\:043e\:0432\:0441\:0435\:0434\:043d\:0435\:0432\
\:043d\:044b\:0445 \:0437\:0430\:0434\:0430\:0447 \:043f\:0440\:043e\:0433\
\:0440\:0430\:043c\:043c\:0438\:0440\:043e\:0432\:0430\:043d\:0438\:044f. \
\:0414\:043b\:044f \:043b\:044e\:0434\:0435\:0439, \:0437\:043d\:0430\:043a\
\:043e\:043c\:044b\:0445 \:0441 \:0441\:0438\:043d\:0442\:0430\:043a\:0441\
\:0438\:0441\:043e\:043c Perl, \:0438 \:043c\:0435\:0445\:0430\:043d\:0438\
\:0437\:043c\:0430\:043c\:0438, \:043a\:043e\:0442\:043e\:0440\:044b\:0435 \
\:0438\:0441\:043f\:043e\:043b\:044c\:0437\:0443\:044e\:0442\:0441\:044f Perl \
\:043f\:0440\:0438 \:043e\:0431\:0440\:0430\:0431\:043e\:0442\:043a\:0435 \
\:0442\:0435\:043a\:0441\:0442\:043e\:0432\:044b\:0445 \:0444\:0440\:0430\
\:0433\:043c\:0435\:043d\:0442\:043e\:0432, \:043f\:0440\:0435\:0434\:043b\
\:0430\:0433\:0430\:0435\:043c\:043e\:0435 \:043d\:0438\:0436\:0435 \:043e\
\:0440\:0438\:0435\:043d\:0442\:0438\:0440\:043e\:0432\:043e\:0447\:043d\:043e\
\:0435 \:0440\:0443\:043a\:043e\:0432\:043e\:0434\:0441\:0442\:0432\:043e \
\:043f\:043e\:043a\:0430\:0437\:044b\:0432\:0430\:0435\:0442, \:043a\:0430\
\:043a \:0434\:043e\:0431\:0438\:0442\:044c\:0441\:044f \:0430\:043d\:0430\
\:043b\:043e\:0433\:0438\:0447\:043d\:043e\:0433\:043e \:0440\:0435\:0437\
\:0443\:043b\:044c\:0442\:0430\:0442\:0430 \:0438\:043d\:0441\:0442\:0440\
\:0443\:043c\:0435\:043d\:0442\:0430\:043c\:0438 ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellTags->"b:0.5.0",
 CellID->86791152],

Cell[TextData[{
 "\:0412\:043e\:0442 \:043a\:0440\:0430\:0442\:043a\:0438\:0439 \:043e\:0431\
\:0437\:043e\:0440 \:0444\:0443\:043d\:043a\:0446\:0438\:0439 ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", \:043f\:0440\:0438\:043c\:0435\:043d\:044f\:0435\:043c\:044b\:0445 \:0432 \
\:0441\:043e\:0437\:0434\:0430\:043d\:0438\:0438 \
Perl-\:043f\:043e\:0434\:043e\:0431\:043d\:044b\:0445 \
\:0444\:0443\:043d\:043a\:0446\:0438\:0439."
}], "Text",
 CellTags->"b:0.5.0",
 CellID->323888524],

Cell[BoxData[GridBox[{
   {Cell["\:043a\:043e\:043d\:0441\:0442\:0440\:0443\:043a\:0446\:0438\:044f \
Perl", "TableHeader"], Cell[
    "\:0444\:0443\:043d\:043a\:0446\:0438\:044f Mathematica", "TableHeader"], 
    Cell["\:043f\:043e\:044f\:0441\:043d\:0435\:043d\:0438\:044f", 
     "TableHeader"]},
   {
    RowBox[{
     RowBox[{
      RowBox[{"m", "/"}], "\[NegativeThinSpace]", "..."}], "/"}], 
    RowBox[{
     ButtonBox["StringFreeQ",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/StringFreeQ"], Cell[
     " \:0438\:043b\:0438 ", "TableText"], 
     ButtonBox["StringCases",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/StringCases"]}], Cell["\<\
\:043f\:0440\:043e\:0432\:0435\:0440\:044f\:0435\:0442 \:0441 \:043f\:043e\
\:043c\:043e\:0449\:044c\:044e \:0440\:0435\:0433\:0443\:043b\:044f\:0440\
\:043d\:043e\:0433\:043e \:0432\:044b\:0440\:0430\:0436\:0435\:043d\:0438\
\:044f \:0442\:0435\:043a\:0441\:0442\:043e\:0432\:044b\:0439 \:0444\:0440\
\:0430\:0433\:043c\:0435\:043d\:0442 \:043d\:0430 \:0441\:043e\:0432\:043f\
\:0430\:0434\:0435\:043d\:0438\:044f, \:0438\:0437\:0432\:043b\:0435\:043a\
\:0430\:044f, \:043f\:043e \:0432\:043e\:0437\:043c\:043e\:0436\:043d\:043e\
\:0441\:0442\:0438, \:0441\:0443\:0431\:0444\:0440\:0430\:0433\:043c\:0435\
\:043d\:0442\:044b\
\>", "TableText"]},
   {
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"s", "/"}], "\[NegativeThinSpace]", "..."}], "/"}], 
      "\[NegativeThinSpace]", "..."}], "/"}], 
    ButtonBox["StringReplace",
     BaseStyle->"Link",
     ButtonData->"paclet:ref/StringReplace"], Cell[
    "\:0437\:0430\:043c\:0435\:043d\:044f\:0435\:0442 \
\:0441\:0443\:0431\:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442\:044b, \
\:0441\:043e\:043e\:0442\:0432\:0435\:0442\:0441\:0442\:0432\:0443\:044e\:0449\
\:0438\:0435 \:0440\:0435\:0433\:0443\:043b\:044f\:0440\:043d\:043e\:043c\
\:0443 \:0432\:044b\:0440\:0430\:0436\:0435\:043d\:0438\:044e", "TableText"]},
   {
    RowBox[{"split", 
     RowBox[{"(", "...", ")"}]}], 
    ButtonBox["StringSplit",
     BaseStyle->"Link",
     ButtonData->"paclet:ref/StringSplit"], Cell["\<\
\:0440\:0430\:0437\:0431\:0438\:0432\:0430\:0435\:0442 \:0442\:0435\:043a\
\:0441\:0442\:043e\:0432\:044b\:0439 \:0444\:0440\:0430\:0433\:043c\:0435\
\:043d\:0442 \:043f\:043e \:043f\:043e\:0437\:0438\:0446\:0438\:044f\:043c, \
\:0441\:043e\:043e\:0442\:0432\:0435\:0442\:0441\:0442\:0432\:0443\:044e\:0449\
\:0438\:043c \:0440\:0435\:0433\:0443\:043b\:044f\:0440\:043d\:044b\:043c \
\:0432\:044b\:0440\:0430\:0436\:0435\:043d\:0438\:044f\:043c\
\>", "TableText"]},
   {
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"tr", "/"}], "\[NegativeThinSpace]", "..."}], "/"}], 
      "\[NegativeThinSpace]", "..."}], "/"}], 
    ButtonBox["StringReplace",
     BaseStyle->"Link",
     ButtonData->"paclet:ref/StringReplace"], Cell[
    "\:0437\:0430\:043c\:0435\:043d\:044f\:0435\:0442 \
\:0441\:0438\:043c\:0432\:043e\:043b\:044b \:0434\:0440\:0443\:0433\:0438\
\:043c\:0438 \:0441\:0438\:043c\:0432\:043e\:043b\:0430\:043c\:0438", 
     "TableText"]},
   {
    RowBox[{"/", "i"}], 
    RowBox[{
     ButtonBox["IgnoreCase",
      BaseStyle->"Link",
      ButtonData->"paclet:ref/IgnoreCase"], "->", 
     RowBox[{
      ButtonBox["True",
       BaseStyle->"Link",
       ButtonData->"paclet:ref/True"], Cell[
      " \:0438\:043b\:0438 ", "TableText"], "\"\<(?i)\>\""}]}], Cell[
    "\:0443\:043f\:0440\:0430\:0432\:043b\:044f\:0435\:0442 \
\:0447\:0443\:0432\:0441\:0442\:0432\:0438\:0442\:0435\:043b\:044c\:043d\:043e\
\:0441\:0442\:044c\:044e \:043a \:0440\:0435\:0433\:0438\:0441\:0442\:0440\
\:0443 \:0441\:0438\:043c\:0432\:043e\:043b\:043e\:0432", "TableText"]},
   {
    RowBox[{"/", "s"}], "\"\<(?s)\>\"", Cell[TextData[{
     "\:043f\:0440\:0438\:043d\:0443\:0436\:0434\:0430\:0435\:0442 \:0432\
\:0441\:0435 \:0441\:0438\:043c\:0432\:043e\:043b\:044b (\:0432\:043a\:043b\
\:044e\:0447\:0430\:044f \:043d\:043e\:0432\:044b\:0435 \:0441\:0442\:0440\
\:043e\:043a\:0438) \:0441\:043e\:043e\:0442\:0432\:0435\:0442\:0441\:0442\
\:0432\:043e\:0432\:0430\:0442\:044c ",
     Cell[BoxData["\"\<.\>\""], "InlineFormula"],
     " "
    }], "TableText"]},
   {
    RowBox[{"/", "x"}], "\"\<(?x)\>\"", Cell["\<\
\:0438\:0433\:043d\:043e\:0440\:0438\:0440\:0443\:0435\:0442 \:043f\:0440\
\:043e\:0431\:0435\:043b \:0438 \:0434\:043e\:043f\:0443\:0441\:043a\:0430\
\:0435\:0442 \:0440\:0430\:0441\:0448\:0438\:0440\:0435\:043d\:043d\:044b\
\:0435 \:043a\:043e\:043c\:043c\:0435\:043d\:0442\:0430\:0440\:0438\:0438 \
\:0432 \:0440\:0435\:0433\:0443\:043b\:044f\:0440\:043d\:043e\:043c \:0432\
\:044b\:0440\:0430\:0436\:0435\:043d\:0438\:0438 \
\>", "TableText"]},
   {
    RowBox[{"/", "m"}], "\"\<(?m)\>\"", Cell[TextData[{
     "\:043c\:043d\:043e\:0433\:043e\:0441\:0442\:0440\:043e\:0447\:043d\:044b\
\:0439 \:0440\:0435\:0436\:0438\:043c (",
     Cell[BoxData["\"\<^\>\""], "InlineFormula"],
     " \:0438 ",
     Cell[BoxData["\"\<$\>\""], "InlineFormula"],
     " \:0441\:043e\:0432\:043f\:0430\:0434\:0430\:044e\:0442 \:0441 \:043d\
\:0430\:0447\:0430\:043b\:043e\:043c/\:043a\:043e\:043d\:0446\:043e\:043c \
\:0441\:0442\:0440\:043e\:043a)"
    }], "TableText"]}
  },
  GridBoxAlignment->{
   "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
    "RowsIndexed" -> {}}]], "DefinitionBox3Col",
 GridBoxOptions->{
 GridBoxDividers->{
  "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
   "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}}},
 CellTags->"b:0.5.0",
 CellID->43654671],

Cell["\<\
\:041d\:0438\:0436\:0435 \:0440\:0430\:0441\:0441\:043a\:0430\:0437\:044b\
\:0432\:0430\:0435\:0442\:0441\:044f \:0431\:043e\:043b\:0435\:0435 \:0434\
\:0435\:0442\:0430\:043b\:044c\:043d\:043e \:043e \:043d\:0435\:043a\:043e\
\:0442\:043e\:0440\:044b\:0445 \:0447\:0430\:0441\:0442\:043e \:0432\:0441\
\:0442\:0440\:0435\:0447\:0430\:044e\:0449\:0438\:0445\:0441\:044f \:043a\
\:043e\:043d\:0441\:0442\:0440\:0443\:043a\:0446\:0438\:044f\:0445 Perl.\
\>", "Text",
 CellTags->"b:0.5.0",
 CellID->575279163]
}, Open  ]],

Cell[CellGroupData[{

Cell["m/.../", "Subsection",
 CellTags->{"c:16", "b:0.5.1"},
 CellID->120637313],

Cell[TextData[{
 "\:0421\:0440\:0430\:0432\:043d\:0438\:0432\:0430\:044e\:0449\:0438\:0439 \
\:043e\:043f\:0435\:0440\:0430\:0442\:043e\:0440 ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"m", "/", "regex"}], "/"}]], "InlineFormula"],
 " \:043f\:0440\:043e\:0432\:0435\:0440\:044f\:0435\:0442 \:0442\:0435\:043a\
\:0441\:0442\:043e\:0432\:044b\:0439 \:0444\:0440\:0430\:0433\:043c\:0435\
\:043d\:0442 \:043d\:0430 \:043f\:0440\:0435\:0434\:043c\:0435\:0442 \:043d\
\:0430\:043b\:0438\:0447\:0438\:044f \:0441\:0443\:0431\:0444\:0440\:0430\
\:0433\:043c\:0435\:043d\:0442\:043e\:0432, \:0441\:043e\:043e\:0442\:0432\
\:0435\:0442\:0441\:0442\:0432\:0443\:044e\:0449\:0438\:0445 ",
 Cell[BoxData["regex"], "InlineFormula"],
 ". \:0415\:0441\:043b\:0438 \:0442\:0440\:0435\:0431\:0443\:0435\:0442\:0441\
\:044f \:043f\:0440\:043e\:0441\:0442\:043e \:043f\:0440\:043e\:0432\:0435\
\:0440\:043a\:0430 \:043d\:0430\:043b\:0438\:0447\:0438\:044f \:0442\:0430\
\:043a\:0438\:0445 \:0441\:043e\:0432\:043f\:0430\:0434\:0435\:043d\:0438\
\:0439 \:0432 ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", \:0432\:043e\:0441\:043f\:043e\:043b\:044c\:0437\:0443\:0439\:0442\:0435\
\:0441\:044c \:0444\:0443\:043d\:043a\:0446\:0438\:0435\:0439 ",
 Cell[BoxData[
  TemplateBox[{Cell["StringFreeQ"],"paclet:ref/StringFreeQ"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 "."
}], "Text",
 CellTags->"b:0.5.1",
 CellID->332493086],

Cell[TextData[{
 "\:0412\:043e\:0442 \:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442 \:0438\
\:0437 Perl \:0434\:043b\:044f \:043f\:0440\:043e\:0432\:0435\:0440\:043a\
\:0438, \:0441\:043e\:0434\:0435\:0440\:0436\:0438\:0442 \:043b\:0438 \:0442\
\:0435\:043a\:0441\:0442\:043e\:0432\:044b\:0439 \:0444\:0440\:0430\:0433\
\:043c\:0435\:043d\:0442 ",
 Cell[BoxData["\<\"b\"\>"], "InlineCode"],
 " \:0432 \:043b\:044e\:0431\:043e\:043c \:043c\:0435\:0441\:0442\:0435 \
\:043f\:043e\:0441\:043b\:0435 ",
 Cell[BoxData["\<\"a\"\>"], "InlineCode"],
 "."
}], "MathCaption",
 CellTags->"b:0.5.1",
 CellID->163086882],

Cell["\<\
$string = \"sdakdb\";
if ($string =~ m/a.*b/){
  print \"Match!\";
}\
\>", "Program",
 CellTags->"b:0.5.1",
 CellID->203403607],

Cell[TextData[{
 "\:042d\:0442\:043e \:0432\:0435\:0440\:0441\:0438\:044f \:0442\:0430\:043a\
\:043e\:0439 \:0436\:0435 \:0441\:0430\:043c\:043e\:0439 \:043f\:0440\:043e\
\:0432\:0435\:0440\:043a\:0438 \:0432 ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "."
}], "MathCaption",
 CellTags->"b:0.5.1",
 CellID->258819916],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"string", "=", "\"\<sdakdb\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"If", "[", 
  RowBox[{
   RowBox[{"!", 
    RowBox[{"StringFreeQ", "[", 
     RowBox[{"string", ",", 
      RowBox[{"RegularExpression", "[", "\"\<a.*b\>\"", "]"}]}], "]"}]}], ",", 
   RowBox[{"Print", "[", "\"\<Match!\>\"", "]"}]}], "]"}]}], "Input",
 CellTags->"b:0.5.1",
 CellLabel->"In[93]:=",
 CellID->403377399],

Cell[BoxData["\<\"Match!\"\>"], "Print",
 CellTags->"b:0.5.1",
 CellLabel->"During evaluation of In[93]:=",
 CellID->320069806]
}, Open  ]],

Cell[TextData[{
 "\:0415\:0441\:043b\:0438 \:043d\:0430\:0439\:0434\:0435\:043d\:043d\:044b\
\:0435 \:0441\:043e\:043e\:0442\:0432\:0435\:0442\:0441\:0442\:0432\:0443\
\:044e\:0449\:0438\:0435 \:0441\:0443\:0431\:0444\:0440\:0430\:0433\:043c\
\:0435\:043d\:0442\:044b \:0434\:043e\:043b\:0436\:043d\:044b \:0431\:044b\
\:0442\:044c \:0434\:043e\:0441\:0442\:0443\:043f\:043d\:044b \:0434\:0430\
\:043b\:0435\:0435, \:043f\:0440\:0438 \:043f\:043e\:043c\:043e\:0449\:0438 \
\:043a\:043e\:043d\:0441\:0442\:0440\:0443\:043a\:0446\:0438\:0439 Perl ",
 Cell[BoxData["$1"], "InlineCode"],
 ", ",
 Cell[BoxData["$2"], "InlineCode"],
 ", \[Ellipsis] , \:0442\:043e \:0432 ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", \:0434\:043b\:044f \:044d\:0442\:043e\:0433\:043e \
\:0438\:0441\:043f\:043e\:043b\:044c\:0437\:0443\:0435\:0442\:0441\:044f \
\:0444\:0443\:043d\:043a\:0446\:0438\:044f ",
 Cell[BoxData[
  TemplateBox[{Cell["StringCases"],"paclet:ref/StringCases"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 "."
}], "Text",
 CellTags->"b:0.5.1",
 CellID->130918903],

Cell["\:0412\:043e\:0442 \:043a\:043e\:0434 Perl \:0434\:043b\:044f \:0438\
\:0437\:0432\:043b\:0435\:0447\:0435\:043d\:0438\:044f \:0441\:043e\:043e\
\:0431\:0449\:0435\:043d\:0438\:0435 \:043e\:0431 \:043e\:0448\:0438\:0431\
\:043a\:0435.", "MathCaption",
 CellTags->"b:0.5.1",
 CellID->272631892],

Cell["\<\
$res = \"ERROR = paper jam\";
if ($res =~ m/ERROR = (.*)/){
  print \"Hey, you should check the $1!\";
}\
\>", "Program",
 CellTags->"b:0.5.1",
 CellID->67879431],

Cell[TextData[{
 "\:0410 \:044d\:0442\:043e - \:0432\:0435\:0440\:0441\:0438\:044f ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "."
}], "MathCaption",
 CellTags->"b:0.5.1",
 CellID->175118403],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"res", "=", "\"\<ERROR = paper jam\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"With", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"test", "=", 
     RowBox[{"StringCases", "[", 
      RowBox[{"res", ",", 
       RowBox[{
        RowBox[{"RegularExpression", "[", "\"\<ERROR = (.*)\>\"", "]"}], 
        "\[Rule]", "\"\<$1\>\""}]}], "]"}]}], "}"}], ",", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"test", "=!=", 
      RowBox[{"{", "}"}]}], ",", 
     RowBox[{"Print", "[", 
      RowBox[{"\"\<Hey, you should check the \>\"", ",", 
       RowBox[{"test", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", "\"\<!\>\""}], "]"}]}], "]"}]}], 
  "]"}]}], "Input",
 CellTags->"b:0.5.1",
 CellLabel->"In[95]:=",
 CellID->399472551],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Hey, you should check the \"\>", 
   "\[InvisibleSpace]", "\<\"paper jam\"\>", 
   "\[InvisibleSpace]", "\<\"!\"\>"}],
  SequenceForm["Hey, you should check the ", "paper jam", "!"],
  Editable->False]], "Print",
 CellTags->"b:0.5.1",
 CellLabel->"During evaluation of In[95]:=",
 CellID->178834455]
}, Open  ]],

Cell["\:0412\:043e\:0442 \:043a\:043e\:0434 Perl \:0434\:043b\:044f \:0438\
\:0437\:0432\:043b\:0435\:0447\:0435\:043d\:0438\:044f \:0441\:0440\:0430\
\:0437\:0443 \:043d\:0435\:0441\:043a\:043e\:043b\:044c\:043a\:0438\:0445 \
\:0441\:0443\:0431\:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442\:043e\:0432\
.", "MathCaption",
 CellTags->"b:0.5.1",
 CellID->161491337],

Cell["\<\
$date = \"88/6/13\";
($year, $month, $day) = $date =~ m/^(\\d+)/(\\d+)/(\\d+)$/;\
\>", "Program",
 CellTags->"b:0.5.1",
 CellID->785509705],

Cell[TextData[{
 "\:0412 ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", \:044d\:0442\:043e \:0432\:044b\:043f\:043e\:043b\:043d\:044f\:0435\:0442\
\:0441\:044f \:0441 \:043f\:043e\:043c\:043e\:0449\:044c\:044e \:0444\:0443\
\:043d\:043a\:0446\:0438\:0438 ",
 Cell[BoxData[
  TemplateBox[{Cell["StringCases"],"paclet:ref/StringCases"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 "."
}], "MathCaption",
 CellTags->"b:0.5.1",
 CellID->445860386],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"date", "=", "\"\<88/6/13\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{"year", ",", "month", ",", "day"}], "}"}], "=", 
  RowBox[{
   RowBox[{"StringCases", "[", 
    RowBox[{"date", ",", 
     RowBox[{
      RowBox[{
      "RegularExpression", "[", "\"\<^(\\\\d+)/(\\\\d+)/(\\\\d+)$\>\"", "]"}],
       "->", 
      RowBox[{"{", 
       RowBox[{"\"\<$1\>\"", ",", "\"\<$2\>\"", ",", "\"\<$3\>\""}], 
       "}"}]}]}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]}], "Input",
 CellTags->"b:0.5.1",
 CellLabel->"In[97]:=",
 CellID->682251121],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"88\"\>", ",", "\<\"6\"\>", ",", "\<\"13\"\>"}], 
  "}"}]], "Output",
 ImageSize->{75, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.5.1",
 CellLabel->"Out[98]=",
 CellID->183755673]
}, Open  ]],

Cell[TextData[{
 "\:042d\:0442\:043e \:0430\:043d\:0430\:043b\:043e\:0433\:0438\:0447\:043d\
\:043e \:043e\:0431\:044a\:0435\:0434\:0438\:043d\:0435\:043d\:0438\:044e \
\:0432\:0441\:0435\:0445 \:043d\:0430\:0439\:0434\:0435\:043d\:043d\:044b\
\:0445 \:0441\:043e\:0432\:043f\:0430\:0434\:0435\:043d\:0438\:0439 \:0432 \
\:043c\:0430\:0441\:0441\:0438\:0432 \:0441 \:043f\:043e\:043c\:043e\:0449\
\:044c\:044e \:043a\:043b\:044e\:0447\:0430 ",
 Cell[BoxData[
  RowBox[{"/", "g"}]], "InlineCode"],
 " ."
}], "MathCaption",
 CellTags->"b:0.5.1",
 CellID->20175135],

Cell["\<\
$text = \"128.32.13.117\";
@nums = $text =~ m/\\d+/g;\
\>", "Program",
 CellTags->"b:0.5.1",
 CellID->19723038],

Cell[TextData[{
 "\:0422\:043e \:0436\:0435 \:0441\:0430\:043c\:043e\:0435 \:043b\:0435\:0433\
\:043a\:043e \:0440\:0435\:0430\:043b\:0438\:0437\:0443\:0435\:0442\:0441\
\:044f \:043f\:0440\:0438 \:043f\:043e\:043c\:043e\:0449\:0438 ",
 Cell[BoxData[
  TemplateBox[{Cell["StringCases"],"paclet:ref/StringCases"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " \:0432 ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "."
}], "MathCaption",
 CellTags->"b:0.5.1",
 CellID->781694409],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"text", "=", "\"\<128.32.13.117\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"nums", "=", 
  RowBox[{"StringCases", "[", 
   RowBox[{"text", ",", 
    RowBox[{"RegularExpression", "[", "\"\<\\\\d+\>\"", "]"}]}], 
   "]"}]}]}], "Input",
 CellTags->"b:0.5.1",
 CellLabel->"In[99]:=",
 CellID->43441911],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"128\"\>", ",", "\<\"32\"\>", ",", "\<\"13\"\>", 
   ",", "\<\"117\"\>"}], "}"}]], "Output",
 ImageSize->{121, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.5.1",
 CellLabel->"Out[100]=",
 CellID->371595541]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["s/.../.../", "Subsection",
 CellTags->{"c:17", "b:0.5.2"},
 CellID->163295011],

Cell[TextData[{
 "\:0412 ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", \:043e\:0447\:0435\:0432\:0438\:0434\:043d\:044b\:043c \:0430\:043d\:0430\
\:043b\:043e\:0433\:043e\:043c \:043e\:043f\:0435\:0440\:0430\:0442\:043e\
\:0440\:0430 \:0437\:0430\:043c\:0435\:043d\:044b Perl ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"s", "/"}], "\[NegativeThinSpace]", "..."}], "/"}], 
    "\[NegativeThinSpace]", "..."}], "/"}]], "InlineCode"],
 "  \:044f\:0432\:043b\:044f\:0435\:0442\:0441\:044f ",
 Cell[BoxData[
  TemplateBox[{Cell["StringReplace"],"paclet:ref/StringReplace"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 "."
}], "MathCaption",
 CellTags->"b:0.5.2",
 CellID->51683055],

Cell["\<\
$text = \"abcagh\";
$text =~ s/a./XX/;\
\>", "Program",
 CellTags->"b:0.5.2",
 CellID->384257252],

Cell["\:041f\:043e \:0443\:043c\:043e\:043b\:0447\:0430\:043d\:0438\:044e, \
Perl \:0432\:044b\:043f\:043e\:043b\:043d\:044f\:0435\:0442 \
\:043e\:0434\:0438\:043d\:043e\:0447\:043d\:0443\:044e \:0437\:0430\:043c\
\:0435\:043d\:0443.", "MathCaption",
 CellTags->"b:0.5.2",
 CellID->179104029],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"text", "=", "\"\<abcagh\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"StringReplace", "[", 
  RowBox[{"text", ",", 
   RowBox[{
    RowBox[{"RegularExpression", "[", "\"\<a.\>\"", "]"}], "->", 
    "\"\<XX\>\""}], ",", "1"}], "]"}]}], "Input",
 CellTags->"b:0.5.2",
 CellLabel->"In[101]:=",
 CellID->252897767],

Cell[BoxData["\<\"XXcagh\"\>"], "Output",
 ImageSize->{46, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.5.2",
 CellLabel->"Out[102]=",
 CellID->207323890]
}, Open  ]],

Cell[TextData[{
 "\:041a\:043b\:044e\:0447 ",
 Cell[BoxData[
  RowBox[{"/", "g"}]], "InlineCode"],
 " \:0432 Perl \:043e\:0431\:0435\:0441\:043f\:0435\:0447\:0438\:0432\:0430\
\:0435\:0442 \:0432\:0441\:0435\:043e\:0431\:0449\:0443\:044e \:0437\:0430\
\:043c\:0435\:043d\:0443 \:0432\:0441\:0435\:0445 \:043d\:0430\:0439\:0434\
\:0435\:043d\:043d\:044b\:0445 \:0441\:043e\:0432\:043f\:0430\:0434\:0435\
\:043d\:0438\:0439."
}], "MathCaption",
 CellTags->"b:0.5.2",
 CellID->317632773],

Cell["$text =~ s/a./XX/g", "Program",
 CellTags->"b:0.5.2",
 CellID->152813715],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringReplace", "[", 
  RowBox[{"text", ",", 
   RowBox[{
    RowBox[{"RegularExpression", "[", "\"\<a.\>\"", "]"}], "->", 
    "\"\<XX\>\""}]}], "]"}]], "Input",
 CellTags->"b:0.5.2",
 CellLabel->"In[103]:=",
 CellID->341597359],

Cell[BoxData["\<\"XXcXXh\"\>"], "Output",
 ImageSize->{46, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.5.2",
 CellLabel->"Out[103]=",
 CellID->203169793]
}, Open  ]],

Cell[TextData[{
 "\:0418\:0441\:043f\:043e\:043b\:044c\:0437\:0443\:044f \:0432\:044b\:0447\
\:0438\:0441\:043b\:0438\:0442\:0435\:043b\:044c\:043d\:044b\:0439 \:043a\
\:043b\:044e\:0447 ",
 Cell[BoxData[
  RowBox[{"/", "e"}]], "InlineCode"],
 " , Perl \:043c\:043e\:0436\:0435\:0442 \:0438\:0441\:043f\:043e\:043b\:044c\
\:0437\:043e\:0432\:0430\:0442\:044c \:0441\:0443\:0431\:0448\:0430\:0431\
\:043b\:043e\:043d\:044b \:043f\:0440\:0438 \:0432\:044b\:043f\:043e\:043b\
\:043d\:0435\:043d\:0438\:0438 \:0437\:0430\:043c\:0435\:043d\:044b. \:042d\
\:0442\:043e \:043b\:0435\:0433\:043a\:043e \:0440\:0435\:0430\:043b\:0438\
\:0437\:0443\:0435\:0442\:0441\:044f \:0432 ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "."
}], "MathCaption",
 CellTags->"b:0.5.2",
 CellID->183807183],

Cell["\<\
$text = \"13 27 3\";
$text =~ s/(\\d+)/$1$1/eg\
\>", "Program",
 CellTags->"b:0.5.2",
 CellID->409627135],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"text", "=", "\"\<13 27 3\>\""}], ";"}], "\n", 
 RowBox[{"StringReplace", "[", 
  RowBox[{"text", ",", 
   RowBox[{
    RowBox[{"RegularExpression", "[", "\"\<(\\\\d+)\>\"", "]"}], 
    "\[RuleDelayed]", "\"\<$1$1\>\""}]}], "]"}]}], "Input",
 CellTags->"b:0.5.2",
 CellLabel->"In[104]:=",
 CellID->69447560],

Cell[BoxData["\<\"1313 2727 33\"\>"], "Output",
 ImageSize->{88, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.5.2",
 CellLabel->"Out[105]=",
 CellID->520395969]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["split(...)", "Subsection",
 CellTags->{"c:18", "b:0.5.3"},
 CellID->45791734],

Cell[TextData[{
 "\:041a\:043e\:043c\:0430\:043d\:0434\:0430 ",
 Cell[BoxData["split"], "InlineCode"],
 " \:0432 Perl \:0430\:043d\:0430\:043b\:043e\:0433\:0438\:0447\:043d\:0430 ",
 Cell[BoxData[
  TemplateBox[{Cell["StringSplit"],"paclet:ref/StringSplit"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " \:0432 ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "."
}], "MathCaption",
 CellTags->"b:0.5.3",
 CellID->12267911],

Cell["\<\
$text = \"ab:cd:efg\";
split(/:/, $text)\
\>", "Program",
 CellTags->"b:0.5.3",
 CellID->189290885],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"text", "=", "\"\<ab:cd:efg\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"StringSplit", "[", 
  RowBox[{"text", ",", "\"\<:\>\""}], "]"}]}], "Input",
 CellTags->"b:0.5.3",
 CellLabel->"In[106]:=",
 CellID->229530619],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"ab\"\>", ",", "\<\"cd\"\>", ",", "\<\"efg\"\>"}], 
  "}"}]], "Output",
 ImageSize->{89, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.5.3",
 CellLabel->"Out[107]=",
 CellID->17569325]
}, Open  ]],

Cell[TextData[{
 "\:041a\:0430\:043a \:0432 Perl, \:0442\:0430\:043a \:0438 \:0432 ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", \:043c\:043e\:0436\:043d\:043e \:0443\:043a\:0430\:0437\:0430\:0442\:044c \
\:043a\:043e\:043b\:0438\:0447\:0435\:0441\:0442\:0432\:043e \:0431\:043b\
\:043e\:043a\:043e\:0432, \:043d\:0430 \:043a\:043e\:0442\:043e\:0440\:044b\
\:0435 \:0434\:043e\:043b\:0436\:0435\:043d \:0431\:044b\:0442\:044c \:0440\
\:0430\:0437\:0431\:0438\:0442 \:0442\:0435\:043a\:0441\:0442\:043e\:0432\
\:044b\:0439 \:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442."
}], "MathCaption",
 CellTags->"b:0.5.3",
 CellID->240418930],

Cell["split(/:/, $text,2)", "Program",
 CellTags->"b:0.5.3",
 CellID->719922593],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringSplit", "[", 
  RowBox[{"text", ",", "\"\<:\>\"", ",", "2"}], "]"}]], "Input",
 CellTags->"b:0.5.3",
 CellLabel->"In[108]:=",
 CellID->502233132],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"ab\"\>", ",", "\<\"cd:efg\"\>"}], "}"}]], "Output",
 ImageSize->{85, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.5.3",
 CellLabel->"Out[108]=",
 CellID->382146358]
}, Open  ]],

Cell[TextData[{
 "\:0424\:0443\:043d\:043a\:0446\:0438\:044f ",
 Cell[BoxData["split"], "InlineCode"],
 " \:0441 \:043f\:0435\:0440\:0435\:0445\:0432\:0430\:0442\:044b\:0432\:0430\
\:044e\:0449\:0438\:043c\:0438 \:0441\:043a\:043e\:0431\:043a\:0430\:043c\
\:0438 \:0432 \:0448\:0430\:0431\:043b\:043e\:043d\:0435, \:0438\:0437-\:0437\
\:0430 \:043a\:043e\:0442\:043e\:0440\:044b\:0445 \:0441\:043e\:0431\:0440\
\:0430\:043d\:043d\:044b\:0435 \:0441\:0443\:0431\:0444\:0440\:0430\:0433\
\:043c\:0435\:043d\:0442\:044b  \:0432\:043a\:043b\:044e\:0447\:0430\:044e\
\:0442\:0441\:044f \:0432 \:0440\:0435\:0437\:0443\:043b\:044c\:0442\:0430\
\:0442, \:043c\:043e\:0436\:0435\:0442 \:0431\:044b\:0442\:044c \:0440\:0435\
\:0430\:043b\:0438\:0437\:043e\:0432\:0430\:043d\:0430 \:0432 ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", \:0438\:0441\:043f\:043e\:043b\:044c\:0437\:0443\:044f \:043f\:0440\:0430\
\:0432\:0438\:043b\:0430 \:0432 \:043a\:0430\:0447\:0435\:0441\:0442\:0432\
\:0435 \:0432\:0442\:043e\:0440\:043e\:0433\:043e \:0430\:0440\:0433\:0443\
\:043c\:0435\:043d\:0442\:0430 ",
 Cell[BoxData[
  TemplateBox[{Cell["StringSplit"],"paclet:ref/StringSplit"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 ". \:0412 ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", \:043f\:043e \:0441\:0440\:0430\:0432\:043d\:0435\:043d\:0438\:044e \
\:0441 Perl, \:043a \:044d\:0442\:0438\:043c \:0441\:0443\:0431\:0444\:0440\
\:0430\:0433\:043c\:0435\:043d\:0442\:0430\:043c \:043f\:0440\:043e\:0449\
\:0435 \:0437\:0430\:0442\:0435\:043c \:043f\:0440\:0438\:043c\:0435\:043d\
\:0438\:0442\:044c \:0444\:0443\:043d\:043a\:0446\:0438\:044e."
}], "MathCaption",
 CellTags->"b:0.5.3",
 CellID->78986018],

Cell["\<\
$text = \"test with <tag1>tags</tag1> and <b>more</b>\";
split(/<([^>]*)>/, $text)\
\>", "Program",
 CellTags->"b:0.5.3",
 CellID->348675863],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
  "text", "=", "\"\<test with <tag1>tags</tag1> and <b>more</b>\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"StringSplit", "[", 
   RowBox[{"text", ",", 
    RowBox[{
     RowBox[{"RegularExpression", "[", "\"\<<([^>]*)>\>\"", "]"}], "\[Rule]", 
     "\"\<$1\>\""}]}], "]"}], "//", "InputForm"}]}], "Input",
 CellTags->"b:0.5.3",
 CellLabel->"In[109]:=",
 CellID->639488513],

Cell["\<\
{\"test with \", \"tag1\", \"tags\", \"/tag1\", \" and \", \"b\", \"more\", \
\"/b\"}\
\>", "Output",
 ImageSize->{469, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.5.3",
 CellLabel->"Out[110]//InputForm=",
 CellID->829343315]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
  "text", "=", "\"\<test with <tag1>tags</tag1> and <b>more</b>\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"StringSplit", "[", 
   RowBox[{"text", ",", 
    RowBox[{
     RowBox[{"RegularExpression", "[", "\"\<<([^>]*)>\>\"", "]"}], 
     "\[RuleDelayed]", 
     RowBox[{"Tag", "[", "\"\<$1\>\"", "]"}]}]}], "]"}], "//", 
  "InputForm"}]}], "Input",
 CellTags->"b:0.5.3",
 CellLabel->"In[111]:=",
 CellID->34696905],

Cell["\<\
{\"test with \", Tag[\"tag1\"], \"tags\", Tag[\"/tag1\"], \" and \", \
Tag[\"b\"], \"more\", Tag[\"/b\"]}\
\>", "Output",
 ImageSize->{609, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.5.3",
 CellLabel->"Out[112]//InputForm=",
 CellID->59433462]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["tr/.../.../", "Subsection",
 CellTags->{"c:19", "b:0.5.4"},
 CellID->627179989],

Cell[TextData[{
 "\:041a\:043e\:043c\:0430\:043d\:0434\:0430 Perl ",
 Cell[BoxData["tr"], "InlineCode"],
 " \:043c\:043e\:0436\:0435\:0442 \:0431\:044b\:0442\:044c \:0432\:043e\:0441\
\:043f\:0440\:043e\:0438\:0437\:0432\:0435\:0434\:0435\:043d\:0430 \:0432 ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " \:043f\:0440\:0438 \:043f\:043e\:043c\:043e\:0449\:0438 ",
 Cell[BoxData[
  TemplateBox[{Cell["StringReplace"],"paclet:ref/StringReplace"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 ", \:0432 \:0441\:043e\:0447\:0435\:0442\:0430\:043d\:0438\:0438 \:0441 \
\:0441\:043e\:043e\:0442\:0432\:0435\:0442\:0441\:0442\:0432\:0443\:044e\:0449\
\:0438\:043c \:0441\:043f\:0438\:0441\:043a\:043e\:043c \:043f\:0440\:0430\
\:0432\:0438\:043b."
}], "Text",
 CellTags->"b:0.5.4",
 CellID->512373978],

Cell[TextData[{
 "\:0412\:043e\:0442 \:043f\:0440\:043e\:0441\:0442\:0435\:0439\:0448\:0438\
\:0439 \:043f\:0440\:0438\:043c\:0435\:0440, \:0433\:0434\:0435 \:0441\:0438\
\:043c\:0432\:043e\:043b\:044b ",
 Cell[BoxData["\<\"a\"\>"], "InlineCode"],
 ", ",
 Cell[BoxData["\<\"b\"\>"], "InlineCode"],
 " \:0438 ",
 Cell[BoxData["\<\"c\"\>"], "InlineCode"],
 " \:0437\:0430\:043c\:0435\:043d\:044f\:044e\:0442\:0441\:044f, \:0441\:043e\
\:043e\:0442\:0432\:0435\:0442\:0441\:0442\:0432\:0435\:043d\:043d\:043e, \
\:043d\:0430 ",
 Cell[BoxData["\<\"X\"\>"], "InlineCode"],
 ", ",
 Cell[BoxData["\<\"Y\"\>"], "InlineCode"],
 " \:0438 ",
 Cell[BoxData["\<\"Z\"\>"], "InlineCode"],
 "."
}], "MathCaption",
 CellTags->"b:0.5.4",
 CellID->75100454],

Cell["\<\
$text = \"abcdef\";
$text =~ tr/abc/XYZ/\
\>", "Program",
 CellTags->"b:0.5.4",
 CellID->2535425],

Cell[TextData[{
 "\:0417\:0434\:0435\:0441\:044c, \:0441\:043e\:043e\:0442\:0432\:0435\:0442\
\:0441\:0442\:0432\:0443\:044e\:0449\:0435\:0435 \:043f\:0440\:0430\:0432\
\:0438\:043b\:043e ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " \:0437\:0430\:0434\:0430\:043d\:043e \:043f\:0440\:0438 \:043f\:043e\:043c\
\:043e\:0449\:0438 \:0444\:0443\:043d\:043a\:0446\:0438\:0438 ",
 Cell[BoxData[
  TemplateBox[{Cell["Thread"],"paclet:ref/Thread"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 "."
}], "MathCaption",
 CellTags->"b:0.5.4",
 CellID->616093666],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"text", "=", "\"\<abcdef\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"StringReplace", "[", 
  RowBox[{"text", ",", 
   RowBox[{"Thread", "[", 
    RowBox[{"Rule", "[", 
     RowBox[{
      RowBox[{"Characters", "[", "\"\<abc\>\"", "]"}], ",", 
      RowBox[{"Characters", "[", "\"\<XYZ\>\"", "]"}]}], "]"}], "]"}]}], 
  "]"}]}], "Input",
 CellTags->"b:0.5.4",
 CellLabel->"In[113]:=",
 CellID->394779265],

Cell[BoxData["\<\"XYZdef\"\>"], "Output",
 ImageSize->{46, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.5.4",
 CellLabel->"Out[114]=",
 CellID->78625730]
}, Open  ]],

Cell[TextData[{
 "\:042d\:0442\:043e \:043f\:0440\:0438\:043c\:0435\:0440, \:0432 \
\:043a\:043e\:0442\:043e\:0440\:043e\:043c \:0441\:043f\:0438\:0441\:043e\
\:043a \:0437\:0430\:043c\:0435\:043d \:043a\:043e\:0440\:043e\:0447\:0435 \
\:0441\:043f\:0438\:0441\:043a\:0430 \:0441\:0438\:043c\:0432\:043e\:043b\
\:043e\:0432, \:043f\:043e\:044d\:0442\:043e\:043c\:0443 ",
 Cell[BoxData["\<\"d\"\>"], "InlineCode"],
 ", ",
 Cell[BoxData["\<\"e\"\>"], "InlineCode"],
 " \:0438 ",
 Cell[BoxData["\<\"f\"\>"], "InlineCode"],
 " \:0437\:0430\:043c\:0435\:043d\:044f\:044e\:0442\:0441\:044f \:043d\:0430 ",
 Cell[BoxData["\<\"Z\"\>"], "InlineCode"],
 "."
}], "MathCaption",
 CellTags->"b:0.5.4",
 CellID->44095121],

Cell["\<\
$text = \"abcdefghi\";
$text =~ tr/abcdef/WXYZ/\
\>", "Program",
 CellTags->"b:0.5.4",
 CellID->260896876],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"text", "=", "\"\<abcdefghi\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"StringReplace", "[", 
  RowBox[{"text", ",", 
   RowBox[{"Append", "[", 
    RowBox[{
     RowBox[{"Thread", "[", 
      RowBox[{"Rule", "[", 
       RowBox[{
        RowBox[{"Characters", "[", "\"\<abc\>\"", "]"}], ",", 
        RowBox[{"Characters", "[", "\"\<WXY\>\"", "]"}]}], "]"}], "]"}], ",", 
     RowBox[{
      RowBox[{"Characters", "[", "\"\<def\>\"", "]"}], "\[Rule]", 
      "\"\<Z\>\""}]}], "]"}]}], "]"}]}], "Input",
 CellTags->"b:0.5.4",
 CellLabel->"In[115]:=",
 CellID->37744320],

Cell[BoxData["\<\"WXYZZZghi\"\>"], "Output",
 ImageSize->{67, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.5.4",
 CellLabel->"Out[116]=",
 CellID->479145987]
}, Open  ]],

Cell[TextData[{
 "\:0414\:0438\:0430\:043f\:0430\:0437\:043e\:043d\:044b \:0441\:0438\:043c\
\:0432\:043e\:043b\:043e\:0432 \:0432 Perl \:044d\:043c\:0443\:043b\:0438\
\:0440\:0443\:044e\:0442\:0441\:044f \:043f\:0440\:0438 \:043f\:043e\:043c\
\:043e\:0449\:0438 ",
 Cell[BoxData[
  TemplateBox[{Cell["CharacterRange"],"paclet:ref/CharacterRange"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " \:0432 ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "."
}], "MathCaption",
 CellTags->"b:0.5.4",
 CellID->291617831],

Cell["\<\
$text = \"this and that\";
$text =~ tr/a-z/x/\
\>", "Program",
 CellTags->"b:0.5.4",
 CellID->820168201],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"text", "=", "\"\<this and that\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"StringReplace", "[", 
  RowBox[{"text", ",", 
   RowBox[{
    RowBox[{"CharacterRange", "[", 
     RowBox[{"\"\<a\>\"", ",", "\"\<z\>\""}], "]"}], "\[Rule]", 
    "\"\<x\>\""}]}], "]"}]}], "Input",
 CellTags->"b:0.5.4",
 CellLabel->"In[117]:=",
 CellID->96850109],

Cell[BoxData["\<\"xxxx xxx xxxx\"\>"], "Output",
 ImageSize->{95, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.5.4",
 CellLabel->"Out[118]=",
 CellID->497337288]
}, Open  ]],

Cell[TextData[{
 "\:041f\:0440\:0438 \:0438\:0441\:043f\:043e\:043b\:044c\:0437\:043e\:0432\
\:0430\:043d\:0438\:0438 \:043a\:043b\:044e\:0447\:0430 ",
 Cell[BoxData[
  RowBox[{"/", "d"}]], "InlineCode"],
 " , \:0438\:0437\:0431\:044b\:0442\:043e\:0447\:043d\:044b\:0435 \
\:0441\:0438\:043c\:0432\:043e\:043b\:044b \:043d\:0435 \:0437\:0430\:043c\
\:0435\:043d\:044f\:044e\:0442\:0441\:044f, \:0430 \:0443\:0434\:0430\:043b\
\:044f\:044e\:0442\:0441\:044f."
}], "MathCaption",
 CellTags->"b:0.5.4",
 CellID->206615673],

Cell["\<\
$text = \"abcdefghi\";
$text =~ tr/abcdef/WXYZ/d\
\>", "Program",
 CellTags->"b:0.5.4",
 CellID->1448094],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"text", "=", "\"\<abcdefghi\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"StringReplace", "[", 
  RowBox[{"text", ",", 
   RowBox[{"Append", "[", 
    RowBox[{
     RowBox[{"Thread", "[", 
      RowBox[{"Rule", "[", 
       RowBox[{
        RowBox[{"Characters", "[", "\"\<abcd\>\"", "]"}], ",", 
        RowBox[{"Characters", "[", "\"\<WXYZ\>\"", "]"}]}], "]"}], "]"}], ",", 
     RowBox[{
      RowBox[{"Characters", "[", "\"\<ef\>\"", "]"}], "\[Rule]", 
      "\"\<\>\""}]}], "]"}]}], "]"}]}], "Input",
 CellTags->"b:0.5.4",
 CellLabel->"In[119]:=",
 CellID->297013012],

Cell[BoxData["\<\"WXYZghi\"\>"], "Output",
 ImageSize->{53, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.5.4",
 CellLabel->"Out[120]=",
 CellID->621733276]
}, Open  ]],

Cell[TextData[{
 "\:041f\:0440\:0438 \:043d\:0430\:043b\:0438\:0447\:0438\:0438 \:043a\:043b\
\:044e\:0447\:0430 ",
 Cell[BoxData[
  RowBox[{"/", "c"}]], "InlineCode"],
 " , \:0438\:0441\:043f\:043e\:043b\:044c\:0437\:0443\:0435\:0442\:0441\:044f \
\:0434\:043e\:043f\:043e\:043b\:043d\:0435\:043d\:0438\:0435 \:0441\:043f\
\:0438\:0441\:043a\:0430 \:0441\:0438\:043c\:0432\:043e\:043b\:043e\:0432."
}], "MathCaption",
 CellTags->"b:0.5.4",
 CellID->809943646],

Cell["$text =~ tr/aeh/ /c", "Program",
 CellTags->"b:0.5.4",
 CellID->727836643],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringReplace", "[", 
  RowBox[{"text", ",", 
   RowBox[{
    RowBox[{"Except", "[", 
     RowBox[{"Characters", "[", "\"\<aeh\>\"", "]"}], "]"}], "\[Rule]", 
    "\"\< \>\""}]}], "]"}]], "Input",
 CellTags->"b:0.5.4",
 CellLabel->"In[121]:=",
 CellID->32783502],

Cell[BoxData["\<\"a   e  h \"\>"], "Output",
 ImageSize->{67, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.5.4",
 CellLabel->"Out[121]=",
 CellID->82701024]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringReplace", "[", 
  RowBox[{"text", ",", 
   RowBox[{
    RowBox[{"RegularExpression", "[", "\"\<[^aeh]\>\"", "]"}], "\[Rule]", 
    "\"\< \>\""}]}], "]"}]], "Input",
 CellTags->"b:0.5.4",
 CellLabel->"In[122]:=",
 CellID->190461549],

Cell[BoxData["\<\"a   e  h \"\>"], "Output",
 ImageSize->{67, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.5.4",
 CellLabel->"Out[122]=",
 CellID->898067845]
}, Open  ]],

Cell[TextData[{
 "\:041a\:043b\:044e\:0447 ",
 Cell[BoxData[
  RowBox[{"/", "s"}]], "InlineCode"],
 " \:0441\:0436\:0438\:043c\:0430\:0435\:0442 \:0434\:043e \:043e\:0434\:043d\
\:043e\:0433\:043e \:0432\:0441\:0435 \:043f\:043e\:0441\:043b\:0435\:0434\
\:043e\:0432\:0430\:0442\:0435\:043b\:044c\:043d\:043e\:0441\:0442\:0438 \
\:043e\:0434\:0438\:043d\:0430\:043a\:043e\:0432\:044b\:0445 \:0441\:0438\
\:043c\:0432\:043e\:043b\:043e\:0432."
}], "MathCaption",
 CellTags->"b:0.5.4",
 CellID->117673595],

Cell["\<\
$text = \"abbcccddddeeeeeeffeeded\";
$text =~ tr/abcde/ABCD/s\
\>", "Program",
 CellTags->"b:0.5.4",
 CellID->144624070],

Cell[TextData[{
 "\:0422\:0430\:043a\:043e\:0439 \:0436\:0435 \:0440\:0435\:0437\:0443\:043b\
\:044c\:0442\:0430\:0442 \:0434\:043e\:0441\:0442\:0438\:0433\:0430\:0435\
\:0442\:0441\:044f \:0432 ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " \:043f\:0440\:0438 \:043f\:043e\:043c\:043e\:0449\:0438 ",
 Cell[BoxData[
  TemplateBox[{Cell["Repeated"],"paclet:ref/Repeated"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " (",
 Cell[BoxData[".."], "InlineFormula"],
 ")."
}], "MathCaption",
 CellTags->"b:0.5.4",
 CellID->688187582],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"text", "=", "\"\<abbcccddddeeeeeeffeeded\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"StringReplace", "[", 
  RowBox[{"text", ",", 
   RowBox[{"Append", "[", 
    RowBox[{
     RowBox[{"Thread", "[", 
      RowBox[{"Rule", "[", 
       RowBox[{
        RowBox[{"Repeated", "/@", 
         RowBox[{"Characters", "[", "\"\<abc\>\"", "]"}]}], ",", 
        RowBox[{"Characters", "[", "\"\<ABC\>\"", "]"}]}], "]"}], "]"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"Characters", "[", "\"\<de\>\"", "]"}], ".."}], "\[Rule]", 
      "\"\<D\>\""}]}], "]"}]}], "]"}]}], "Input",
 CellTags->"b:0.5.4",
 CellLabel->"In[123]:=",
 CellID->141316627],

Cell[BoxData["\<\"ABCDffD\"\>"], "Output",
 ImageSize->{53, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.5.4",
 CellLabel->"Out[124]=",
 CellID->57680932]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\:041d\:0435\:0441\:043a\:043e\:043b\:044c\:043a\:043e \:043f\:0440\
\:0438\:043c\:0435\:0440\:043e\:0432", "Section",
 CellTags->"c:20",
 CellID->2083974],

Cell["\<\
\:0412 \:044d\:0442\:043e\:043c \:0440\:0430\:0437\:0434\:0435\:043b\:0435 \
\:043f\:0440\:0435\:0434\:0441\:0442\:0430\:0432\:043b\:0435\:043d\:044b \
\:043d\:0435\:0441\:043a\:043e\:043b\:044c\:043a\:043e \:043a\:0440\:0430\
\:0442\:043a\:0438\:0445 \:043f\:0440\:0438\:043c\:0435\:0440\:043e\:0432 \
\:0438\:0441\:043f\:043e\:043b\:044c\:0437\:043e\:0432\:0430\:043d\:0438\:044f\
 \:0448\:0430\:0431\:043b\:043e\:043d\:043e\:0432 \:0434\:043b\:044f \:0442\
\:0435\:043a\:0441\:0442\:043e\:0432\:044b\:0445 \:0444\:0440\:0430\:0433\
\:043c\:0435\:043d\:0442\:043e\:0432. \
\>", "Text",
 CellID->118415745],

Cell[CellGroupData[{

Cell["\:041f\:043e\:0434\:0441\:0432\:0435\:0447\:0438\:0432\:0430\:0435\:043c\
 \:0441\:043e\:0432\:043f\:0430\:0434\:0435\:043d\:0438\:044f", "Subsection",
 CellTags->{"c:22", "b:0.6.1"},
 CellID->738873845],

Cell["\<\
\:0422\:0430\:043a \:0441\:043e\:0437\:0434\:0430\:0435\:0442\:0441\:044f \
\:0442\:0435\:043a\:0441\:0442\:043e\:0432\:044b\:0439 \:0444\:0440\:0430\
\:0433\:043c\:0435\:043d\:0442, \:043e\:0442\:043e\:0436\:0434\:0435\:0441\
\:0442\:0432\:043b\:044f\:044e\:0449\:0438\:0439 \:043f\:0440\:043e\:0438\
\:0437\:0432\:043e\:043b\:044c\:043d\:0443\:044e \:0446\:0435\:043f\:043e\
\:0447\:043a\:0443 \:0414\:041d\:041a \:0438\:0437 1000 \:044d\:043b\:0435\
\:043c\:0435\:043d\:0442\:043e\:0432. \
\>", "MathCaption",
 CellTags->"b:0.6.1",
 CellID->24257838],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"SeedRandom", "[", "12345", "]"}], ";", 
  RowBox[{"dna", "=", 
   RowBox[{"StringJoin", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{
        "\"\<a\>\"", ",", "\"\<c\>\"", ",", "\"\<g\>\"", ",", "\"\<t\>\""}], 
        "}"}], "[", 
       RowBox[{"[", 
        RowBox[{"RandomInteger", "[", 
         RowBox[{"{", 
          RowBox[{"1", ",", "4"}], "}"}], "]"}], "]"}], "]"}], ",", 
      RowBox[{"{", "1000", "}"}]}], "]"}], "]"}]}]}]], "Input",
 CellTags->"b:0.6.1",
 CellLabel->"In[125]:=",
 CellID->140406151],

Cell[BoxData["\<\"\
acttaagctttcgggtgagtgtactgcccactcctagctttcctttagttcttagacgagctggcgcgtagatggcta\
cgtgacttgaatgcattagtgtctagatgcattatggaaccattccaatcgtctcggagggctagtgctgccatcttg\
gttatgtggtatcgtgatttgaatcagtccagcgctataaagtcttcgctgttaggctgcaggagccgagggcatcgg\
acgtacaaaatgcgggggtagactgacgaccgcagaggccacatacgacaggccgccggcgtgcgactagatagccgc\
gagtggggttggctaagcacatcgaagtgtacagaaaacccctaccccatgagtcgtgcagacgcctccagaaaccag\
gagtttacagcaggacctgagaactaatgttaatgctccatcacctctgcatgcctatccattaagcaaggcacactc\
agcccctaaaagcgagcggctccccaggagaagcttacactcagtgatcgaggtttactcaccagttcacgtactgat\
acgaatcggtaccggtccggctatgacgtcacctactgcggtaagcgtcctgagttgttaaggctcggagtgcccgcg\
gtgagcatggctccagattgcctcactgtctctgatccgagaaggagtggacacgtaacaccagtacgggactctgta\
ccgacgtgtgttaccataactgtttatcccttgtgtcttagtccgacggtatgtgtacgtgcgcacacgacaagtcac\
ctccctccaggaccaaacgcaaaccatgtgggtatctcagcattttcgccaccatgcatattctccttaacatttcag\
ctggccccgactgcttcttgtggtcagacttcgtcacttttgccgtgcacttcctgtattcgaatgtcgggcgggaac\
gaggtgagtggcacagctcttctacgaatgcgcaactagacatcgattcacgcgtcctgggacg\"\>"], \
"Output",
 ImageSize->{578, 220},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.6.1",
 CellLabel->"Out[125]=",
 CellID->152083121]
}, Open  ]],

Cell["\<\
\:0422\:0430\:043a \:0440\:0435\:0430\:043b\:0438\:0437\:0443\:0435\:0442\
\:0441\:044f \"\:043f\:043e\:0434\:0441\:0432\:0435\:0442\:043a\:0430\" \
\:0447\:0430\:0441\:0442\:0435\:0439 \:0414\:041d\:041a, \:0441\:043e\:043e\
\:0442\:0432\:0435\:0442\:0441\:0442\:0432\:0443\:044e\:0449\:0438\:0445 \
\:0437\:0430\:0434\:0430\:043d\:043d\:043e\:043c\:0443 \:0448\:0430\:0431\
\:043b\:043e\:043d\:0443.\
\>", "MathCaption",
 CellTags->"b:0.6.1",
 CellID->301369684],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringReplace", "[", 
  RowBox[{"dna", ",", 
   RowBox[{
    RowBox[{"x", ":", 
     RowBox[{"(", 
      RowBox[{"\"\<ag\>\"", "~~", 
       RowBox[{"_", "~~", 
        RowBox[{"_", "~~", 
         RowBox[{"\"\<t\>\"", "~~", 
          RowBox[{"_", "~~", "\"\<ca\>\""}]}]}]}]}], ")"}]}], 
    "\[RuleDelayed]", 
    RowBox[{
    "\"\<\\!\\(\\*StyleBox[\\\"\>\"", "<>", "x", "<>", 
     "\"\<\\\",FontColor->RGBColor[1,0,0],FontSize->18,FontWeight->\\\"Bold\\\
\"]\\)\>\""}]}]}], "]"}]], "Input",
 CellTags->"b:0.6.1",
 CellLabel->"In[126]:=",
 CellID->614903007],

Cell[BoxData["\<\"\
acttaagctttcgggtgagtgtactgcccactcctagctttcctttagttcttagacgagctggcgcgtagatggcta\
cgtgacttgaatgcattagtgtctagatgcattatggaaccattccaatcgtctcggagggctagtgctgccatcttg\
gttatgtggtatcgtgatttgaatcagtccagcgctataaagtcttcgctgtt\\!\\(\\*StyleBox[\\\"\
aggctgca\\\",FontColor->RGBColor[1,0,0],FontSize->18,FontWeight->\\\"Bold\\\"]\
\\)ggagccgagggcatcggacgtacaaaatgcgggggtagactgacgaccgcagaggccacatacgacaggccgccg\
gcgtgcgactagatagccgcgagtggggttggctaagcacatcga\\!\\(\\*StyleBox[\\\"agtgtaca\\\
\",FontColor->RGBColor[1,0,0],FontSize->18,FontWeight->\\\"Bold\\\"]\\)\
gaaaacccctaccccatgagtcgtgcagacgcctccagaaaccagg\\!\\(\\*StyleBox[\\\"agtttaca\\\
\",FontColor->RGBColor[1,0,0],FontSize->18,FontWeight->\\\"Bold\\\"]\\)\
gcaggacctgagaactaatgttaatgctccatcacctctgcatgcctatccattaagcaaggcacactcagcccctaa\
aagcgagcggctccccaggaga\\!\\(\\*StyleBox[\\\"agcttaca\\\",FontColor->RGBColor[\
1,0,0],FontSize->18,FontWeight->\\\"Bold\\\"]\\)\
ctcagtgatcgaggtttactcaccagttcacgtactgatacgaatcggtaccggtccggctatgacgtcacctactgc\
ggtaagcgtcctgagttgttaaggctcggagtgcccgcggtgagcatggctccagattgcctcactgtctctgatccg\
agaaggagtggacacgtaacaccagtacgggactctgtaccgacgtgtgttaccataactgtttatcccttgtgtctt\
agtccgacggtatgtgtacgtgcgcacacgacaagtcacctccctccaggaccaaacgcaaaccatgtgggtatctca\
gcattttcgccaccatgcatattctccttaacatttcagctggccccgactgcttcttgtggtcagacttcgtcactt\
ttgccgtgcacttcctgtattcgaatgtcgggcgggaacgaggtgagtggcacagctcttctacgaatgcgcaactag\
acatcgattcacgcgtcctgggacg\"\>"], "Output",
 ImageSize->{584, 237},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.6.1",
 CellLabel->"Out[126]=",
 CellID->79975839]
}, Open  ]],

Cell["\<\
\:0417\:0434\:0435\:0441\:044c \:043f\:043e\:043b\:0443\:0447\:0435\:043d \
\:0442\:043e\:0442 \:0436\:0435 \:0441\:0430\:043c\:044b\:0439 \:0440\:0435\
\:0437\:0443\:043b\:044c\:0442\:0430\:0442, \:043d\:043e \:0441 \:043f\:043e\
\:043c\:043e\:0449\:044c\:044e \:0440\:0435\:0433\:0443\:043b\:044f\:0440\
\:043d\:044b\:0445 \:0432\:044b\:0440\:0430\:0436\:0435\:043d\:0438\:0439.\
\>", "MathCaption",
 CellTags->"b:0.6.1",
 CellID->12939824],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringReplace", "[", 
  RowBox[{"dna", ",", 
   RowBox[{
    RowBox[{"RegularExpression", "[", "\"\<ag..t.ca\>\"", "]"}], 
    "\[RuleDelayed]", 
    "\"\<\\!\\(\\*StyleBox[\\\"$0\\\",FontColor->RGBColor[1,0,0],FontSize->18,\
FontWeight->\\\"Bold\\\"]\\)\>\""}]}], "]"}]], "Input",
 CellTags->"b:0.6.1",
 CellLabel->"In[127]:=",
 CellID->131627168],

Cell[BoxData["\<\"\
acttaagctttcgggtgagtgtactgcccactcctagctttcctttagttcttagacgagctggcgcgtagatggcta\
cgtgacttgaatgcattagtgtctagatgcattatggaaccattccaatcgtctcggagggctagtgctgccatcttg\
gttatgtggtatcgtgatttgaatcagtccagcgctataaagtcttcgctgtt\\!\\(\\*StyleBox[\\\"\
aggctgca\\\",FontColor->RGBColor[1,0,0],FontSize->18,FontWeight->\\\"Bold\\\"]\
\\)ggagccgagggcatcggacgtacaaaatgcgggggtagactgacgaccgcagaggccacatacgacaggccgccg\
gcgtgcgactagatagccgcgagtggggttggctaagcacatcga\\!\\(\\*StyleBox[\\\"agtgtaca\\\
\",FontColor->RGBColor[1,0,0],FontSize->18,FontWeight->\\\"Bold\\\"]\\)\
gaaaacccctaccccatgagtcgtgcagacgcctccagaaaccagg\\!\\(\\*StyleBox[\\\"agtttaca\\\
\",FontColor->RGBColor[1,0,0],FontSize->18,FontWeight->\\\"Bold\\\"]\\)\
gcaggacctgagaactaatgttaatgctccatcacctctgcatgcctatccattaagcaaggcacactcagcccctaa\
aagcgagcggctccccaggaga\\!\\(\\*StyleBox[\\\"agcttaca\\\",FontColor->RGBColor[\
1,0,0],FontSize->18,FontWeight->\\\"Bold\\\"]\\)\
ctcagtgatcgaggtttactcaccagttcacgtactgatacgaatcggtaccggtccggctatgacgtcacctactgc\
ggtaagcgtcctgagttgttaaggctcggagtgcccgcggtgagcatggctccagattgcctcactgtctctgatccg\
agaaggagtggacacgtaacaccagtacgggactctgtaccgacgtgtgttaccataactgtttatcccttgtgtctt\
agtccgacggtatgtgtacgtgcgcacacgacaagtcacctccctccaggaccaaacgcaaaccatgtgggtatctca\
gcattttcgccaccatgcatattctccttaacatttcagctggccccgactgcttcttgtggtcagacttcgtcactt\
ttgccgtgcacttcctgtattcgaatgtcgggcgggaacgaggtgagtggcacagctcttctacgaatgcgcaactag\
acatcgattcacgcgtcctgggacg\"\>"], "Output",
 ImageSize->{584, 237},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.6.1",
 CellLabel->"Out[127]=",
 CellID->678802383]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\:0410\:043d\:0430\:043b\:0438\:0437 \:043a\:043e\:0434\:0430 HTML", \
"Subsection",
 CellTags->{"c:23", "b:0.6.2"},
 CellID->146223979],

Cell["\<\
\:0428\:0430\:0431\:043b\:043e\:043d\:044b \:0434\:043b\:044f \:0442\:0435\
\:043a\:0441\:0442\:043e\:0432\:044b\:0445 \:0444\:0440\:0430\:0433\:043c\
\:0435\:043d\:0442\:043e\:0432 \:044f\:0432\:043b\:044f\:044e\:0442\:0441\
\:044f \:0443\:0434\:043e\:0431\:043d\:044b\:043c \:0438\:043d\:0441\:0442\
\:0440\:0443\:043c\:0435\:043d\:0442\:043e\:043c \:0434\:043b\:044f \:0438\
\:0437\:0432\:043b\:0435\:0447\:0435\:043d\:0438\:044f \:0438\:043d\:0444\
\:043e\:0440\:043c\:0430\:0446\:0438\:0438 \:0438\:0437 \:043d\:0435\:0444\
\:043e\:0440\:043c\:0430\:0442\:0438\:0440\:043e\:0432\:0430\:043d\:043d\:043e\
\:0433\:043e HTML \:043a\:043e\:0434\:0430.\
\>", "Text",
 CellTags->"b:0.6.2",
 CellID->454604247],

Cell[TextData[{
 "\:0412\:043e\:0442 \:0438\:0441\:0445\:043e\:0434\:043d\:044b\:0439 \:043a\
\:043e\:0434 \:0438\:0437 ",
 ButtonBox["www.google.com",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www.google.com"], None}],
 "."
}], "MathCaption",
 CellTags->"b:0.6.2",
 CellID->450806450],

Cell[BoxData[
 RowBox[{
  RowBox[{
  "text", "=", 
   "\"\<\\<<html><head><meta http-equiv='content-type' \
content='text/html;charset=UTF-8'><title>Google</title><style><!--body,td,a,p,\
.h{font-family:arial,sans-serif;}\n.h{font-size:20px;}\n.q{color:#0000cc;}\n\
//-->\[IndentingNewLine]</style>\[IndentingNewLine]<script>\[IndentingNewLine]\
<!--function sf(){document.f.q.focus();}\n//-->\[IndentingNewLine]</script>\
\[IndentingNewLine]</head><body bgcolor=#ffffff text=#000000 link=#0000cc \
vlink=#551a8b alink=#ff0000 onLoad=sf()><center><table border=0 cellspacing=0 \
cellpadding=0><tr><td><img src='/images/logo.gif' width=276 height=110 \
alt='Google'></td></tr></table><br>\[IndentingNewLine]<form action='/search' \
name=f><script><!--function qs(el) {if \
(window.RegExp&&window.encodeURIComponent) {var \
qe=encodeURIComponent(document.f.q.value);if \
(el.href.indexOf('q=')\[NotEqual]-1) {el.href=el.href.replace(new \
RegExp('q=[^&$]*'),'q='+qe);} else {el.href+='&q='+qe;}}return 1;}\n//-->\
\[IndentingNewLine]</script><table border=0 cellspacing=0 \
cellpadding=4><tr><td nowrap class=q><font size=-1><b><font \
color=#000000>Web</font></b>&nbsp;&nbsp;&nbsp;&nbsp;<a id=1a class=q \
href='/imghp?hl=en&tab=wi' onClick='return \
qs(this);'>Images</a>&nbsp;&nbsp;&nbsp;&nbsp;<a id=2a class=q \
href='/grphp?hl=en&tab=wg' onClick='return \
qs(this);'>Groups</a>&nbsp;&nbsp;&nbsp;&nbsp;<a id=4a class=q \
href='/nwshp?hl=en&tab=wn' onClick='return \
qs(this);'>News</a>&nbsp;&nbsp;&nbsp;&nbsp;<a id=5a class=q \
href='/froogle?hl=en&tab=wf' onClick='return \
qs(this);'>Froogle</a>&nbsp;&nbsp;&nbsp;&nbsp;<b><a \
href='/options/index.html' \
class=q>more&nbsp;&raquo;</a></b></font></td></tr></table>  <table \
cellspacing=0 cellpadding=0><tr><td width=25%>&nbsp;</td><td \
align=center><input type=hidden name=hl value=en><span id=hf></span><input \
type=hidden name=ie value='UTF-8'><input maxLength=256 size=55 name=q \
value=''><br><input type=submit value='Google Search' name=btnG><input \
type=submit value='I'm Feeling Lucky' name=btnI></td><td valign=top nowrap \
width=25%><font size=-2>&nbsp;&nbsp;<a \
href=/advanced_search?hl=en>Advanced&nbsp;Search</a><br>&nbsp;&nbsp;<a \
href=/preferences?hl=en>Preferences</a><br>&nbsp;&nbsp;<a \
href=/language_tools?hl=en>Language \
Tools</a></font></td></tr></table></form><br><br><font size=-1><a \
href='/ads/'>Advertising&nbsp;Programs</a>- <a \
href='/services/'>Business&nbsp;Solutions</a>- <a href=/about.html>About \
Google</a><span id=hp style='behavior:url(#default#homepage)'></span>\
\[IndentingNewLine]<script>\[IndentingNewLine]//<!--if \
(!hp.isHomePage('http://www.google.com/')) {document.write('<p><a \
href=\\'/mgyhp.html\\' \
onClick=\\'style.behavior='url(#default#homepage)';setHomePage('http://www.\
google.com/');\\'>Make Google Your Homepage!</a>');}\n\
//-->\[IndentingNewLine]</script></font><p><font size=-2>&copy;2004 \
Google-Searching 4,285,199,774 web pages</font></p></center></body></html>\\>\
\>\""}], ";"}]], "Input",
 CellTags->"b:0.6.2",
 CellLabel->"In[128]:=",
 CellID->237894310],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringLength", "[", "text", "]"}]], "Input",
 CellTags->"b:0.6.2",
 CellLabel->"In[129]:=",
 CellID->73854272],

Cell[BoxData["2639"], "Output",
 ImageSize->{32, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.6.2",
 CellLabel->"Out[129]=",
 CellID->435720061]
}, Open  ]],

Cell["\:0422\:0430\:043a \:0438\:0437 \:0438\:0441\:0445\:043e\:0434\:043d\
\:043e\:0433\:043e \:043a\:043e\:0434\:0430 \:0438\:0437\:0432\:043b\:0435\
\:043a\:0430\:044e\:0442\:0441\:044f \:0432\:0441\:0435 \:043f\:0440\:044f\
\:043c\:044b\:0435 \:0433\:0438\:043f\:0435\:0440\:0441\:0441\:044b\:043b\
\:043a\:0438.", "MathCaption",
 CellTags->"b:0.6.2",
 CellID->328231447],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringCases", "[", 
  RowBox[{"text", ",", 
   RowBox[{
    RowBox[{"Shortest", "[", 
     RowBox[{"\"\<<a\>\"", "~~", 
      RowBox[{"__", "~~", 
       RowBox[{"\"\<href=\>\"", "~~", 
        RowBox[{"ref__", "~~", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"WhitespaceCharacter", "|", "\"\<>\>\""}], ")"}], "~~", 
          RowBox[{"___", "~~", "\"\<>\>\""}]}]}]}]}]}], "]"}], 
    "\[RuleDelayed]", "ref"}]}], "]"}]], "Input",
 CellTags->"b:0.6.2",
 CellLabel->"In[130]:=",
 CellID->10965036],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"'/imghp?hl=en&tab=wi'\"\>", 
   ",", "\<\"'/grphp?hl=en&tab=wg'\"\>", ",", "\<\"'/nwshp?hl=en&tab=wn'\"\>",
    ",", "\<\"'/froogle?hl=en&tab=wf'\"\>", 
   ",", "\<\"'/options/index.html'\"\>", 
   ",", "\<\"/advanced_search?hl=en\"\>", ",", "\<\"/preferences?hl=en\"\>", 
   ",", "\<\"/language_tools?hl=en\"\>", ",", "\<\"'/ads/'\"\>", 
   ",", "\<\"'/services/'\"\>", ",", "\<\"/about.html\"\>", 
   ",", "\<\"\\\\'/mgyhp.html\\\\'\"\>"}], "}"}]], "Output",
 ImageSize->{496, 67},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.6.2",
 CellLabel->"Out[130]=",
 CellID->658475649]
}, Open  ]],

Cell[TextData[{
 "\:0422\:0430\:043a \:0443\:0434\:0430\:043b\:044f\:0435\:0442\:0441\:044f \
\:0432\:0441\:0435, \:0447\:0442\:043e \:043d\:0430\:0445\:043e\:0434\:0438\
\:0442\:0441\:044f \:0432\:043d\:0443\:0442\:0440\:0438 \:0442\:0435\:0433\
\:043e\:0432 ",
 Cell[BoxData[
  RowBox[{"<", 
   StyleBox["\[Ellipsis]", "TR"], ">"}]], "InlineFormula"],
 "."
}], "MathCaption",
 CellTags->"b:0.6.2",
 CellID->135521350],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringReplace", "[", 
  RowBox[{"text", ",", 
   RowBox[{
    RowBox[{"Shortest", "[", 
     RowBox[{"\"\<<\>\"", "~~", "___", "~~", "\"\<>\>\""}], "]"}], "\[Rule]", 
    "\"\<\>\""}]}], "]"}]], "Input",
 CellTags->"b:0.6.2",
 CellLabel->"In[131]:=",
 CellID->499683580],

Cell[BoxData["\<\"Google\[IndentingNewLine]\[IndentingNewLine]\
\[IndentingNewLine]\[IndentingNewLine]\[IndentingNewLine]\[IndentingNewLine]\
\[IndentingNewLine]Web&nbsp;&nbsp;&nbsp;&nbsp;Images&nbsp;&nbsp;&nbsp;&nbsp;\
Groups&nbsp;&nbsp;&nbsp;&nbsp;News&nbsp;&nbsp;&nbsp;&nbsp;Froogle&nbsp;&nbsp;&\
nbsp;&nbsp;more&nbsp;&raquo;  \
&nbsp;&nbsp;&nbsp;Advanced&nbsp;Search&nbsp;&nbsp;Preferences&nbsp;&nbsp;\
Language ToolsAdvertising&nbsp;Programs- Business&nbsp;Solutions- About \
Google\[IndentingNewLine]\[IndentingNewLine]//Make Google Your \
Homepage!');}\\n//-->\[IndentingNewLine]&copy;2004 Google-Searching \
4,285,199,774 web pages\"\>"], "Output",
 ImageSize->{579, 288},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.6.2",
 CellLabel->"Out[131]=",
 CellID->339097831]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\:041f\:043e\:0438\:0441\:043a \:0434\:0435\:043d\:0435\:0436\:043d\
\:044b\:0445 \:0437\:043d\:0430\:043a\:043e\:0432", "Subsection",
 CellTags->{"c:24", "b:0.6.3"},
 CellID->263221749],

Cell["\<\
\:0412\:043e\:0442 \:0442\:0435\:043a\:0441\:0442, \:0433\:0434\:0435 \:043d\
\:0443\:0436\:043d\:043e \:043d\:0430\:0439\:0442\:0438 \:0444\:0440\:0430\
\:0433\:043c\:0435\:043d\:0442\:044b, \:043a\:043e\:0442\:043e\:0440\:044b\
\:0435 \:0432\:044b\:0433\:043b\:044f\:0434\:044f\:0442 \:043a\:0430\:043a \
\:0441\:0443\:043c\:043c\:044b \:0432 \:0434\:043e\:043b\:043b\:0430\:0440\
\:0430\:0445.\
\>", "MathCaption",
 CellTags->"b:0.6.3",
 CellID->456762081],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"text", "=", 
  "\"\<This $100 sentence can be bought for $85.00, at 15% discount\>\""}]], \
"Input",
 CellTags->"b:0.6.3",
 CellLabel->"In[132]:=",
 CellID->324262933],

Cell[BoxData["\<\"This $100 sentence can be bought for $85.00, at 15% \
discount\"\>"], "Output",
 ImageSize->{424, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.6.3",
 CellLabel->"Out[132]=",
 CellID->84181818]
}, Open  ]],

Cell["\<\
\:042d\:0442\:043e \:043e\:0434\:0438\:043d \:0438\:0437 \:0441\:043f\:043e\
\:0441\:043e\:0431\:043e\:0432 \:0440\:0435\:0430\:043b\:0438\:0437\:0430\
\:0446\:0438\:0438 \:043f\:043e\:0438\:0441\:043a\:0430, \:0441 \:043f\:043e\
\:043c\:043e\:0449\:044c\:044e \:0441\:0438\:043c\:0432\:043e\:043b\:044c\
\:043d\:044b\:0445 \:0448\:0430\:0431\:043b\:043e\:043d\:043e\:0432.\
\>", "MathCaption",
 CellTags->"b:0.6.3",
 CellID->47750368],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringCases", "[", 
  RowBox[{"text", ",", 
   RowBox[{"\"\<$\>\"", "~~", 
    RowBox[{
     RowBox[{"DigitCharacter", ".."}], "~~", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"\"\<.\>\"", "~~", 
         RowBox[{"DigitCharacter", ".."}]}], ")"}], "|", "\"\<\>\""}], 
      ")"}]}]}]}], "]"}]], "Input",
 CellTags->"b:0.6.3",
 CellLabel->"In[133]:=",
 CellID->16455114],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"$100\"\>", ",", "\<\"$85.00\"\>"}], "}"}]], "Output",
 ImageSize->{99, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.6.3",
 CellLabel->"Out[133]=",
 CellID->1028029313]
}, Open  ]],

Cell["\<\
\:0412\:043e\:0442 \:0440\:0435\:0448\:0435\:043d\:0438\:0435 \:044d\:0442\
\:043e\:0439 \:0436\:0435 \:0437\:0430\:0434\:0430\:0447\:0438 \:0441 \:0438\
\:0441\:043f\:043e\:043b\:044c\:0437\:043e\:0432\:0430\:043d\:0438\:0435\:043c\
 \:0440\:0435\:0433\:0443\:043b\:044f\:0440\:043d\:044b\:0445 \:0432\:044b\
\:0440\:0430\:0436\:0435\:043d\:0438\:0439 (\:043d\:0430\:043f\:043e\:043c\
\:043d\:0438\:043c, \:0447\:0442\:043e \:043d\:0443\:0436\:043d\:043e \:0438\
\:0437\:0431\:0435\:0433\:0430\:0442\:044c \:0437\:043d\:0430\:043a\:0430 \
\:0434\:043e\:043b\:043b\:0430\:0440\:0430\:0432 \:0440\:0435\:0433\:0443\
\:043b\:044f\:0440\:043d\:044b\:0445 \:0432\:044b\:0440\:0430\:0436\:0435\
\:043d\:0438\:044f\:0445, \:0430 \:0432 \:0441\:043b\:0443\:0447\:0430\:0435 \
\:0442\:0430\:043a\:043e\:0439 \:043d\:0435\:043e\:0431\:0445\:043e\:0434\
\:0438\:043c\:043e\:0441\:0442\:0438, \:043f\:043e\:043b\:044c\:0437\:043e\
\:0432\:0430\:0442\:044c\:0441\:044f \:0441\:043f\:0435\:0446\:0438\:0430\
\:043b\:044c\:043d\:043e\:0439 \:043a\:043e\:043d\:0441\:0442\:0440\:0443\
\:043a\:0446\:0438\:0435\:0439).\
\>", "MathCaption",
 CellTags->"b:0.6.3",
 CellID->507462346],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringCases", "[", 
  RowBox[{"text", ",", 
   RowBox[{
   "RegularExpression", "[", "\"\<\\\\$\\\\d+(\\\\.\\\\d+)?\>\"", "]"}]}], 
  "]"}]], "Input",
 CellTags->"b:0.6.3",
 CellLabel->"In[134]:=",
 CellID->28199983],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"$100\"\>", ",", "\<\"$85.00\"\>"}], "}"}]], "Output",
 ImageSize->{99, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.6.3",
 CellLabel->"Out[134]=",
 CellID->211704891]
}, Open  ]],

Cell[TextData[{
 "\:0412 \:0434\:0430\:043d\:043d\:043e\:0439 \:043a\:043e\:043d\:043a\:0440\
\:0435\:0442\:043d\:043e\:0439 \:0441\:0438\:0442\:0443\:0430\:0446\:0438\
\:0438, \:043c\:043e\:0436\:043d\:043e \:0442\:0430\:043a\:0436\:0435 \:0432\
\:043e\:0441\:043f\:043e\:043b\:044c\:0437\:043e\:0432\:0430\:0442\:044c\:0441\
\:044f \:0432\:0441\:0442\:0440\:043e\:0435\:043d\:043d\:044b\:043c \:0448\
\:0430\:0431\:043b\:043e\:043d\:043d\:044b\:043c \:043e\:0431\:044a\:0435\
\:043a\:0442\:043e\:043c ",
 Cell[BoxData[
  TemplateBox[{Cell["NumberString"],"paclet:ref/NumberString"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 "."
}], "MathCaption",
 CellTags->"b:0.6.3",
 CellID->1024052339],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringCases", "[", 
  RowBox[{"text", ",", 
   RowBox[{"\"\<$\>\"", "~~", "NumberString"}]}], "]"}]], "Input",
 CellTags->"b:0.6.3",
 CellLabel->"In[135]:=",
 CellID->5891025],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"$100\"\>", ",", "\<\"$85.00\"\>"}], "}"}]], "Output",
 ImageSize->{99, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.6.3",
 CellLabel->"Out[135]=",
 CellID->182707870]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\:041f\:043e\:0438\:0441\:043a \:0442\:0435\:043a\:0441\:0442\:0430 \
\:0432 \:0444\:0430\:0439\:043b\:0430\:0445", "Subsection",
 CellTags->"b:0.6.4",
 CellID->355263806],

Cell["\<\
\:0412\:043e\:0442 \:043e\:0447\:0435\:043d\:044c \:043f\:0440\:043e\:0441\
\:0442\:0430\:044f \:0444\:0443\:043d\:043a\:0446\:0438\:044f \:0434\:043b\
\:044f \:043f\:043e\:0438\:0441\:043a\:0430 \:0432 \:0442\:0435\:043a\:0441\
\:0442\:043e\:0432\:043e\:043c \:0444\:0430\:0439\:043b\:0435 \:0441\:0442\
\:0440\:043e\:043a, \:043a\:043e\:0442\:043e\:0440\:044b\:0435 \:0441\:043e\
\:0434\:0435\:0440\:0436\:0430\:0442 \:0442\:0435\:043a\:0441\:0442, \:0441\
\:043e\:043e\:0442\:0432\:0435\:0442\:0441\:0442\:0432\:0443\:044e\:0449\:0438\
\:0439 \:0437\:0430\:0434\:0430\:043d\:043d\:043e\:043c\:0443 \:0448\:0430\
\:0431\:043b\:043e\:043d\:0443.\
\>", "MathCaption",
 CellTags->"b:0.6.4",
 CellID->115242927],

Cell[BoxData[
 RowBox[{
  RowBox[{"Grep", "[", 
   RowBox[{"file_", ",", "patt_"}], "]"}], ":=", 
  RowBox[{"With", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"data", "=", 
      RowBox[{"Import", "[", 
       RowBox[{"file", ",", "\"\<Lines\>\""}], "]"}]}], "}"}], ",", 
    RowBox[{"Pick", "[", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Range", "[", 
          RowBox[{"Length", "[", "data", "]"}], "]"}], ",", "data"}], "}"}], 
       "]"}], ",", 
      RowBox[{"StringFreeQ", "[", 
       RowBox[{"data", ",", " ", "patt"}], "]"}], ",", "False"}], "]"}]}], 
   "]"}]}]], "Input",
 CellTags->"b:0.6.4",
 CellLabel->"In[136]:=",
 CellID->78571466],

Cell["\:0422\:0430\:043a \:0441\:043e\:0437\:0434\:0430\:0435\:0442\:0441\
\:044f \:043f\:0440\:043e\:0431\:043d\:044b\:0439 \:0442\:0435\:043a\:0441\
\:0442\:043e\:0432\:044b\:0439 \:0444\:0430\:0439\:043b.", "MathCaption",
 CellTags->"b:0.6.4",
 CellID->97869725],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Export", "[", 
  RowBox[{"\"\<test.txt\>\"", ",", 
   RowBox[{"{", 
    RowBox[{
    "\"\<this is a line\>\"", ",", "\"\<a line with 2 numbers 5\>\"", ",", 
     "\"\<third line and more\>\"", ",", "\"\<line 4\>\""}], "}"}], ",", 
   "\"\<Lines\>\""}], "]"}]], "Input",
 CellTags->"b:0.6.4",
 CellLabel->"In[137]:=",
 CellID->46155371],

Cell[BoxData["\<\"test.txt\"\>"], "Output",
 ImageSize->{60, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.6.4",
 CellLabel->"Out[137]=",
 CellID->551981229]
}, Open  ]],

Cell[TextData[{
 "\:042d\:0442\:043e \:0432\:043e\:0437\:0432\:0440\:0430\:0449\:0430\:0435\
\:0442 \:043d\:043e\:043c\:0435\:0440\:0430 \:0441\:0442\:0440\:043e\:043a \
\:0438 \:0441\:0430\:043c\:0438 \:0441\:0442\:0440\:043e\:043a\:0438 \:0438\
\:0437 ",
 Cell[BoxData["\<\"text.txt\"\>"], "InlineFormula"],
 ", \:043a\:043e\:0442\:043e\:0440\:044b\:0435 \:0441\:043e\:0434\:0435\:0440\
\:0436\:0430\:0442 \:043b\:044e\:0431\:044b\:0435 \:0446\:0438\:0444\:0440\
\:044b."
}], "MathCaption",
 CellTags->"b:0.6.4",
 CellID->252811811],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Grep", "[", 
   RowBox[{"\"\<test.txt\>\"", ",", "DigitCharacter"}], "]"}], "//", 
  "TableForm"}]], "Input",
 CellTags->"b:0.6.4",
 CellLabel->"In[138]:=",
 CellID->580624370],

Cell[BoxData[
 TagBox[GridBox[{
    {"2", "\<\"a line with 2 numbers 5\"\>"},
    {"4", "\<\"line 4\"\>"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 ImageSize->{197, 27},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.6.4",
 CellLabel->"Out[138]//TableForm=",
 CellID->776583665]
}, Open  ]],

Cell[TextData[{
 "\:0422\:0430\:043a \:0432\:044b\:043f\:043e\:043b\:043d\:044f\:0435\:0442\
\:0441\:044f \:043f\:043e\:0438\:0441\:043a \:0441\:0442\:0440\:043e\:043a, \
\:0441\:043e\:0434\:0435\:0440\:0436\:0430\:0449\:0438\:0445 ",
 Cell[BoxData["\<\"a\"\>"], "InlineFormula"],
 " \:0432 \:0432\:0438\:0434\:0435 \:043e\:0442\:0434\:0435\:043b\:044c\:043d\
\:043e\:0433\:043e \:0441\:043b\:043e\:0432\:0430."
}], "MathCaption",
 CellTags->"b:0.6.4",
 CellID->612266699],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Grep", "[", 
   RowBox[{"\"\<test.txt\>\"", ",", 
    RowBox[{"RegularExpression", "[", "\"\<\\\\ba\\\\b\>\"", "]"}]}], "]"}], "//",
   "TableForm"}]], "Input",
 CellTags->"b:0.6.4",
 CellLabel->"In[139]:=",
 CellID->28035752],

Cell[BoxData[
 TagBox[GridBox[{
    {"1", "\<\"this is a line\"\>"},
    {"2", "\<\"a line with 2 numbers 5\"\>"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 ImageSize->{197, 27},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.6.4",
 CellLabel->"Out[139]//TableForm=",
 CellID->552317211]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\:0421\:043e\:0432\:0435\:0442\:044b \:0438 \:0440\:0435\:043a\:043e\
\:043c\:0435\:043d\:0434\:0430\:0446\:0438\:0438 \:0434\:043b\:044f \:044d\
\:0444\:0444\:0435\:043a\:0442\:0438\:0432\:043d\:043e\:0433\:043e \:043f\
\:043e\:0438\:0441\:043a\:0430 \:0441\:043e\:0432\:043f\:0430\:0434\:0435\
\:043d\:0438\:0439", "Section",
 CellTags->{"c:25", "Tips and Tricks", "b:0.7"},
 CellID->319138910],

Cell["\<\
\:0412 \:044d\:0442\:043e\:043c \:0440\:0430\:0437\:0434\:0435\:043b\:0435 \
\:0440\:0430\:0441\:0441\:043c\:0430\:0442\:0440\:0438\:0432\:0430\:044e\:0442\
\:0441\:044f \:043d\:0435\:043a\:043e\:0442\:043e\:0440\:044b\:0435 \:0432\
\:043e\:043f\:0440\:043e\:0441\:044b \:044d\:0444\:0444\:0435\:043a\:0442\
\:0438\:0432\:043d\:043e\:0441\:0442\:0438 \:043f\:0440\:0438 \:0441\:043e\
\:043f\:043e\:0441\:0442\:0430\:0432\:043b\:0435\:043d\:0438\:0438 \:0442\
\:0435\:043a\:0441\:0442\:043e\:0432\:044b\:0445 \:044d\:043b\:0435\:043c\
\:0435\:043d\:0442\:043e\:0432 \:0448\:0430\:0431\:043b\:043e\:043d\:0430\
\:043c.\
\>", "Text",
 CellTags->"b:0.7",
 CellID->1088522],

Cell[CellGroupData[{

Cell["StringExpression \:0432 \
\:0441\:0440\:0430\:0432\:043d\:0435\:043d\:0438\:0438 \:0441 \
RegularExpression", "Subsection",
 CellTags->{"c:26", "b:0.7"},
 CellID->571253149],

Cell[TextData[{
 "\:041f\:043e\:0441\:043a\:043e\:043b\:044c\:043a\:0443 \:0448\:0430\:0431\
\:043b\:043e\:043d \:0434\:043b\:044f \:0442\:0435\:043a\:0441\:0442\:043e\
\:0432\:044b\:0445 \:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442\:043e\
\:0432, \:0437\:0430\:043f\:0438\:0441\:0430\:043d\:043d\:044b\:0439 \:0432 \
\:0441\:0438\:043d\:0442\:0430\:043a\:0441\:0438\:0441\:0435 ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", \:043d\:0435\:043c\:0435\:0434\:043b\:0435\:043d\:043d\:043e \:043f\:0435\
\:0440\:0435\:0432\:043e\:0434\:0438\:0442\:0441\:044f \:0432 \:0440\:0435\
\:0433\:0443\:043b\:044f\:0440\:043d\:043e\:0435 \:0432\:044b\:0440\:0430\
\:0436\:0435\:043d\:0438\:0435, \:0430 \:0437\:0430\:0442\:0435\:043c \:043a\
\:043e\:043c\:043f\:0438\:043b\:0438\:0440\:0443\:0435\:0442\:0441\:044f \
\:0438 \:043a\:044d\:0448\:0438\:0440\:0443\:0435\:0442\:0441\:044f, \:043d\
\:0435\:043f\:0440\:043e\:0438\:0437\:0432\:043e\:0434\:0438\:0442\:0435\:043b\
\:044c\:043d\:044b\:0435 \:0438\:0437\:0434\:0435\:0440\:0436\:043a\:0438 \
\:0438\:0441\:043f\:043e\:043b\:044c\:0437\:043e\:0432\:0430\:043d\:0438\:044f\
 \:0441\:0438\:043d\:0442\:0430\:043a\:0441\:0438\:0441\:0430 ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", \:043f\:043e \:0441\:0440\:0430\:0432\:043d\:0435\:043d\:0438\:044e \
\:0441 \:0441\:0438\:043d\:0442\:0430\:043a\:0441\:0438\:0441\:043e\:043c \
\:0440\:0435\:0433\:0443\:043b\:044f\:0440\:043d\:044b\:0445 \:0432\:044b\
\:0440\:0430\:0436\:0435\:043d\:0438\:0439, \:043d\:0435\:0437\:043d\:0430\
\:0447\:0438\:0442\:0435\:043b\:044c\:043d\:044b. \:0418\:0441\:043a\:043b\
\:044e\:0447\:0435\:043d\:0438\:0435 \:0441\:043e\:0441\:0442\:0430\:0432\
\:043b\:044f\:044e\:0442 \:0441\:043b\:0443\:0447\:0430\:0438, \:043a\:043e\
\:0433\:0434\:0430 \:0431\:043e\:043b\:044c\:0448\:043e\:0435 \:043a\:043e\
\:043b\:0438\:0447\:0435\:0441\:0442\:0432\:043e \:0440\:0430\:0437\:043b\
\:0438\:0447\:043d\:044b\:0445 \:0448\:0430\:0431\:043b\:043e\:043d\:043e\
\:0432 \:0438\:0441\:043f\:043e\:043b\:044c\:0437\:0443\:044e\:0442\:0441\
\:044f \:043c\:043d\:043e\:0433\:043e\:043a\:0440\:0430\:0442\:043d\:043e; \
\:0432 \:044d\:0442\:043e\:043c \:0441\:043b\:0443\:0447\:0430\:0435 \:043d\
\:0435\:043f\:0440\:043e\:0438\:0437\:0432\:043e\:0434\:0438\:0442\:0435\:043b\
\:044c\:043d\:044b\:0435 \:0438\:0437\:0434\:0435\:0440\:0436\:043a\:0438 \
\:043c\:043e\:0433\:0443\:0442 \:0431\:044b\:0442\:044c \:0437\:0430\:043c\
\:0435\:0442\:043d\:044b."
}], "Text",
 CellTags->"b:0.7",
 CellID->527245798]
}, Open  ]],

Cell[CellGroupData[{

Cell["\:041e\:043f\:0435\:0440\:0430\:0442\:043e\:0440\:044b Conditions \
\:0438 PatternTests", "Subsection",
 CellTags->{"c:27", "b:0.7"},
 CellID->11710184],

Cell[TextData[{
 "\:0415\:0441\:043b\:0438 \:0448\:0430\:0431\:043b\:043e\:043d \:0441\:043e\
\:0434\:0435\:0440\:0436\:0438\:0442 \:043e\:043f\:0435\:0440\:0430\:0442\
\:043e\:0440 ",
 Cell[BoxData[
  TemplateBox[{Cell["Condition"],"paclet:ref/Condition"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " (",
 Cell[BoxData["/;"], "InlineFormula"],
 ") \:0438\:043b\:0438 ",
 Cell[BoxData[
  TemplateBox[{Cell["PatternTest"],"paclet:ref/PatternTest"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " (",
 Cell[BoxData["?"], "InlineFormula"],
 "), \:044d\:0442\:043e \:0432\:0435\:0434\:0435\:0442 \:043a \:043d\:0435\
\:043e\:0431\:0445\:043e\:0434\:0438\:043c\:043e\:0441\:0442\:0438 \:0432\
\:044b\:0437\:043e\:0432\:0430 \:043e\:0441\:043d\:043e\:0432\:043d\:043e\
\:0433\:043e \:0432\:044b\:0447\:0438\:0441\:043b\:0438\:0442\:0435\:043b\
\:044c\:043d\:043e\:0433\:043e \:044f\:0434\:0440\:0430 ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", \:0442\:0435\:043c \:0441\:0430\:043c\:044b\:043c, \:0437\:0430\:043c\
\:0435\:0434\:043b\:044f\:044f \:0440\:0430\:0431\:043e\:0442\:0443 \:0448\
\:0430\:0431\:043b\:043e\:043d\:0430. \:0415\:0441\:043b\:0438 \:0448\:0430\
\:0431\:043b\:043e\:043d \:043c\:043e\:0436\:043d\:043e \:0441\:043e\:0441\
\:0442\:0430\:0432\:0438\:0442\:044c \:0431\:0435\:0437 \:0442\:0430\:043a\
\:0438\:0445 \:043a\:043e\:043d\:0441\:0442\:0440\:0443\:043a\:0446\:0438\
\:0439, \:043a\:0430\:043a \:043f\:0440\:0430\:0432\:0438\:043b\:043e, \:043e\
\:043d \:0431\:0443\:0434\:0435\:0442 \:0440\:0430\:0431\:043e\:0442\:0430\
\:0442\:044c \:0431\:044b\:0441\:0442\:0440\:0435\:0435."
}], "MathCaption",
 CellTags->"b:0.7",
 CellID->168089851],

Cell[BoxData[
 RowBox[{
  RowBox[{"SeedRandom", "[", "1234", "]"}], ";", 
  RowBox[{"test", "=", 
   RowBox[{"StringJoin", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"FromCharacterCode", "[", 
       RowBox[{"RandomInteger", "[", 
        RowBox[{"{", 
         RowBox[{"48", ",", "80"}], "}"}], "]"}], "]"}], ",", 
      RowBox[{"{", "200", "}"}]}], "]"}], "]"}]}], ";"}]], "Input",
 CellTags->"b:0.7",
 CellLabel->"In[140]:=",
 CellID->45298985],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"StringCases", "[", 
    RowBox[{"test", ",", 
     RowBox[{"DigitCharacter", ".."}]}], "]"}], "//", "Length"}], "//", 
  "Timing"}]], "Input",
 CellTags->"b:0.7",
 CellLabel->"In[141]:=",
 CellID->334473682],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.`", ",", "32"}], "}"}]], "Output",
 ImageSize->{57, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.7",
 CellLabel->"Out[141]=",
 CellID->60278642]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"StringCases", "[", 
    RowBox[{"test", ",", 
     RowBox[{"__", "?", "DigitQ"}]}], "]"}], "//", "Length"}], "//", 
  "Timing"}]], "Input",
 CellTags->"b:0.7",
 CellLabel->"In[142]:=",
 CellID->108146462],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.015625`4.214419939295737", ",", "32"}], "}"}]], "Output",
 ImageSize->{99, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.7",
 CellLabel->"Out[142]=",
 CellID->840100588]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\:0418\:0437\:0431\:0435\:0433\:0430\:0439\:0442\:0435 \:0432\:043b\
\:043e\:0436\:0435\:043d\:043d\:044b\:0445 \:043a\:0432\:0430\:043d\:0442\
\:043e\:0440\:043e\:0432", "Subsection",
 CellTags->{"c:28", "b:0.7"},
 CellID->39608680],

Cell[TextData[{
 "\:0412\:0432\:0438\:0434\:0443 \:0442\:043e\:0433\:043e, \:0447\:0442\:043e \
\:0432 \:043f\:0440\:043e\:0446\:0435\:0434\:0443\:0440\:0435 \:043f\:043e\
\:0438\:0441\:043a\:0430 \:0441\:043e\:043e\:0442\:0432\:0435\:0442\:0441\
\:0442\:0432\:0438\:0439 \:0438\:0441\:043f\:043e\:043b\:044c\:0437\:0443\
\:0435\:0442\:0441\:044f \:0430\:043b\:0433\:043e\:0440\:0438\:0442\:043c \
\:043d\:0435\:0434\:0435\:0442\:0435\:0440\:043c\:0438\:043d\:0438\:0440\:043e\
\:0432\:0430\:043d\:043d\:044b\:0445 \:043a\:043e\:043d\:0435\:0447\:043d\
\:044b\:0445 \:0430\:0432\:0442\:043e\:043c\:0430\:0442\:043e\:0432 (NFA), \
\:0440\:0430\:0431\:043e\:0442\:0430 \:0448\:0430\:0431\:043b\:043e\:043d\
\:043e\:0432, \:0441\:043e\:0434\:0435\:0440\:0436\:0430\:0449\:0438\:0435 \
\:0432\:043b\:043e\:0436\:0435\:043d\:043d\:044b\:0435 \:043a\:0432\:0430\
\:043d\:0442\:043e\:0440\:044b (\:0442\:0430\:043a\:0438\:0435 \:043a\:0430\
\:043a ",
 Cell[BoxData["__"], "InlineFormula"],
 " \:0438 ",
 Cell[BoxData[
  RowBox[{"patt", ".."}]], "InlineFormula"],
 " \:0438\:043b\:0438 \:0438\:0445 \:044d\:043a\:0432\:0438\:0432\:0430\:043b\
\:0435\:043d\:0442\:044b \:0432 \:0440\:0435\:0433\:0443\:043b\:044f\:0440\
\:043d\:044b\:0445 \:0432\:044b\:0440\:0430\:0436\:0435\:043d\:0438\:044f\
\:0445), \:043c\:043e\:0436\:0435\:0442 \:0441\:0442\:0430\:0442\:044c \:043d\
\:0435\:043f\:0440\:043e\:0433\:043d\:043e\:0437\:0438\:0440\:0443\:0435\:043c\
\:043e \:043c\:0435\:0434\:043b\:0435\:043d\:043d\:043e\:0439. \:0422\:0430\
\:043a\:0438\:0435 \:0448\:0430\:0431\:043b\:043e\:043d\:044b \:043e\:0431\
\:044b\:0447\:043d\:043e \:043c\:043e\:0433\:0443\:0442 \:0431\:044b\:0442\
\:044c \"\:0440\:0430\:0437\:0432\:0435\:0440\:043d\:0443\:0442\:044b\" \
\:0432 \:0431\:043e\:043b\:0435\:0435 \:044d\:0444\:0444\:0435\:043a\:0442\
\:0438\:0432\:043d\:044b\:0435 \:0432\:0435\:0440\:0441\:0438\:0438 (\:0441\
\:043c. Friedl ",
 ButtonBox["[2]",
  BaseStyle->"Link",
  ButtonData->"paclet:tutorial/WorkingWithStringPatterns#201956504"],
 " \:0434\:043b\:044f \:043f\:043e\:043b\:0443\:0447\:0435\:043d\:0438\:044f \
\:0434\:043e\:043f\:043e\:043b\:043d\:0438\:0442\:0435\:043b\:044c\:043d\:043e\
\:0439 \:0438\:043d\:0444\:043e\:0440\:043c\:0430\:0446\:0438\:0438)."
}], "Text",
 CellTags->"b:0.7",
 CellID->350158018]
}, Open  ]],

Cell[CellGroupData[{

Cell["\:0418\:0437\:0431\:0435\:0433\:0430\:0439\:0442\:0435 \:043c\:043d\
\:043e\:0433\:043e\:0447\:0438\:0441\:043b\:0435\:043d\:043d\:044b\:0445 \
\:0432\:044b\:0437\:043e\:0432\:043e\:0432 \:0444\:0443\:043d\:043a\:0446\
\:0438\:0439", "Subsection",
 CellTags->{"c:29", "b:0.7"},
 CellID->73358011],

Cell[TextData[{
 "\:0415\:0441\:043b\:0438 \:0432\:044b \:0438\:0449\:0435\:0442\:0435 \:043e\
\:043f\:0440\:0435\:0434\:0435\:043b\:0435\:043d\:043d\:044b\:0435 \:0441\
\:043e\:0432\:043f\:0430\:0434\:0435\:043d\:0438\:044f \:0432 \:0434\:043b\
\:0438\:043d\:043d\:043e\:043c \:043f\:0435\:0440\:0435\:0447\:043d\:0435 \
\:0442\:0435\:043a\:0441\:0442\:043e\:0432\:044b\:0445 \:0444\:0440\:0430\
\:0433\:043c\:0435\:043d\:0442\:043e\:0432, \:043d\:0430\:0438\:0431\:043e\
\:043b\:0435\:0435 \:044d\:0444\:0444\:0435\:043a\:0442\:0438\:0432\:043d\
\:044b\:043c \:0431\:0443\:0434\:0435\:0442 \:043f\:043e\:0434\:0430\:0442\
\:044c \:043d\:0430 \:0432\:0445\:043e\:0434 \:0444\:0443\:043d\:043a\:0446\
\:0438\:0438 \:0441\:0440\:0430\:0437\:0443 \:0432\:0435\:0441\:044c \:043f\
\:0435\:0440\:0435\:0447\:0435\:043d\:044c \:0442\:0435\:043a\:0441\:0442\
\:043e\:0432\:044b\:0445 \:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442\
\:043e\:0432, \:0430 \:043d\:0435 \:0438\:0441\:043f\:043e\:043b\:044c\:0437\
\:043e\:0432\:0430\:0442\:044c \:0447\:0442\:043e-\:0442\:043e \:0432\:0440\
\:043e\:0434\:0435 ",
 Cell[BoxData[
  TemplateBox[{Cell["Select"],"paclet:ref/Select"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " \:0438 ",
 Cell[BoxData[
  TemplateBox[{Cell["StringMatchQ"],"paclet:ref/StringMatchQ"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " (\:0441\:043c. \
\:043f\:0440\:0438\:0432\:0435\:0434\:0435\:043d\:043d\:044b\:0435 \:0440\
\:0430\:043d\:0435\:0435 \:043f\:0440\:0438\:043c\:0435\:0440\:044b). \:0412\
\:043e\:0442 \:0435\:0449\:0435 \:043e\:0434\:0438\:043d \:043f\:0440\:0438\
\:043c\:0435\:0440, \:043a\:043e\:0442\:043e\:0440\:044b\:0439 \:0433\:0435\
\:043d\:0435\:0440\:0438\:0440\:0443\:0435\:0442 \:0441\:043f\:0438\:0441\
\:043e\:043a \:0438\:0437 2000 \:0442\:0435\:043a\:0441\:0442\:043e\:0432\
\:044b\:0445 \:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442\:043e\:0432 \
\:0441 10 \:0441\:0438\:043c\:0432\:043e\:043b\:0430\:043c\:0438 \:0432 \
\:043a\:0430\:0436\:0434\:043e\:043c \:0438 \:0438\:0449\:0435\:0442 \:0444\
\:0440\:0430\:0433\:043c\:0435\:043d\:0442\:044b, \:043a\:043e\:0442\:043e\
\:0440\:044b\:0435 \:043d\:0430\:0447\:0438\:043d\:0430\:044e\:0442\:0441\
\:044f \:0441 ",
 Cell[BoxData["\<\"a\"\>"], "InlineFormula"],
 " \:0438 \:0441\:043e\:0434\:0435\:0440\:0436\:0430\:0442 ",
 Cell[BoxData["\<\"ggg\"\>"], "InlineFormula"],
 " \:0432 \:043a\:0430\:0447\:0435\:0441\:0442\:0432\:0435 \:0441\:0443\:0431\
\:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442\:0430."
}], "MathCaption",
 CellTags->"b:0.7",
 CellID->274569970],

Cell[BoxData[
 RowBox[{
  RowBox[{"SeedRandom", "[", "1234", "]"}], ";", 
  RowBox[{"test", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"StringJoin", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"{", 
          RowBox[{
          "\"\<a\>\"", ",", "\"\<c\>\"", ",", "\"\<g\>\"", ",", "\"\<t\>\""}],
           "}"}], "[", 
         RowBox[{"[", "#", "]"}], "]"}], "&"}], "/@", 
       RowBox[{"Table", "[", 
        RowBox[{
         RowBox[{"RandomInteger", "[", 
          RowBox[{"{", 
           RowBox[{"1", ",", "4"}], "}"}], "]"}], ",", 
         RowBox[{"{", "10", "}"}]}], "]"}]}], "]"}], ",", 
     RowBox[{"{", "2000", "}"}]}], "]"}]}], ";"}]], "Input",
 CellTags->"b:0.7",
 CellLabel->"In[143]:=",
 CellID->88405937],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Take", "[", 
  RowBox[{"test", ",", "3"}], "]"}]], "Input",
 CellTags->"b:0.7",
 CellLabel->"In[144]:=",
 CellID->171329605],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"tgaacggccg\"\>", ",", "\<\"ggaactaaaa\"\>", 
   ",", "\<\"gacacagacc\"\>"}], "}"}]], "Output",
 ImageSize->{250, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.7",
 CellLabel->"Out[144]=",
 CellID->24933409]
}, Open  ]],

Cell[TextData[{
 "\:042d\:0442\:043e \:043c\:0435\:0434\:043b\:0435\:043d\:043d\:044b\:0439 \
\:0432\:0430\:0440\:0438\:0430\:043d\:0442, \:0438\:0441\:043f\:043e\:043b\
\:044c\:0437\:0443\:044e\:0449\:0438\:0439 ",
 Cell[BoxData[
  TemplateBox[{Cell["Select"],"paclet:ref/Select"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " \:0438 ",
 Cell[BoxData[
  TemplateBox[{Cell["StringMatchQ"],"paclet:ref/StringMatchQ"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 "."
}], "MathCaption",
 CellTags->"b:0.7",
 CellID->482988001],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Select", "[", 
   RowBox[{"test", ",", 
    RowBox[{
     RowBox[{"StringMatchQ", "[", 
      RowBox[{"#", ",", 
       RowBox[{"\"\<a\>\"", "~~", 
        RowBox[{"___", "~~", 
         RowBox[{"\"\<ggg\>\"", "~~", "___"}]}]}]}], "]"}], "&"}]}], "]"}], "//",
   "Timing"}]], "Input",
 CellTags->"b:0.7",
 CellLabel->"In[145]:=",
 CellID->235104226],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.015625`4.214419939295737", ",", 
   RowBox[{"{", 
    RowBox[{"\<\"agcccacggg\"\>", ",", "\<\"aatttgggtc\"\>", 
     ",", "\<\"agggctgcat\"\>", ",", "\<\"agaaccggga\"\>", 
     ",", "\<\"acacagggct\"\>", ",", "\<\"ataatcgggg\"\>", 
     ",", "\<\"aatagggccc\"\>", ",", "\<\"agtgggcgcc\"\>", 
     ",", "\<\"agggtaaggg\"\>", ",", "\<\"atcagagggt\"\>", 
     ",", "\<\"aggggcgtaa\"\>", ",", "\<\"atgctggggt\"\>", 
     ",", "\<\"accttgggtc\"\>", ",", "\<\"agtgggatgc\"\>", 
     ",", "\<\"agatagggtc\"\>", ",", "\<\"aaccatgggg\"\>", 
     ",", "\<\"atcgggatgg\"\>", ",", "\<\"actcctcggg\"\>", 
     ",", "\<\"atccgggttc\"\>", ",", "\<\"atagggaggc\"\>", 
     ",", "\<\"aatgatcggg\"\>", ",", "\<\"atctttaggg\"\>", 
     ",", "\<\"agaggggtag\"\>", ",", "\<\"atacgggtag\"\>", 
     ",", "\<\"acgagtcggg\"\>", ",", "\<\"aacaaagggt\"\>", 
     ",", "\<\"agtaagggtc\"\>", ",", "\<\"aacgggtgtc\"\>", 
     ",", "\<\"aggggcgcga\"\>", ",", "\<\"aggagggata\"\>", 
     ",", "\<\"aggtgggaaa\"\>", ",", "\<\"atcactgggc\"\>", 
     ",", "\<\"aggatgggcc\"\>", ",", "\<\"aaagggcggc\"\>", 
     ",", "\<\"agtgggagcg\"\>", ",", "\<\"aggtggggac\"\>", 
     ",", "\<\"accaatggga\"\>", ",", "\<\"aggggcactt\"\>", 
     ",", "\<\"agaagggtgt\"\>", ",", "\<\"agggatttgg\"\>", 
     ",", "\<\"aggacgggca\"\>", ",", "\<\"atgggaccct\"\>", 
     ",", "\<\"acttcacggg\"\>", ",", "\<\"aacgggagtc\"\>"}], "}"}]}], 
  "}"}]], "Output",
 ImageSize->{501, 135},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.7",
 CellLabel->"Out[145]=",
 CellID->5314957]
}, Open  ]],

Cell[TextData[{
 "\:0415\:0441\:043b\:0438, \:0432\:043c\:0435\:0441\:0442\:043e \:044d\:0442\
\:043e\:0433\:043e, \:043f\:043e\:0434\:0430\:0442\:044c \:0441\:0440\:0430\
\:0437\:0443 \:0432\:0435\:0441\:044c \:0441\:043f\:0438\:0441\:043e\:043a \
\:043d\:0430 \:0432\:0445\:043e\:0434 ",
 Cell[BoxData[
  TemplateBox[{Cell["StringMatchQ"],"paclet:ref/StringMatchQ"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 ", \:0432\:0441\:0435 \:0431\:0443\:0434\:0435\:0442 \
\:0440\:0430\:0431\:043e\:0442\:0430\:0442\:044c \:0433\:043e\:0440\:0430\
\:0437\:0434\:043e \:0431\:044b\:0441\:0442\:0440\:0435\:0435. \:0410 \:043a\
\:043e\:043c\:0430\:043d\:0434\:0443 ",
 Cell[BoxData[
  TemplateBox[{Cell["Pick"],"paclet:ref/Pick"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " \:043c\:043e\:0436\:043d\:043e \:0438\:0441\:043f\:043e\:043b\:044c\:0437\
\:043e\:0432\:0430\:0442\:044c \:0434\:043b\:044f \:0438\:0437\:0432\:043b\
\:0435\:0447\:0435\:043d\:0438\:044f \:0438\:0441\:043a\:043e\:043c\:044b\
\:0445 \:044d\:043b\:0435\:043c\:0435\:043d\:0442\:043e\:0432."
}], "MathCaption",
 CellTags->"b:0.7",
 CellID->940575378],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Pick", "[", 
   RowBox[{"test", ",", 
    RowBox[{"StringMatchQ", "[", 
     RowBox[{"test", ",", 
      RowBox[{"\"\<a\>\"", "~~", 
       RowBox[{"___", "~~", 
        RowBox[{"\"\<ggg\>\"", "~~", "___"}]}]}]}], "]"}]}], "]"}], "//", 
  "Timing"}]], "Input",
 CellTags->"b:0.7",
 CellLabel->"In[146]:=",
 CellID->159751616],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.`", ",", 
   RowBox[{"{", 
    RowBox[{"\<\"agcccacggg\"\>", ",", "\<\"aatttgggtc\"\>", 
     ",", "\<\"agggctgcat\"\>", ",", "\<\"agaaccggga\"\>", 
     ",", "\<\"acacagggct\"\>", ",", "\<\"ataatcgggg\"\>", 
     ",", "\<\"aatagggccc\"\>", ",", "\<\"agtgggcgcc\"\>", 
     ",", "\<\"agggtaaggg\"\>", ",", "\<\"atcagagggt\"\>", 
     ",", "\<\"aggggcgtaa\"\>", ",", "\<\"atgctggggt\"\>", 
     ",", "\<\"accttgggtc\"\>", ",", "\<\"agtgggatgc\"\>", 
     ",", "\<\"agatagggtc\"\>", ",", "\<\"aaccatgggg\"\>", 
     ",", "\<\"atcgggatgg\"\>", ",", "\<\"actcctcggg\"\>", 
     ",", "\<\"atccgggttc\"\>", ",", "\<\"atagggaggc\"\>", 
     ",", "\<\"aatgatcggg\"\>", ",", "\<\"atctttaggg\"\>", 
     ",", "\<\"agaggggtag\"\>", ",", "\<\"atacgggtag\"\>", 
     ",", "\<\"acgagtcggg\"\>", ",", "\<\"aacaaagggt\"\>", 
     ",", "\<\"agtaagggtc\"\>", ",", "\<\"aacgggtgtc\"\>", 
     ",", "\<\"aggggcgcga\"\>", ",", "\<\"aggagggata\"\>", 
     ",", "\<\"aggtgggaaa\"\>", ",", "\<\"atcactgggc\"\>", 
     ",", "\<\"aggatgggcc\"\>", ",", "\<\"aaagggcggc\"\>", 
     ",", "\<\"agtgggagcg\"\>", ",", "\<\"aggtggggac\"\>", 
     ",", "\<\"accaatggga\"\>", ",", "\<\"aggggcactt\"\>", 
     ",", "\<\"agaagggtgt\"\>", ",", "\<\"agggatttgg\"\>", 
     ",", "\<\"aggacgggca\"\>", ",", "\<\"atgggaccct\"\>", 
     ",", "\<\"acttcacggg\"\>", ",", "\<\"aacgggagtc\"\>"}], "}"}]}], 
  "}"}]], "Output",
 ImageSize->{501, 135},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.7",
 CellLabel->"Out[146]=",
 CellID->356900352]
}, Open  ]],

Cell[TextData[{
 "\:041a\:0440\:043e\:043c\:0435 \:0442\:043e\:0433\:043e, \:043c\:043e\:0436\
\:043d\:043e \:0438\:0441\:043f\:043e\:043b\:044c\:0437\:043e\:0432\:0430\
\:0442\:044c \:0444\:0443\:043d\:043a\:0446\:0438\:044e ",
 Cell[BoxData[
  TemplateBox[{Cell["StringCases"],"paclet:ref/StringCases"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 ", \:043a\:043e\:0442\:043e\:0440\:0430\:044f \:0440\:0430\:0431\:043e\:0442\
\:0430\:0435\:0442 \:0442\:0430\:043a \:0436\:0435 \:0431\:044b\:0441\:0442\
\:0440\:043e. \:041e\:0431\:0440\:0430\:0442\:0438\:0442\:0435 \:0432\:043d\
\:0438\:043c\:0430\:043d\:0438\:0435, \:0447\:0442\:043e \:0432 \:0448\:0430\
\:0431\:043b\:043e\:043d\:0435 \:043d\:0443\:0436\:043d\:043e \:0437\:0430\
\:0434\:0430\:0442\:044c \:0442\:043e\:0447\:043a\:0443 \:043f\:0440\:0438\
\:0432\:044f\:0437\:043a\:0438, \:0438\:0441\:043f\:043e\:043b\:044c\:0437\
\:0443\:044f \:0434\:043b\:044f \:044d\:0442\:043e\:0433\:043e ",
 Cell[BoxData[
  TemplateBox[{Cell["StartOfString"],"paclet:ref/StartOfString"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 ", \:0447\:0442\:043e\:0431\:044b   \:0438\:0441\:043a\:0430\:0442\:044c ",
 Cell[BoxData["\<\"a\"\>"], "InlineFormula"],
 ", \:0440\:0430\:0441\:043f\:043e\:043b\:043e\:0436\:0435\:043d\:043d\:043e\
\:0435 \:0432 \:043d\:0430\:0447\:0430\:043b\:0435 \:0444\:0440\:0430\:0433\
\:043c\:0435\:043d\:0442\:0430 (",
 Cell[BoxData[
  TemplateBox[{Cell["EndOfString"],"paclet:ref/EndOfString"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " \:0438\:0437\:043b\:0438\:0448\:043d\:0435 \:0432 \:0434\:0430\:043d\:043d\
\:043e\:043c \:043a\:043e\:043d\:043a\:0440\:0435\:0442\:043d\:043e\:043c \
\:0441\:043b\:0443\:0447\:0430\:0435)."
}], "MathCaption",
 CellTags->"b:0.7",
 CellID->440945305],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Flatten", "[", 
   RowBox[{"StringCases", "[", 
    RowBox[{"test", ",", 
     RowBox[{"StartOfString", "~~", 
      RowBox[{"\"\<a\>\"", "~~", 
       RowBox[{"___", "~~", 
        RowBox[{"\"\<ggg\>\"", "~~", 
         RowBox[{"___", "~~", "EndOfString"}]}]}]}]}]}], "]"}], "]"}], "//", 
  "Timing"}]], "Input",
 CellTags->"b:0.7",
 CellLabel->"In[147]:=",
 CellID->344941105],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.`", ",", 
   RowBox[{"{", 
    RowBox[{"\<\"agcccacggg\"\>", ",", "\<\"aatttgggtc\"\>", 
     ",", "\<\"agggctgcat\"\>", ",", "\<\"agaaccggga\"\>", 
     ",", "\<\"acacagggct\"\>", ",", "\<\"ataatcgggg\"\>", 
     ",", "\<\"aatagggccc\"\>", ",", "\<\"agtgggcgcc\"\>", 
     ",", "\<\"agggtaaggg\"\>", ",", "\<\"atcagagggt\"\>", 
     ",", "\<\"aggggcgtaa\"\>", ",", "\<\"atgctggggt\"\>", 
     ",", "\<\"accttgggtc\"\>", ",", "\<\"agtgggatgc\"\>", 
     ",", "\<\"agatagggtc\"\>", ",", "\<\"aaccatgggg\"\>", 
     ",", "\<\"atcgggatgg\"\>", ",", "\<\"actcctcggg\"\>", 
     ",", "\<\"atccgggttc\"\>", ",", "\<\"atagggaggc\"\>", 
     ",", "\<\"aatgatcggg\"\>", ",", "\<\"atctttaggg\"\>", 
     ",", "\<\"agaggggtag\"\>", ",", "\<\"atacgggtag\"\>", 
     ",", "\<\"acgagtcggg\"\>", ",", "\<\"aacaaagggt\"\>", 
     ",", "\<\"agtaagggtc\"\>", ",", "\<\"aacgggtgtc\"\>", 
     ",", "\<\"aggggcgcga\"\>", ",", "\<\"aggagggata\"\>", 
     ",", "\<\"aggtgggaaa\"\>", ",", "\<\"atcactgggc\"\>", 
     ",", "\<\"aggatgggcc\"\>", ",", "\<\"aaagggcggc\"\>", 
     ",", "\<\"agtgggagcg\"\>", ",", "\<\"aggtggggac\"\>", 
     ",", "\<\"accaatggga\"\>", ",", "\<\"aggggcactt\"\>", 
     ",", "\<\"agaagggtgt\"\>", ",", "\<\"agggatttgg\"\>", 
     ",", "\<\"aggacgggca\"\>", ",", "\<\"atgggaccct\"\>", 
     ",", "\<\"acttcacggg\"\>", ",", "\<\"aacgggagtc\"\>"}], "}"}]}], 
  "}"}]], "Output",
 ImageSize->{501, 135},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.7",
 CellLabel->"Out[147]=",
 CellID->615031247]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
\:0422\:0440\:0430\:043d\:0441\:0444\:043e\:0440\:043c\:0438\:0440\:0443\:0439\
\:0442\:0435 \:0441\:0440\:0430\:0432\:043d\:0435\:043d\:0438\:0435 \:043e\
\:0431\:044b\:0447\:043d\:044b\:0445 \:0432\:044b\:0440\:0430\:0436\:0435\
\:043d\:0438\:0439 \:0432 \:0441\:0440\:0430\:0432\:043d\:0435\:043d\:0438\
\:0435 \:0442\:0435\:043a\:0441\:0442\:043e\:0432\:044b\:0445 \:0444\:0440\
\:0430\:0433\:043c\:0435\:043d\:0442\:043e\:0432\
\>", "Subsection",
 CellTags->{"c:30", "b:0.7"},
 CellID->148652143],

Cell[TextData[{
 "\:041f\:043e\:0441\:043a\:043e\:043b\:044c\:043a\:0443 \:0430\:043b\:0433\
\:043e\:0440\:0438\:0442\:043c \:0441\:0440\:0430\:0432\:043d\:0435\:043d\
\:0438\:044f \:0442\:0435\:043a\:0441\:0442\:043e\:0432\:044b\:0445 \:0444\
\:0440\:0430\:0433\:043c\:0435\:043d\:0442\:043e\:0432 \:043e\:0442\:043b\
\:0438\:0447\:0430\:0435\:0442\:0441\:044f \:043e\:0442 \:0430\:043b\:0433\
\:043e\:0440\:0438\:0442\:043c\:0430, \:0438\:0441\:043f\:043e\:043b\:044c\
\:0437\:0443\:0435\:043c\:043e\:0433\:043e ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " \:0434\:043b\:044f \:0441\:0440\:0430\:0432\:043d\:0435\:043d\:0438\:044f \
\:043e\:0431\:044b\:0447\:043d\:044b\:0445 \:0432\:044b\:0440\:0430\:0436\
\:0435\:043d\:0438\:0439 (\:043a \:043f\:0440\:0438\:043c\:0435\:0440\:0443, \
\:0441\:0440\:0430\:0432\:043d\:0435\:043d\:0438\:0435 \:0442\:0435\:043a\
\:0441\:0442\:043e\:0432\:044b\:0445 \:0444\:0440\:0430\:0433\:043c\:0435\
\:043d\:0442\:043e\:0432 \:043c\:043e\:0436\:0435\:0442 \:043f\:0440\:0435\
\:0434\:043f\:043e\:043b\:0430\:0433\:0430\:0442\:044c \:0438\:0441\:0447\
\:0435\:0440\:043f\:044b\:0432\:0430\:044e\:0449\:0438\:0439 \:0430\:043b\
\:0444\:0430\:0432\:0438\:0442 \:0438 \:043f\:043b\:043e\:0441\:043a\:0443\
\:044e \:0441\:0442\:0440\:0443\:043a\:0442\:0443\:0440\:0443), \:0431\:044b\
\:0432\:0430\:044e\:0442 \:0441\:043b\:0443\:0447\:0430\:0438, \:043a\:043e\
\:0433\:0434\:0430 \:0438\:043c\:0435\:0435\:0442 \:0441\:043c\:044b\:0441\
\:043b \:043f\:0440\:0435\:043e\:0431\:0440\:0430\:0437\:043e\:0432\:0430\
\:0442\:044c \:0437\:0430\:0434\:0430\:0447\:0443 \:0441\:0440\:0430\:0432\
\:043d\:0435\:043d\:0438\:044f \:043e\:0431\:044b\:0447\:043d\:044b\:0445 \
\:0432\:044b\:0440\:0430\:0436\:0435\:043d\:0438\:0439 \:0432 \:0437\:0430\
\:0434\:0430\:0447\:0443 \:0441\:0440\:0430\:0432\:043d\:0435\:043d\:0438\
\:044f \:0442\:0435\:043a\:0441\:0442\:043e\:0432\:044b\:0445 \:0444\:0440\
\:0430\:0433\:043c\:0435\:043d\:0442\:043e\:0432. \:0422\:0438\:043f\:0438\
\:0447\:043d\:044b\:043c \:0441\:043b\:0443\:0447\:0430\:0435\:043c \:044f\
\:0432\:043b\:044f\:0435\:0442\:0441\:044f \:043f\:043e\:0438\:0441\:043a \
\:0441\:043e\:043e\:0442\:0432\:0435\:0442\:0441\:0442\:0432\:0438\:044f \
\:0432 \:0434\:043b\:0438\:043d\:043d\:043e\:043c \:0441\:043f\:0438\:0441\
\:043a\:0435 \:0441\:0438\:043c\:0432\:043e\:043b\:043e\:0432, \:043f\:043e \
\:0448\:0430\:0431\:043b\:043e\:043d\:0443, \:0433\:0434\:0435 \:043f\:0440\
\:0438\:0441\:0443\:0442\:0441\:0442\:0432\:0443\:044e\:0442 \:0441\:0440\
\:0430\:0437\:0443 \:043d\:0435\:0441\:043a\:043e\:043b\:044c\:043a\:043e ",
 Cell[BoxData["__"], "InlineFormula"],
 " \:0438 ",
 Cell[BoxData["___"], "InlineFormula"],
 "."
}], "Text",
 CellTags->"b:0.7",
 CellID->13332812],

Cell["\<\
\:0412 \:043a\:0430\:0447\:0435\:0441\:0442\:0432\:0435 \:043f\:0440\:0438\
\:043c\:0435\:0440\:0430, \:0434\:043e\:043f\:0443\:0441\:0442\:0438\:043c, \
\:0447\:0442\:043e \:0432\:044b \:0445\:043e\:0442\:0438\:0442\:0435 \:043d\
\:0430\:0439\:0442\:0438 \:043f\:0440\:043e\:0441\:0442\:044b\:0435 \:0447\
\:0438\:0441\:043b\:0430 (\:0441\:043a\:0430\:0436\:0435\:043c, \:043f\:043e\
\:0441\:043b\:0435 1000000-\:0433\:043e), \
\:043a\:043e\:0442\:043e\:0440\:044b\:0435 \:0438\:043c\:0435\:044e\:0442, \
\:043f\:043e \:043c\:0435\:043d\:044c\:0448\:0435\:0439 \:043c\:0435\:0440\
\:0435, \:0447\:0435\:0442\:044b\:0440\:0435 \:043e\:0434\:0438\:043d\:0430\
\:043a\:043e\:0432\:044b\:0435 \:0446\:0438\:0444\:0440\:044b. \:041f\:0440\
\:0438 \:0438\:0441\:043f\:043e\:043b\:044c\:0437\:043e\:0432\:0430\:043d\
\:0438\:0438 \:0441\:0440\:0430\:0432\:043d\:0435\:043d\:0438\:044f \:043e\
\:0431\:044b\:0447\:043d\:044b\:0445 \:0432\:044b\:0440\:0430\:0436\:0435\
\:043d\:0438\:0439, \:044d\:0442\:043e \:043c\:043e\:0436\:043d\:043e \:0441\
\:0434\:0435\:043b\:0430\:0442\:044c \:0441\:043b\:0435\:0434\:0443\:044e\
\:0449\:0438\:043c \:043e\:0431\:0440\:0430\:0437\:043e\:043c.\
\>", "MathCaption",
 CellTags->"b:0.7",
 CellID->349310128],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Select", "[", 
   RowBox[{
    RowBox[{"Array", "[", 
     RowBox[{"Prime", ",", "1000", ",", "1000000"}], "]"}], ",", 
    RowBox[{
     RowBox[{"MatchQ", "[", 
      RowBox[{
       RowBox[{"IntegerDigits", "[", "#", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "___", ",", "x_", ",", "___", ",", "x_", ",", "___", ",", "x_", ",", 
         "___", ",", "x_", ",", "___"}], "}"}]}], "]"}], "&"}]}], "]"}], "//",
   "Timing"}]], "Input",
 CellTags->"b:0.7",
 CellLabel->"In[148]:=",
 CellID->34682433],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.078125`4.913389943631755", ",", 
   RowBox[{"{", 
    RowBox[{
    "15488881", ",", "15491117", ",", "15491171", ",", "15491711", ",", 
     "15493333", ",", "15493999", ",", "15496111", ",", "15499111", ",", 
     "15499199", ",", "15499399", ",", "15499499", ",", "15499919", ",", 
     "15499997", ",", "15500557", ",", "15501119", ",", "15501121", ",", 
     "15501151", ",", "15501553", ",", "15501559", ",", "15501911", ",", 
     "15502111"}], "}"}]}], "}"}]], "Output",
 ImageSize->{578, 50},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.7",
 CellLabel->"Out[148]=",
 CellID->2287957]
}, Open  ]],

Cell["\<\
\:041f\:0440\:0435\:043e\:0431\:0440\:0430\:0437\:043e\:0432\:0430\:0432 \
\:0441\:043f\:0438\:0441\:043e\:043a \:0446\:0435\:043b\:044b\:0445 \:0447\
\:0438\:0441\:0435\:043b \:0432 \:0442\:0435\:043a\:0441\:0442\:043e\:0432\
\:044b\:0439 \:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442, \:043c\:043e\
\:0436\:043d\:043e \:0438\:0441\:043f\:043e\:043b\:044c\:0437\:043e\:0432\
\:0430\:0442\:044c \:0441\:0440\:0430\:0432\:043d\:0435\:043d\:0438\:0435 \
\:0442\:0435\:043a\:0441\:0442\:043e\:0432\:044b\:0445 \:0444\:0440\:0430\
\:0433\:043c\:0435\:043d\:0442\:043e\:0432 \:0434\:043b\:044f \:043f\:043e\
\:0438\:0441\:043a\:0430 \:0441\:043e\:043e\:0442\:0432\:0435\:0442\:0441\
\:0442\:0432\:0438\:044f.\
\>", "MathCaption",
 CellTags->"b:0.7",
 CellID->19330986],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Select", "[", 
   RowBox[{
    RowBox[{"Array", "[", 
     RowBox[{"Prime", ",", "1000", ",", "1000000"}], "]"}], ",", 
    RowBox[{
     RowBox[{"StringMatchQ", "[", 
      RowBox[{
       RowBox[{"FromCharacterCode", "[", 
        RowBox[{"48", "+", 
         RowBox[{"IntegerDigits", "[", "#", "]"}]}], "]"}], ",", 
       RowBox[{"StringExpression", "[", 
        RowBox[{
        "___", ",", "x_", ",", "___", ",", "x_", ",", "___", ",", "x_", ",", 
         "___", ",", "x_", ",", "___"}], "]"}]}], "]"}], "&"}]}], "]"}], "//",
   "Timing"}]], "Input",
 CellTags->"b:0.7",
 CellLabel->"In[149]:=",
 CellID->115301483],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.03125`4.515449934959718", ",", 
   RowBox[{"{", 
    RowBox[{
    "15488881", ",", "15491117", ",", "15491171", ",", "15491711", ",", 
     "15493333", ",", "15493999", ",", "15496111", ",", "15499111", ",", 
     "15499199", ",", "15499399", ",", "15499499", ",", "15499919", ",", 
     "15499997", ",", "15500557", ",", "15501119", ",", "15501121", ",", 
     "15501151", ",", "15501553", ",", "15501559", ",", "15501911", ",", 
     "15502111"}], "}"}]}], "}"}]], "Output",
 ImageSize->{578, 50},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.7",
 CellLabel->"Out[149]=",
 CellID->284787246]
}, Open  ]],

Cell[TextData[{
 "\:0412\:043e\:0441\:043f\:043e\:043b\:044c\:0437\:043e\:0432\:0430\:0432\
\:0448\:0438\:0441\:044c \:0443\:043f\:043e\:043c\:044f\:043d\:0443\:0442\
\:044b\:043c\:0438 \:0440\:0430\:043d\:0435\:0435 \:0441\:043e\:0432\:0435\
\:0442\:0430\:043c\:0438 \:043f\:043e \:043f\:0440\:0438\:043c\:0435\:043d\
\:0435\:043d\:0438\:044e ",
 Cell[BoxData[
  TemplateBox[{Cell["Pick"],"paclet:ref/Pick"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " \:0438\:043b\:0438 ",
 Cell[BoxData[
  TemplateBox[{Cell["StringCases"],"paclet:ref/StringCases"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 ", \:043c\:043e\:0436\:043d\:043e \:0434\:043e\:0431\:0438\:0442\:044c\:0441\
\:044f \:0435\:0449\:0435 \:0431\:043e\:043b\:044c\:0448\:0435\:0439 \:0441\
\:043a\:043e\:0440\:043e\:0441\:0442\:0438."
}], "MathCaption",
 CellTags->"b:0.7",
 CellID->309333144],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"With", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"list", "=", 
      RowBox[{"Array", "[", 
       RowBox[{"Prime", ",", "1000", ",", "1000000"}], "]"}]}], "}"}], ",", 
    RowBox[{"Pick", "[", 
     RowBox[{"list", ",", 
      RowBox[{"StringMatchQ", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"FromCharacterCode", "[", 
           RowBox[{"48", "+", 
            RowBox[{"IntegerDigits", "[", "#", "]"}]}], "]"}], "&"}], "/@", 
         "list"}], ",", 
        RowBox[{"StringExpression", "[", 
         RowBox[{
         "___", ",", "x_", ",", "___", ",", "x_", ",", "___", ",", "x_", ",", 
          "___", ",", "x_", ",", "___"}], "]"}]}], "]"}]}], "]"}]}], "]"}], "//",
   "Timing"}]], "Input",
 CellTags->"b:0.7",
 CellLabel->"In[150]:=",
 CellID->238693932],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.015625`4.214419939295737", ",", 
   RowBox[{"{", 
    RowBox[{
    "15488881", ",", "15491117", ",", "15491171", ",", "15491711", ",", 
     "15493333", ",", "15493999", ",", "15496111", ",", "15499111", ",", 
     "15499199", ",", "15499399", ",", "15499499", ",", "15499919", ",", 
     "15499997", ",", "15500557", ",", "15501119", ",", "15501121", ",", 
     "15501151", ",", "15501553", ",", "15501559", ",", "15501911", ",", 
     "15502111"}], "}"}]}], "}"}]], "Output",
 ImageSize->{578, 50},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.7",
 CellLabel->"Out[150]=",
 CellID->131475791]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Flatten", "[", 
   RowBox[{"StringCases", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"FromCharacterCode", "[", 
        RowBox[{"48", "+", 
         RowBox[{"IntegerDigits", "[", "#", "]"}]}], "]"}], "&"}], "/@", 
      RowBox[{"Array", "[", 
       RowBox[{"Prime", ",", "1000", ",", "1000000"}], "]"}]}], ",", 
     RowBox[{"StringExpression", "[", 
      RowBox[{
      "StartOfString", ",", "___", ",", "x_", ",", "___", ",", "x_", ",", 
       "___", ",", "x_", ",", "___", ",", "x_", ",", "___", ",", 
       "EndOfString"}], "]"}]}], "]"}], "]"}], "//", "Timing"}]], "Input",
 CellTags->"b:0.7",
 CellLabel->"In[151]:=",
 CellID->74230660],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.`", ",", 
   RowBox[{"{", 
    RowBox[{"\<\"15488881\"\>", ",", "\<\"15491117\"\>", 
     ",", "\<\"15491171\"\>", ",", "\<\"15491711\"\>", 
     ",", "\<\"15493333\"\>", ",", "\<\"15493999\"\>", 
     ",", "\<\"15496111\"\>", ",", "\<\"15499111\"\>", 
     ",", "\<\"15499199\"\>", ",", "\<\"15499399\"\>", 
     ",", "\<\"15499499\"\>", ",", "\<\"15499919\"\>", 
     ",", "\<\"15499997\"\>", ",", "\<\"15500557\"\>", 
     ",", "\<\"15501119\"\>", ",", "\<\"15501121\"\>", 
     ",", "\<\"15501151\"\>", ",", "\<\"15501553\"\>", 
     ",", "\<\"15501559\"\>", ",", "\<\"15501911\"\>", 
     ",", "\<\"15502111\"\>"}], "}"}]}], "}"}]], "Output",
 ImageSize->{508, 50},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.7",
 CellLabel->"Out[151]=",
 CellID->251254336]
}, Open  ]],

Cell["\<\
\:0414\:043b\:044f \:0434\:043b\:0438\:043d\:043d\:044b\:0445 \:043f\:043e\
\:0441\:043b\:0435\:0434\:043e\:0432\:0430\:0442\:0435\:043b\:044c\:043d\:043e\
\:0441\:0442\:0435\:0439, \:0440\:0430\:0437\:043d\:0438\:0446\:0430 \:0432\
\:043e \:0432\:0440\:0435\:043c\:0435\:043d\:0438 \:0432\:044b\:043f\:043e\
\:043b\:043d\:0435\:043d\:0438\:044f \:043c\:043e\:0436\:0435\:0442 \:043e\
\:043a\:0430\:0437\:0430\:0442\:044c\:0441\:044f \:043e\:0447\:0435\:043d\
\:044c \:0432\:0435\:0441\:043e\:043c\:043e\:0439.\
\>", "MathCaption",
 CellTags->"b:0.7",
 CellID->778852497],

Cell[BoxData[
 RowBox[{
  RowBox[{"test", "=", 
   RowBox[{"Range", "[", "100", "]"}]}], ";", 
  RowBox[{
   RowBox[{"test", "[", 
    RowBox[{"[", 
     RowBox[{"{", 
      RowBox[{"50", ",", "75"}], "}"}], "]"}], "]"}], "=", "5"}], 
  ";"}]], "Input",
 CellTags->"b:0.7",
 CellLabel->"In[152]:=",
 CellID->166716726],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Position", "[", 
  RowBox[{"test", ",", "5"}], "]"}]], "Input",
 CellTags->"b:0.7",
 CellLabel->"In[153]:=",
 CellID->143881214],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", "5", "}"}], ",", 
   RowBox[{"{", "50", "}"}], ",", 
   RowBox[{"{", "75", "}"}]}], "}"}]], "Output",
 ImageSize->{117, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.7",
 CellLabel->"Out[153]=",
 CellID->811151718]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"MatchQ", "[", 
   RowBox[{"test", ",", 
    RowBox[{"{", 
     RowBox[{
     "___", ",", "x_", ",", "___", ",", "x_", ",", "___", ",", "x_", ",", 
      "___"}], "}"}]}], "]"}], "//", "Timing"}]], "Input",
 CellTags->"b:0.7",
 CellLabel->"In[154]:=",
 CellID->9520874],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.03125`4.515449934959718", ",", "True"}], "}"}]], "Output",
 ImageSize->{113, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.7",
 CellLabel->"Out[154]=",
 CellID->37879651]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"teststr", "=", 
   RowBox[{"FromCharacterCode", "[", "test", "]"}]}], ";"}]], "Input",
 CellTags->"b:0.7",
 CellLabel->"In[155]:=",
 CellID->55052828],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"StringPosition", "[", 
  RowBox[{"teststr", ",", 
   RowBox[{"FromCharacterCode", "[", "5", "]"}]}], "]"}]], "Input",
 CellTags->"b:0.7",
 CellLabel->"In[156]:=",
 CellID->106844855],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"5", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"50", ",", "50"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"75", ",", "75"}], "}"}]}], "}"}]], "Output",
 ImageSize->{185, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.7",
 CellLabel->"Out[156]=",
 CellID->505448699]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"StringMatchQ", "[", 
   RowBox[{"teststr", ",", 
    RowBox[{"StringExpression", "[", 
     RowBox[{
     "___", ",", "x_", ",", "___", ",", "x_", ",", "___", ",", "x_", ",", 
      "___"}], "]"}]}], "]"}], "//", "Timing"}]], "Input",
 CellTags->"b:0.7",
 CellLabel->"In[157]:=",
 CellID->483013677],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.`", ",", "True"}], "}"}]], "Output",
 ImageSize->{71, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.7",
 CellLabel->"Out[157]=",
 CellID->486101578]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\:041f\:043e\:0434\:0440\:043e\:0431\:043d\:043e\:0441\:0442\:0438 \
\:043c\:0435\:0445\:0430\:043d\:0438\:0437\:043c\:0430 \:0440\:0435\:0430\
\:043b\:0438\:0437\:0430\:0446\:0438\:0438", "Section",
 CellTags->{"c:31", "b:0.8"},
 CellID->337819047],

Cell[TextData[{
 "\:0412 ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", \:043f\:043e\:0438\:0441\:043a \:0441\:043e\:043e\:0442\:0432\:0435\:0442\
\:0441\:0442\:0432\:0438\:044f \:0442\:0435\:043a\:0441\:0442\:043e\:0432\
\:044b\:0445 \:0444\:0440\:0430\:0433\:043c\:0435\:043d\:0442\:043e\:0432 \
\:0448\:0430\:0431\:043b\:043e\:043d\:0443 \:043f\:043e\:0441\:0442\:0440\
\:043e\:0435\:043d \:043d\:0430 \:043e\:0441\:043d\:043e\:0432\:0435 \:0432\
\:0435\:0440\:0445\:043d\:0435\:0439 \:0447\:0430\:0441\:0442\:0438 \:0431\
\:0438\:0431\:043b\:0438\:043e\:0442\:0435\:043a\:0438 PCRE (Perl Compatible \
Regular Expressions), \:043e\:043f\:0443\:0431\:043b\:0438\:043a\:043e\:0432\
\:0430\:043d\:043d\:043e\:0439 \:0424\:0438\:043b\:0438\:043f\:043e\:043c \
\:0425\:0430\:0437\:0435\:043b\:0435\:043c (Philip Hazel) [1]."
}], "Text",
 CellTags->"b:0.8",
 CellID->68963779],

Cell[TextData[{
 "\:0412 \:043d\:0435\:043a\:043e\:0442\:043e\:0440\:044b\:0445 \:0441\:043b\
\:0443\:0447\:0430\:044f\:0445 \:0438\:0441\:043f\:043e\:043b\:044c\:0437\
\:0443\:044e\:0442\:0441\:044f \:0430\:043b\:0433\:043e\:0440\:0438\:0442\
\:043c\:044b \:0438\:0437 \:0431\:043e\:043b\:0435\:0435 \:0440\:0430\:043d\
\:043d\:0438\:0445 \:0432\:0435\:0440\:0441\:0438\:0439 ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", \:0447\:0435\:043c 5.1  \
(\:043d\:0430\:043f\:0440\:0438\:043c\:0435\:0440, \:043a\:043e\:0433\:0434\
\:0430 \:0448\:0430\:0431\:043b\:043e\:043d \:044f\:0432\:043b\:044f\:0435\
\:0442\:0441\:044f \:043e\:0434\:0438\:043d\:043e\:0447\:043d\:044b\:043c \
\:043b\:0438\:0442\:0435\:0440\:043d\:044b\:043c \:0444\:0440\:0430\:0433\
\:043c\:0435\:043d\:0442\:043e\:043c)."
}], "Text",
 CellTags->"b:0.8",
 CellID->57047539],

Cell[TextData[{
 "\:041b\:044e\:0431\:043e\:0439 \:0441\:0438\:043c\:0432\:043e\:043b\:044c\
\:043d\:044b\:0439 \:0448\:0430\:0431\:043b\:043e\:043d \:0434\:043b\:044f \
\:0442\:0435\:043a\:0441\:0442\:043e\:0432\:044b\:0445 \:0444\:0440\:0430\
\:0433\:043c\:0435\:043d\:0442\:043e\:0432 \:0441\:043d\:0430\:0447\:0430\
\:043b\:0430 \:043f\:0440\:0435\:043e\:0431\:0440\:0430\:0437\:0443\:0435\
\:0442\:0441\:044f \:0432 \:0440\:0435\:0433\:0443\:043b\:044f\:0440\:043d\
\:043e\:0435 \:0432\:044b\:0440\:0430\:0436\:0435\:043d\:0438\:0435. \:042d\
\:0442\:043e\:0442 \"\:043f\:0435\:0440\:0435\:0432\:043e\:0434\" \
\:043c\:043e\:0436\:043d\:043e \:0443\:0432\:0438\:0434\:0435\:0442\:044c \
\:043f\:0440\:0438 \:043f\:043e\:043c\:043e\:0449\:0438 \:0432\:043d\:0443\
\:0442\:0440\:0435\:043d\:043d\:0435\:0439 \:0444\:0443\:043d\:043a\:0446\
\:0438\:0438 ",
 Cell[BoxData["StringPattern`PatternConvert"], "InlineFormula"],
 "."
}], "MathCaption",
 CellTags->"b:0.8",
 CellID->169990753],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"StringPattern`PatternConvert", "[", 
   RowBox[{
    RowBox[{"\"\<a\>\"", "|", "\"\<\>\""}], "~~", 
    RowBox[{"DigitCharacter", ".."}]}], "]"}], "//", "InputForm"}]], "Input",
 CellTags->"b:0.8",
 CellLabel->"In[158]:=",
 CellID->201123037],

Cell["{\"(?ms)a?\\\\d+\", {}, {}, Hold[None]}", "Output",
 ImageSize->{245, 15},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"b:0.8",
 CellLabel->"Out[158]//InputForm=",
 CellID->32699069]
}, Open  ]],

Cell["\<\
\:041f\:0435\:0440\:0432\:044b\:043c \:0432\:043e\:0437\:0432\:0440\:0430\
\:0449\:0430\:0435\:043c\:044b\:043c \:044d\:043b\:0435\:043c\:0435\:043d\
\:0442\:043e\:043c \:044f\:0432\:043b\:044f\:0435\:0442\:0441\:044f \:0440\
\:0435\:0433\:0443\:043b\:044f\:0440\:043d\:043e\:0435 \:0432\:044b\:0440\
\:0430\:0436\:0435\:043d\:0438\:0435, \:0430 \:043e\:0441\:0442\:0430\:043b\
\:044c\:043d\:044b\:0435 \:044d\:043b\:0435\:043c\:0435\:043d\:0442\:044b \
\:0438\:043c\:0435\:044e\:0442 \:0434\:0435\:043b\:043e \:0441 \:0443\:0441\
\:043b\:043e\:0432\:0438\:044f\:043c\:0438, \:043f\:0440\:0430\:0432\:0438\
\:043b\:0430\:043c\:0438 \:043f\:0440\:0435\:043e\:0431\:0440\:0430\:0437\
\:043e\:0432\:0430\:043d\:0438\:044f \:0438 \:0438\:043c\:0435\:043d\:043e\
\:0432\:0430\:043d\:043d\:044b\:043c\:0438 \:0448\:0430\:0431\:043b\:043e\
\:043d\:0430\:043c\:0438.\
\>", "Text",
 CellTags->"b:0.8",
 CellID->190255727],

Cell["\<\
\:0420\:0435\:0433\:0443\:043b\:044f\:0440\:043d\:043e\:0435 \:0432\:044b\
\:0440\:0430\:0436\:0435\:043d\:0438\:0435 \:0437\:0430\:0442\:0435\:043c \
\:043a\:043e\:043c\:043f\:0438\:043b\:0438\:0440\:0443\:0435\:0442\:0441\:044f\
 \:0431\:0438\:0431\:043b\:0438\:043e\:0442\:0435\:043a\:043e\:0439 PCRE, \
\:0430 \:0443\:0436\:0435 \:0441\:043a\:043e\:043c\:043f\:0438\:043b\:0438\
\:0440\:043e\:0432\:0430\:043d\:043d\:044b\:0439 \:0432\:0430\:0440\:0438\
\:0430\:043d\:0442 \:043a\:044d\:0448\:0438\:0440\:0443\:044e\:0442\:0441\
\:044f \:0434\:043b\:044f \:0434\:0430\:043b\:044c\:043d\:0435\:0439\:0448\
\:0435\:0433\:043e \:0438\:0441\:043f\:043e\:043b\:044c\:0437\:043e\:0432\
\:0430\:043d\:0438\:044f \:0432 \:0441\:043b\:0443\:0447\:0430\:0435 \:043f\
\:043e\:044f\:0432\:043b\:0435\:043d\:0438\:044f \:0442\:0430\:043a\:043e\
\:0433\:043e \:0436\:0435 \:0441\:0430\:043c\:043e\:0433\:043e \:0448\:0430\
\:0431\:043b\:043e\:043d\:0430 \:0432\:043d\:043e\:0432\:044c. \:041f\:0435\
\:0440\:0435\:0432\:043e\:0434 \:0441\:0438\:043c\:0432\:043e\:043b\:044c\
\:043d\:044b\:0445 \:0448\:0430\:0431\:043b\:043e\:043d\:043e\:0432 \:0432 \
\:0440\:0435\:0433\:0443\:043b\:044f\:0440\:043d\:044b\:0435 \:0432\:044b\
\:0440\:0430\:0436\:0435\:043d\:0438\:044f \:043f\:0440\:043e\:0438\:0441\
\:0445\:043e\:0434\:0438\:0442 \:0442\:043e\:043b\:044c\:043a\:043e \:043e\
\:0434\:043d\:043e\:043a\:0440\:0430\:0442\:043d\:043e.\
\>", "Text",
 CellTags->"b:0.8",
 CellID->210149359],

Cell[TextData[{
 "\:0423\:0441\:043b\:043e\:0432\:0438\:044f ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", \:0441\:043e\:0434\:0435\:0440\:0436\:0430\:0449\:0438\:0435\:0441\:044f \
\:0432 \:0448\:0430\:0431\:043b\:043e\:043d\:0435, \:043e\:0431\:0440\:0430\
\:0431\:0430\:0442\:044b\:0432\:0430\:044e\:0442\:0441\:044f \:0432\:043d\
\:0435\:0448\:043d\:0438\:043c\:0438 \:0432\:044b\:0437\:043e\:0432\:0430\
\:043c\:0438 \:0438\:0437 \:0431\:0438\:0431\:043b\:0438\:043e\:0442\:0435\
\:043a\:0438 PCRE \:043a \:0432\:044b\:0447\:0438\:0441\:043b\:0438\:0442\
\:0435\:043b\:044c\:043d\:043e\:043c\:0443 \:044f\:0434\:0440\:0443 ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 ", \:0447\:0442\:043e \:0437\:0430\:043c\:0435\:0434\:043b\:044f\:0435\:0442 \
\:043f\:043e\:0438\:0441\:043a \:0441\:043e\:0432\:043f\:0430\:0434\:0435\
\:043d\:0438\:0439."
}], "Text",
 CellTags->"b:0.8",
 CellID->953153723],

Cell[TextData[{
 "\:0417\:0430\:0434\:0430\:043d\:043d\:044b\:0435 \:0432 \:044f\:0432\:043d\
\:043e\:043c \:0432\:0438\:0434\:0435 \:043e\:0431\:044a\:0435\:043a\:0442\
\:044b ",
 Cell[BoxData[
  TemplateBox[{Cell["RegularExpression"],"paclet:ref/RegularExpression"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 ",  \:0432\:043d\:0435\:0434\:0440\:0435\:043d\:043d\:044b\:0435 \:0432 \
\:043e\:0431\:0449\:0438\:0439 \:0448\:0430\:0431\:043b\:043e\:043d \:0434\
\:043b\:044f \:0442\:0435\:043a\:0441\:0442\:043e\:0432\:044b\:0445 \:0444\
\:0440\:0430\:0433\:043c\:0435\:043d\:0442\:043e\:0432,  \:0431\:0443\:0434\
\:0443\:0442 \:0441\:043e\:0441\:0442\:044b\:043a\:043e\:0432\:0430\:043d\
\:044b \:0432 \:043a\:043e\:043d\:0435\:0447\:043d\:043e\:043c \:0440\:0435\
\:0433\:0443\:043b\:044f\:0440\:043d\:043e\:043c \:0432\:044b\:0440\:0430\
\:0436\:0435\:043d\:0438\:0438 (\:0437\:0430\:043a\:043b\:044e\:0447\:0435\
\:043d\:043d\:044b\:0435 \:0432 \:043d\:0435-\:043f\:0435\:0440\:0435\:0445\
\:0432\:0430\:0442\:044b\:0432\:0430\:044e\:0449\:0438\:0435 \:0441\:043a\
\:043e\:0431\:043a\:0438  ",
 Cell[BoxData["\<\"(?:...)\"\>"], "InlineFormula"],
 "); \:0442\:0430\:043a \:0447\:0442\:043e \:043d\:0443\:043c\:0435\:0440\
\:0430\:0446\:0438\:044f \:0438\:043c\:0435\:043d\:043e\:0432\:0430\:043d\
\:043d\:044b\:0445 \:0448\:0430\:0431\:043b\:043e\:043d\:043e\:0432 \:043c\
\:043e\:0436\:0435\:0442 \:0431\:044b\:0442\:044c \:0441\:043c\:0435\:0449\
\:0435\:043d\:0430 \:043f\:043e \:0441\:0440\:0430\:0432\:043d\:0435\:043d\
\:0438\:044e \:0441 \:0442\:0435\:043c, \:0447\:0442\:043e \:043c\:043e\:0436\
\:043d\:043e \:0431\:044b\:043b\:043e \:0431\:044b \:043e\:0436\:0438\:0434\
\:0430\:0442\:044c."
}], "Text",
 CellTags->"b:0.8",
 CellID->198359003],

Cell[TextData[{
 "\:041f\:043e\:0441\:043a\:043e\:043b\:044c\:043a\:0443 \:0431\:0438\:0431\
\:043b\:0438\:043e\:0442\:0435\:043a\:0430 PCRE \:0432 \:043d\:0430\:0441\
\:0442\:043e\:044f\:0449\:0435\:0435 \:0432\:0440\:0435\:043c\:044f \:043d\
\:0435 \:043f\:043e\:0434\:0434\:0435\:0440\:0436\:0438\:0432\:0430\:0435\
\:0442 \:043f\:0440\:0435\:0434\:0443\:0441\:0442\:0430\:043d\:043e\:0432\
\:043b\:0435\:043d\:043d\:044b\:0435 \:043a\:043b\:0430\:0441\:0441\:044b \
\:0441\:0438\:043c\:0432\:043e\:043b\:043e\:0432 \:0434\:043b\:044f \:0441\
\:0438\:043c\:0432\:043e\:043b\:043e\:0432 \:0441 \:043a\:043e\:0434\:0430\
\:043c\:0438 \:0432\:044b\:0448\:0435 255, \:043a\:043b\:0430\:0441\:0441\
\:044b \:0441\:043b\:043e\:0432 \:0438 \:0441\:0438\:043c\:0432\:043e\:043b\
\:043e\:0432 (\:0442\:0430\:043a\:0438\:0435 \:043a\:0430\:043a ",
 Cell[BoxData[
  TemplateBox[{Cell["WordCharacter"],"paclet:ref/WordCharacter"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " \:0438 ",
 Cell[BoxData[
  TemplateBox[{Cell["LetterCharacter"],"paclet:ref/LetterCharacter"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 ") \:0432\:043a\:043b\:044e\:0447\:0430\:044e\:0442 \:0442\:043e\:043b\:044c\
\:043a\:043e \:043a\:043e\:0434\:044b \:0441\:0438\:043c\:0432\:043e\:043b\
\:043e\:0432 \:0432 \:0434\:0438\:0430\:043f\:0430\:0437\:043e\:043d\:0435 \
Unicode 0\[Dash]255. \:0418\:043c\:0435\:043d\:043d\:043e \:043f\:043e\:044d\
\:0442\:043e\:043c\:0443, \:043a\:043e\:043d\:0441\:0442\:0440\:0443\:043a\
\:0446\:0438\:0438  ",
 Cell[BoxData[
  TemplateBox[{Cell["LetterCharacter"],"paclet:ref/LetterCharacter"},
   "RefLink",
   BaseStyle->"InlineFormula"]], "InlineFormula"],
 " \:0438 ",
 Cell[BoxData[
  RowBox[{"_", "?", 
   TemplateBox[{Cell["LetterQ"],"paclet:ref/LetterQ"},
    "RefLink",
    BaseStyle->"InlineFormula"]}]], "InlineFormula"],
 "  \:043d\:0435 \:0434\:0430\:044e\:0442 \
\:044d\:043a\:0432\:0438\:0432\:0430\:043b\:0435\:043d\:0442\:043d\:044b\:0445\
 \:0440\:0435\:0437\:0443\:043b\:044c\:0442\:0430\:0442\:043e\:0432 \:0434\
\:043b\:044f \:0441\:0438\:043c\:0432\:043e\:043b\:043e\:0432 \:0441 \:043a\
\:043e\:0434\:0430\:043c\:0438 \:0432\:044b\:0448\:0435 255."
}], "Text",
 CellTags->"b:0.8",
 CellID->908430859],

Cell[TextData[{
 "\:0412\:0441\:043b\:0435\:0434\:0441\:0442\:0432\:0438\:0435 \:043f\:043e\
\:0445\:043e\:0436\:0435\:0433\:043e \:043e\:0433\:0440\:0430\:043d\:0438\
\:0447\:0435\:043d\:0438\:044f, \:043d\:0430\:043a\:043b\:0430\:0434\:044b\
\:0432\:0430\:0435\:043c\:043e\:0433\:043e \:0431\:0438\:0431\:043b\:0438\
\:043e\:0442\:0435\:043a\:043e\:0439 PCRE, \:043f\:043e\:0438\:0441\:043a \
\:0441\:043e\:043e\:0442\:0432\:0435\:0442\:0441\:0442\:0432\:0438\:044f \
\:0431\:0435\:0437 \:0443\:0447\:0435\:0442\:0430 \:0440\:0430\:0437\:0440\
\:044f\:0434\:0430 \:0441\:0438\:043c\:0432\:043e\:043b\:043e\:0432 (\:043d\
\:0430\:043f\:0440\:0438\:043c\:0435\:0440, \:043f\:0440\:0438 \:0432\:043a\
\:043b\:044e\:0447\:0435\:043d\:043d\:043e\:0439 \:043e\:043f\:0446\:0438\
\:0438 ",
 Cell[BoxData[
  RowBox[{
   TemplateBox[{Cell["IgnoreCase"],"paclet:ref/IgnoreCase"},
    "RefLink",
    BaseStyle->"InlineFormula"], "->", 
   TemplateBox[{Cell["True"],"paclet:ref/True"},
    "RefLink",
    BaseStyle->"InlineFormula"]}]], "InlineFormula"],
 ") \:0431\:0443\:0434\:0435\:0442 \:043f\:0440\:0438\:043c\:0435\:043d\:044f\
\:0442\:044c\:0441\:044f \:0442\:043e\:043b\:044c\:043a\:043e \:043a \:0431\
\:0443\:043a\:0432\:0435\:043d\:043d\:044b\:043c \:0441\:0438\:043c\:0432\
\:043e\:043b\:0430\:043c \:0432 \:0434\:0438\:0430\:043f\:0430\:0437\:043e\
\:043d\:0435 Unicode 0\[Dash]127 (\:0442\:043e \:0435\:0441\:0442\:044c \
\:043a \:043e\:0431\:044b\:0447\:043d\:044b\:043c \:0431\:0443\:043a\:0432\
\:0430\:043c \:0430\:043d\:0433\:043b\:0438\:0439\:0441\:043a\:043e\:0433\
\:043e \:0430\:043b\:0444\:0430\:0432\:0438\:0442\:0430 ",
 Cell[BoxData["\<\"a\"\>"], "InlineFormula"],
 "\[Dash]",
 Cell[BoxData["\<\"z\"\>"], "InlineFormula"],
 " \:0438 ",
 Cell[BoxData["\<\"A\"\>"], "InlineFormula"],
 "\[Dash]",
 Cell[BoxData["\<\"Z\"\>"], "InlineFormula"],
 ")."
}], "Text",
 CellTags->"b:0.8",
 CellID->1015887440]
}, Open  ]],

Cell[CellGroupData[{

Cell["\:0421\:0441\:044b\:043b\:043a\:0438", "Section",
 CellTags->{"c:32", "b:0.9"},
 CellID->503575505],

Cell[TextData[{
 "[1] Hazel, P. \"PCRE\[LongDash]Perl Compatible Regular Expressions.\" 2004. \
",
 ButtonBox["www.pcre.org",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www.pcre.org"], None}]
}], "Reference",
 CellTags->{"Ref-1", "b:0.9"},
 CellID->872737084],

Cell[TextData[{
 "[2] Friedl, J. E. F. ",
 StyleBox["Mastering Regular Expressions",
  FontSlant->"Italic"],
 ", 2nd ed. O'Reilly & Associates, 2002."
}], "Reference",
 CellTags->{"Ref-2", "b:0.9"},
 CellID->201956504]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 Cell[BoxData[
  InterpretationBox[
   StyleBox[
    GraphicsBox[{},
     BaselinePosition->Baseline,
     ImageSize->{6, 0}],
    CacheGraphics->False],
   Spacer[6]]]],
 "\:0423\:0437\:043d\:0430\:0442\:044c \:0431\:043e\:043b\:044c\:0448\:0435"
}], "TutorialMoreAboutSection",
 WholeCellGroupOpener->True,
 CellID->776935],

Cell["", "SectionHeaderSpacer"],

Cell[TextData[ButtonBox["String Patterns",
 BaseStyle->"Link",
 ButtonData->"paclet:guide/StringPatterns"]], "TutorialMoreAbout",
 CellID->1387738557]
}, Open  ]]
}, Open  ]],

Cell[" ", "FooterCell"]
},
FileChangeProtection->None,
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowSize->{Automatic, 510},
WindowMargins->{{312, Automatic}, {Automatic, 0}},
WindowFrame->"Normal",
WindowTitle->"Working with String Patterns - Wolfram Mathematica",
DockedCells->FEPrivate`FrontEndResource["FEExpressions", "HelpViewerToolbar"],
TaggingRules->{
 "ModificationHighlight" -> False, "ColorType" -> "TutorialColor", 
  "LinkTrails" -> GridBox[{{
      RowBox[{
        ButtonBox[
        "Virtual Book", ButtonData -> "paclet:tutorial/VirtualBookOverview", 
         BaseStyle -> {"Link", "DockedLinkTrail"}], 
        Cell[">", "DockedLinkTrailSeparator"], 
        ButtonBox[
        "Core Language", ButtonData -> "paclet:tutorial/CoreLanguageOverview",
          BaseStyle -> {"Link", "DockedLinkTrail"}], 
        Cell[">", "DockedLinkTrailSeparator"], 
        ButtonBox[
        "Strings and Characters", ButtonData -> 
         "paclet:tutorial/StringsAndCharactersOverview", 
         BaseStyle -> {"Link", "DockedLinkTrail"}], 
        Cell[">", "DockedLinkTrailSeparator"], 
        ButtonBox[
        "Working with String Patterns", ButtonData -> 
         "paclet:tutorial/WorkingWithStringPatternsOverview", 
         BaseStyle -> {"Link", "DockedLinkTrail"}], 
        Cell[">", "DockedLinkTrailSeparator"], 
        ButtonBox[
        "Working with String Patterns", ButtonData -> 
         "paclet:tutorial/WorkingWithStringPatterns", 
         BaseStyle -> {"Link", "DockedLinkTrail"}]}]}}, ColumnAlignments -> 
    Left], "ExampleCounter" -> 1, "ExamplePageLinks" -> {}, "RootCaptions" -> 
  "", "Metadata" -> {
   "built" -> "{2012, 11, 20, 2, 13, 10.3388794}", 
    "history" -> {"XX", "", "", ""}, "context" -> "System`", 
    "keywords" -> {
     "_", "__", "___", ":", ".", "..", "regular expression", "regex", 
      "string pattern", "string expression", "StringMatchQ", "StringFreeQ", 
      "StringCases", "StringPosition", "StringCount", "StringSplit"}, 
    "specialkeywords" -> {}, 
    "tutorialcollectionlinks" -> {{
      "Advanced String Patterns", 
       "http://www.wolfram.com/learningcenter/tutorialcollection/\
AdvancedStringPatterns/"}, {
      "Core Language", 
       "http://www.wolfram.com/learningcenter/tutorialcollection/CoreLanguage/\
"}}, "index" -> True, "label" -> "Mathematica Tutorial", "language" -> "en", 
    "paclet" -> "Mathematica", "status" -> "None", "summary" -> 
    "The general symbolic string patterns in Mathematica allow you to perform \
powerful string manipulation efficiently. What follows discusses the details \
of string patterns, including usage and implementation notes. The emphasis is \
on issues not mentioned elsewhere in the help system. At the heart of \
Mathematica is a powerful language for describing patterns in general \
expressions. This language is used in function definitions, substitutions, \
and searches, with constructs like x_, a|b, x.., and so on. ", 
    "synonyms" -> {}, "title" -> "Working with String Patterns", 
    "titlemodifier" -> "", "windowtitle" -> "Working with String Patterns", 
    "type" -> "Tutorial", "uri" -> "tutorial/WorkingWithStringPatterns"}, 
  "SearchTextTranslated" -> ""},
FrontEndVersion->"10.1 for Microsoft Windows (64-bit) (March 23, 2015)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[
    StyleDefinitions -> FrontEnd`FileName[{"Wolfram"}, "Reference.nb"]]], 
   Cell[
    StyleData["Input"], CellContext -> Notebook], 
   Cell[
    StyleData["Output"], CellContext -> Notebook], 
   Cell[
    StyleData["TutorialMoreAboutSection"], 
    CellGroupingRules -> {"SectionGrouping", 30}], 
   Cell[
    StyleData["RelatedTutorialsSection"], 
    CellGroupingRules -> {"SectionGrouping", 30}], 
   Cell[
    StyleData["TutorialRelatedLinksSection"], 
    CellGroupingRules -> {"SectionGrouping", 30}]}, Visible -> False, 
  FrontEndVersion -> "10.1 for Microsoft Windows (64-bit) (March 23, 2015)", 
  StyleDefinitions -> "Default.nb"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "c:1"->{
  Cell[11192, 282, 114, 2, 62, "Section",
   CellTags->{"c:1", "b:0.0"},
   CellID->6475218]},
 "b:0.0"->{
  Cell[11192, 282, 114, 2, 62, "Section",
   CellTags->{"c:1", "b:0.0"},
   CellID->6475218],
  Cell[11309, 286, 2175, 33, 102, "Text",
   CellTags->"b:0.0",
   CellID->879271277],
  Cell[13487, 321, 1319, 26, 63, "MathCaption",
   CellTags->"b:0.0",
   CellID->217261366],
  Cell[14831, 351, 290, 10, 28, "Input",
   CellTags->"b:0.0",
   CellID->6793186],
  Cell[15124, 363, 181, 6, 36, "Output",
   CellTags->"b:0.0",
   CellID->88064594],
  Cell[15342, 374, 302, 10, 28, "Input",
   CellTags->"b:0.0",
   CellID->397472003],
  Cell[15647, 386, 181, 6, 36, "Output",
   CellTags->"b:0.0",
   CellID->293854130],
  Cell[15865, 397, 244, 8, 28, "Input",
   CellTags->"b:0.0",
   CellID->108872960],
  Cell[16112, 407, 233, 8, 36, "Output",
   CellTags->"b:0.0",
   CellID->516087023],
  Cell[16360, 418, 2166, 34, 73, "MathCaption",
   CellTags->"b:0.0",
   CellID->47601161],
  Cell[18551, 456, 246, 8, 28, "Input",
   CellTags->"b:0.0",
   CellID->164239912],
  Cell[18800, 466, 181, 6, 36, "Output",
   CellTags->"b:0.0",
   CellID->22481105],
  Cell[19018, 477, 247, 8, 28, "Input",
   CellTags->"b:0.0",
   CellID->340018981],
  Cell[19268, 487, 181, 6, 36, "Output",
   CellTags->"b:0.0",
   CellID->335521681],
  Cell[19486, 498, 176, 5, 28, "Input",
   CellTags->"b:0.0",
   CellID->327756114],
  Cell[19665, 505, 257, 8, 36, "Output",
   CellTags->"b:0.0",
   CellID->365251227],
  Cell[19937, 516, 1064, 17, 45, "MathCaption",
   CellTags->"b:0.0",
   CellID->7623660],
  Cell[21026, 537, 229, 7, 28, "Input",
   CellTags->"b:0.0",
   CellID->257665367],
  Cell[21258, 546, 180, 6, 36, "Output",
   CellTags->"b:0.0",
   CellID->1666481],
  Cell[21475, 557, 229, 7, 28, "Input",
   CellTags->"b:0.0",
   CellID->15296355],
  Cell[21707, 566, 181, 6, 36, "Output",
   CellTags->"b:0.0",
   CellID->816730330],
  Cell[21925, 577, 219, 6, 28, "Input",
   CellTags->"b:0.0",
   CellID->44443359],
  Cell[22147, 585, 257, 8, 36, "Output",
   CellTags->"b:0.0",
   CellID->259369629],
  Cell[22419, 596, 593, 10, 48, "Text",
   CellTags->"b:0.0",
   CellID->131976413],
  Cell[30456, 797, 374, 6, 31, "Caption",
   CellTags->"b:0.0",
   CellID->49176434]},
 "c:2"->{
  Cell[30867, 808, 282, 5, 62, "Section",
   CellTags->{"c:2", "b:0.1"},
   CellID->316252289]},
 "b:0.1"->{
  Cell[30867, 808, 282, 5, 62, "Section",
   CellTags->{"c:2", "b:0.1"},
   CellID->316252289],
  Cell[31152, 815, 1436, 27, 62, "MathCaption",
   CellTags->"b:0.1",
   CellID->775969280],
  Cell[32613, 846, 156, 5, 28, "Input",
   CellTags->"b:0.1",
   CellID->14216555],
  Cell[32772, 853, 418, 15, 50, "Output",
   CellTags->"b:0.1",
   CellID->577426259],
  Cell[33205, 871, 1262, 24, 62, "MathCaption",
   CellTags->"b:0.1",
   CellID->143628873],
  Cell[34492, 899, 165, 5, 28, "Input",
   CellTags->"b:0.1",
   CellID->220445018],
  Cell[34660, 906, 192, 6, 36, "Output",
   CellTags->"b:0.1",
   CellID->109635832],
  Cell[34867, 915, 2342, 42, 106, "Text",
   CellTags->"b:0.1",
   CellID->100231778],
  Cell[37212, 959, 542, 10, 30, "Text",
   CellTags->"b:0.1",
   CellID->206331185],
  Cell[45876, 1160, 239, 4, 30, "Text",
   CellTags->"b:0.1",
   CellID->104465889],
  Cell[50076, 1276, 320, 5, 30, "Text",
   CellTags->"b:0.1",
   CellID->97881266],
  Cell[52674, 1340, 674, 11, 48, "Text",
   CellTags->"b:0.1",
   CellID->138112839],
  Cell[54980, 1393, 56, 2, 30, "Text",
   CellTags->"b:0.1",
   CellID->833514613],
  Cell[55039, 1397, 453, 9, 30, "Text",
   CellTags->"b:0.1",
   CellID->691886255],
  Cell[55495, 1408, 2085, 48, 65, "MathCaption",
   CellTags->"b:0.1",
   CellID->110717692],
  Cell[57605, 1460, 174, 5, 28, "Input",
   CellTags->"b:0.1",
   CellID->32115820],
  Cell[57782, 1467, 224, 7, 71, "Output",
   CellTags->"b:0.1",
   CellID->140880394],
  Cell[58043, 1479, 239, 7, 28, "Input",
   CellTags->"b:0.1",
   CellID->280132484],
  Cell[58285, 1488, 248, 8, 36, "Output",
   CellTags->"b:0.1",
   CellID->269517925],
  Cell[58570, 1501, 228, 6, 28, "Input",
   CellTags->"b:0.1",
   CellID->406476748],
  Cell[58801, 1509, 247, 8, 36, "Output",
   CellTags->"b:0.1",
   CellID->59754046],
  Cell[59063, 1520, 1374, 30, 65, "MathCaption",
   CellTags->"b:0.1",
   CellID->694363556],
  Cell[60462, 1554, 318, 9, 28, "Input",
   CellTags->"b:0.1",
   CellID->140507535],
  Cell[60783, 1565, 210, 6, 36, "Output",
   CellTags->"b:0.1",
   CellID->669388833],
  Cell[61008, 1574, 1935, 36, 81, "MathCaption",
   CellTags->"b:0.1",
   CellID->48865639],
  Cell[62968, 1614, 460, 14, 47, "Input",
   CellTags->"b:0.1",
   CellID->134667756],
  Cell[63431, 1630, 242, 8, 36, "Output",
   CellTags->"b:0.1",
   CellID->252805576],
  Cell[63688, 1641, 802, 19, 49, "MathCaption",
   CellTags->"b:0.1",
   CellID->408165015],
  Cell[64515, 1664, 312, 11, 28, "Input",
   CellTags->"b:0.1",
   CellID->149685880],
  Cell[64830, 1677, 263, 9, 36, "Output",
   CellTags->"b:0.1",
   CellID->25020691],
  Cell[65108, 1689, 550, 15, 35, "MathCaption",
   CellTags->"b:0.1",
   CellID->212294979],
  Cell[65683, 1708, 229, 6, 28, "Input",
   CellTags->"b:0.1",
   CellID->318389946],
  Cell[65915, 1716, 197, 6, 36, "Output",
   CellTags->"b:0.1",
   CellID->150923485],
  Cell[66127, 1725, 583, 12, 35, "MathCaption",
   CellTags->"b:0.1",
   CellID->384134564],
  Cell[66735, 1741, 332, 10, 28, "Input",
   CellTags->"b:0.1",
   CellID->23848909],
  Cell[67070, 1753, 242, 8, 36, "Output",
   CellTags->"b:0.1",
   CellID->262077309],
  Cell[67327, 1764, 1151, 20, 47, "MathCaption",
   CellTags->"b:0.1",
   CellID->603056891],
  Cell[68503, 1788, 296, 8, 28, "Input",
   CellTags->"b:0.1",
   CellID->291672169],
  Cell[68802, 1798, 244, 8, 36, "Output",
   CellTags->"b:0.1",
   CellID->674525324],
  Cell[69061, 1809, 574, 12, 34, "MathCaption",
   CellTags->"b:0.1",
   CellID->344292962],
  Cell[69660, 1825, 304, 10, 28, "Input",
   CellTags->"b:0.1",
   CellID->57194593],
  Cell[69967, 1837, 248, 8, 36, "Output",
   CellTags->"b:0.1",
   CellID->137492503],
  Cell[70230, 1848, 974, 18, 51, "Text",
   CellTags->"b:0.1",
   CellID->2661260],
  Cell[71207, 1868, 513, 9, 31, "MathCaption",
   CellTags->"b:0.1",
   CellID->704437595],
  Cell[71745, 1881, 307, 9, 28, "Input",
   CellTags->"b:0.1",
   CellID->190390204],
  Cell[72055, 1892, 190, 6, 36, "Output",
   CellTags->"b:0.1",
   CellID->36878244],
  Cell[72260, 1901, 2128, 38, 79, "MathCaption",
   CellTags->"b:0.1",
   CellID->422987297],
  Cell[74413, 1943, 236, 7, 28, "Input",
   CellTags->"b:0.1",
   CellID->262589375],
  Cell[74652, 1952, 218, 7, 36, "Output",
   CellTags->"b:0.1",
   CellID->446243857],
  Cell[74907, 1964, 260, 8, 28, "Input",
   CellTags->"b:0.1",
   CellID->87767072],
  Cell[75170, 1974, 246, 8, 36, "Output",
   CellTags->"b:0.1",
   CellID->10974229],
  Cell[75431, 1985, 803, 17, 48, "MathCaption",
   CellTags->"b:0.1",
   CellID->30079273],
  Cell[76259, 2006, 403, 11, 47, "Input",
   CellTags->"b:0.1",
   CellID->336262030],
  Cell[76665, 2019, 240, 8, 36, "Output",
   CellTags->"b:0.1",
   CellID->124605047],
  Cell[76942, 2032, 440, 12, 47, "Input",
   CellTags->"b:0.1",
   CellID->46781425],
  Cell[77385, 2046, 243, 8, 36, "Output",
   CellTags->"b:0.1",
   CellID->35253798],
  Cell[77643, 2057, 647, 14, 34, "MathCaption",
   CellTags->"b:0.1",
   CellID->165376289],
  Cell[78315, 2075, 434, 12, 47, "Input",
   CellTags->"b:0.1",
   CellID->33998707],
  Cell[78752, 2089, 244, 8, 36, "Output",
   CellTags->"b:0.1",
   CellID->266461623]},
 "Regular Expressions"->{
  Cell[79045, 2103, 208, 3, 62, "Section",
   CellTags->{"Regular Expressions", "c:3", "b:0.2"},
   CellID->274403895]},
 "c:3"->{
  Cell[79045, 2103, 208, 3, 62, "Section",
   CellTags->{"Regular Expressions", "c:3", "b:0.2"},
   CellID->274403895]},
 "b:0.2"->{
  Cell[79045, 2103, 208, 3, 62, "Section",
   CellTags->{"Regular Expressions", "c:3", "b:0.2"},
   CellID->274403895],
  Cell[79256, 2108, 1576, 30, 87, "Text",
   CellTags->"b:0.2",
   CellID->179324024],
  Cell[80835, 2140, 536, 10, 38, "Text",
   CellTags->"b:0.2",
   CellID->311647046],
  Cell[88244, 2331, 354, 6, 30, "Text",
   CellTags->"b:0.2",
   CellID->326926809],
  Cell[90983, 2388, 1299, 49, 50, "Text",
   CellTags->"b:0.2",
   CellID->423328124],
  Cell[92285, 2439, 510, 9, 30, "Text",
   CellTags->"b:0.2",
   CellID->53679581],
  Cell[92798, 2450, 2044, 44, 192, "DefinitionBox",
   CellTags->"b:0.2",
   CellID->438051314],
  Cell[94845, 2496, 366, 6, 30, "Text",
   CellTags->"b:0.2",
   CellID->446511798],
  Cell[95214, 2504, 2553, 57, 191, "DefinitionBox",
   CellTags->"b:0.2",
   CellID->103937476],
  Cell[97770, 2563, 325, 5, 30, "Text",
   CellTags->"b:0.2",
   CellID->725709264],
  Cell[98098, 2570, 2196, 61, 125, "DefinitionBox",
   CellTags->"b:0.2",
   CellID->324529988],
  Cell[100297, 2633, 465, 9, 30, "Text",
   CellTags->"b:0.2",
   CellID->36188322],
  Cell[100765, 2644, 519, 9, 31, "MathCaption",
   CellTags->"b:0.2",
   CellID->17419283],
  Cell[101309, 2657, 252, 7, 28, "Input",
   CellTags->"b:0.2",
   CellID->636896070],
  Cell[101564, 2666, 268, 9, 36, "Output",
   CellTags->"b:0.2",
   CellID->179137521],
  Cell[101847, 2678, 1255, 20, 61, "MathCaption",
   CellTags->"b:0.2",
   CellID->228635176],
  Cell[103127, 2702, 229, 7, 28, "Input",
   CellTags->"b:0.2",
   CellID->149453386],
  Cell[103359, 2711, 242, 8, 36, "Output",
   CellTags->"b:0.2",
   CellID->134310985],
  Cell[103638, 2724, 229, 7, 28, "Input",
   CellTags->"b:0.2",
   CellID->27057531],
  Cell[103870, 2733, 196, 7, 36, "Output",
   CellTags->"b:0.2",
   CellID->167625736],
  Cell[104103, 2745, 229, 7, 28, "Input",
   CellTags->"b:0.2",
   CellID->72747825],
  Cell[104335, 2754, 243, 8, 36, "Output",
   CellTags->"b:0.2",
   CellID->136763727],
  Cell[104593, 2765, 567, 14, 33, "MathCaption",
   CellTags->"b:0.2",
   CellID->574029527],
  Cell[105185, 2783, 246, 7, 28, "Input",
   CellTags->"b:0.2",
   CellID->972490785],
  Cell[105434, 2792, 286, 9, 36, "Output",
   CellTags->"b:0.2",
   CellID->467284740],
  Cell[105735, 2804, 1926, 49, 72, "Text",
   CellTags->"b:0.2",
   CellID->645192577],
  Cell[107664, 2855, 863, 21, 52, "Text",
   CellTags->"b:0.2",
   CellID->38350545],
  Cell[108530, 2878, 908, 14, 45, "MathCaption",
   CellTags->"b:0.2",
   CellID->87518571],
  Cell[109463, 2896, 226, 6, 28, "Input",
   CellTags->"b:0.2",
   CellID->310325877],
  Cell[109692, 2904, 213, 7, 36, "Output",
   CellTags->"b:0.2",
   CellID->252964877],
  Cell[109942, 2916, 232, 7, 28, "Input",
   CellTags->"b:0.2",
   CellID->47695904],
  Cell[110177, 2925, 247, 8, 36, "Output",
   CellTags->"b:0.2",
   CellID->25259495],
  Cell[110439, 2936, 759, 17, 49, "MathCaption",
   CellTags->"b:0.2",
   CellID->428461048],
  Cell[111223, 2957, 238, 7, 28, "Input",
   CellTags->"b:0.2",
   CellID->1001621228],
  Cell[111464, 2966, 213, 7, 36, "Output",
   CellTags->"b:0.2",
   CellID->377933075],
  Cell[111692, 2976, 701, 14, 47, "MathCaption",
   CellTags->"b:0.2",
   CellID->667194970],
  Cell[112418, 2994, 346, 10, 83, "Input",
   CellTags->"b:0.2",
   CellID->562254777],
  Cell[112767, 3006, 247, 8, 36, "Output",
   CellTags->"b:0.2",
   CellID->72339243],
  Cell[113029, 3017, 2412, 43, 77, "MathCaption",
   CellTags->"b:0.2",
   CellID->1379250],
  Cell[115466, 3064, 245, 7, 28, "Input",
   CellTags->"b:0.2",
   CellID->425844705],
  Cell[115714, 3073, 246, 8, 36, "Output",
   CellTags->"b:0.2",
   CellID->104389920],
  Cell[115997, 3086, 378, 11, 47, "Input",
   CellTags->"b:0.2",
   CellID->25483089],
  Cell[116378, 3099, 422, 14, 36, "Output",
   CellTags->"b:0.2",
   CellID->19980348],
  Cell[116815, 3116, 1126, 21, 49, "MathCaption",
   CellTags->"b:0.2",
   CellID->251858179],
  Cell[117966, 3141, 416, 12, 47, "Input",
   CellTags->"b:0.2",
   CellID->84036725],
  Cell[118385, 3155, 479, 14, 36, "Output",
   CellTags->"b:0.2",
   CellID->759065165],
  Cell[118879, 3172, 1309, 21, 61, "MathCaption",
   CellTags->"b:0.2",
   CellID->695998127],
  Cell[120213, 3197, 435, 11, 47, "Input",
   CellTags->"b:0.2",
   CellID->28505115],
  Cell[120651, 3210, 487, 14, 36, "Output",
   CellTags->"b:0.2",
   CellID->693657665],
  Cell[121153, 3227, 955, 18, 47, "MathCaption",
   CellTags->"b:0.2",
   CellID->465786935],
  Cell[122133, 3249, 243, 7, 28, "Input",
   CellTags->"b:0.2",
   CellID->38936688],
  Cell[122379, 3258, 244, 8, 36, "Output",
   CellTags->"b:0.2",
   CellID->486204157],
  Cell[122638, 3269, 1044, 16, 66, "Text",
   CellTags->"b:0.2",
   CellID->377461404],
  Cell[123685, 3287, 543, 11, 33, "MathCaption",
   CellTags->"b:0.2",
   CellID->114009367],
  Cell[124253, 3302, 246, 7, 28, "Input",
   CellTags->"b:0.2",
   CellID->635063856],
  Cell[124502, 3311, 244, 8, 36, "Output",
   CellTags->"b:0.2",
   CellID->206193907],
  Cell[124761, 3322, 740, 12, 45, "MathCaption",
   CellTags->"b:0.2",
   CellID->142585462],
  Cell[125526, 3338, 425, 13, 47, "Input",
   CellTags->"b:0.2",
   CellID->4084787],
  Cell[125954, 3353, 301, 9, 36, "Output",
   CellTags->"b:0.2",
   CellID->20535323],
  Cell[126270, 3365, 1385, 22, 59, "MathCaption",
   CellTags->"b:0.2",
   CellID->68612708],
  Cell[127680, 3391, 452, 14, 47, "Input",
   CellTags->"b:0.2",
   CellID->373128525],
  Cell[128135, 3407, 241, 8, 36, "Output",
   CellTags->"b:0.2",
   CellID->43881256]},
 "c:4"->{
  Cell[128425, 3421, 166, 3, 62, "Section",
   CellTags->{"c:4", "b:0.3"},
   CellID->182364929]},
 "b:0.3"->{
  Cell[128425, 3421, 166, 3, 62, "Section",
   CellTags->{"c:4", "b:0.3"},
   CellID->182364929],
  Cell[128594, 3426, 1576, 23, 84, "Text",
   CellTags->"b:0.3",
   CellID->100369965],
  Cell[130173, 3451, 12866, 309, 979, "DefinitionBox3Col",
   CellTags->"b:0.3",
   CellID->195821352],
  Cell[143042, 3762, 1410, 30, 68, "Text",
   CellTags->"b:0.3",
   CellID->143238647],
  Cell[144455, 3794, 1846, 30, 88, "Text",
   CellTags->"b:0.3",
   CellID->121646424]},
 "c:5"->{
  Cell[146338, 3829, 296, 5, 62, "Section",
   CellTags->"c:5",
   CellID->393353162]},
 "c:6"->{
  Cell[147936, 3859, 85, 2, 52, "Subsection",
   CellTags->{"c:6", "b:0.4.0"},
   CellID->115748480]},
 "b:0.4.0"->{
  Cell[147936, 3859, 85, 2, 52, "Subsection",
   CellTags->{"c:6", "b:0.4.0"},
   CellID->115748480],
  Cell[148024, 3863, 752, 14, 49, "MathCaption",
   CellTags->"b:0.4.0",
   CellID->88806953],
  Cell[148801, 3881, 233, 7, 28, "Input",
   CellTags->"b:0.4.0",
   CellID->631912780],
  Cell[149037, 3890, 184, 6, 36, "Output",
   CellTags->"b:0.4.0",
   CellID->700553192],
  Cell[149258, 3901, 235, 7, 28, "Input",
   CellTags->"b:0.4.0",
   CellID->116558020],
  Cell[149496, 3910, 184, 6, 36, "Output",
   CellTags->"b:0.4.0",
   CellID->90928558],
  Cell[149695, 3919, 2519, 60, 120, "Text",
   CellTags->"b:0.4.0",
   CellID->406868558],
  Cell[152217, 3981, 437, 8, 31, "MathCaption",
   CellTags->"b:0.4.0",
   CellID->90376082],
  Cell[152679, 3993, 199, 6, 28, "Input",
   CellTags->"b:0.4.0",
   CellID->996820522],
  Cell[152881, 4001, 184, 6, 36, "Output",
   CellTags->"b:0.4.0",
   CellID->324203704],
  Cell[153102, 4012, 247, 7, 28, "Input",
   CellTags->"b:0.4.0",
   CellID->44778046],
  Cell[153352, 4021, 182, 6, 36, "Output",
   CellTags->"b:0.4.0",
   CellID->2677979],
  Cell[153571, 4032, 228, 7, 28, "Input",
   CellTags->"b:0.4.0",
   CellID->22423222],
  Cell[153802, 4041, 184, 6, 36, "Output",
   CellTags->"b:0.4.0",
   CellID->299266338],
  Cell[154001, 4050, 1219, 21, 70, "Text",
   CellTags->"b:0.4.0",
   CellID->60232086],
  Cell[155223, 4073, 1090, 23, 52, "Text",
   CellTags->"b:0.4.0",
   CellID->716869318],
  Cell[156316, 4098, 1935, 32, 76, "MathCaption",
   CellTags->"b:0.4.0",
   CellID->554439476],
  Cell[158276, 4134, 236, 6, 28, "Input",
   CellTags->"b:0.4.0",
   CellID->70925498],
  Cell[158515, 4142, 183, 6, 36, "Output",
   CellTags->"b:0.4.0",
   CellID->36702422]},
 "c:7"->{
  Cell[158747, 4154, 84, 2, 52, "Subsection",
   CellTags->{"c:7", "b:0.4.1"},
   CellID->221687989]},
 "b:0.4.1"->{
  Cell[158747, 4154, 84, 2, 52, "Subsection",
   CellTags->{"c:7", "b:0.4.1"},
   CellID->221687989],
  Cell[158834, 4158, 2019, 40, 82, "MathCaption",
   CellTags->"b:0.4.1",
   CellID->58760444],
  Cell[160878, 4202, 233, 7, 28, "Input",
   CellTags->"b:0.4.1",
   CellID->208914080],
  Cell[161114, 4211, 185, 6, 36, "Output",
   CellTags->"b:0.4.1",
   CellID->419298952],
  Cell[161336, 4222, 221, 6, 28, "Input",
   CellTags->"b:0.4.1",
   CellID->113974042],
  Cell[161560, 4230, 185, 6, 36, "Output",
   CellTags->"b:0.4.1",
   CellID->180843643]},
 "c:8"->{
  Cell[161794, 4242, 82, 2, 52, "Subsection",
   CellTags->{"c:8", "b:0.4.2"},
   CellID->3968257]},
 "b:0.4.2"->{
  Cell[161794, 4242, 82, 2, 52, "Subsection",
   CellTags->{"c:8", "b:0.4.2"},
   CellID->3968257],
  Cell[161879, 4246, 1115, 19, 69, "Text",
   CellTags->"b:0.4.2",
   CellID->46676764],
  Cell[162997, 4267, 316, 5, 31, "MathCaption",
   CellTags->"b:0.4.2",
   CellID->143958968],
  Cell[163338, 4276, 206, 6, 28, "Input",
   CellTags->"b:0.4.2",
   CellID->459256047],
  Cell[163547, 4284, 266, 9, 36, "Output",
   CellTags->"b:0.4.2",
   CellID->265787987],
  Cell[163828, 4296, 519, 9, 31, "MathCaption",
   CellTags->"b:0.4.2",
   CellID->697884743],
  Cell[164372, 4309, 301, 10, 28, "Input",
   CellTags->"b:0.4.2",
   CellID->85500109],
  Cell[164676, 4321, 264, 9, 36, "Output",
   CellTags->"b:0.4.2",
   CellID->32377990],
  Cell[164977, 4335, 279, 8, 28, "Input",
   CellTags->"b:0.4.2",
   CellID->493985103],
  Cell[165259, 4345, 264, 9, 36, "Output",
   CellTags->"b:0.4.2",
   CellID->82819926],
  Cell[165538, 4357, 339, 5, 31, "MathCaption",
   CellTags->"b:0.4.2",
   CellID->121882887],
  Cell[165902, 4366, 196, 6, 28, "Input",
   CellTags->"b:0.4.2",
   CellID->240722779],
  Cell[166101, 4374, 260, 8, 36, "Output",
   CellTags->"b:0.4.2",
   CellID->266942857],
  Cell[166376, 4385, 247, 4, 31, "MathCaption",
   CellTags->"b:0.4.2",
   CellID->608581590],
  Cell[166648, 4393, 725, 22, 47, "Input",
   CellTags->"b:0.4.2",
   CellID->94888225],
  Cell[167376, 4417, 405, 12, 36, "Output",
   CellTags->"b:0.4.2",
   CellID->628308907],
  Cell[167796, 4432, 1388, 26, 63, "MathCaption",
   CellTags->"b:0.4.2",
   CellID->255423450],
  Cell[169209, 4462, 343, 11, 28, "Input",
   CellTags->"b:0.4.2",
   CellID->1009786679],
  Cell[169555, 4475, 353, 12, 36, "Output",
   CellTags->"b:0.4.2",
   CellID->686212242],
  Cell[169945, 4492, 125, 4, 28, "Input",
   CellTags->"b:0.4.2",
   CellID->51924450],
  Cell[170073, 4498, 245, 8, 36, "Output",
   CellTags->"b:0.4.2",
   CellID->15829095]},
 "c:9"->{
  Cell[170367, 4512, 177, 3, 52, "Subsection",
   CellTags->{"c:9", "b:0.4.3"},
   CellID->351610464]},
 "b:0.4.3"->{
  Cell[170367, 4512, 177, 3, 52, "Subsection",
   CellTags->{"c:9", "b:0.4.3"},
   CellID->351610464],
  Cell[170547, 4517, 3130, 77, 118, "Text",
   CellTags->"b:0.4.3",
   CellID->542672475],
  Cell[173680, 4596, 1085, 21, 49, "MathCaption",
   CellTags->"b:0.4.3",
   CellID->271649068],
  Cell[174790, 4621, 262, 8, 28, "Input",
   CellTags->"b:0.4.3",
   CellID->323915583],
  Cell[175055, 4631, 248, 8, 36, "Output",
   CellTags->"b:0.4.3",
   CellID->595622412],
  Cell[175318, 4642, 1362, 25, 63, "MathCaption",
   CellTags->"b:0.4.3",
   CellID->18408293],
  Cell[176705, 4671, 309, 8, 28, "Input",
   CellTags->"b:0.4.3",
   CellID->123426060],
  Cell[177017, 4681, 271, 9, 36, "Output",
   CellTags->"b:0.4.3",
   CellID->59960422],
  Cell[177303, 4693, 1109, 22, 49, "MathCaption",
   CellTags->"b:0.4.3",
   CellID->326611308],
  Cell[178437, 4719, 308, 8, 28, "Input",
   CellTags->"b:0.4.3",
   CellID->237410754],
  Cell[178748, 4729, 323, 9, 36, "Output",
   CellTags->"b:0.4.3",
   CellID->634444596],
  Cell[179086, 4741, 1387, 26, 63, "MathCaption",
   CellTags->"b:0.4.3",
   CellID->627314046],
  Cell[180498, 4771, 459, 13, 47, "Input",
   CellTags->"b:0.4.3",
   CellID->87536172],
  Cell[180960, 4786, 314, 9, 36, "Output",
   CellTags->"b:0.4.3",
   CellID->71742834],
  Cell[181311, 4800, 460, 13, 47, "Input",
   CellTags->"b:0.4.3",
   CellID->31744191],
  Cell[181774, 4815, 246, 8, 36, "Output",
   CellTags->"b:0.4.3",
   CellID->8853572],
  Cell[182035, 4826, 1318, 26, 67, "MathCaption",
   CellTags->"b:0.4.3",
   CellID->1005472710],
  Cell[183378, 4856, 262, 8, 28, "Input",
   CellTags->"b:0.4.3",
   CellID->168142260],
  Cell[183643, 4866, 283, 9, 36, "Output",
   CellTags->"b:0.4.3",
   CellID->238296370],
  Cell[183963, 4880, 236, 7, 28, "Input",
   CellTags->"b:0.4.3",
   CellID->42485134],
  Cell[184202, 4889, 242, 8, 36, "Output",
   CellTags->"b:0.4.3",
   CellID->252851274]},
 "c:10"->{
  Cell[184493, 4903, 88, 2, 52, "Subsection",
   CellTags->{"c:10", "b:0.4.4"},
   CellID->363493082]},
 "b:0.4.4"->{
  Cell[184493, 4903, 88, 2, 52, "Subsection",
   CellTags->{"c:10", "b:0.4.4"},
   CellID->363493082],
  Cell[184584, 4907, 1056, 21, 48, "MathCaption",
   CellTags->"b:0.4.4",
   CellID->3234460],
  Cell[185665, 4932, 209, 6, 28, "Input",
   CellTags->"b:0.4.4",
   CellID->175418910],
  Cell[185877, 4940, 386, 14, 36, "Output",
   CellTags->"b:0.4.4",
   CellID->480693168],
  Cell[186300, 4959, 220, 8, 28, "Input",
   CellTags->"b:0.4.4",
   CellID->352798794],
  Cell[186523, 4969, 265, 9, 36, "Output",
   CellTags->"b:0.4.4",
   CellID->69188359],
  Cell[186803, 4981, 962, 22, 48, "MathCaption",
   CellTags->"b:0.4.4",
   CellID->771123683],
  Cell[187790, 5007, 265, 8, 28, "Input",
   CellTags->"b:0.4.4",
   CellID->227693171],
  Cell[188058, 5017, 384, 14, 36, "Output",
   CellTags->"b:0.4.4",
   CellID->177581636],
  Cell[188457, 5034, 540, 10, 31, "MathCaption",
   CellTags->"b:0.4.4",
   CellID->141395505],
  Cell[189022, 5048, 168, 5, 28, "Input",
   CellTags->"b:0.4.4",
   CellID->695066864],
  Cell[189193, 5055, 443, 16, 36, "Output",
   CellTags->"b:0.4.4",
   CellID->130484574]},
 "c:11"->{
  Cell[189685, 5077, 85, 2, 52, "Subsection",
   CellTags->{"c:11", "b:0.4.5"},
   CellID->401719377]},
 "b:0.4.5"->{
  Cell[189685, 5077, 85, 2, 52, "Subsection",
   CellTags->{"c:11", "b:0.4.5"},
   CellID->401719377],
  Cell[189773, 5081, 2039, 37, 79, "MathCaption",
   CellTags->"b:0.4.5",
   CellID->771573730],
  Cell[191837, 5122, 287, 8, 28, "Input",
   CellTags->"b:0.4.5",
   CellID->175837266],
  Cell[192127, 5132, 181, 6, 36, "Output",
   CellTags->"b:0.4.5",
   CellID->20751351],
  Cell[192345, 5143, 322, 10, 28, "Input",
   CellTags->"b:0.4.5",
   CellID->16340890],
  Cell[192670, 5155, 182, 6, 36, "Output",
   CellTags->"b:0.4.5",
   CellID->993559588],
  Cell[192867, 5164, 872, 22, 54, "Text",
   CellTags->"b:0.4.5",
   CellID->12491824]},
 "c:12"->{
  Cell[193776, 5191, 85, 2, 52, "Subsection",
   CellTags->{"c:12", "b:0.4.6"},
   CellID->1274428]},
 "b:0.4.6"->{
  Cell[193776, 5191, 85, 2, 52, "Subsection",
   CellTags->{"c:12", "b:0.4.6"},
   CellID->1274428],
  Cell[193864, 5195, 682, 14, 48, "MathCaption",
   CellTags->"b:0.4.6",
   CellID->45121066],
  Cell[194571, 5213, 316, 10, 28, "Input",
   CellTags->"b:0.4.6",
   CellID->67067787],
  Cell[194890, 5225, 192, 6, 36, "Output",
   CellTags->"b:0.4.6",
   CellID->72659497],
  Cell[195097, 5234, 1415, 25, 63, "MathCaption",
   CellTags->"b:0.4.6",
   CellID->21617589],
  Cell[196537, 5263, 314, 9, 28, "Input",
   CellTags->"b:0.4.6",
   CellID->801931404],
  Cell[196854, 5274, 203, 6, 36, "Output",
   CellTags->"b:0.4.6",
   CellID->789854925],
  Cell[197072, 5283, 1069, 18, 47, "MathCaption",
   CellTags->"b:0.4.6",
   CellID->150245402],
  Cell[198166, 5305, 327, 9, 28, "Input",
   CellTags->"b:0.4.6",
   CellID->85246728],
  Cell[198496, 5316, 203, 6, 36, "Output",
   CellTags->"b:0.4.6",
   CellID->264349508],
  Cell[198714, 5325, 458, 9, 31, "MathCaption",
   CellTags->"b:0.4.6",
   CellID->203144771],
  Cell[199197, 5338, 323, 9, 28, "Input",
   CellTags->"b:0.4.6",
   CellID->17461363],
  Cell[199523, 5349, 203, 6, 36, "Output",
   CellTags->"b:0.4.6",
   CellID->216313918],
  Cell[199741, 5358, 1214, 21, 63, "MathCaption",
   CellTags->"b:0.4.6",
   CellID->131051894],
  Cell[200980, 5383, 366, 10, 47, "Input",
   CellTags->"b:0.4.6",
   CellID->459415768],
  Cell[201349, 5395, 492, 11, 36, "Output",
   CellTags->"b:0.4.6",
   CellID->29452506],
  Cell[201878, 5411, 126, 4, 28, "Input",
   CellTags->"b:0.4.6",
   CellID->28871706],
  Cell[202007, 5417, 674, 18, 68, "Output",
   CellTags->"b:0.4.6",
   CellID->18384563],
  Cell[202696, 5438, 1225, 20, 68, "Text",
   CellTags->"b:0.4.6",
   CellID->623263418]},
 "c:13"->{
  Cell[203958, 5463, 91, 2, 52, "Subsection",
   CellTags->{"c:13", "b:0.4.7"},
   CellID->239124212]},
 "b:0.4.7"->{
  Cell[203958, 5463, 91, 2, 52, "Subsection",
   CellTags->{"c:13", "b:0.4.7"},
   CellID->239124212],
  Cell[204052, 5467, 912, 19, 48, "MathCaption",
   CellTags->"b:0.4.7",
   CellID->758815075],
  Cell[204989, 5490, 282, 8, 28, "Input",
   CellTags->"b:0.4.7",
   CellID->34244212],
  Cell[205274, 5500, 272, 9, 36, "Output",
   CellTags->"b:0.4.7",
   CellID->76378783],
  Cell[205561, 5512, 805, 13, 45, "MathCaption",
   CellTags->"b:0.4.7",
   CellID->578481874],
  Cell[206391, 5529, 343, 10, 28, "Input",
   CellTags->"b:0.4.7",
   CellID->80963487],
  Cell[206737, 5541, 394, 13, 36, "Output",
   CellTags->"b:0.4.7",
   CellID->228987248]},
 "c:14"->{
  Cell[207180, 5560, 85, 2, 52, "Subsection",
   CellTags->{"c:14", "b:0.4.8"},
   CellID->343107939]},
 "b:0.4.8"->{
  Cell[207180, 5560, 85, 2, 52, "Subsection",
   CellTags->{"c:14", "b:0.4.8"},
   CellID->343107939],
  Cell[207268, 5564, 1392, 23, 63, "MathCaption",
   CellTags->"b:0.4.8",
   CellID->19737335],
  Cell[208685, 5591, 150, 4, 28, "Input",
   CellTags->"b:0.4.8",
   CellID->20551734],
  Cell[208838, 5597, 290, 9, 36, "Output",
   CellTags->"b:0.4.8",
   CellID->713279886],
  Cell[209143, 5609, 692, 12, 45, "MathCaption",
   CellTags->"b:0.4.8",
   CellID->27447488],
  Cell[209860, 5625, 281, 8, 28, "Input",
   CellTags->"b:0.4.8",
   CellID->107169258],
  Cell[210144, 5635, 348, 10, 36, "Output",
   CellTags->"b:0.4.8",
   CellID->176497510],
  Cell[210507, 5648, 537, 10, 31, "MathCaption",
   CellTags->"b:0.4.8",
   CellID->60098082],
  Cell[211069, 5662, 174, 5, 28, "Input",
   CellTags->"b:0.4.8",
   CellID->72110840],
  Cell[211246, 5669, 260, 8, 36, "Output",
   CellTags->"b:0.4.8",
   CellID->362458191],
  Cell[211521, 5680, 637, 14, 35, "MathCaption",
   CellTags->"b:0.4.8",
   CellID->103751328],
  Cell[212183, 5698, 187, 5, 28, "Input",
   CellTags->"b:0.4.8",
   CellID->460561670],
  Cell[212373, 5705, 298, 9, 36, "Output",
   CellTags->"b:0.4.8",
   CellID->236770642],
  Cell[212686, 5717, 856, 14, 45, "MathCaption",
   CellTags->"b:0.4.8",
   CellID->656954062],
  Cell[213567, 5735, 194, 6, 28, "Input",
   CellTags->"b:0.4.8",
   CellID->1019234],
  Cell[213764, 5743, 253, 8, 36, "Output",
   CellTags->"b:0.4.8",
   CellID->14534217],
  Cell[214032, 5754, 443, 8, 31, "MathCaption",
   CellTags->"b:0.4.8",
   CellID->241434771],
  Cell[214500, 5766, 203, 6, 28, "Input",
   CellTags->"b:0.4.8",
   CellID->171055668],
  Cell[214706, 5774, 286, 9, 36, "Output",
   CellTags->"b:0.4.8",
   CellID->204773299],
  Cell[215007, 5786, 1156, 21, 62, "MathCaption",
   CellTags->"b:0.4.8",
   CellID->590437369],
  Cell[216188, 5811, 201, 6, 28, "Input",
   CellTags->"b:0.4.8",
   CellID->4669335],
  Cell[216392, 5819, 293, 9, 71, "Output",
   CellTags->"b:0.4.8",
   CellID->1024030217],
  Cell[216700, 5831, 943, 15, 45, "MathCaption",
   CellTags->"b:0.4.8",
   CellID->11065132],
  Cell[217668, 5850, 220, 6, 28, "Input",
   CellTags->"b:0.4.8",
   CellID->386084822],
  Cell[217891, 5858, 348, 10, 36, "Output",
   CellTags->"b:0.4.8",
   CellID->245134745],
  Cell[218276, 5873, 219, 6, 28, "Input",
   CellTags->"b:0.4.8",
   CellID->60902233],
  Cell[218498, 5881, 348, 10, 36, "Output",
   CellTags->"b:0.4.8",
   CellID->132373715],
  Cell[218883, 5896, 302, 8, 47, "Input",
   CellTags->"b:0.4.8",
   CellID->73670271],
  Cell[219188, 5906, 303, 9, 36, "Output",
   CellTags->"b:0.4.8",
   CellID->169972716],
  Cell[219528, 5920, 377, 10, 47, "Input",
   CellTags->"b:0.4.8",
   CellID->153068299],
  Cell[219908, 5932, 508, 12, 36, "Output",
   CellTags->"b:0.4.8",
   CellID->41820933],
  Cell[220431, 5947, 910, 14, 45, "MathCaption",
   CellTags->"b:0.4.8",
   CellID->307113028],
  Cell[221366, 5965, 487, 14, 47, "Input",
   CellTags->"b:0.4.8",
   CellID->36223674],
  Cell[221856, 5981, 323, 9, 50, "Output",
   CellTags->"b:0.4.8",
   CellID->894580067]},
 "c:15"->{
  Cell[222240, 5997, 162, 3, 62, "Section",
   CellTags->"c:15",
   CellID->759470019]},
 "c:15.5"->{
  Cell[222427, 6004, 150, 3, 52, "Subsection",
   CellTags->{"c:15.5", "b:0.5.0"},
   CellID->20697950]},
 "b:0.5.0"->{
  Cell[222427, 6004, 150, 3, 52, "Subsection",
   CellTags->{"c:15.5", "b:0.5.0"},
   CellID->20697950],
  Cell[222580, 6009, 2529, 40, 120, "Text",
   CellTags->"b:0.5.0",
   CellID->86791152],
  Cell[225112, 6051, 493, 11, 30, "Text",
   CellTags->"b:0.5.0",
   CellID->323888524],
  Cell[225608, 6064, 5582, 124, 379, "DefinitionBox3Col",
   CellTags->"b:0.5.0",
   CellID->43654671],
  Cell[231193, 6190, 516, 9, 30, "Text",
   CellTags->"b:0.5.0",
   CellID->575279163]},
 "c:16"->{
  Cell[231746, 6204, 80, 2, 52, "Subsection",
   CellTags->{"c:16", "b:0.5.1"},
   CellID->120637313]},
 "b:0.5.1"->{
  Cell[231746, 6204, 80, 2, 52, "Subsection",
   CellTags->{"c:16", "b:0.5.1"},
   CellID->120637313],
  Cell[231829, 6208, 1431, 29, 74, "Text",
   CellTags->"b:0.5.1",
   CellID->332493086],
  Cell[233263, 6239, 609, 13, 33, "MathCaption",
   CellTags->"b:0.5.1",
   CellID->163086882],
  Cell[233875, 6254, 137, 7, 100, "Program",
   CellTags->"b:0.5.1",
   CellID->203403607],
  Cell[234015, 6263, 326, 9, 31, "MathCaption",
   CellTags->"b:0.5.1",
   CellID->258819916],
  Cell[234366, 6276, 427, 12, 47, "Input",
   CellTags->"b:0.5.1",
   CellID->403377399],
  Cell[234796, 6290, 127, 3, 23, "Print",
   CellTags->"b:0.5.1",
   CellID->320069806],
  Cell[234938, 6296, 1094, 24, 52, "Text",
   CellTags->"b:0.5.1",
   CellID->130918903],
  Cell[236035, 6322, 299, 5, 31, "MathCaption",
   CellTags->"b:0.5.1",
   CellID->272631892],
  Cell[236337, 6329, 172, 7, 100, "Program",
   CellTags->"b:0.5.1",
   CellID->67879431],
  Cell[236512, 6338, 200, 7, 31, "MathCaption",
   CellTags->"b:0.5.1",
   CellID->175118403],
  Cell[236737, 6349, 777, 24, 65, "Input",
   CellTags->"b:0.5.1",
   CellID->399472551],
  Cell[237517, 6375, 348, 9, 23, "Print",
   CellTags->"b:0.5.1",
   CellID->178834455],
  Cell[237880, 6387, 367, 6, 31, "MathCaption",
   CellTags->"b:0.5.1",
   CellID->161491337],
  Cell[238250, 6395, 149, 5, 62, "Program",
   CellTags->"b:0.5.1",
   CellID->785509705],
  Cell[238402, 6402, 474, 14, 34, "MathCaption",
   CellTags->"b:0.5.1",
   CellID->445860386],
  Cell[238901, 6420, 611, 19, 65, "Input",
   CellTags->"b:0.5.1",
   CellID->682251121],
  Cell[239515, 6441, 265, 9, 36, "Output",
   CellTags->"b:0.5.1",
   CellID->183755673],
  Cell[239795, 6453, 562, 12, 33, "MathCaption",
   CellTags->"b:0.5.1",
   CellID->20175135],
  Cell[240360, 6467, 121, 5, 62, "Program",
   CellTags->"b:0.5.1",
   CellID->19723038],
  Cell[240484, 6474, 505, 14, 34, "MathCaption",
   CellTags->"b:0.5.1",
   CellID->781694409],
  Cell[241014, 6492, 341, 11, 47, "Input",
   CellTags->"b:0.5.1",
   CellID->43441911],
  Cell[241358, 6505, 290, 9, 36, "Output",
   CellTags->"b:0.5.1",
   CellID->371595541]},
 "c:17"->{
  Cell[241697, 6520, 84, 2, 52, "Subsection",
   CellTags->{"c:17", "b:0.5.2"},
   CellID->163295011]},
 "b:0.5.2"->{
  Cell[241697, 6520, 84, 2, 52, "Subsection",
   CellTags->{"c:17", "b:0.5.2"},
   CellID->163295011],
  Cell[241784, 6524, 747, 22, 34, "MathCaption",
   CellTags->"b:0.5.2",
   CellID->51683055],
  Cell[242534, 6548, 107, 5, 62, "Program",
   CellTags->"b:0.5.2",
   CellID->384257252],
  Cell[242644, 6555, 292, 5, 31, "MathCaption",
   CellTags->"b:0.5.2",
   CellID->179104029],
  Cell[242961, 6564, 349, 10, 47, "Input",
   CellTags->"b:0.5.2",
   CellID->252897767],
  Cell[243313, 6576, 195, 6, 36, "Output",
   CellTags->"b:0.5.2",
   CellID->207323890],
  Cell[243523, 6585, 484, 11, 33, "MathCaption",
   CellTags->"b:0.5.2",
   CellID->317632773],
  Cell[244010, 6598, 79, 2, 43, "Program",
   CellTags->"b:0.5.2",
   CellID->152813715],
  Cell[244114, 6604, 253, 8, 28, "Input",
   CellTags->"b:0.5.2",
   CellID->341597359],
  Cell[244370, 6614, 195, 6, 36, "Output",
   CellTags->"b:0.5.2",
   CellID->203169793],
  Cell[244580, 6623, 787, 17, 47, "MathCaption",
   CellTags->"b:0.5.2",
   CellID->183807183],
  Cell[245370, 6642, 115, 5, 62, "Program",
   CellTags->"b:0.5.2",
   CellID->409627135],
  Cell[245510, 6651, 342, 10, 47, "Input",
   CellTags->"b:0.5.2",
   CellID->69447560],
  Cell[245855, 6663, 201, 6, 36, "Output",
   CellTags->"b:0.5.2",
   CellID->520395969]},
 "c:18"->{
  Cell[246105, 6675, 83, 2, 52, "Subsection",
   CellTags->{"c:18", "b:0.5.3"},
   CellID->45791734]},
 "b:0.5.3"->{
  Cell[246105, 6675, 83, 2, 52, "Subsection",
   CellTags->{"c:18", "b:0.5.3"},
   CellID->45791734],
  Cell[246191, 6679, 450, 14, 34, "MathCaption",
   CellTags->"b:0.5.3",
   CellID->12267911],
  Cell[246644, 6695, 109, 5, 62, "Program",
   CellTags->"b:0.5.3",
   CellID->189290885],
  Cell[246778, 6704, 254, 7, 47, "Input",
   CellTags->"b:0.5.3",
   CellID->229530619],
  Cell[247035, 6713, 267, 9, 36, "Output",
   CellTags->"b:0.5.3",
   CellID->17569325],
  Cell[247317, 6725, 643, 12, 45, "MathCaption",
   CellTags->"b:0.5.3",
   CellID->240418930],
  Cell[247963, 6739, 80, 2, 43, "Program",
   CellTags->"b:0.5.3",
   CellID->719922593],
  Cell[248068, 6745, 175, 5, 28, "Input",
   CellTags->"b:0.5.3",
   CellID->502233132],
  Cell[248246, 6752, 249, 8, 36, "Output",
   CellTags->"b:0.5.3",
   CellID->382146358],
  Cell[248510, 6763, 1725, 32, 78, "MathCaption",
   CellTags->"b:0.5.3",
   CellID->78986018],
  Cell[250238, 6797, 151, 5, 62, "Program",
   CellTags->"b:0.5.3",
   CellID->348675863],
  Cell[250414, 6806, 428, 13, 47, "Input",
   CellTags->"b:0.5.3",
   CellID->639488513],
  Cell[250845, 6821, 277, 9, 50, "Output",
   CellTags->"b:0.5.3",
   CellID->829343315],
  Cell[251159, 6835, 470, 15, 47, "Input",
   CellTags->"b:0.5.3",
   CellID->34696905],
  Cell[251632, 6852, 296, 9, 50, "Output",
   CellTags->"b:0.5.3",
   CellID->59433462]},
 "c:19"->{
  Cell[251977, 6867, 85, 2, 52, "Subsection",
   CellTags->{"c:19", "b:0.5.4"},
   CellID->627179989]},
 "b:0.5.4"->{
  Cell[251977, 6867, 85, 2, 52, "Subsection",
   CellTags->{"c:19", "b:0.5.4"},
   CellID->627179989],
  Cell[252065, 6871, 823, 18, 52, "Text",
   CellTags->"b:0.5.4",
   CellID->512373978],
  Cell[252891, 6891, 738, 20, 33, "MathCaption",
   CellTags->"b:0.5.4",
   CellID->75100454],
  Cell[253632, 6913, 107, 5, 62, "Program",
   CellTags->"b:0.5.4",
   CellID->2535425],
  Cell[253742, 6920, 581, 15, 35, "MathCaption",
   CellTags->"b:0.5.4",
   CellID->616093666],
  Cell[254348, 6939, 443, 13, 47, "Input",
   CellTags->"b:0.5.4",
   CellID->394779265],
  Cell[254794, 6954, 194, 6, 36, "Output",
   CellTags->"b:0.5.4",
   CellID->78625730],
  Cell[255003, 6963, 707, 16, 33, "MathCaption",
   CellTags->"b:0.5.4",
   CellID->44095121],
  Cell[255713, 6981, 116, 5, 62, "Program",
   CellTags->"b:0.5.4",
   CellID->260896876],
  Cell[255854, 6990, 609, 17, 65, "Input",
   CellTags->"b:0.5.4",
   CellID->37744320],
  Cell[256466, 7009, 198, 6, 36, "Output",
   CellTags->"b:0.5.4",
   CellID->479145987],
  Cell[256679, 7018, 541, 15, 34, "MathCaption",
   CellTags->"b:0.5.4",
   CellID->291617831],
  Cell[257223, 7035, 114, 5, 62, "Program",
   CellTags->"b:0.5.4",
   CellID->820168201],
  Cell[257362, 7044, 382, 12, 47, "Input",
   CellTags->"b:0.5.4",
   CellID->96850109],
  Cell[257747, 7058, 202, 6, 36, "Output",
   CellTags->"b:0.5.4",
   CellID->497337288],
  Cell[257964, 7067, 519, 11, 33, "MathCaption",
   CellTags->"b:0.5.4",
   CellID->206615673],
  Cell[258486, 7080, 115, 5, 62, "Program",
   CellTags->"b:0.5.4",
   CellID->1448094],
  Cell[258626, 7089, 610, 17, 65, "Input",
   CellTags->"b:0.5.4",
   CellID->297013012],
  Cell[259239, 7108, 196, 6, 36, "Output",
   CellTags->"b:0.5.4",
   CellID->621733276],
  Cell[259450, 7117, 460, 10, 33, "MathCaption",
   CellTags->"b:0.5.4",
   CellID->809943646],
  Cell[259913, 7129, 80, 2, 43, "Program",
   CellTags->"b:0.5.4",
   CellID->727836643],
  Cell[260018, 7135, 286, 9, 28, "Input",
   CellTags->"b:0.5.4",
   CellID->32783502],
  Cell[260307, 7146, 197, 6, 36, "Output",
   CellTags->"b:0.5.4",
   CellID->82701024],
  Cell[260541, 7157, 261, 8, 28, "Input",
   CellTags->"b:0.5.4",
   CellID->190461549],
  Cell[260805, 7167, 198, 6, 36, "Output",
   CellTags->"b:0.5.4",
   CellID->898067845],
  Cell[261018, 7176, 503, 11, 33, "MathCaption",
   CellTags->"b:0.5.4",
   CellID->117673595],
  Cell[261524, 7189, 130, 5, 62, "Program",
   CellTags->"b:0.5.4",
   CellID->144624070],
  Cell[261657, 7196, 557, 16, 35, "MathCaption",
   CellTags->"b:0.5.4",
   CellID->688187582],
  Cell[262239, 7216, 688, 20, 83, "Input",
   CellTags->"b:0.5.4",
   CellID->141316627],
  Cell[262930, 7238, 195, 6, 36, "Output",
   CellTags->"b:0.5.4",
   CellID->57680932]},
 "c:20"->{
  Cell[263186, 7251, 161, 3, 62, "Section",
   CellTags->"c:20",
   CellID->2083974]},
 "c:22"->{
  Cell[263992, 7270, 209, 3, 52, "Subsection",
   CellTags->{"c:22", "b:0.6.1"},
   CellID->738873845]},
 "b:0.6.1"->{
  Cell[263992, 7270, 209, 3, 52, "Subsection",
   CellTags->{"c:22", "b:0.6.1"},
   CellID->738873845],
  Cell[264204, 7275, 563, 10, 31, "MathCaption",
   CellTags->"b:0.6.1",
   CellID->24257838],
  Cell[264792, 7289, 604, 19, 47, "Input",
   CellTags->"b:0.6.1",
   CellID->140406151],
  Cell[265399, 7310, 1219, 20, 224, "Output",
   CellTags->"b:0.6.1",
   CellID->152083121],
  Cell[266633, 7333, 474, 9, 31, "MathCaption",
   CellTags->"b:0.6.1",
   CellID->301369684],
  Cell[267132, 7346, 586, 18, 47, "Input",
   CellTags->"b:0.6.1",
   CellID->614903007],
  Cell[267721, 7366, 1608, 25, 241, "Output",
   CellTags->"b:0.6.1",
   CellID->79975839],
  Cell[269344, 7394, 452, 8, 31, "MathCaption",
   CellTags->"b:0.6.1",
   CellID->12939824],
  Cell[269821, 7406, 372, 10, 65, "Input",
   CellTags->"b:0.6.1",
   CellID->131627168],
  Cell[270196, 7418, 1609, 25, 241, "Output",
   CellTags->"b:0.6.1",
   CellID->678802383]},
 "c:23"->{
  Cell[271854, 7449, 142, 3, 52, "Subsection",
   CellTags->{"c:23", "b:0.6.2"},
   CellID->146223979]},
 "b:0.6.2"->{
  Cell[271854, 7449, 142, 3, 52, "Subsection",
   CellTags->{"c:23", "b:0.6.2"},
   CellID->146223979],
  Cell[271999, 7454, 718, 12, 48, "Text",
   CellTags->"b:0.6.2",
   CellID->454604247],
  Cell[272720, 7468, 301, 10, 31, "MathCaption",
   CellTags->"b:0.6.2",
   CellID->450806450],
  Cell[273024, 7480, 3090, 54, 1001, "Input",
   CellTags->"b:0.6.2",
   CellID->237894310],
  Cell[276139, 7538, 134, 4, 28, "Input",
   CellTags->"b:0.6.2",
   CellID->73854272],
  Cell[276276, 7544, 185, 6, 36, "Output",
   CellTags->"b:0.6.2",
   CellID->435720061],
  Cell[276476, 7553, 375, 6, 31, "MathCaption",
   CellTags->"b:0.6.2",
   CellID->328231447],
  Cell[276876, 7563, 539, 16, 47, "Input",
   CellTags->"b:0.6.2",
   CellID->10965036],
  Cell[277418, 7581, 659, 15, 88, "Output",
   CellTags->"b:0.6.2",
   CellID->658475649],
  Cell[278092, 7599, 419, 11, 33, "MathCaption",
   CellTags->"b:0.6.2",
   CellID->135521350],
  Cell[278536, 7614, 294, 9, 28, "Input",
   CellTags->"b:0.6.2",
   CellID->499683580],
  Cell[278833, 7625, 812, 15, 309, "Output",
   CellTags->"b:0.6.2",
   CellID->339097831]},
 "c:24"->{
  Cell[279694, 7646, 192, 3, 52, "Subsection",
   CellTags->{"c:24", "b:0.6.3"},
   CellID->263221749]},
 "b:0.6.3"->{
  Cell[279694, 7646, 192, 3, 52, "Subsection",
   CellTags->{"c:24", "b:0.6.3"},
   CellID->263221749],
  Cell[279889, 7651, 469, 9, 31, "MathCaption",
   CellTags->"b:0.6.3",
   CellID->456762081],
  Cell[280383, 7664, 191, 6, 28, "Input",
   CellTags->"b:0.6.3",
   CellID->324262933],
  Cell[280577, 7672, 251, 7, 36, "Output",
   CellTags->"b:0.6.3",
   CellID->84181818],
  Cell[280843, 7682, 445, 8, 31, "MathCaption",
   CellTags->"b:0.6.3",
   CellID->47750368],
  Cell[281313, 7694, 422, 14, 28, "Input",
   CellTags->"b:0.6.3",
   CellID->16455114],
  Cell[281738, 7710, 252, 8, 36, "Output",
   CellTags->"b:0.6.3",
   CellID->1028029313],
  Cell[282005, 7721, 1175, 18, 59, "MathCaption",
   CellTags->"b:0.6.3",
   CellID->507462346],
  Cell[283205, 7743, 240, 8, 28, "Input",
   CellTags->"b:0.6.3",
   CellID->28199983],
  Cell[283448, 7753, 251, 8, 36, "Output",
   CellTags->"b:0.6.3",
   CellID->211704891],
  Cell[283714, 7764, 716, 15, 48, "MathCaption",
   CellTags->"b:0.6.3",
   CellID->1024052339],
  Cell[284455, 7783, 199, 6, 28, "Input",
   CellTags->"b:0.6.3",
   CellID->5891025],
  Cell[284657, 7791, 251, 8, 36, "Output",
   CellTags->"b:0.6.3",
   CellID->182707870]},
 "b:0.6.4"->{
  Cell[284957, 7805, 177, 3, 52, "Subsection",
   CellTags->"b:0.6.4",
   CellID->355263806],
  Cell[285137, 7810, 719, 12, 45, "MathCaption",
   CellTags->"b:0.6.4",
   CellID->115242927],
  Cell[285859, 7824, 717, 23, 47, "Input",
   CellTags->"b:0.6.4",
   CellID->78571466],
  Cell[286579, 7849, 265, 4, 31, "MathCaption",
   CellTags->"b:0.6.4",
   CellID->97869725],
  Cell[286869, 7857, 359, 10, 47, "Input",
   CellTags->"b:0.6.4",
   CellID->46155371],
  Cell[287231, 7869, 197, 6, 36, "Output",
   CellTags->"b:0.6.4",
   CellID->551981229],
  Cell[287443, 7878, 534, 11, 33, "MathCaption",
   CellTags->"b:0.6.4",
   CellID->252811811],
  Cell[288002, 7893, 211, 7, 28, "Input",
   CellTags->"b:0.6.4",
   CellID->580624370],
  Cell[288216, 7902, 743, 22, 62, "Output",
   CellTags->"b:0.6.4",
   CellID->776583665],
  Cell[288974, 7927, 472, 9, 33, "MathCaption",
   CellTags->"b:0.6.4",
   CellID->612266699],
  Cell[289471, 7940, 261, 8, 28, "Input",
   CellTags->"b:0.6.4",
   CellID->28035752],
  Cell[289735, 7950, 751, 22, 62, "Output",
   CellTags->"b:0.6.4",
   CellID->552317211]},
 "c:25"->{
  Cell[290547, 7979, 402, 6, 62, "Section",
   CellTags->{"c:25", "Tips and Tricks", "b:0.7"},
   CellID->319138910]},
 "Tips and Tricks"->{
  Cell[290547, 7979, 402, 6, 62, "Section",
   CellTags->{"c:25", "Tips and Tricks", "b:0.7"},
   CellID->319138910]},
 "b:0.7"->{
  Cell[290547, 7979, 402, 6, 62, "Section",
   CellTags->{"c:25", "Tips and Tricks", "b:0.7"},
   CellID->319138910],
  Cell[290952, 7987, 678, 12, 48, "Text",
   CellTags->"b:0.7",
   CellID->1088522],
  Cell[291655, 8003, 179, 4, 52, "Subsection",
   CellTags->{"c:26", "b:0.7"},
   CellID->571253149],
  Cell[291837, 8009, 2539, 39, 120, "Text",
   CellTags->"b:0.7",
   CellID->527245798],
  Cell[294413, 8053, 158, 3, 52, "Subsection",
   CellTags->{"c:27", "b:0.7"},
   CellID->11710184],
  Cell[294574, 8058, 1717, 35, 62, "MathCaption",
   CellTags->"b:0.7",
   CellID->168089851],
  Cell[296294, 8095, 465, 14, 47, "Input",
   CellTags->"b:0.7",
   CellID->45298985],
  Cell[296784, 8113, 254, 9, 28, "Input",
   CellTags->"b:0.7",
   CellID->334473682],
  Cell[297041, 8124, 227, 8, 36, "Output",
   CellTags->"b:0.7",
   CellID->60278642],
  Cell[297305, 8137, 251, 9, 28, "Input",
   CellTags->"b:0.7",
   CellID->108146462],
  Cell[297559, 8148, 251, 8, 36, "Output",
   CellTags->"b:0.7",
   CellID->840100588],
  Cell[297859, 8162, 239, 4, 52, "Subsection",
   CellTags->{"c:28", "b:0.7"},
   CellID->39608680],
  Cell[298101, 8168, 2309, 38, 122, "Text",
   CellTags->"b:0.7",
   CellID->350158018],
  Cell[300447, 8211, 302, 5, 52, "Subsection",
   CellTags->{"c:29", "b:0.7"},
   CellID->73358011],
  Cell[300752, 8218, 2616, 45, 95, "MathCaption",
   CellTags->"b:0.7",
   CellID->274569970],
  Cell[303371, 8265, 768, 24, 47, "Input",
   CellTags->"b:0.7",
   CellID->88405937],
  Cell[304164, 8293, 148, 5, 28, "Input",
   CellTags->"b:0.7",
   CellID->171329605],
  Cell[304315, 8300, 290, 9, 36, "Output",
   CellTags->"b:0.7",
   CellID->24933409],
  Cell[304620, 8312, 568, 16, 35, "MathCaption",
   CellTags->"b:0.7",
   CellID->482988001],
  Cell[305213, 8332, 384, 13, 28, "Input",
   CellTags->"b:0.7",
   CellID->235104226],
  Cell[305600, 8347, 1596, 32, 139, "Output",
   CellTags->"b:0.7",
   CellID->5314957],
  Cell[307211, 8382, 1162, 23, 53, "MathCaption",
   CellTags->"b:0.7",
   CellID->940575378],
  Cell[308398, 8409, 360, 12, 28, "Input",
   CellTags->"b:0.7",
   CellID->159751616],
  Cell[308761, 8423, 1575, 32, 139, "Output",
   CellTags->"b:0.7",
   CellID->356900352],
  Cell[310351, 8458, 1830, 34, 82, "MathCaption",
   CellTags->"b:0.7",
   CellID->440945305],
  Cell[312206, 8496, 413, 13, 47, "Input",
   CellTags->"b:0.7",
   CellID->344941105],
  Cell[312622, 8511, 1575, 32, 139, "Output",
   CellTags->"b:0.7",
   CellID->615031247],
  Cell[314246, 8549, 511, 9, 72, "Subsection",
   CellTags->{"c:30", "b:0.7"},
   CellID->148652143],
  Cell[314760, 8560, 2769, 43, 122, "Text",
   CellTags->"b:0.7",
   CellID->13332812],
  Cell[317532, 8605, 1248, 19, 59, "MathCaption",
   CellTags->"b:0.7",
   CellID->349310128],
  Cell[318805, 8628, 550, 17, 47, "Input",
   CellTags->"b:0.7",
   CellID->34682433],
  Cell[319358, 8647, 670, 16, 71, "Output",
   CellTags->"b:0.7",
   CellID->2287957],
  Cell[320043, 8666, 776, 13, 45, "MathCaption",
   CellTags->"b:0.7",
   CellID->19330986],
  Cell[320844, 8683, 658, 19, 47, "Input",
   CellTags->"b:0.7",
   CellID->115301483],
  Cell[321505, 8704, 671, 16, 71, "Output",
   CellTags->"b:0.7",
   CellID->284787246],
  Cell[322191, 8723, 901, 20, 49, "MathCaption",
   CellTags->"b:0.7",
   CellID->309333144],
  Cell[323117, 8747, 839, 25, 65, "Input",
   CellTags->"b:0.7",
   CellID->238693932],
  Cell[323959, 8774, 672, 16, 71, "Output",
   CellTags->"b:0.7",
   CellID->131475791],
  Cell[324668, 8795, 701, 19, 83, "Input",
   CellTags->"b:0.7",
   CellID->74230660],
  Cell[325372, 8816, 842, 20, 71, "Output",
   CellTags->"b:0.7",
   CellID->251254336],
  Cell[326229, 8839, 581, 10, 31, "MathCaption",
   CellTags->"b:0.7",
   CellID->778852497],
  Cell[326813, 8851, 318, 12, 28, "Input",
   CellTags->"b:0.7",
   CellID->166716726],
  Cell[327156, 8867, 152, 5, 28, "Input",
   CellTags->"b:0.7",
   CellID->143881214],
  Cell[327311, 8874, 310, 11, 36, "Output",
   CellTags->"b:0.7",
   CellID->811151718],
  Cell[327658, 8890, 303, 10, 28, "Input",
   CellTags->"b:0.7",
   CellID->9520874],
  Cell[327964, 8902, 252, 8, 36, "Output",
   CellTags->"b:0.7",
   CellID->37879651],
  Cell[328231, 8913, 185, 6, 28, "Input",
   CellTags->"b:0.7",
   CellID->55052828],
  Cell[328441, 8923, 206, 6, 28, "Input",
   CellTags->"b:0.7",
   CellID->106844855],
  Cell[328650, 8931, 387, 14, 36, "Output",
   CellTags->"b:0.7",
   CellID->505448699],
  Cell[329074, 8950, 334, 10, 28, "Input",
   CellTags->"b:0.7",
   CellID->483013677],
  Cell[329411, 8962, 230, 8, 36, "Output",
   CellTags->"b:0.7",
   CellID->486101578]},
 "c:26"->{
  Cell[291655, 8003, 179, 4, 52, "Subsection",
   CellTags->{"c:26", "b:0.7"},
   CellID->571253149]},
 "c:27"->{
  Cell[294413, 8053, 158, 3, 52, "Subsection",
   CellTags->{"c:27", "b:0.7"},
   CellID->11710184]},
 "c:28"->{
  Cell[297859, 8162, 239, 4, 52, "Subsection",
   CellTags->{"c:28", "b:0.7"},
   CellID->39608680]},
 "c:29"->{
  Cell[300447, 8211, 302, 5, 52, "Subsection",
   CellTags->{"c:29", "b:0.7"},
   CellID->73358011]},
 "c:30"->{
  Cell[314246, 8549, 511, 9, 72, "Subsection",
   CellTags->{"c:30", "b:0.7"},
   CellID->148652143]},
 "c:31"->{
  Cell[329702, 8977, 255, 4, 62, "Section",
   CellTags->{"c:31", "b:0.8"},
   CellID->337819047]},
 "b:0.8"->{
  Cell[329702, 8977, 255, 4, 62, "Section",
   CellTags->{"c:31", "b:0.8"},
   CellID->337819047],
  Cell[329960, 8983, 882, 16, 66, "Text",
   CellTags->"b:0.8",
   CellID->68963779],
  Cell[330845, 9001, 853, 16, 48, "Text",
   CellTags->"b:0.8",
   CellID->57047539],
  Cell[331701, 9019, 987, 17, 47, "MathCaption",
   CellTags->"b:0.8",
   CellID->169990753],
  Cell[332713, 9040, 277, 8, 28, "Input",
   CellTags->"b:0.8",
   CellID->201123037],
  Cell[332993, 9050, 220, 6, 50, "Output",
   CellTags->"b:0.8",
   CellID->32699069],
  Cell[333228, 9059, 922, 15, 48, "Text",
   CellTags->"b:0.8",
   CellID->190255727],
  Cell[334153, 9076, 1487, 22, 66, "Text",
   CellTags->"b:0.8",
   CellID->210149359],
  Cell[335643, 9100, 917, 18, 48, "Text",
   CellTags->"b:0.8",
   CellID->953153723],
  Cell[336563, 9120, 1780, 30, 90, "Text",
   CellTags->"b:0.8",
   CellID->198359003],
  Cell[338346, 9152, 2272, 44, 114, "Text",
   CellTags->"b:0.8",
   CellID->908430859],
  Cell[340621, 9198, 1915, 38, 90, "Text",
   CellTags->"b:0.8",
   CellID->1015887440]},
 "c:32"->{
  Cell[342573, 9241, 105, 2, 62, "Section",
   CellTags->{"c:32", "b:0.9"},
   CellID->503575505]},
 "b:0.9"->{
  Cell[342573, 9241, 105, 2, 62, "Section",
   CellTags->{"c:32", "b:0.9"},
   CellID->503575505],
  Cell[342681, 9245, 274, 9, 30, "Reference",
   CellTags->{"Ref-1", "b:0.9"},
   CellID->872737084],
  Cell[342958, 9256, 218, 7, 30, "Reference",
   CellTags->{"Ref-2", "b:0.9"},
   CellID->201956504]},
 "Ref-1"->{
  Cell[342681, 9245, 274, 9, 30, "Reference",
   CellTags->{"Ref-1", "b:0.9"},
   CellID->872737084]},
 "Ref-2"->{
  Cell[342958, 9256, 218, 7, 30, "Reference",
   CellTags->{"Ref-2", "b:0.9"},
   CellID->201956504]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"c:1", 347876, 9381},
 {"b:0.0", 347983, 9385},
 {"c:2", 350155, 9461},
 {"b:0.1", 350264, 9465},
 {"Regular Expressions", 355477, 9643},
 {"c:3", 355608, 9647},
 {"b:0.2", 355741, 9651},
 {"c:4", 361301, 9838},
 {"b:0.3", 361412, 9842},
 {"c:5", 361889, 9858},
 {"c:6", 361987, 9862},
 {"b:0.4.0", 362104, 9866},
 {"c:7", 363840, 9924},
 {"b:0.4.1", 363957, 9928},
 {"c:8", 364524, 9947},
 {"b:0.4.2", 364639, 9951},
 {"c:9", 366569, 10015},
 {"b:0.4.3", 366687, 10019},
 {"c:10", 368626, 10083},
 {"b:0.4.4", 368744, 10087},
 {"c:11", 369864, 10124},
 {"b:0.4.5", 369982, 10128},
 {"c:12", 370639, 10150},
 {"b:0.4.6", 370755, 10154},
 {"c:13", 372509, 10212},
 {"b:0.4.7", 372627, 10216},
 {"c:14", 373291, 10238},
 {"b:0.4.8", 373409, 10242},
 {"c:15", 376529, 10345},
 {"c:15.5", 376631, 10349},
 {"b:0.5.0", 376751, 10353},
 {"c:16", 377239, 10369},
 {"b:0.5.1", 377357, 10373},
 {"c:17", 379496, 10443},
 {"b:0.5.2", 379614, 10447},
 {"c:18", 380921, 10490},
 {"b:0.5.3", 381038, 10494},
 {"c:19", 382426, 10540},
 {"b:0.5.4", 382544, 10544},
 {"c:20", 385307, 10635},
 {"c:22", 385405, 10639},
 {"b:0.6.1", 385524, 10643},
 {"c:23", 386472, 10674},
 {"b:0.6.2", 386591, 10678},
 {"c:24", 387715, 10715},
 {"b:0.6.3", 387834, 10719},
 {"b:0.6.4", 389049, 10759},
 {"c:25", 390163, 10796},
 {"Tips and Tricks", 390304, 10800},
 {"b:0.7", 390435, 10804},
 {"c:26", 395084, 10958},
 {"c:27", 395198, 10962},
 {"c:28", 395311, 10966},
 {"c:29", 395424, 10970},
 {"c:30", 395537, 10974},
 {"c:31", 395651, 10978},
 {"b:0.8", 395763, 10982},
 {"c:32", 396842, 11019},
 {"b:0.9", 396954, 11023},
 {"Ref-1", 397270, 11033},
 {"Ref-2", 397385, 11037}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[621, 21, 5990, 136, 48, "AnchorBarGrid",
 CellID->1],
Cell[CellGroupData[{
Cell[6636, 161, 276, 4, 47, "Title",
 CellID->174764828],
Cell[6915, 167, 4252, 111, 151, "TutorialJumpBox",
 CellID->499765158],
Cell[CellGroupData[{
Cell[11192, 282, 114, 2, 62, "Section",
 CellTags->{"c:1", "b:0.0"},
 CellID->6475218],
Cell[11309, 286, 2175, 33, 102, "Text",
 CellTags->"b:0.0",
 CellID->879271277],
Cell[13487, 321, 1319, 26, 63, "MathCaption",
 CellTags->"b:0.0",
 CellID->217261366],
Cell[CellGroupData[{
Cell[14831, 351, 290, 10, 28, "Input",
 CellTags->"b:0.0",
 CellID->6793186],
Cell[15124, 363, 181, 6, 36, "Output",
 CellTags->"b:0.0",
 CellID->88064594]
}, Open  ]],
Cell[CellGroupData[{
Cell[15342, 374, 302, 10, 28, "Input",
 CellTags->"b:0.0",
 CellID->397472003],
Cell[15647, 386, 181, 6, 36, "Output",
 CellTags->"b:0.0",
 CellID->293854130]
}, Open  ]],
Cell[CellGroupData[{
Cell[15865, 397, 244, 8, 28, "Input",
 CellTags->"b:0.0",
 CellID->108872960],
Cell[16112, 407, 233, 8, 36, "Output",
 CellTags->"b:0.0",
 CellID->516087023]
}, Open  ]],
Cell[16360, 418, 2166, 34, 73, "MathCaption",
 CellTags->"b:0.0",
 CellID->47601161],
Cell[CellGroupData[{
Cell[18551, 456, 246, 8, 28, "Input",
 CellTags->"b:0.0",
 CellID->164239912],
Cell[18800, 466, 181, 6, 36, "Output",
 CellTags->"b:0.0",
 CellID->22481105]
}, Open  ]],
Cell[CellGroupData[{
Cell[19018, 477, 247, 8, 28, "Input",
 CellTags->"b:0.0",
 CellID->340018981],
Cell[19268, 487, 181, 6, 36, "Output",
 CellTags->"b:0.0",
 CellID->335521681]
}, Open  ]],
Cell[CellGroupData[{
Cell[19486, 498, 176, 5, 28, "Input",
 CellTags->"b:0.0",
 CellID->327756114],
Cell[19665, 505, 257, 8, 36, "Output",
 CellTags->"b:0.0",
 CellID->365251227]
}, Open  ]],
Cell[19937, 516, 1064, 17, 45, "MathCaption",
 CellTags->"b:0.0",
 CellID->7623660],
Cell[CellGroupData[{
Cell[21026, 537, 229, 7, 28, "Input",
 CellTags->"b:0.0",
 CellID->257665367],
Cell[21258, 546, 180, 6, 36, "Output",
 CellTags->"b:0.0",
 CellID->1666481]
}, Open  ]],
Cell[CellGroupData[{
Cell[21475, 557, 229, 7, 28, "Input",
 CellTags->"b:0.0",
 CellID->15296355],
Cell[21707, 566, 181, 6, 36, "Output",
 CellTags->"b:0.0",
 CellID->816730330]
}, Open  ]],
Cell[CellGroupData[{
Cell[21925, 577, 219, 6, 28, "Input",
 CellTags->"b:0.0",
 CellID->44443359],
Cell[22147, 585, 257, 8, 36, "Output",
 CellTags->"b:0.0",
 CellID->259369629]
}, Open  ]],
Cell[22419, 596, 593, 10, 48, "Text",
 CellTags->"b:0.0",
 CellID->131976413],
Cell[23015, 608, 7438, 187, 354, "DefinitionBox",
 CellID->28981],
Cell[30456, 797, 374, 6, 31, "Caption",
 CellTags->"b:0.0",
 CellID->49176434]
}, Open  ]],
Cell[CellGroupData[{
Cell[30867, 808, 282, 5, 62, "Section",
 CellTags->{"c:2", "b:0.1"},
 CellID->316252289],
Cell[31152, 815, 1436, 27, 62, "MathCaption",
 CellTags->"b:0.1",
 CellID->775969280],
Cell[CellGroupData[{
Cell[32613, 846, 156, 5, 28, "Input",
 CellTags->"b:0.1",
 CellID->14216555],
Cell[32772, 853, 418, 15, 50, "Output",
 CellTags->"b:0.1",
 CellID->577426259]
}, Open  ]],
Cell[33205, 871, 1262, 24, 62, "MathCaption",
 CellTags->"b:0.1",
 CellID->143628873],
Cell[CellGroupData[{
Cell[34492, 899, 165, 5, 28, "Input",
 CellTags->"b:0.1",
 CellID->220445018],
Cell[34660, 906, 192, 6, 36, "Output",
 CellTags->"b:0.1",
 CellID->109635832]
}, Open  ]],
Cell[34867, 915, 2342, 42, 106, "Text",
 CellTags->"b:0.1",
 CellID->100231778],
Cell[37212, 959, 542, 10, 30, "Text",
 CellTags->"b:0.1",
 CellID->206331185],
Cell[37757, 971, 8116, 187, 477, "DefinitionBox",
 CellID->31675],
Cell[45876, 1160, 239, 4, 30, "Text",
 CellTags->"b:0.1",
 CellID->104465889],
Cell[46118, 1166, 3955, 108, 251, "DefinitionBox",
 CellID->9253],
Cell[50076, 1276, 320, 5, 30, "Text",
 CellTags->"b:0.1",
 CellID->97881266],
Cell[50399, 1283, 2272, 55, 184, "DefinitionBox",
 CellID->25418],
Cell[52674, 1340, 674, 11, 48, "Text",
 CellTags->"b:0.1",
 CellID->138112839],
Cell[53351, 1353, 1626, 38, 111, "DefinitionBox",
 CellID->20324],
Cell[54980, 1393, 56, 2, 30, "Text",
 CellTags->"b:0.1",
 CellID->833514613],
Cell[55039, 1397, 453, 9, 30, "Text",
 CellTags->"b:0.1",
 CellID->691886255],
Cell[55495, 1408, 2085, 48, 65, "MathCaption",
 CellTags->"b:0.1",
 CellID->110717692],
Cell[CellGroupData[{
Cell[57605, 1460, 174, 5, 28, "Input",
 CellTags->"b:0.1",
 CellID->32115820],
Cell[57782, 1467, 224, 7, 71, "Output",
 CellTags->"b:0.1",
 CellID->140880394]
}, Open  ]],
Cell[CellGroupData[{
Cell[58043, 1479, 239, 7, 28, "Input",
 CellTags->"b:0.1",
 CellID->280132484],
Cell[58285, 1488, 248, 8, 36, "Output",
 CellTags->"b:0.1",
 CellID->269517925]
}, Open  ]],
Cell[CellGroupData[{
Cell[58570, 1501, 228, 6, 28, "Input",
 CellTags->"b:0.1",
 CellID->406476748],
Cell[58801, 1509, 247, 8, 36, "Output",
 CellTags->"b:0.1",
 CellID->59754046]
}, Open  ]],
Cell[59063, 1520, 1374, 30, 65, "MathCaption",
 CellTags->"b:0.1",
 CellID->694363556],
Cell[CellGroupData[{
Cell[60462, 1554, 318, 9, 28, "Input",
 CellTags->"b:0.1",
 CellID->140507535],
Cell[60783, 1565, 210, 6, 36, "Output",
 CellTags->"b:0.1",
 CellID->669388833]
}, Open  ]],
Cell[61008, 1574, 1935, 36, 81, "MathCaption",
 CellTags->"b:0.1",
 CellID->48865639],
Cell[CellGroupData[{
Cell[62968, 1614, 460, 14, 47, "Input",
 CellTags->"b:0.1",
 CellID->134667756],
Cell[63431, 1630, 242, 8, 36, "Output",
 CellTags->"b:0.1",
 CellID->252805576]
}, Open  ]],
Cell[63688, 1641, 802, 19, 49, "MathCaption",
 CellTags->"b:0.1",
 CellID->408165015],
Cell[CellGroupData[{
Cell[64515, 1664, 312, 11, 28, "Input",
 CellTags->"b:0.1",
 CellID->149685880],
Cell[64830, 1677, 263, 9, 36, "Output",
 CellTags->"b:0.1",
 CellID->25020691]
}, Open  ]],
Cell[65108, 1689, 550, 15, 35, "MathCaption",
 CellTags->"b:0.1",
 CellID->212294979],
Cell[CellGroupData[{
Cell[65683, 1708, 229, 6, 28, "Input",
 CellTags->"b:0.1",
 CellID->318389946],
Cell[65915, 1716, 197, 6, 36, "Output",
 CellTags->"b:0.1",
 CellID->150923485]
}, Open  ]],
Cell[66127, 1725, 583, 12, 35, "MathCaption",
 CellTags->"b:0.1",
 CellID->384134564],
Cell[CellGroupData[{
Cell[66735, 1741, 332, 10, 28, "Input",
 CellTags->"b:0.1",
 CellID->23848909],
Cell[67070, 1753, 242, 8, 36, "Output",
 CellTags->"b:0.1",
 CellID->262077309]
}, Open  ]],
Cell[67327, 1764, 1151, 20, 47, "MathCaption",
 CellTags->"b:0.1",
 CellID->603056891],
Cell[CellGroupData[{
Cell[68503, 1788, 296, 8, 28, "Input",
 CellTags->"b:0.1",
 CellID->291672169],
Cell[68802, 1798, 244, 8, 36, "Output",
 CellTags->"b:0.1",
 CellID->674525324]
}, Open  ]],
Cell[69061, 1809, 574, 12, 34, "MathCaption",
 CellTags->"b:0.1",
 CellID->344292962],
Cell[CellGroupData[{
Cell[69660, 1825, 304, 10, 28, "Input",
 CellTags->"b:0.1",
 CellID->57194593],
Cell[69967, 1837, 248, 8, 36, "Output",
 CellTags->"b:0.1",
 CellID->137492503]
}, Open  ]],
Cell[70230, 1848, 974, 18, 51, "Text",
 CellTags->"b:0.1",
 CellID->2661260],
Cell[71207, 1868, 513, 9, 31, "MathCaption",
 CellTags->"b:0.1",
 CellID->704437595],
Cell[CellGroupData[{
Cell[71745, 1881, 307, 9, 28, "Input",
 CellTags->"b:0.1",
 CellID->190390204],
Cell[72055, 1892, 190, 6, 36, "Output",
 CellTags->"b:0.1",
 CellID->36878244]
}, Open  ]],
Cell[72260, 1901, 2128, 38, 79, "MathCaption",
 CellTags->"b:0.1",
 CellID->422987297],
Cell[CellGroupData[{
Cell[74413, 1943, 236, 7, 28, "Input",
 CellTags->"b:0.1",
 CellID->262589375],
Cell[74652, 1952, 218, 7, 36, "Output",
 CellTags->"b:0.1",
 CellID->446243857]
}, Open  ]],
Cell[CellGroupData[{
Cell[74907, 1964, 260, 8, 28, "Input",
 CellTags->"b:0.1",
 CellID->87767072],
Cell[75170, 1974, 246, 8, 36, "Output",
 CellTags->"b:0.1",
 CellID->10974229]
}, Open  ]],
Cell[75431, 1985, 803, 17, 48, "MathCaption",
 CellTags->"b:0.1",
 CellID->30079273],
Cell[CellGroupData[{
Cell[76259, 2006, 403, 11, 47, "Input",
 CellTags->"b:0.1",
 CellID->336262030],
Cell[76665, 2019, 240, 8, 36, "Output",
 CellTags->"b:0.1",
 CellID->124605047]
}, Open  ]],
Cell[CellGroupData[{
Cell[76942, 2032, 440, 12, 47, "Input",
 CellTags->"b:0.1",
 CellID->46781425],
Cell[77385, 2046, 243, 8, 36, "Output",
 CellTags->"b:0.1",
 CellID->35253798]
}, Open  ]],
Cell[77643, 2057, 647, 14, 34, "MathCaption",
 CellTags->"b:0.1",
 CellID->165376289],
Cell[CellGroupData[{
Cell[78315, 2075, 434, 12, 47, "Input",
 CellTags->"b:0.1",
 CellID->33998707],
Cell[78752, 2089, 244, 8, 36, "Output",
 CellTags->"b:0.1",
 CellID->266461623]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[79045, 2103, 208, 3, 62, "Section",
 CellTags->{"Regular Expressions", "c:3", "b:0.2"},
 CellID->274403895],
Cell[79256, 2108, 1576, 30, 87, "Text",
 CellTags->"b:0.2",
 CellID->179324024],
Cell[80835, 2140, 536, 10, 38, "Text",
 CellTags->"b:0.2",
 CellID->311647046],
Cell[81374, 2152, 6867, 177, 348, "DefinitionBox",
 CellID->30983],
Cell[88244, 2331, 354, 6, 30, "Text",
 CellTags->"b:0.2",
 CellID->326926809],
Cell[88601, 2339, 2379, 47, 214, "DefinitionBox",
 CellID->3341],
Cell[90983, 2388, 1299, 49, 50, "Text",
 CellTags->"b:0.2",
 CellID->423328124],
Cell[92285, 2439, 510, 9, 30, "Text",
 CellTags->"b:0.2",
 CellID->53679581],
Cell[92798, 2450, 2044, 44, 192, "DefinitionBox",
 CellTags->"b:0.2",
 CellID->438051314],
Cell[94845, 2496, 366, 6, 30, "Text",
 CellTags->"b:0.2",
 CellID->446511798],
Cell[95214, 2504, 2553, 57, 191, "DefinitionBox",
 CellTags->"b:0.2",
 CellID->103937476],
Cell[97770, 2563, 325, 5, 30, "Text",
 CellTags->"b:0.2",
 CellID->725709264],
Cell[98098, 2570, 2196, 61, 125, "DefinitionBox",
 CellTags->"b:0.2",
 CellID->324529988],
Cell[100297, 2633, 465, 9, 30, "Text",
 CellTags->"b:0.2",
 CellID->36188322],
Cell[100765, 2644, 519, 9, 31, "MathCaption",
 CellTags->"b:0.2",
 CellID->17419283],
Cell[CellGroupData[{
Cell[101309, 2657, 252, 7, 28, "Input",
 CellTags->"b:0.2",
 CellID->636896070],
Cell[101564, 2666, 268, 9, 36, "Output",
 CellTags->"b:0.2",
 CellID->179137521]
}, Open  ]],
Cell[101847, 2678, 1255, 20, 61, "MathCaption",
 CellTags->"b:0.2",
 CellID->228635176],
Cell[CellGroupData[{
Cell[103127, 2702, 229, 7, 28, "Input",
 CellTags->"b:0.2",
 CellID->149453386],
Cell[103359, 2711, 242, 8, 36, "Output",
 CellTags->"b:0.2",
 CellID->134310985]
}, Open  ]],
Cell[CellGroupData[{
Cell[103638, 2724, 229, 7, 28, "Input",
 CellTags->"b:0.2",
 CellID->27057531],
Cell[103870, 2733, 196, 7, 36, "Output",
 CellTags->"b:0.2",
 CellID->167625736]
}, Open  ]],
Cell[CellGroupData[{
Cell[104103, 2745, 229, 7, 28, "Input",
 CellTags->"b:0.2",
 CellID->72747825],
Cell[104335, 2754, 243, 8, 36, "Output",
 CellTags->"b:0.2",
 CellID->136763727]
}, Open  ]],
Cell[104593, 2765, 567, 14, 33, "MathCaption",
 CellTags->"b:0.2",
 CellID->574029527],
Cell[CellGroupData[{
Cell[105185, 2783, 246, 7, 28, "Input",
 CellTags->"b:0.2",
 CellID->972490785],
Cell[105434, 2792, 286, 9, 36, "Output",
 CellTags->"b:0.2",
 CellID->467284740]
}, Open  ]],
Cell[105735, 2804, 1926, 49, 72, "Text",
 CellTags->"b:0.2",
 CellID->645192577],
Cell[107664, 2855, 863, 21, 52, "Text",
 CellTags->"b:0.2",
 CellID->38350545],
Cell[108530, 2878, 908, 14, 45, "MathCaption",
 CellTags->"b:0.2",
 CellID->87518571],
Cell[CellGroupData[{
Cell[109463, 2896, 226, 6, 28, "Input",
 CellTags->"b:0.2",
 CellID->310325877],
Cell[109692, 2904, 213, 7, 36, "Output",
 CellTags->"b:0.2",
 CellID->252964877]
}, Open  ]],
Cell[CellGroupData[{
Cell[109942, 2916, 232, 7, 28, "Input",
 CellTags->"b:0.2",
 CellID->47695904],
Cell[110177, 2925, 247, 8, 36, "Output",
 CellTags->"b:0.2",
 CellID->25259495]
}, Open  ]],
Cell[110439, 2936, 759, 17, 49, "MathCaption",
 CellTags->"b:0.2",
 CellID->428461048],
Cell[CellGroupData[{
Cell[111223, 2957, 238, 7, 28, "Input",
 CellTags->"b:0.2",
 CellID->1001621228],
Cell[111464, 2966, 213, 7, 36, "Output",
 CellTags->"b:0.2",
 CellID->377933075]
}, Open  ]],
Cell[111692, 2976, 701, 14, 47, "MathCaption",
 CellTags->"b:0.2",
 CellID->667194970],
Cell[CellGroupData[{
Cell[112418, 2994, 346, 10, 83, "Input",
 CellTags->"b:0.2",
 CellID->562254777],
Cell[112767, 3006, 247, 8, 36, "Output",
 CellTags->"b:0.2",
 CellID->72339243]
}, Open  ]],
Cell[113029, 3017, 2412, 43, 77, "MathCaption",
 CellTags->"b:0.2",
 CellID->1379250],
Cell[CellGroupData[{
Cell[115466, 3064, 245, 7, 28, "Input",
 CellTags->"b:0.2",
 CellID->425844705],
Cell[115714, 3073, 246, 8, 36, "Output",
 CellTags->"b:0.2",
 CellID->104389920]
}, Open  ]],
Cell[CellGroupData[{
Cell[115997, 3086, 378, 11, 47, "Input",
 CellTags->"b:0.2",
 CellID->25483089],
Cell[116378, 3099, 422, 14, 36, "Output",
 CellTags->"b:0.2",
 CellID->19980348]
}, Open  ]],
Cell[116815, 3116, 1126, 21, 49, "MathCaption",
 CellTags->"b:0.2",
 CellID->251858179],
Cell[CellGroupData[{
Cell[117966, 3141, 416, 12, 47, "Input",
 CellTags->"b:0.2",
 CellID->84036725],
Cell[118385, 3155, 479, 14, 36, "Output",
 CellTags->"b:0.2",
 CellID->759065165]
}, Open  ]],
Cell[118879, 3172, 1309, 21, 61, "MathCaption",
 CellTags->"b:0.2",
 CellID->695998127],
Cell[CellGroupData[{
Cell[120213, 3197, 435, 11, 47, "Input",
 CellTags->"b:0.2",
 CellID->28505115],
Cell[120651, 3210, 487, 14, 36, "Output",
 CellTags->"b:0.2",
 CellID->693657665]
}, Open  ]],
Cell[121153, 3227, 955, 18, 47, "MathCaption",
 CellTags->"b:0.2",
 CellID->465786935],
Cell[CellGroupData[{
Cell[122133, 3249, 243, 7, 28, "Input",
 CellTags->"b:0.2",
 CellID->38936688],
Cell[122379, 3258, 244, 8, 36, "Output",
 CellTags->"b:0.2",
 CellID->486204157]
}, Open  ]],
Cell[122638, 3269, 1044, 16, 66, "Text",
 CellTags->"b:0.2",
 CellID->377461404],
Cell[123685, 3287, 543, 11, 33, "MathCaption",
 CellTags->"b:0.2",
 CellID->114009367],
Cell[CellGroupData[{
Cell[124253, 3302, 246, 7, 28, "Input",
 CellTags->"b:0.2",
 CellID->635063856],
Cell[124502, 3311, 244, 8, 36, "Output",
 CellTags->"b:0.2",
 CellID->206193907]
}, Open  ]],
Cell[124761, 3322, 740, 12, 45, "MathCaption",
 CellTags->"b:0.2",
 CellID->142585462],
Cell[CellGroupData[{
Cell[125526, 3338, 425, 13, 47, "Input",
 CellTags->"b:0.2",
 CellID->4084787],
Cell[125954, 3353, 301, 9, 36, "Output",
 CellTags->"b:0.2",
 CellID->20535323]
}, Open  ]],
Cell[126270, 3365, 1385, 22, 59, "MathCaption",
 CellTags->"b:0.2",
 CellID->68612708],
Cell[CellGroupData[{
Cell[127680, 3391, 452, 14, 47, "Input",
 CellTags->"b:0.2",
 CellID->373128525],
Cell[128135, 3407, 241, 8, 36, "Output",
 CellTags->"b:0.2",
 CellID->43881256]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[128425, 3421, 166, 3, 62, "Section",
 CellTags->{"c:4", "b:0.3"},
 CellID->182364929],
Cell[128594, 3426, 1576, 23, 84, "Text",
 CellTags->"b:0.3",
 CellID->100369965],
Cell[130173, 3451, 12866, 309, 979, "DefinitionBox3Col",
 CellTags->"b:0.3",
 CellID->195821352],
Cell[143042, 3762, 1410, 30, 68, "Text",
 CellTags->"b:0.3",
 CellID->143238647],
Cell[144455, 3794, 1846, 30, 88, "Text",
 CellTags->"b:0.3",
 CellID->121646424]
}, Open  ]],
Cell[CellGroupData[{
Cell[146338, 3829, 296, 5, 62, "Section",
 CellTags->"c:5",
 CellID->393353162],
Cell[146637, 3836, 1274, 19, 66, "Text",
 CellID->447203085],
Cell[CellGroupData[{
Cell[147936, 3859, 85, 2, 52, "Subsection",
 CellTags->{"c:6", "b:0.4.0"},
 CellID->115748480],
Cell[148024, 3863, 752, 14, 49, "MathCaption",
 CellTags->"b:0.4.0",
 CellID->88806953],
Cell[CellGroupData[{
Cell[148801, 3881, 233, 7, 28, "Input",
 CellTags->"b:0.4.0",
 CellID->631912780],
Cell[149037, 3890, 184, 6, 36, "Output",
 CellTags->"b:0.4.0",
 CellID->700553192]
}, Open  ]],
Cell[CellGroupData[{
Cell[149258, 3901, 235, 7, 28, "Input",
 CellTags->"b:0.4.0",
 CellID->116558020],
Cell[149496, 3910, 184, 6, 36, "Output",
 CellTags->"b:0.4.0",
 CellID->90928558]
}, Open  ]],
Cell[149695, 3919, 2519, 60, 120, "Text",
 CellTags->"b:0.4.0",
 CellID->406868558],
Cell[152217, 3981, 437, 8, 31, "MathCaption",
 CellTags->"b:0.4.0",
 CellID->90376082],
Cell[CellGroupData[{
Cell[152679, 3993, 199, 6, 28, "Input",
 CellTags->"b:0.4.0",
 CellID->996820522],
Cell[152881, 4001, 184, 6, 36, "Output",
 CellTags->"b:0.4.0",
 CellID->324203704]
}, Open  ]],
Cell[CellGroupData[{
Cell[153102, 4012, 247, 7, 28, "Input",
 CellTags->"b:0.4.0",
 CellID->44778046],
Cell[153352, 4021, 182, 6, 36, "Output",
 CellTags->"b:0.4.0",
 CellID->2677979]
}, Open  ]],
Cell[CellGroupData[{
Cell[153571, 4032, 228, 7, 28, "Input",
 CellTags->"b:0.4.0",
 CellID->22423222],
Cell[153802, 4041, 184, 6, 36, "Output",
 CellTags->"b:0.4.0",
 CellID->299266338]
}, Open  ]],
Cell[154001, 4050, 1219, 21, 70, "Text",
 CellTags->"b:0.4.0",
 CellID->60232086],
Cell[155223, 4073, 1090, 23, 52, "Text",
 CellTags->"b:0.4.0",
 CellID->716869318],
Cell[156316, 4098, 1935, 32, 76, "MathCaption",
 CellTags->"b:0.4.0",
 CellID->554439476],
Cell[CellGroupData[{
Cell[158276, 4134, 236, 6, 28, "Input",
 CellTags->"b:0.4.0",
 CellID->70925498],
Cell[158515, 4142, 183, 6, 36, "Output",
 CellTags->"b:0.4.0",
 CellID->36702422]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[158747, 4154, 84, 2, 52, "Subsection",
 CellTags->{"c:7", "b:0.4.1"},
 CellID->221687989],
Cell[158834, 4158, 2019, 40, 82, "MathCaption",
 CellTags->"b:0.4.1",
 CellID->58760444],
Cell[CellGroupData[{
Cell[160878, 4202, 233, 7, 28, "Input",
 CellTags->"b:0.4.1",
 CellID->208914080],
Cell[161114, 4211, 185, 6, 36, "Output",
 CellTags->"b:0.4.1",
 CellID->419298952]
}, Open  ]],
Cell[CellGroupData[{
Cell[161336, 4222, 221, 6, 28, "Input",
 CellTags->"b:0.4.1",
 CellID->113974042],
Cell[161560, 4230, 185, 6, 36, "Output",
 CellTags->"b:0.4.1",
 CellID->180843643]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[161794, 4242, 82, 2, 52, "Subsection",
 CellTags->{"c:8", "b:0.4.2"},
 CellID->3968257],
Cell[161879, 4246, 1115, 19, 69, "Text",
 CellTags->"b:0.4.2",
 CellID->46676764],
Cell[162997, 4267, 316, 5, 31, "MathCaption",
 CellTags->"b:0.4.2",
 CellID->143958968],
Cell[CellGroupData[{
Cell[163338, 4276, 206, 6, 28, "Input",
 CellTags->"b:0.4.2",
 CellID->459256047],
Cell[163547, 4284, 266, 9, 36, "Output",
 CellTags->"b:0.4.2",
 CellID->265787987]
}, Open  ]],
Cell[163828, 4296, 519, 9, 31, "MathCaption",
 CellTags->"b:0.4.2",
 CellID->697884743],
Cell[CellGroupData[{
Cell[164372, 4309, 301, 10, 28, "Input",
 CellTags->"b:0.4.2",
 CellID->85500109],
Cell[164676, 4321, 264, 9, 36, "Output",
 CellTags->"b:0.4.2",
 CellID->32377990]
}, Open  ]],
Cell[CellGroupData[{
Cell[164977, 4335, 279, 8, 28, "Input",
 CellTags->"b:0.4.2",
 CellID->493985103],
Cell[165259, 4345, 264, 9, 36, "Output",
 CellTags->"b:0.4.2",
 CellID->82819926]
}, Open  ]],
Cell[165538, 4357, 339, 5, 31, "MathCaption",
 CellTags->"b:0.4.2",
 CellID->121882887],
Cell[CellGroupData[{
Cell[165902, 4366, 196, 6, 28, "Input",
 CellTags->"b:0.4.2",
 CellID->240722779],
Cell[166101, 4374, 260, 8, 36, "Output",
 CellTags->"b:0.4.2",
 CellID->266942857]
}, Open  ]],
Cell[166376, 4385, 247, 4, 31, "MathCaption",
 CellTags->"b:0.4.2",
 CellID->608581590],
Cell[CellGroupData[{
Cell[166648, 4393, 725, 22, 47, "Input",
 CellTags->"b:0.4.2",
 CellID->94888225],
Cell[167376, 4417, 405, 12, 36, "Output",
 CellTags->"b:0.4.2",
 CellID->628308907]
}, Open  ]],
Cell[167796, 4432, 1388, 26, 63, "MathCaption",
 CellTags->"b:0.4.2",
 CellID->255423450],
Cell[CellGroupData[{
Cell[169209, 4462, 343, 11, 28, "Input",
 CellTags->"b:0.4.2",
 CellID->1009786679],
Cell[169555, 4475, 353, 12, 36, "Output",
 CellTags->"b:0.4.2",
 CellID->686212242]
}, Open  ]],
Cell[CellGroupData[{
Cell[169945, 4492, 125, 4, 28, "Input",
 CellTags->"b:0.4.2",
 CellID->51924450],
Cell[170073, 4498, 245, 8, 36, "Output",
 CellTags->"b:0.4.2",
 CellID->15829095]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[170367, 4512, 177, 3, 52, "Subsection",
 CellTags->{"c:9", "b:0.4.3"},
 CellID->351610464],
Cell[170547, 4517, 3130, 77, 118, "Text",
 CellTags->"b:0.4.3",
 CellID->542672475],
Cell[173680, 4596, 1085, 21, 49, "MathCaption",
 CellTags->"b:0.4.3",
 CellID->271649068],
Cell[CellGroupData[{
Cell[174790, 4621, 262, 8, 28, "Input",
 CellTags->"b:0.4.3",
 CellID->323915583],
Cell[175055, 4631, 248, 8, 36, "Output",
 CellTags->"b:0.4.3",
 CellID->595622412]
}, Open  ]],
Cell[175318, 4642, 1362, 25, 63, "MathCaption",
 CellTags->"b:0.4.3",
 CellID->18408293],
Cell[CellGroupData[{
Cell[176705, 4671, 309, 8, 28, "Input",
 CellTags->"b:0.4.3",
 CellID->123426060],
Cell[177017, 4681, 271, 9, 36, "Output",
 CellTags->"b:0.4.3",
 CellID->59960422]
}, Open  ]],
Cell[177303, 4693, 1109, 22, 49, "MathCaption",
 CellTags->"b:0.4.3",
 CellID->326611308],
Cell[CellGroupData[{
Cell[178437, 4719, 308, 8, 28, "Input",
 CellTags->"b:0.4.3",
 CellID->237410754],
Cell[178748, 4729, 323, 9, 36, "Output",
 CellTags->"b:0.4.3",
 CellID->634444596]
}, Open  ]],
Cell[179086, 4741, 1387, 26, 63, "MathCaption",
 CellTags->"b:0.4.3",
 CellID->627314046],
Cell[CellGroupData[{
Cell[180498, 4771, 459, 13, 47, "Input",
 CellTags->"b:0.4.3",
 CellID->87536172],
Cell[180960, 4786, 314, 9, 36, "Output",
 CellTags->"b:0.4.3",
 CellID->71742834]
}, Open  ]],
Cell[CellGroupData[{
Cell[181311, 4800, 460, 13, 47, "Input",
 CellTags->"b:0.4.3",
 CellID->31744191],
Cell[181774, 4815, 246, 8, 36, "Output",
 CellTags->"b:0.4.3",
 CellID->8853572]
}, Open  ]],
Cell[182035, 4826, 1318, 26, 67, "MathCaption",
 CellTags->"b:0.4.3",
 CellID->1005472710],
Cell[CellGroupData[{
Cell[183378, 4856, 262, 8, 28, "Input",
 CellTags->"b:0.4.3",
 CellID->168142260],
Cell[183643, 4866, 283, 9, 36, "Output",
 CellTags->"b:0.4.3",
 CellID->238296370]
}, Open  ]],
Cell[CellGroupData[{
Cell[183963, 4880, 236, 7, 28, "Input",
 CellTags->"b:0.4.3",
 CellID->42485134],
Cell[184202, 4889, 242, 8, 36, "Output",
 CellTags->"b:0.4.3",
 CellID->252851274]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[184493, 4903, 88, 2, 52, "Subsection",
 CellTags->{"c:10", "b:0.4.4"},
 CellID->363493082],
Cell[184584, 4907, 1056, 21, 48, "MathCaption",
 CellTags->"b:0.4.4",
 CellID->3234460],
Cell[CellGroupData[{
Cell[185665, 4932, 209, 6, 28, "Input",
 CellTags->"b:0.4.4",
 CellID->175418910],
Cell[185877, 4940, 386, 14, 36, "Output",
 CellTags->"b:0.4.4",
 CellID->480693168]
}, Open  ]],
Cell[CellGroupData[{
Cell[186300, 4959, 220, 8, 28, "Input",
 CellTags->"b:0.4.4",
 CellID->352798794],
Cell[186523, 4969, 265, 9, 36, "Output",
 CellTags->"b:0.4.4",
 CellID->69188359]
}, Open  ]],
Cell[186803, 4981, 962, 22, 48, "MathCaption",
 CellTags->"b:0.4.4",
 CellID->771123683],
Cell[CellGroupData[{
Cell[187790, 5007, 265, 8, 28, "Input",
 CellTags->"b:0.4.4",
 CellID->227693171],
Cell[188058, 5017, 384, 14, 36, "Output",
 CellTags->"b:0.4.4",
 CellID->177581636]
}, Open  ]],
Cell[188457, 5034, 540, 10, 31, "MathCaption",
 CellTags->"b:0.4.4",
 CellID->141395505],
Cell[CellGroupData[{
Cell[189022, 5048, 168, 5, 28, "Input",
 CellTags->"b:0.4.4",
 CellID->695066864],
Cell[189193, 5055, 443, 16, 36, "Output",
 CellTags->"b:0.4.4",
 CellID->130484574]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[189685, 5077, 85, 2, 52, "Subsection",
 CellTags->{"c:11", "b:0.4.5"},
 CellID->401719377],
Cell[189773, 5081, 2039, 37, 79, "MathCaption",
 CellTags->"b:0.4.5",
 CellID->771573730],
Cell[CellGroupData[{
Cell[191837, 5122, 287, 8, 28, "Input",
 CellTags->"b:0.4.5",
 CellID->175837266],
Cell[192127, 5132, 181, 6, 36, "Output",
 CellTags->"b:0.4.5",
 CellID->20751351]
}, Open  ]],
Cell[CellGroupData[{
Cell[192345, 5143, 322, 10, 28, "Input",
 CellTags->"b:0.4.5",
 CellID->16340890],
Cell[192670, 5155, 182, 6, 36, "Output",
 CellTags->"b:0.4.5",
 CellID->993559588]
}, Open  ]],
Cell[192867, 5164, 872, 22, 54, "Text",
 CellTags->"b:0.4.5",
 CellID->12491824]
}, Open  ]],
Cell[CellGroupData[{
Cell[193776, 5191, 85, 2, 52, "Subsection",
 CellTags->{"c:12", "b:0.4.6"},
 CellID->1274428],
Cell[193864, 5195, 682, 14, 48, "MathCaption",
 CellTags->"b:0.4.6",
 CellID->45121066],
Cell[CellGroupData[{
Cell[194571, 5213, 316, 10, 28, "Input",
 CellTags->"b:0.4.6",
 CellID->67067787],
Cell[194890, 5225, 192, 6, 36, "Output",
 CellTags->"b:0.4.6",
 CellID->72659497]
}, Open  ]],
Cell[195097, 5234, 1415, 25, 63, "MathCaption",
 CellTags->"b:0.4.6",
 CellID->21617589],
Cell[CellGroupData[{
Cell[196537, 5263, 314, 9, 28, "Input",
 CellTags->"b:0.4.6",
 CellID->801931404],
Cell[196854, 5274, 203, 6, 36, "Output",
 CellTags->"b:0.4.6",
 CellID->789854925]
}, Open  ]],
Cell[197072, 5283, 1069, 18, 47, "MathCaption",
 CellTags->"b:0.4.6",
 CellID->150245402],
Cell[CellGroupData[{
Cell[198166, 5305, 327, 9, 28, "Input",
 CellTags->"b:0.4.6",
 CellID->85246728],
Cell[198496, 5316, 203, 6, 36, "Output",
 CellTags->"b:0.4.6",
 CellID->264349508]
}, Open  ]],
Cell[198714, 5325, 458, 9, 31, "MathCaption",
 CellTags->"b:0.4.6",
 CellID->203144771],
Cell[CellGroupData[{
Cell[199197, 5338, 323, 9, 28, "Input",
 CellTags->"b:0.4.6",
 CellID->17461363],
Cell[199523, 5349, 203, 6, 36, "Output",
 CellTags->"b:0.4.6",
 CellID->216313918]
}, Open  ]],
Cell[199741, 5358, 1214, 21, 63, "MathCaption",
 CellTags->"b:0.4.6",
 CellID->131051894],
Cell[CellGroupData[{
Cell[200980, 5383, 366, 10, 47, "Input",
 CellTags->"b:0.4.6",
 CellID->459415768],
Cell[201349, 5395, 492, 11, 36, "Output",
 CellTags->"b:0.4.6",
 CellID->29452506]
}, Open  ]],
Cell[CellGroupData[{
Cell[201878, 5411, 126, 4, 28, "Input",
 CellTags->"b:0.4.6",
 CellID->28871706],
Cell[202007, 5417, 674, 18, 68, "Output",
 CellTags->"b:0.4.6",
 CellID->18384563]
}, Open  ]],
Cell[202696, 5438, 1225, 20, 68, "Text",
 CellTags->"b:0.4.6",
 CellID->623263418]
}, Open  ]],
Cell[CellGroupData[{
Cell[203958, 5463, 91, 2, 52, "Subsection",
 CellTags->{"c:13", "b:0.4.7"},
 CellID->239124212],
Cell[204052, 5467, 912, 19, 48, "MathCaption",
 CellTags->"b:0.4.7",
 CellID->758815075],
Cell[CellGroupData[{
Cell[204989, 5490, 282, 8, 28, "Input",
 CellTags->"b:0.4.7",
 CellID->34244212],
Cell[205274, 5500, 272, 9, 36, "Output",
 CellTags->"b:0.4.7",
 CellID->76378783]
}, Open  ]],
Cell[205561, 5512, 805, 13, 45, "MathCaption",
 CellTags->"b:0.4.7",
 CellID->578481874],
Cell[CellGroupData[{
Cell[206391, 5529, 343, 10, 28, "Input",
 CellTags->"b:0.4.7",
 CellID->80963487],
Cell[206737, 5541, 394, 13, 36, "Output",
 CellTags->"b:0.4.7",
 CellID->228987248]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[207180, 5560, 85, 2, 52, "Subsection",
 CellTags->{"c:14", "b:0.4.8"},
 CellID->343107939],
Cell[207268, 5564, 1392, 23, 63, "MathCaption",
 CellTags->"b:0.4.8",
 CellID->19737335],
Cell[CellGroupData[{
Cell[208685, 5591, 150, 4, 28, "Input",
 CellTags->"b:0.4.8",
 CellID->20551734],
Cell[208838, 5597, 290, 9, 36, "Output",
 CellTags->"b:0.4.8",
 CellID->713279886]
}, Open  ]],
Cell[209143, 5609, 692, 12, 45, "MathCaption",
 CellTags->"b:0.4.8",
 CellID->27447488],
Cell[CellGroupData[{
Cell[209860, 5625, 281, 8, 28, "Input",
 CellTags->"b:0.4.8",
 CellID->107169258],
Cell[210144, 5635, 348, 10, 36, "Output",
 CellTags->"b:0.4.8",
 CellID->176497510]
}, Open  ]],
Cell[210507, 5648, 537, 10, 31, "MathCaption",
 CellTags->"b:0.4.8",
 CellID->60098082],
Cell[CellGroupData[{
Cell[211069, 5662, 174, 5, 28, "Input",
 CellTags->"b:0.4.8",
 CellID->72110840],
Cell[211246, 5669, 260, 8, 36, "Output",
 CellTags->"b:0.4.8",
 CellID->362458191]
}, Open  ]],
Cell[211521, 5680, 637, 14, 35, "MathCaption",
 CellTags->"b:0.4.8",
 CellID->103751328],
Cell[CellGroupData[{
Cell[212183, 5698, 187, 5, 28, "Input",
 CellTags->"b:0.4.8",
 CellID->460561670],
Cell[212373, 5705, 298, 9, 36, "Output",
 CellTags->"b:0.4.8",
 CellID->236770642]
}, Open  ]],
Cell[212686, 5717, 856, 14, 45, "MathCaption",
 CellTags->"b:0.4.8",
 CellID->656954062],
Cell[CellGroupData[{
Cell[213567, 5735, 194, 6, 28, "Input",
 CellTags->"b:0.4.8",
 CellID->1019234],
Cell[213764, 5743, 253, 8, 36, "Output",
 CellTags->"b:0.4.8",
 CellID->14534217]
}, Open  ]],
Cell[214032, 5754, 443, 8, 31, "MathCaption",
 CellTags->"b:0.4.8",
 CellID->241434771],
Cell[CellGroupData[{
Cell[214500, 5766, 203, 6, 28, "Input",
 CellTags->"b:0.4.8",
 CellID->171055668],
Cell[214706, 5774, 286, 9, 36, "Output",
 CellTags->"b:0.4.8",
 CellID->204773299]
}, Open  ]],
Cell[215007, 5786, 1156, 21, 62, "MathCaption",
 CellTags->"b:0.4.8",
 CellID->590437369],
Cell[CellGroupData[{
Cell[216188, 5811, 201, 6, 28, "Input",
 CellTags->"b:0.4.8",
 CellID->4669335],
Cell[216392, 5819, 293, 9, 71, "Output",
 CellTags->"b:0.4.8",
 CellID->1024030217]
}, Open  ]],
Cell[216700, 5831, 943, 15, 45, "MathCaption",
 CellTags->"b:0.4.8",
 CellID->11065132],
Cell[CellGroupData[{
Cell[217668, 5850, 220, 6, 28, "Input",
 CellTags->"b:0.4.8",
 CellID->386084822],
Cell[217891, 5858, 348, 10, 36, "Output",
 CellTags->"b:0.4.8",
 CellID->245134745]
}, Open  ]],
Cell[CellGroupData[{
Cell[218276, 5873, 219, 6, 28, "Input",
 CellTags->"b:0.4.8",
 CellID->60902233],
Cell[218498, 5881, 348, 10, 36, "Output",
 CellTags->"b:0.4.8",
 CellID->132373715]
}, Open  ]],
Cell[CellGroupData[{
Cell[218883, 5896, 302, 8, 47, "Input",
 CellTags->"b:0.4.8",
 CellID->73670271],
Cell[219188, 5906, 303, 9, 36, "Output",
 CellTags->"b:0.4.8",
 CellID->169972716]
}, Open  ]],
Cell[CellGroupData[{
Cell[219528, 5920, 377, 10, 47, "Input",
 CellTags->"b:0.4.8",
 CellID->153068299],
Cell[219908, 5932, 508, 12, 36, "Output",
 CellTags->"b:0.4.8",
 CellID->41820933]
}, Open  ]],
Cell[220431, 5947, 910, 14, 45, "MathCaption",
 CellTags->"b:0.4.8",
 CellID->307113028],
Cell[CellGroupData[{
Cell[221366, 5965, 487, 14, 47, "Input",
 CellTags->"b:0.4.8",
 CellID->36223674],
Cell[221856, 5981, 323, 9, 50, "Output",
 CellTags->"b:0.4.8",
 CellID->894580067]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[222240, 5997, 162, 3, 62, "Section",
 CellTags->"c:15",
 CellID->759470019],
Cell[CellGroupData[{
Cell[222427, 6004, 150, 3, 52, "Subsection",
 CellTags->{"c:15.5", "b:0.5.0"},
 CellID->20697950],
Cell[222580, 6009, 2529, 40, 120, "Text",
 CellTags->"b:0.5.0",
 CellID->86791152],
Cell[225112, 6051, 493, 11, 30, "Text",
 CellTags->"b:0.5.0",
 CellID->323888524],
Cell[225608, 6064, 5582, 124, 379, "DefinitionBox3Col",
 CellTags->"b:0.5.0",
 CellID->43654671],
Cell[231193, 6190, 516, 9, 30, "Text",
 CellTags->"b:0.5.0",
 CellID->575279163]
}, Open  ]],
Cell[CellGroupData[{
Cell[231746, 6204, 80, 2, 52, "Subsection",
 CellTags->{"c:16", "b:0.5.1"},
 CellID->120637313],
Cell[231829, 6208, 1431, 29, 74, "Text",
 CellTags->"b:0.5.1",
 CellID->332493086],
Cell[233263, 6239, 609, 13, 33, "MathCaption",
 CellTags->"b:0.5.1",
 CellID->163086882],
Cell[233875, 6254, 137, 7, 100, "Program",
 CellTags->"b:0.5.1",
 CellID->203403607],
Cell[234015, 6263, 326, 9, 31, "MathCaption",
 CellTags->"b:0.5.1",
 CellID->258819916],
Cell[CellGroupData[{
Cell[234366, 6276, 427, 12, 47, "Input",
 CellTags->"b:0.5.1",
 CellID->403377399],
Cell[234796, 6290, 127, 3, 23, "Print",
 CellTags->"b:0.5.1",
 CellID->320069806]
}, Open  ]],
Cell[234938, 6296, 1094, 24, 52, "Text",
 CellTags->"b:0.5.1",
 CellID->130918903],
Cell[236035, 6322, 299, 5, 31, "MathCaption",
 CellTags->"b:0.5.1",
 CellID->272631892],
Cell[236337, 6329, 172, 7, 100, "Program",
 CellTags->"b:0.5.1",
 CellID->67879431],
Cell[236512, 6338, 200, 7, 31, "MathCaption",
 CellTags->"b:0.5.1",
 CellID->175118403],
Cell[CellGroupData[{
Cell[236737, 6349, 777, 24, 65, "Input",
 CellTags->"b:0.5.1",
 CellID->399472551],
Cell[237517, 6375, 348, 9, 23, "Print",
 CellTags->"b:0.5.1",
 CellID->178834455]
}, Open  ]],
Cell[237880, 6387, 367, 6, 31, "MathCaption",
 CellTags->"b:0.5.1",
 CellID->161491337],
Cell[238250, 6395, 149, 5, 62, "Program",
 CellTags->"b:0.5.1",
 CellID->785509705],
Cell[238402, 6402, 474, 14, 34, "MathCaption",
 CellTags->"b:0.5.1",
 CellID->445860386],
Cell[CellGroupData[{
Cell[238901, 6420, 611, 19, 65, "Input",
 CellTags->"b:0.5.1",
 CellID->682251121],
Cell[239515, 6441, 265, 9, 36, "Output",
 CellTags->"b:0.5.1",
 CellID->183755673]
}, Open  ]],
Cell[239795, 6453, 562, 12, 33, "MathCaption",
 CellTags->"b:0.5.1",
 CellID->20175135],
Cell[240360, 6467, 121, 5, 62, "Program",
 CellTags->"b:0.5.1",
 CellID->19723038],
Cell[240484, 6474, 505, 14, 34, "MathCaption",
 CellTags->"b:0.5.1",
 CellID->781694409],
Cell[CellGroupData[{
Cell[241014, 6492, 341, 11, 47, "Input",
 CellTags->"b:0.5.1",
 CellID->43441911],
Cell[241358, 6505, 290, 9, 36, "Output",
 CellTags->"b:0.5.1",
 CellID->371595541]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[241697, 6520, 84, 2, 52, "Subsection",
 CellTags->{"c:17", "b:0.5.2"},
 CellID->163295011],
Cell[241784, 6524, 747, 22, 34, "MathCaption",
 CellTags->"b:0.5.2",
 CellID->51683055],
Cell[242534, 6548, 107, 5, 62, "Program",
 CellTags->"b:0.5.2",
 CellID->384257252],
Cell[242644, 6555, 292, 5, 31, "MathCaption",
 CellTags->"b:0.5.2",
 CellID->179104029],
Cell[CellGroupData[{
Cell[242961, 6564, 349, 10, 47, "Input",
 CellTags->"b:0.5.2",
 CellID->252897767],
Cell[243313, 6576, 195, 6, 36, "Output",
 CellTags->"b:0.5.2",
 CellID->207323890]
}, Open  ]],
Cell[243523, 6585, 484, 11, 33, "MathCaption",
 CellTags->"b:0.5.2",
 CellID->317632773],
Cell[244010, 6598, 79, 2, 43, "Program",
 CellTags->"b:0.5.2",
 CellID->152813715],
Cell[CellGroupData[{
Cell[244114, 6604, 253, 8, 28, "Input",
 CellTags->"b:0.5.2",
 CellID->341597359],
Cell[244370, 6614, 195, 6, 36, "Output",
 CellTags->"b:0.5.2",
 CellID->203169793]
}, Open  ]],
Cell[244580, 6623, 787, 17, 47, "MathCaption",
 CellTags->"b:0.5.2",
 CellID->183807183],
Cell[245370, 6642, 115, 5, 62, "Program",
 CellTags->"b:0.5.2",
 CellID->409627135],
Cell[CellGroupData[{
Cell[245510, 6651, 342, 10, 47, "Input",
 CellTags->"b:0.5.2",
 CellID->69447560],
Cell[245855, 6663, 201, 6, 36, "Output",
 CellTags->"b:0.5.2",
 CellID->520395969]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[246105, 6675, 83, 2, 52, "Subsection",
 CellTags->{"c:18", "b:0.5.3"},
 CellID->45791734],
Cell[246191, 6679, 450, 14, 34, "MathCaption",
 CellTags->"b:0.5.3",
 CellID->12267911],
Cell[246644, 6695, 109, 5, 62, "Program",
 CellTags->"b:0.5.3",
 CellID->189290885],
Cell[CellGroupData[{
Cell[246778, 6704, 254, 7, 47, "Input",
 CellTags->"b:0.5.3",
 CellID->229530619],
Cell[247035, 6713, 267, 9, 36, "Output",
 CellTags->"b:0.5.3",
 CellID->17569325]
}, Open  ]],
Cell[247317, 6725, 643, 12, 45, "MathCaption",
 CellTags->"b:0.5.3",
 CellID->240418930],
Cell[247963, 6739, 80, 2, 43, "Program",
 CellTags->"b:0.5.3",
 CellID->719922593],
Cell[CellGroupData[{
Cell[248068, 6745, 175, 5, 28, "Input",
 CellTags->"b:0.5.3",
 CellID->502233132],
Cell[248246, 6752, 249, 8, 36, "Output",
 CellTags->"b:0.5.3",
 CellID->382146358]
}, Open  ]],
Cell[248510, 6763, 1725, 32, 78, "MathCaption",
 CellTags->"b:0.5.3",
 CellID->78986018],
Cell[250238, 6797, 151, 5, 62, "Program",
 CellTags->"b:0.5.3",
 CellID->348675863],
Cell[CellGroupData[{
Cell[250414, 6806, 428, 13, 47, "Input",
 CellTags->"b:0.5.3",
 CellID->639488513],
Cell[250845, 6821, 277, 9, 50, "Output",
 CellTags->"b:0.5.3",
 CellID->829343315]
}, Open  ]],
Cell[CellGroupData[{
Cell[251159, 6835, 470, 15, 47, "Input",
 CellTags->"b:0.5.3",
 CellID->34696905],
Cell[251632, 6852, 296, 9, 50, "Output",
 CellTags->"b:0.5.3",
 CellID->59433462]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[251977, 6867, 85, 2, 52, "Subsection",
 CellTags->{"c:19", "b:0.5.4"},
 CellID->627179989],
Cell[252065, 6871, 823, 18, 52, "Text",
 CellTags->"b:0.5.4",
 CellID->512373978],
Cell[252891, 6891, 738, 20, 33, "MathCaption",
 CellTags->"b:0.5.4",
 CellID->75100454],
Cell[253632, 6913, 107, 5, 62, "Program",
 CellTags->"b:0.5.4",
 CellID->2535425],
Cell[253742, 6920, 581, 15, 35, "MathCaption",
 CellTags->"b:0.5.4",
 CellID->616093666],
Cell[CellGroupData[{
Cell[254348, 6939, 443, 13, 47, "Input",
 CellTags->"b:0.5.4",
 CellID->394779265],
Cell[254794, 6954, 194, 6, 36, "Output",
 CellTags->"b:0.5.4",
 CellID->78625730]
}, Open  ]],
Cell[255003, 6963, 707, 16, 33, "MathCaption",
 CellTags->"b:0.5.4",
 CellID->44095121],
Cell[255713, 6981, 116, 5, 62, "Program",
 CellTags->"b:0.5.4",
 CellID->260896876],
Cell[CellGroupData[{
Cell[255854, 6990, 609, 17, 65, "Input",
 CellTags->"b:0.5.4",
 CellID->37744320],
Cell[256466, 7009, 198, 6, 36, "Output",
 CellTags->"b:0.5.4",
 CellID->479145987]
}, Open  ]],
Cell[256679, 7018, 541, 15, 34, "MathCaption",
 CellTags->"b:0.5.4",
 CellID->291617831],
Cell[257223, 7035, 114, 5, 62, "Program",
 CellTags->"b:0.5.4",
 CellID->820168201],
Cell[CellGroupData[{
Cell[257362, 7044, 382, 12, 47, "Input",
 CellTags->"b:0.5.4",
 CellID->96850109],
Cell[257747, 7058, 202, 6, 36, "Output",
 CellTags->"b:0.5.4",
 CellID->497337288]
}, Open  ]],
Cell[257964, 7067, 519, 11, 33, "MathCaption",
 CellTags->"b:0.5.4",
 CellID->206615673],
Cell[258486, 7080, 115, 5, 62, "Program",
 CellTags->"b:0.5.4",
 CellID->1448094],
Cell[CellGroupData[{
Cell[258626, 7089, 610, 17, 65, "Input",
 CellTags->"b:0.5.4",
 CellID->297013012],
Cell[259239, 7108, 196, 6, 36, "Output",
 CellTags->"b:0.5.4",
 CellID->621733276]
}, Open  ]],
Cell[259450, 7117, 460, 10, 33, "MathCaption",
 CellTags->"b:0.5.4",
 CellID->809943646],
Cell[259913, 7129, 80, 2, 43, "Program",
 CellTags->"b:0.5.4",
 CellID->727836643],
Cell[CellGroupData[{
Cell[260018, 7135, 286, 9, 28, "Input",
 CellTags->"b:0.5.4",
 CellID->32783502],
Cell[260307, 7146, 197, 6, 36, "Output",
 CellTags->"b:0.5.4",
 CellID->82701024]
}, Open  ]],
Cell[CellGroupData[{
Cell[260541, 7157, 261, 8, 28, "Input",
 CellTags->"b:0.5.4",
 CellID->190461549],
Cell[260805, 7167, 198, 6, 36, "Output",
 CellTags->"b:0.5.4",
 CellID->898067845]
}, Open  ]],
Cell[261018, 7176, 503, 11, 33, "MathCaption",
 CellTags->"b:0.5.4",
 CellID->117673595],
Cell[261524, 7189, 130, 5, 62, "Program",
 CellTags->"b:0.5.4",
 CellID->144624070],
Cell[261657, 7196, 557, 16, 35, "MathCaption",
 CellTags->"b:0.5.4",
 CellID->688187582],
Cell[CellGroupData[{
Cell[262239, 7216, 688, 20, 83, "Input",
 CellTags->"b:0.5.4",
 CellID->141316627],
Cell[262930, 7238, 195, 6, 36, "Output",
 CellTags->"b:0.5.4",
 CellID->57680932]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[263186, 7251, 161, 3, 62, "Section",
 CellTags->"c:20",
 CellID->2083974],
Cell[263350, 7256, 617, 10, 48, "Text",
 CellID->118415745],
Cell[CellGroupData[{
Cell[263992, 7270, 209, 3, 52, "Subsection",
 CellTags->{"c:22", "b:0.6.1"},
 CellID->738873845],
Cell[264204, 7275, 563, 10, 31, "MathCaption",
 CellTags->"b:0.6.1",
 CellID->24257838],
Cell[CellGroupData[{
Cell[264792, 7289, 604, 19, 47, "Input",
 CellTags->"b:0.6.1",
 CellID->140406151],
Cell[265399, 7310, 1219, 20, 224, "Output",
 CellTags->"b:0.6.1",
 CellID->152083121]
}, Open  ]],
Cell[266633, 7333, 474, 9, 31, "MathCaption",
 CellTags->"b:0.6.1",
 CellID->301369684],
Cell[CellGroupData[{
Cell[267132, 7346, 586, 18, 47, "Input",
 CellTags->"b:0.6.1",
 CellID->614903007],
Cell[267721, 7366, 1608, 25, 241, "Output",
 CellTags->"b:0.6.1",
 CellID->79975839]
}, Open  ]],
Cell[269344, 7394, 452, 8, 31, "MathCaption",
 CellTags->"b:0.6.1",
 CellID->12939824],
Cell[CellGroupData[{
Cell[269821, 7406, 372, 10, 65, "Input",
 CellTags->"b:0.6.1",
 CellID->131627168],
Cell[270196, 7418, 1609, 25, 241, "Output",
 CellTags->"b:0.6.1",
 CellID->678802383]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[271854, 7449, 142, 3, 52, "Subsection",
 CellTags->{"c:23", "b:0.6.2"},
 CellID->146223979],
Cell[271999, 7454, 718, 12, 48, "Text",
 CellTags->"b:0.6.2",
 CellID->454604247],
Cell[272720, 7468, 301, 10, 31, "MathCaption",
 CellTags->"b:0.6.2",
 CellID->450806450],
Cell[273024, 7480, 3090, 54, 1001, "Input",
 CellTags->"b:0.6.2",
 CellID->237894310],
Cell[CellGroupData[{
Cell[276139, 7538, 134, 4, 28, "Input",
 CellTags->"b:0.6.2",
 CellID->73854272],
Cell[276276, 7544, 185, 6, 36, "Output",
 CellTags->"b:0.6.2",
 CellID->435720061]
}, Open  ]],
Cell[276476, 7553, 375, 6, 31, "MathCaption",
 CellTags->"b:0.6.2",
 CellID->328231447],
Cell[CellGroupData[{
Cell[276876, 7563, 539, 16, 47, "Input",
 CellTags->"b:0.6.2",
 CellID->10965036],
Cell[277418, 7581, 659, 15, 88, "Output",
 CellTags->"b:0.6.2",
 CellID->658475649]
}, Open  ]],
Cell[278092, 7599, 419, 11, 33, "MathCaption",
 CellTags->"b:0.6.2",
 CellID->135521350],
Cell[CellGroupData[{
Cell[278536, 7614, 294, 9, 28, "Input",
 CellTags->"b:0.6.2",
 CellID->499683580],
Cell[278833, 7625, 812, 15, 309, "Output",
 CellTags->"b:0.6.2",
 CellID->339097831]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[279694, 7646, 192, 3, 52, "Subsection",
 CellTags->{"c:24", "b:0.6.3"},
 CellID->263221749],
Cell[279889, 7651, 469, 9, 31, "MathCaption",
 CellTags->"b:0.6.3",
 CellID->456762081],
Cell[CellGroupData[{
Cell[280383, 7664, 191, 6, 28, "Input",
 CellTags->"b:0.6.3",
 CellID->324262933],
Cell[280577, 7672, 251, 7, 36, "Output",
 CellTags->"b:0.6.3",
 CellID->84181818]
}, Open  ]],
Cell[280843, 7682, 445, 8, 31, "MathCaption",
 CellTags->"b:0.6.3",
 CellID->47750368],
Cell[CellGroupData[{
Cell[281313, 7694, 422, 14, 28, "Input",
 CellTags->"b:0.6.3",
 CellID->16455114],
Cell[281738, 7710, 252, 8, 36, "Output",
 CellTags->"b:0.6.3",
 CellID->1028029313]
}, Open  ]],
Cell[282005, 7721, 1175, 18, 59, "MathCaption",
 CellTags->"b:0.6.3",
 CellID->507462346],
Cell[CellGroupData[{
Cell[283205, 7743, 240, 8, 28, "Input",
 CellTags->"b:0.6.3",
 CellID->28199983],
Cell[283448, 7753, 251, 8, 36, "Output",
 CellTags->"b:0.6.3",
 CellID->211704891]
}, Open  ]],
Cell[283714, 7764, 716, 15, 48, "MathCaption",
 CellTags->"b:0.6.3",
 CellID->1024052339],
Cell[CellGroupData[{
Cell[284455, 7783, 199, 6, 28, "Input",
 CellTags->"b:0.6.3",
 CellID->5891025],
Cell[284657, 7791, 251, 8, 36, "Output",
 CellTags->"b:0.6.3",
 CellID->182707870]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[284957, 7805, 177, 3, 52, "Subsection",
 CellTags->"b:0.6.4",
 CellID->355263806],
Cell[285137, 7810, 719, 12, 45, "MathCaption",
 CellTags->"b:0.6.4",
 CellID->115242927],
Cell[285859, 7824, 717, 23, 47, "Input",
 CellTags->"b:0.6.4",
 CellID->78571466],
Cell[286579, 7849, 265, 4, 31, "MathCaption",
 CellTags->"b:0.6.4",
 CellID->97869725],
Cell[CellGroupData[{
Cell[286869, 7857, 359, 10, 47, "Input",
 CellTags->"b:0.6.4",
 CellID->46155371],
Cell[287231, 7869, 197, 6, 36, "Output",
 CellTags->"b:0.6.4",
 CellID->551981229]
}, Open  ]],
Cell[287443, 7878, 534, 11, 33, "MathCaption",
 CellTags->"b:0.6.4",
 CellID->252811811],
Cell[CellGroupData[{
Cell[288002, 7893, 211, 7, 28, "Input",
 CellTags->"b:0.6.4",
 CellID->580624370],
Cell[288216, 7902, 743, 22, 62, "Output",
 CellTags->"b:0.6.4",
 CellID->776583665]
}, Open  ]],
Cell[288974, 7927, 472, 9, 33, "MathCaption",
 CellTags->"b:0.6.4",
 CellID->612266699],
Cell[CellGroupData[{
Cell[289471, 7940, 261, 8, 28, "Input",
 CellTags->"b:0.6.4",
 CellID->28035752],
Cell[289735, 7950, 751, 22, 62, "Output",
 CellTags->"b:0.6.4",
 CellID->552317211]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[290547, 7979, 402, 6, 62, "Section",
 CellTags->{"c:25", "Tips and Tricks", "b:0.7"},
 CellID->319138910],
Cell[290952, 7987, 678, 12, 48, "Text",
 CellTags->"b:0.7",
 CellID->1088522],
Cell[CellGroupData[{
Cell[291655, 8003, 179, 4, 52, "Subsection",
 CellTags->{"c:26", "b:0.7"},
 CellID->571253149],
Cell[291837, 8009, 2539, 39, 120, "Text",
 CellTags->"b:0.7",
 CellID->527245798]
}, Open  ]],
Cell[CellGroupData[{
Cell[294413, 8053, 158, 3, 52, "Subsection",
 CellTags->{"c:27", "b:0.7"},
 CellID->11710184],
Cell[294574, 8058, 1717, 35, 62, "MathCaption",
 CellTags->"b:0.7",
 CellID->168089851],
Cell[296294, 8095, 465, 14, 47, "Input",
 CellTags->"b:0.7",
 CellID->45298985],
Cell[CellGroupData[{
Cell[296784, 8113, 254, 9, 28, "Input",
 CellTags->"b:0.7",
 CellID->334473682],
Cell[297041, 8124, 227, 8, 36, "Output",
 CellTags->"b:0.7",
 CellID->60278642]
}, Open  ]],
Cell[CellGroupData[{
Cell[297305, 8137, 251, 9, 28, "Input",
 CellTags->"b:0.7",
 CellID->108146462],
Cell[297559, 8148, 251, 8, 36, "Output",
 CellTags->"b:0.7",
 CellID->840100588]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[297859, 8162, 239, 4, 52, "Subsection",
 CellTags->{"c:28", "b:0.7"},
 CellID->39608680],
Cell[298101, 8168, 2309, 38, 122, "Text",
 CellTags->"b:0.7",
 CellID->350158018]
}, Open  ]],
Cell[CellGroupData[{
Cell[300447, 8211, 302, 5, 52, "Subsection",
 CellTags->{"c:29", "b:0.7"},
 CellID->73358011],
Cell[300752, 8218, 2616, 45, 95, "MathCaption",
 CellTags->"b:0.7",
 CellID->274569970],
Cell[303371, 8265, 768, 24, 47, "Input",
 CellTags->"b:0.7",
 CellID->88405937],
Cell[CellGroupData[{
Cell[304164, 8293, 148, 5, 28, "Input",
 CellTags->"b:0.7",
 CellID->171329605],
Cell[304315, 8300, 290, 9, 36, "Output",
 CellTags->"b:0.7",
 CellID->24933409]
}, Open  ]],
Cell[304620, 8312, 568, 16, 35, "MathCaption",
 CellTags->"b:0.7",
 CellID->482988001],
Cell[CellGroupData[{
Cell[305213, 8332, 384, 13, 28, "Input",
 CellTags->"b:0.7",
 CellID->235104226],
Cell[305600, 8347, 1596, 32, 139, "Output",
 CellTags->"b:0.7",
 CellID->5314957]
}, Open  ]],
Cell[307211, 8382, 1162, 23, 53, "MathCaption",
 CellTags->"b:0.7",
 CellID->940575378],
Cell[CellGroupData[{
Cell[308398, 8409, 360, 12, 28, "Input",
 CellTags->"b:0.7",
 CellID->159751616],
Cell[308761, 8423, 1575, 32, 139, "Output",
 CellTags->"b:0.7",
 CellID->356900352]
}, Open  ]],
Cell[310351, 8458, 1830, 34, 82, "MathCaption",
 CellTags->"b:0.7",
 CellID->440945305],
Cell[CellGroupData[{
Cell[312206, 8496, 413, 13, 47, "Input",
 CellTags->"b:0.7",
 CellID->344941105],
Cell[312622, 8511, 1575, 32, 139, "Output",
 CellTags->"b:0.7",
 CellID->615031247]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[314246, 8549, 511, 9, 72, "Subsection",
 CellTags->{"c:30", "b:0.7"},
 CellID->148652143],
Cell[314760, 8560, 2769, 43, 122, "Text",
 CellTags->"b:0.7",
 CellID->13332812],
Cell[317532, 8605, 1248, 19, 59, "MathCaption",
 CellTags->"b:0.7",
 CellID->349310128],
Cell[CellGroupData[{
Cell[318805, 8628, 550, 17, 47, "Input",
 CellTags->"b:0.7",
 CellID->34682433],
Cell[319358, 8647, 670, 16, 71, "Output",
 CellTags->"b:0.7",
 CellID->2287957]
}, Open  ]],
Cell[320043, 8666, 776, 13, 45, "MathCaption",
 CellTags->"b:0.7",
 CellID->19330986],
Cell[CellGroupData[{
Cell[320844, 8683, 658, 19, 47, "Input",
 CellTags->"b:0.7",
 CellID->115301483],
Cell[321505, 8704, 671, 16, 71, "Output",
 CellTags->"b:0.7",
 CellID->284787246]
}, Open  ]],
Cell[322191, 8723, 901, 20, 49, "MathCaption",
 CellTags->"b:0.7",
 CellID->309333144],
Cell[CellGroupData[{
Cell[323117, 8747, 839, 25, 65, "Input",
 CellTags->"b:0.7",
 CellID->238693932],
Cell[323959, 8774, 672, 16, 71, "Output",
 CellTags->"b:0.7",
 CellID->131475791]
}, Open  ]],
Cell[CellGroupData[{
Cell[324668, 8795, 701, 19, 83, "Input",
 CellTags->"b:0.7",
 CellID->74230660],
Cell[325372, 8816, 842, 20, 71, "Output",
 CellTags->"b:0.7",
 CellID->251254336]
}, Open  ]],
Cell[326229, 8839, 581, 10, 31, "MathCaption",
 CellTags->"b:0.7",
 CellID->778852497],
Cell[326813, 8851, 318, 12, 28, "Input",
 CellTags->"b:0.7",
 CellID->166716726],
Cell[CellGroupData[{
Cell[327156, 8867, 152, 5, 28, "Input",
 CellTags->"b:0.7",
 CellID->143881214],
Cell[327311, 8874, 310, 11, 36, "Output",
 CellTags->"b:0.7",
 CellID->811151718]
}, Open  ]],
Cell[CellGroupData[{
Cell[327658, 8890, 303, 10, 28, "Input",
 CellTags->"b:0.7",
 CellID->9520874],
Cell[327964, 8902, 252, 8, 36, "Output",
 CellTags->"b:0.7",
 CellID->37879651]
}, Open  ]],
Cell[328231, 8913, 185, 6, 28, "Input",
 CellTags->"b:0.7",
 CellID->55052828],
Cell[CellGroupData[{
Cell[328441, 8923, 206, 6, 28, "Input",
 CellTags->"b:0.7",
 CellID->106844855],
Cell[328650, 8931, 387, 14, 36, "Output",
 CellTags->"b:0.7",
 CellID->505448699]
}, Open  ]],
Cell[CellGroupData[{
Cell[329074, 8950, 334, 10, 28, "Input",
 CellTags->"b:0.7",
 CellID->483013677],
Cell[329411, 8962, 230, 8, 36, "Output",
 CellTags->"b:0.7",
 CellID->486101578]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[329702, 8977, 255, 4, 62, "Section",
 CellTags->{"c:31", "b:0.8"},
 CellID->337819047],
Cell[329960, 8983, 882, 16, 66, "Text",
 CellTags->"b:0.8",
 CellID->68963779],
Cell[330845, 9001, 853, 16, 48, "Text",
 CellTags->"b:0.8",
 CellID->57047539],
Cell[331701, 9019, 987, 17, 47, "MathCaption",
 CellTags->"b:0.8",
 CellID->169990753],
Cell[CellGroupData[{
Cell[332713, 9040, 277, 8, 28, "Input",
 CellTags->"b:0.8",
 CellID->201123037],
Cell[332993, 9050, 220, 6, 50, "Output",
 CellTags->"b:0.8",
 CellID->32699069]
}, Open  ]],
Cell[333228, 9059, 922, 15, 48, "Text",
 CellTags->"b:0.8",
 CellID->190255727],
Cell[334153, 9076, 1487, 22, 66, "Text",
 CellTags->"b:0.8",
 CellID->210149359],
Cell[335643, 9100, 917, 18, 48, "Text",
 CellTags->"b:0.8",
 CellID->953153723],
Cell[336563, 9120, 1780, 30, 90, "Text",
 CellTags->"b:0.8",
 CellID->198359003],
Cell[338346, 9152, 2272, 44, 114, "Text",
 CellTags->"b:0.8",
 CellID->908430859],
Cell[340621, 9198, 1915, 38, 90, "Text",
 CellTags->"b:0.8",
 CellID->1015887440]
}, Open  ]],
Cell[CellGroupData[{
Cell[342573, 9241, 105, 2, 62, "Section",
 CellTags->{"c:32", "b:0.9"},
 CellID->503575505],
Cell[342681, 9245, 274, 9, 30, "Reference",
 CellTags->{"Ref-1", "b:0.9"},
 CellID->872737084],
Cell[342958, 9256, 218, 7, 30, "Reference",
 CellTags->{"Ref-2", "b:0.9"},
 CellID->201956504]
}, Open  ]],
Cell[CellGroupData[{
Cell[343213, 9268, 341, 12, 31, "TutorialMoreAboutSection",
 CellID->776935],
Cell[343557, 9282, 31, 0, 14, "SectionHeaderSpacer"],
Cell[343591, 9284, 150, 3, 18, "TutorialMoreAbout",
 CellID->1387738557]
}, Open  ]]
}, Open  ]],
Cell[343768, 9291, 23, 0, 41, "FooterCell"]
}
]
*)

(* End of internal cache information *)
